@@ -2,39 +2,30 @@
 
 """
 Developer script to convert yaml periodic table to json format.
-Created on Nov 15, 2011
+Created on Nov 15, 2011.
 """
 
 from __future__ import annotations
 
+import collections
 import json
 import re
 from itertools import product
 
+import requests
+from bs4 import BeautifulSoup
 from monty.serialization import dumpfn, loadfn
 from ruamel import yaml
 
-from pymatgen.core import Element
-from pymatgen.core.periodic_table import get_el_sp
+from pymatgen.core import Element, get_el_sp
 
-
-def test_yaml():
-    with open("periodic_table.yaml") as f:
-        data = yaml.load(f)
-        print(data)
-
-
-def test_json():
-    with open("periodic_table.json") as f:
-        data = json.load(f)
-        print(data)
+ptable_yaml_path = "periodic_table.yaml"
 
 
 def parse_oxi_state():
-    with open("periodic_table.yaml") as f:
-        data = yaml.load(f)
-    with open("oxidation_states.txt") as f:
-        oxi_data = f.read()
+    data = loadfn(ptable_yaml_path)
+    with open("oxidation_states.txt") as file:
+        oxi_data = file.read()
     oxi_data = re.sub("[\n\r]", "", oxi_data)
     patt = re.compile("<tr>(.*?)</tr>", re.MULTILINE)
 
@@ -65,29 +56,28 @@ def parse_oxi_state():
             data[el]["Common oxidation states"] = common_oxi
         else:
             print(el)
-    with open("periodic_table2.yaml", "w") as f:
-        yaml.dump(data, f)
+    with open("periodic_table2.yaml", mode="w") as file:
+        yaml.dump(data, file)
 
 
 def parse_ionic_radii():
-    with open("periodic_table.yaml") as f:
-        data = yaml.load(f)
-    with open("ionic_radii.csv") as f:
-        radii_data = f.read()
+    data = loadfn(ptable_yaml_path)
+    with open("ionic_radii.csv") as file:
+        radii_data = file.read()
     radii_data = radii_data.split("\r")
     header = radii_data[0].split(",")
     for idx in range(1, len(radii_data)):
         line = radii_data[idx]
-        toks = line.strip().split(",")
+        tokens = line.strip().split(",")
         suffix = ""
-        name = toks[1]
+        name = tokens[1]
         if len(name.split(" ")) > 1:
             suffix = "_" + name.split(" ")[1]
-        el = toks[2]
+        el = tokens[2]
 
         ionic_radii = {}
-        for j in range(3, len(toks)):
-            m = re.match(r"^\s*([0-9\.]+)", toks[j])
+        for j in range(3, len(tokens)):
+            m = re.match(r"^\s*([0-9\.]+)", tokens[j])
             if m:
                 ionic_radii[int(header[j])] = float(m.group(1))
 
@@ -97,35 +87,33 @@ def parse_ionic_radii():
                 data[el]["Ionic_radii"] = ionic_radii
         else:
             print(el)
-    with open("periodic_table2.yaml", "w") as f:
-        yaml.dump(data, f)
+    with open("periodic_table2.yaml", mode="w") as file:
+        yaml.dump(data, file)
 
 
 def parse_radii():
-    with open("periodic_table.yaml") as f:
-        data = yaml.load(f)
-    with open("radii.csv") as f:
-        radiidata = f.read()
-    radiidata = radiidata.split("\r")
+    data = loadfn(ptable_yaml_path)
+    with open("radii.csv") as file:
+        radii_data = file.read()
+    radii_data = radii_data.split("\r")
 
-    for i in range(1, len(radiidata)):
-        line = radiidata[i]
-        toks = line.strip().split(",")
-        el = toks[1]
+    for line in radii_data:
+        tokens = line.strip().split(",")
+        el = tokens[1]
         try:
-            atomic_radii = float(toks[3]) / 100
+            atomic_radii = float(tokens[3]) / 100
         except Exception:
-            atomic_radii = toks[3]
+            atomic_radii = tokens[3]
 
         try:
-            atomic_radii_calc = float(toks[4]) / 100
+            atomic_radii_calc = float(tokens[4]) / 100
         except Exception:
-            atomic_radii_calc = toks[4]
+            atomic_radii_calc = tokens[4]
 
         try:
-            vdw_radii = float(toks[5]) / 100
+            vdw_radii = float(tokens[5]) / 100
         except Exception:
-            vdw_radii = toks[5]
+            vdw_radii = tokens[5]
 
         if el in data:
             data[el]["Atomic radius"] = atomic_radii
@@ -133,15 +121,14 @@ def parse_radii():
             data[el]["Van der waals radius"] = vdw_radii
         else:
             print(el)
-    with open("periodic_table2.yaml", "w") as f:
-        yaml.dump(data, f)
-    with open("periodic_table.json", "w") as f:
-        json.dump(data, f)
+    with open("periodic_table2.yaml", mode="w") as file:
+        yaml.dump(data, file)
+    with open("../pymatgen/core/periodic_table.json", mode="w") as file:
+        json.dump(data, file)
 
 
 def update_ionic_radii():
-    with open("periodic_table.yaml") as f:
-        data = yaml.load(f)
+    data = loadfn(ptable_yaml_path)
 
     for d in data.values():
         if "Ionic_radii" in d:
@@ -153,16 +140,14 @@ def update_ionic_radii():
         if "Ionic_radii_ls" in d:
             d["Ionic radii ls"] = {k: v / 100 for k, v in d["Ionic_radii_ls"].items()}
             del d["Ionic_radii_ls"]
-    with open("periodic_table2.yaml", "w") as f:
-        yaml.dump(data, f)
-    with open("periodic_table.json", "w") as f:
-        json.dump(data, f)
+    with open("periodic_table2.yaml", mode="w") as file:
+        yaml.dump(data, file)
+    with open("../pymatgen/core/periodic_table.json", mode="w") as file:
+        json.dump(data, file)
 
 
 def parse_shannon_radii():
-    with open("periodic_table.yaml") as f:
-        data = yaml.load(f)
-    import collections
+    data = loadfn(ptable_yaml_path)
 
     from openpyxl import load_workbook
 
@@ -194,22 +179,20 @@ def parse_shannon_radii():
         if el in data:
             data[el]["Shannon radii"] = dict(radii[el])
 
-    with open("periodic_table.yaml", "w") as f:
-        yaml.safe_dump(data, f)
-    with open("periodic_table.json", "w") as f:
-        json.dump(data, f)
+    dumpfn(data, ptable_yaml_path)
+    with open("../pymatgen/core/periodic_table.json", mode="w") as file:
+        json.dump(data, file)
 
 
 def gen_periodic_table():
-    with open("periodic_table.yaml") as f:
-        data = yaml.load(f)
+    data = loadfn(ptable_yaml_path)
 
-    with open("periodic_table.json", "w") as f:
-        json.dump(data, f)
+    with open("../pymatgen/core/periodic_table.json", mode="w") as file:
+        json.dump(data, file)
 
 
 def gen_iupac_ordering():
-    periodic_table = loadfn("periodic_table.json")
+    periodic_table = loadfn("../pymatgen/core/periodic_table.json")
     order = [
         ([18], range(6, 0, -1)),  # noble gasses
         ([1], range(7, 1, -1)),  # alkali metals
@@ -251,49 +234,52 @@ def gen_iupac_ordering():
 
 
 def add_electron_affinities():
-    """
-    Update the periodic table data file with electron affinities.
-    """
-    import requests
-    from bs4 import BeautifulSoup
+    """Update the periodic table data file with electron affinities."""
 
-    req = requests.get("https://en.wikipedia.org/wiki/Electron_affinity_(data_page)")
+    req = requests.get("https://wikipedia.org/wiki/Electron_affinity_(data_page)")
     soup = BeautifulSoup(req.text, "html.parser")
-    for t in soup.find_all("table"):
-        if "Hydrogen" in t.text:
+    for table in soup.find_all("table"):
+        if "Hydrogen" in table.text:
             break
     data = []
-    for tr in t.find_all("tr"):
+    for tr in table.find_all("tr"):
         row = []
         for td in tr.find_all("td"):
             row.append(td.get_text().strip())
         data.append(row)
     data.pop(0)
-    ea = {int(r[0]): float(re.sub(r"[\s\(\)]", "", r[3].strip("()[]"))) for r in data}
-    assert set(ea).issuperset(range(1, 93))  # Ensure that we have data for up to U.
+
+    ea = {}
+    max_Z = max(Element(element).Z for element in Element.__members__)
+    for r in data:
+        # don't want superheavy elements or less common isotopes
+        if int(r[0]) > max_Z or r[2] in ea:
+            continue
+        temp_str = re.sub(r"[\s\(\)]", "", r[3].strip("()[]"))
+        # hyphen-like characters used that can't be parsed by .float
+        bytes_rep = temp_str.encode("unicode_escape").replace(b"\\u2212", b"-")
+        ea[r[2]] = float(bytes_rep.decode("unicode_escape"))
+
+    Z_set = {Element.from_name(element).Z for element in ea}
+    assert Z_set.issuperset(range(1, 93))  # Ensure that we have data for up to U.
     print(ea)
     pt = loadfn("../pymatgen/core/periodic_table.json")
-    for k, v in pt.items():
-        v["Electron affinity"] = ea.get(Element(k).Z)
+    for key, val in pt.items():
+        val["Electron affinity"] = ea.get(Element(key).long_name)
     dumpfn(pt, "../pymatgen/core/periodic_table.json")
 
 
 def add_ionization_energies():
-    """
-    Update the periodic table data file with ground level and ionization energies from NIST.
-    """
-    import collections
+    """Update the periodic table data file with ground level and ionization energies from NIST."""
 
-    from bs4 import BeautifulSoup
-
-    with open("NIST Atomic Ionization Energies Output.html") as f:
-        soup = BeautifulSoup(f.read(), "html.parser")
-    for t in soup.find_all("table"):
-        if "Hydrogen" in t.text:
+    with open("NIST Atomic Ionization Energies Output.html") as file:
+        soup = BeautifulSoup(file.read(), "html.parser")
+    for table in soup.find_all("table"):
+        if "Hydrogen" in table.text:
             break
     data = collections.defaultdict(list)
-    for tr in t.find_all("tr"):
-        row = [td.get_text().strip() for td in tr.find_all("td")]
+    for row in table.find_all("tr"):
+        row = [td.get_text().strip() for td in row.find_all("td")]
         if row:
             Z = int(row[0])
             val = re.sub(r"\s", "", row[8].strip("()[]"))
@@ -303,9 +289,9 @@ def add_ionization_energies():
     print(data[51])
     assert set(data).issuperset(range(1, 93))  # Ensure that we have data for up to U.
     pt = loadfn("../pymatgen/core/periodic_table.json")
-    for k, v in pt.items():
-        del v["Ionization energy"]
-        v["Ionization energies"] = data.get(Element(k).Z, [])
+    for key, val in pt.items():
+        del val["Ionization energy"]
+        val["Ionization energies"] = data.get(Element(key).long_name, [])
     dumpfn(pt, "../pymatgen/core/periodic_table.json")
 
 
