@@ -1,6 +1,4 @@
-"""
-This module provides various methods to analyze order/disorder in materials.
-"""
+"""This module provides various methods to analyze order/disorder in materials."""
 
 from __future__ import annotations
 
@@ -14,7 +12,7 @@ if TYPE_CHECKING:
 
 def get_warren_cowley_parameters(structure: Structure, r: float, dr: float) -> dict[tuple, float]:
     """
-    Warren-Crowley parameters
+    Warren-Crowley parameters.
 
     Args:
         structure: Pymatgen Structure.
