@@ -1,14 +1,15 @@
 """
 This module provides a class used to describe the elastic tensor,
 including methods used to fit the elastic tensor from linear response
-stress-strain data
+stress-strain data.
 """
 
 from __future__ import annotations
 
 import itertools
+import math
 import warnings
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Literal
 
 import numpy as np
 import sympy as sp
@@ -20,8 +21,13 @@ from pymatgen.analysis.elasticity.strain import Strain
 from pymatgen.analysis.elasticity.stress import Stress
 from pymatgen.core.tensors import DEFAULT_QUAD, SquareTensor, Tensor, TensorCollection, get_uvec
 from pymatgen.core.units import Unit
+from pymatgen.util.due import Doi, due
 
 if TYPE_CHECKING:
+    from collections.abc import Sequence
+
+    from numpy.typing import ArrayLike
+
     from pymatgen.core import Structure
 
 
@@ -38,7 +44,7 @@ __date__ = "July 24, 2018"
 class NthOrderElasticTensor(Tensor):
     """
     An object representing an nth-order tensor expansion
-    of the stress-strain constitutive equations
+    of the stress-strain constitutive equations.
     """
 
     GPa_to_eV_A3 = Unit("GPa").get_conversion_factor(Unit("eV ang^-3"))
@@ -60,15 +66,13 @@ class NthOrderElasticTensor(Tensor):
 
     @property
     def order(self):
-        """
-        Order of the elastic tensor
-        """
+        """Order of the elastic tensor."""
         return self.rank // 2
 
     def calculate_stress(self, strain):
         """
         Calculate's a given elastic tensor's contribution to the
-        stress using Einstein summation
+        stress using Einstein summation.
 
         Args:
             strain (3x3 array-like): matrix corresponding to strain
@@ -76,14 +80,12 @@ class NthOrderElasticTensor(Tensor):
         strain = np.array(strain)
         if strain.shape == (6,):
             strain = Strain.from_voigt(strain)
-        assert strain.shape == (3, 3), "Strain must be 3x3 or voigt-notation"
+        assert strain.shape == (3, 3), "Strain must be 3x3 or Voigt notation"
         stress_matrix = self.einsum_sequence([strain] * (self.order - 1)) / factorial(self.order - 1)
         return Stress(stress_matrix)
 
     def energy_density(self, strain, convert_GPa_to_eV=True):
-        """
-        Calculates the elastic energy density due to a strain
-        """
+        """Calculates the elastic energy density due to a strain."""
         e_density = np.sum(self.calculate_stress(strain) * strain) / self.order
         if convert_GPa_to_eV:
             e_density *= self.GPa_to_eV_A3  # Conversion factor for GPa to eV/A^3
@@ -108,48 +110,38 @@ class NthOrderElasticTensor(Tensor):
         return cls(diff_fit(strains, stresses, eq_stress, order, tol)[order - 2])
 
 
-def raise_error_if_unphysical(f):
+def raise_if_unphysical(func):
     """
     Wrapper for functions or properties that should raise an error
     if tensor is unphysical.
     """
 
     def wrapper(self, *args, **kwargs):
-        """
-        Args:
-            self ():
-            *args ():
-            **kwargs ():
-
-        Returns:
-        """
         if self.k_vrh < 0 or self.g_vrh < 0:
             raise ValueError("Bulk or shear modulus is negative, property cannot be determined")
-        return f(self, *args, **kwargs)
+        return func(self, *args, **kwargs)
 
     return wrapper
 
 
 class ElasticTensor(NthOrderElasticTensor):
     """
-    This class extends Tensor to describe the 3x3x3x3
-    second-order elastic tensor, C_{ijkl}, with various
-    methods for estimating other properties derived from
-    the second order elastic tensor
+    This class extends Tensor to describe the 3x3x3x3 second-order elastic tensor,
+    C_{ijkl}, with various methods for estimating other properties derived from the second
+    order elastic tensor (e. g. bulk modulus, shear modulus, Young's modulus, Poisson's ratio)
+    in units of eV/A^3.
     """
 
     def __new__(cls, input_array, tol: float = 1e-4):
         """
-        Create an ElasticTensor object. The constructor throws an error if
-        the shape of the input_matrix argument is not 3x3x3x3, i. e. in true
-        tensor notation. Issues a warning if the input_matrix argument does
-        not satisfy standard symmetries. Note that the constructor uses
-        __new__ rather than __init__ according to the standard method of
-        subclassing numpy ndarrays.
+        Create an ElasticTensor object. The constructor throws an error if the shape of
+        the input_matrix argument is not 3x3x3x3, i. e. in true tensor notation. Issues a
+        warning if the input_matrix argument does not satisfy standard symmetries. Note
+        that the constructor uses __new__ rather than __init__ according to the standard
+        method of subclassing numpy ndarrays.
 
         Args:
-            input_array (3x3x3x3 array-like): the 3x3x3x3 array-like
-                representing the elastic tensor
+            input_array (3x3x3x3 array-like): the 3x3x3x3 array-like representing the elastic tensor
 
             tol (float): tolerance for initial symmetry test of tensor
         """
@@ -159,41 +151,32 @@ class ElasticTensor(NthOrderElasticTensor):
     @property
     def compliance_tensor(self):
         """
-        Returns the Voigt-notation compliance tensor,
-        which is the matrix inverse of the
-        Voigt-notation elastic tensor
+        Returns the Voigt notation compliance tensor, which is the matrix
+        inverse of the Voigt notation elastic tensor.
         """
         s_voigt = np.linalg.inv(self.voigt)
         return ComplianceTensor.from_voigt(s_voigt)
 
     @property
-    def k_voigt(self):
-        """
-        Returns the K_v bulk modulus
-        """
+    def k_voigt(self) -> float:
+        """Returns the K_v bulk modulus (in eV/A^3)."""
         return self.voigt[:3, :3].mean()
 
     @property
-    def g_voigt(self):
-        """
-        Returns the G_v shear modulus
-        """
+    def g_voigt(self) -> float:
+        """Returns the G_v shear modulus (in eV/A^3)."""
         return (
             2 * self.voigt[:3, :3].trace() - np.triu(self.voigt[:3, :3]).sum() + 3 * self.voigt[3:, 3:].trace()
         ) / 15.0
 
     @property
-    def k_reuss(self):
-        """
-        Returns the K_r bulk modulus
-        """
+    def k_reuss(self) -> float:
+        """Returns the K_r bulk modulus (in eV/A^3)."""
         return 1 / self.compliance_tensor.voigt[:3, :3].sum()
 
     @property
-    def g_reuss(self):
-        """
-        Returns the G_r shear modulus
-        """
+    def g_reuss(self) -> float:
+        """Returns the G_r shear modulus (in eV/A^3)."""
         return 15 / (
             8 * self.compliance_tensor.voigt[:3, :3].trace()
             - 4 * np.triu(self.compliance_tensor.voigt[:3, :3]).sum()
@@ -201,31 +184,27 @@ class ElasticTensor(NthOrderElasticTensor):
         )
 
     @property
-    def k_vrh(self):
-        """
-        Returns the K_vrh (Voigt-Reuss-Hill) average bulk modulus
-        """
+    def k_vrh(self) -> float:
+        """Returns the K_vrh (Voigt-Reuss-Hill) average bulk modulus (in eV/A^3)."""
         return 0.5 * (self.k_voigt + self.k_reuss)
 
     @property
-    def g_vrh(self):
-        """
-        Returns the G_vrh (Voigt-Reuss-Hill) average shear modulus
-        """
+    def g_vrh(self) -> float:
+        """Returns the G_vrh (Voigt-Reuss-Hill) average shear modulus (in eV/A^3)."""
         return 0.5 * (self.g_voigt + self.g_reuss)
 
     @property
-    def y_mod(self):
+    def y_mod(self) -> float:
         """
         Calculates Young's modulus (in SI units) using the
-        Voigt-Reuss-Hill averages of bulk and shear moduli
+        Voigt-Reuss-Hill averages of bulk and shear moduli.
         """
         return 9.0e9 * self.k_vrh * self.g_vrh / (3 * self.k_vrh + self.g_vrh)
 
-    def directional_poisson_ratio(self, n, m, tol: float = 1e-8):
+    def directional_poisson_ratio(self, n: ArrayLike, m: ArrayLike, tol: float = 1e-8) -> float:
         """
         Calculates the poisson ratio for a specific direction
-        relative to a second, orthogonal direction
+        relative to a second, orthogonal direction.
 
         Args:
             n (3-d vector): principal direction
@@ -239,186 +218,199 @@ class ElasticTensor(NthOrderElasticTensor):
         v *= -1 / self.compliance_tensor.einsum_sequence([n] * 4)
         return v
 
-    def directional_elastic_mod(self, n):
-        """
-        Calculates directional elastic modulus for a specific vector
-        """
+    def directional_elastic_mod(self, n) -> float:
+        """Calculates directional elastic modulus for a specific vector."""
         n = get_uvec(n)
         return self.einsum_sequence([n] * 4)
 
-    @raise_error_if_unphysical
-    def trans_v(self, structure: Structure):
+    @raise_if_unphysical
+    def trans_v(self, structure: Structure) -> float:
         """
-        Calculates transverse sound velocity (in SI units) using the
-        Voigt-Reuss-Hill average bulk modulus
+        Calculates transverse sound velocity using the
+        Voigt-Reuss-Hill average bulk modulus.
 
         Args:
             structure: pymatgen structure object
 
-        Returns: transverse sound velocity (in SI units)
+        Returns:
+            float: transverse sound velocity (in SI units)
         """
-        nsites = structure.num_sites
-        volume = structure.volume
-        natoms = structure.composition.num_atoms
+        n_sites = len(structure)
+        n_atoms = structure.composition.num_atoms
         weight = float(structure.composition.weight)
-        mass_density = 1.6605e3 * nsites * weight / (natoms * volume)
+        mass_density = 1.6605e3 * n_sites * weight / (n_atoms * structure.volume)
         if self.g_vrh < 0:
             raise ValueError("k_vrh or g_vrh is negative, sound velocity is undefined")
         return (1e9 * self.g_vrh / mass_density) ** 0.5
 
-    @raise_error_if_unphysical
-    def long_v(self, structure: Structure):
+    @raise_if_unphysical
+    def long_v(self, structure: Structure) -> float:
         """
-        Calculates longitudinal sound velocity (in SI units)
-        using the Voigt-Reuss-Hill average bulk modulus
+        Calculates longitudinal sound velocity using the Voigt-Reuss-Hill average bulk modulus.
 
         Args:
             structure: pymatgen structure object
 
-        Returns: longitudinal sound velocity (in SI units)
+        Returns:
+            float: longitudinal sound velocity (in SI units)
         """
-        nsites = structure.num_sites
-        volume = structure.volume
-        natoms = structure.composition.num_atoms
+        n_sites = len(structure)
+        n_atoms = structure.composition.num_atoms
         weight = float(structure.composition.weight)
-        mass_density = 1.6605e3 * nsites * weight / (natoms * volume)
+        mass_density = 1.6605e3 * n_sites * weight / (n_atoms * structure.volume)
         if self.g_vrh < 0:
             raise ValueError("k_vrh or g_vrh is negative, sound velocity is undefined")
         return (1e9 * (self.k_vrh + 4 / 3 * self.g_vrh) / mass_density) ** 0.5
 
-    @raise_error_if_unphysical
-    def snyder_ac(self, structure: Structure):
-        """
-        Calculates Snyder's acoustic sound velocity (in SI units)
+    @raise_if_unphysical
+    def snyder_ac(self, structure: Structure) -> float:
+        """Calculates Snyder's acoustic sound velocity.
 
         Args:
             structure: pymatgen structure object
 
-        Returns: Snyder's acoustic sound velocity (in SI units)
+        Returns:
+            float: Snyder's acoustic sound velocity (in SI units)
         """
-        nsites = structure.num_sites
-        volume = structure.volume
-        natoms = structure.composition.num_atoms
-        num_density = 1e30 * nsites / volume
+        n_sites = len(structure)
+        n_atoms = structure.composition.num_atoms
+        site_density = 1e30 * n_sites / structure.volume
         tot_mass = sum(e.atomic_mass for e in structure.species)
-        avg_mass = 1.6605e-27 * tot_mass / natoms
+        avg_mass = 1.6605e-27 * tot_mass / n_atoms
         return (
             0.38483
             * avg_mass
             * ((self.long_v(structure) + 2 * self.trans_v(structure)) / 3) ** 3.0
-            / (300 * num_density ** (-2 / 3) * nsites ** (1 / 3))
+            / (300 * site_density ** (-2 / 3) * n_sites ** (1 / 3))
         )
 
-    @raise_error_if_unphysical
-    def snyder_opt(self, structure: Structure):
+    @raise_if_unphysical
+    def snyder_opt(self, structure: Structure) -> float:
         """
-        Calculates Snyder's optical sound velocity (in SI units)
+        Calculates Snyder's optical sound velocity (in SI units).
 
         Args:
-            structure: pymatgen structure object
+            structure: pymatgen Structure object
 
-        Returns: Snyder's optical sound velocity (in SI units)
+        Returns:
+            float: Snyder's optical sound velocity (in SI units)
         """
-        nsites = structure.num_sites
-        volume = structure.volume
-        num_density = 1e30 * nsites / volume
+        n_sites = len(structure)
+        site_density = 1e30 * n_sites / structure.volume
         return (
             1.66914e-23
             * (self.long_v(structure) + 2 * self.trans_v(structure))
             / 3.0
-            / num_density ** (-2 / 3)
-            * (1 - nsites ** (-1 / 3))
+            / site_density ** (-2 / 3)
+            * (1 - n_sites ** (-1 / 3))
         )
 
-    @raise_error_if_unphysical
-    def snyder_total(self, structure: Structure):
+    @raise_if_unphysical
+    def snyder_total(self, structure: Structure) -> float:
         """
-        Calculates Snyder's total sound velocity (in SI units)
+        Calculates Snyder's total sound velocity (in SI units).
 
         Args:
             structure: pymatgen structure object
 
-        Returns: Snyder's total sound velocity (in SI units)
+        Returns:
+            float: Snyder's total sound velocity (in SI units)
         """
         return self.snyder_ac(structure) + self.snyder_opt(structure)
 
-    @raise_error_if_unphysical
-    def clarke_thermalcond(self, structure: Structure):
-        """
-        Calculates Clarke's thermal conductivity (in SI units)
+    @raise_if_unphysical
+    def clarke_thermalcond(self, structure: Structure) -> float:
+        """Calculates Clarke's thermal conductivity.
 
         Args:
             structure: pymatgen structure object
 
-        Returns: Clarke's thermal conductivity (in SI units)
+        Returns:
+            float: Clarke's thermal conductivity (in SI units)
         """
-        nsites = structure.num_sites
-        volume = structure.volume
+        n_sites = len(structure)
         tot_mass = sum(e.atomic_mass for e in structure.species)
-        natoms = structure.composition.num_atoms
+        n_atoms = structure.composition.num_atoms
         weight = float(structure.composition.weight)
-        avg_mass = 1.6605e-27 * tot_mass / natoms
-        mass_density = 1.6605e3 * nsites * weight / (natoms * volume)
+        avg_mass = 1.6605e-27 * tot_mass / n_atoms
+        mass_density = 1.6605e3 * n_sites * weight / (n_atoms * structure.volume)
         return 0.87 * 1.3806e-23 * avg_mass ** (-2 / 3) * mass_density ** (1 / 6) * self.y_mod**0.5
 
-    @raise_error_if_unphysical
-    def cahill_thermalcond(self, structure: Structure):
-        """
-        Calculates Cahill's thermal conductivity (in SI units)
+    @raise_if_unphysical
+    def cahill_thermalcond(self, structure: Structure) -> float:
+        """Calculate Cahill's thermal conductivity.
 
         Args:
             structure: pymatgen structure object
 
-        Returns: Cahill's thermal conductivity (in SI units)
+        Returns:
+            float: Cahill's thermal conductivity (in SI units)
         """
-        nsites = structure.num_sites
-        volume = structure.volume
-        num_density = 1e30 * nsites / volume
-        return 1.3806e-23 / 2.48 * num_density ** (2 / 3) * (self.long_v(structure) + 2 * self.trans_v(structure))
+        n_sites = len(structure)
+        site_density = 1e30 * n_sites / structure.volume
+        return 1.3806e-23 / 2.48 * site_density ** (2 / 3) * (self.long_v(structure) + 2 * self.trans_v(structure))
 
-    @raise_error_if_unphysical
-    def debye_temperature(self, structure: Structure):
-        """
-        Estimates the debye temperature from longitudinal and
-        transverse sound velocities
+    @due.dcite(
+        Doi("10.1039/C7EE03256K"),
+        description="Minimum thermal conductivity in the context of diffusion-mediated thermal transport",
+    )
+    @raise_if_unphysical
+    def agne_diffusive_thermalcond(self, structure: Structure) -> float:
+        """Calculates Agne's diffusive thermal conductivity.
+
+        Please cite the original authors if using this method
+        M. T. Agne, R. Hanus, G. J. Snyder, Energy Environ. Sci. 2018, 11, 609-616.
+        DOI: https://doi.org/10.1039/C7EE03256K
 
         Args:
             structure: pymatgen structure object
 
-        Returns: debye temperature (in SI units)
+        Returns:
+            float: Agne's diffusive thermal conductivity (in SI units)
         """
-        v0 = structure.volume * 1e-30 / structure.num_sites
+        n_sites = len(structure)
+        site_density = 1e30 * n_sites / structure.volume
+        return (
+            0.76
+            * (site_density ** (2 / 3))
+            * 1.3806e-23
+            * ((1 / 3) * (2 * self.trans_v(structure) + self.long_v(structure)))
+        )
+
+    @raise_if_unphysical
+    def debye_temperature(self, structure: Structure) -> float:
+        """
+        Estimates the Debye temperature from longitudinal and transverse sound velocities.
+
+        Args:
+            structure: pymatgen structure object
+
+        Returns:
+            float: Debye temperature (in SI units)
+        """
+        v0 = structure.volume * 1e-30 / len(structure)
         vl, vt = self.long_v(structure), self.trans_v(structure)
         vm = 3 ** (1 / 3) * (1 / vl**3 + 2 / vt**3) ** (-1 / 3)
-        td = 1.05457e-34 / 1.38065e-23 * vm * (6 * np.pi**2 / v0) ** (1 / 3)
-        return td
+        return 1.05457e-34 / 1.38065e-23 * vm * (6 * np.pi**2 / v0) ** (1 / 3)
 
     @property
-    def universal_anisotropy(self):
-        """
-        Returns the universal anisotropy value
-        """
+    def universal_anisotropy(self) -> float:
+        """Returns the universal anisotropy value."""
         return 5 * self.g_voigt / self.g_reuss + self.k_voigt / self.k_reuss - 6.0
 
     @property
-    def homogeneous_poisson(self):
-        """
-        Returns the homogeneous poisson ratio
-        """
+    def homogeneous_poisson(self) -> float:
+        """Returns the homogeneous poisson ratio."""
         return (1 - 2 / 3 * self.g_vrh / self.k_vrh) / (2 + 2 / 3 * self.g_vrh / self.k_vrh)
 
-    def green_kristoffel(self, u):
-        """
-        Returns the Green-Kristoffel tensor for a second-order tensor
-        """
+    def green_kristoffel(self, u) -> float:
+        """Returns the Green-Kristoffel tensor for a second-order tensor."""
         return self.einsum_sequence([u, u], "ijkl,i,l")
 
     @property
     def property_dict(self):
-        """
-        Returns a dictionary of properties derived from the elastic tensor
-        """
-        props = [
+        """Returns a dictionary of properties derived from the elastic tensor."""
+        props = (
             "k_voigt",
             "k_reuss",
             "k_vrh",
@@ -428,7 +420,7 @@ class ElasticTensor(NthOrderElasticTensor):
             "universal_anisotropy",
             "homogeneous_poisson",
             "y_mod",
-        ]
+        )
         return {prop: getattr(self, prop) for prop in props}
 
     def get_structure_property_dict(
@@ -436,7 +428,7 @@ class ElasticTensor(NthOrderElasticTensor):
     ) -> dict[str, float | Structure | None]:
         """
         Returns a dictionary of properties derived from the elastic tensor
-        and an associated structure
+        and an associated structure.
 
         Args:
             structure (Structure): structure object for which to calculate
@@ -446,7 +438,7 @@ class ElasticTensor(NthOrderElasticTensor):
             ignore_errors (bool): if set to true, will set problem properties
                 that depend on a physical tensor to None, defaults to False
         """
-        s_props = [
+        s_props = (
             "trans_v",
             "long_v",
             "snyder_ac",
@@ -455,7 +447,7 @@ class ElasticTensor(NthOrderElasticTensor):
             "clarke_thermalcond",
             "cahill_thermalcond",
             "debye_temperature",
-        ]
+        )
         sp_dict: dict[str, float | Structure | None]
         if ignore_errors and (self.k_vrh < 0 or self.g_vrh < 0):
             sp_dict = {prop: None for prop in s_props}
@@ -470,21 +462,21 @@ class ElasticTensor(NthOrderElasticTensor):
     def from_pseudoinverse(cls, strains, stresses):
         """
         Class method to fit an elastic tensor from stress/strain
-        data. Method uses Moore-Penrose pseudoinverse to invert
+        data. Method uses Moore-Penrose pseudo-inverse to invert
         the s = C*e equation with elastic tensor, stress, and
-        strain in voigt notation
+        strain in voigt notation.
 
         Args:
             stresses (Nx3x3 array-like): list or array of stresses
             strains (Nx3x3 array-like): list or array of strains
         """
-        # convert the stress/strain to Nx6 arrays of voigt-notation
+        # convert the stress/strain to Nx6 arrays of voigt notation
         warnings.warn(
-            "Pseudoinverse fitting of Strain/Stress lists may yield "
+            "Pseudo-inverse fitting of Strain/Stress lists may yield "
             "questionable results from vasp data, use with caution."
         )
         stresses = np.array([Stress(stress).voigt for stress in stresses])
-        with warnings.catch_warnings(record=True):
+        with warnings.catch_warnings():
             strains = np.array([Strain(strain).voigt for strain in strains])
 
         voigt_fit = np.transpose(np.dot(np.linalg.pinv(strains), stresses))
@@ -494,6 +486,7 @@ class ElasticTensor(NthOrderElasticTensor):
     def from_independent_strains(cls, strains, stresses, eq_stress=None, vasp=False, tol: float = 1e-10):
         """
         Constructs the elastic tensor least-squares fit of independent strains
+
         Args:
             strains (list of Strains): list of strain objects to fit
             stresses (list of Stresses): list of stress objects to use in fit
@@ -502,7 +495,7 @@ class ElasticTensor(NthOrderElasticTensor):
             vasp (bool): flag for whether the stress tensor should be
                 converted based on vasp units/convention for stress
             tol (float): tolerance for removing near-zero elements of the
-                resulting tensor
+                resulting tensor.
         """
         strain_states = [tuple(ss) for ss in np.eye(6)]
         ss_dict = get_strain_state_dict(strains, stresses, eq_stress=eq_stress)
@@ -511,23 +504,22 @@ class ElasticTensor(NthOrderElasticTensor):
         if len(set(ss_dict) - set(strain_states)) > 0:
             warnings.warn("Extra strain states in strain-stress pairs are neglected in independent strain fitting")
         c_ij = np.zeros((6, 6))
-        for i in range(6):
-            istrains = ss_dict[strain_states[i]]["strains"]
-            istresses = ss_dict[strain_states[i]]["stresses"]
-            for j in range(6):
-                c_ij[i, j] = np.polyfit(istrains[:, i], istresses[:, j], 1)[0]
+        for ii in range(6):
+            strains = ss_dict[strain_states[ii]]["strains"]
+            stresses = ss_dict[strain_states[ii]]["stresses"]
+            for jj in range(6):
+                c_ij[ii, jj] = np.polyfit(strains[:, ii], stresses[:, jj], 1)[0]
         if vasp:
             c_ij *= -0.1  # Convert units/sign convention of vasp stress tensor
-        c = cls.from_voigt(c_ij)
-        c = c.zeroed(tol)
-        return c
+        instance = cls.from_voigt(c_ij)
+        return instance.zeroed(tol)
 
 
 class ComplianceTensor(Tensor):
     """
     This class represents the compliance tensor, and exists
     primarily to keep the voigt-conversion scheme consistent
-    since the compliance tensor has a unique vscale
+    since the compliance tensor has a unique vscale.
     """
 
     def __new__(cls, s_array):
@@ -548,49 +540,46 @@ class ElasticTensorExpansion(TensorCollection):
     to an elastic tensor expansion, which can be used to
     calculate stress and energy density and inherits all
     of the list-based properties of TensorCollection
-    (e. g. symmetrization, voigt conversion, etc.)
+    (e. g. symmetrization, voigt conversion, etc.).
     """
 
-    def __init__(self, c_list):
+    def __init__(self, c_list: Sequence) -> None:
         """
-        Initialization method for ElasticTensorExpansion
+        Initialization method for ElasticTensorExpansion.
 
         Args:
-            c_list (list or tuple): sequence of Tensor inputs
-                or tensors from which the elastic tensor
-                expansion is constructed.
+            c_list (list or tuple): sequence of Tensor inputs or tensors from which
+                the elastic tensor expansion is constructed.
         """
-        c_list = [NthOrderElasticTensor(c, check_rank=4 + i * 2) for i, c in enumerate(c_list)]
+        c_list = [NthOrderElasticTensor(c, check_rank=4 + idx * 2) for idx, c in enumerate(c_list)]
         super().__init__(c_list)
 
     @classmethod
     def from_diff_fit(cls, strains, stresses, eq_stress=None, tol: float = 1e-10, order=3):
         """
         Generates an elastic tensor expansion via the fitting function
-        defined below in diff_fit
+        defined below in diff_fit.
         """
         c_list = diff_fit(strains, stresses, eq_stress, order, tol)
         return cls(c_list)
 
     @property
-    def order(self):
+    def order(self) -> int:
         """
         Order of the elastic tensor expansion, i. e. the order of the
-        highest included set of elastic constants
+        highest included set of elastic constants.
         """
         return self[-1].order
 
-    def calculate_stress(self, strain):
+    def calculate_stress(self, strain) -> float:
         """
         Calculate's a given elastic tensor's contribution to the
-        stress using Einstein summation
+        stress using Einstein summation.
         """
         return sum(c.calculate_stress(strain) for c in self)
 
     def energy_density(self, strain, convert_GPa_to_eV=True):
-        """
-        Calculates the elastic energy density due to a strain
-        """
+        """Calculates the elastic energy density due to a strain in eV/A^3 or GPa."""
         return sum(c.energy_density(strain, convert_GPa_to_eV) for c in self)
 
     def get_ggt(self, n, u):
@@ -603,12 +592,11 @@ class ElasticTensorExpansion(TensorCollection):
             u (3x1 array-like): polarization direction
         """
         gk = self[0].einsum_sequence([n, u, n, u])
-        result = -(
-            2 * gk * np.outer(u, u) + self[0].einsum_sequence([n, n]) + self[1].einsum_sequence([n, u, n, u])
-        ) / (2 * gk)
-        return result
+        return -(2 * gk * np.outer(u, u) + self[0].einsum_sequence([n, n]) + self[1].einsum_sequence([n, u, n, u])) / (
+            2 * gk
+        )
 
-    def get_tgt(self, temperature=None, structure=None, quad=None):
+    def get_tgt(self, temperature: float | None = None, structure: Structure = None, quad=None):
         """
         Gets the thermodynamic Gruneisen tensor (TGT) by via an
         integration of the GGT weighted by the directional heat
@@ -621,7 +609,7 @@ class ElasticTensorExpansion(TensorCollection):
         Args:
             temperature (float): Temperature in kelvin, if not specified
                 will return non-cv-normalized value
-            structure (float): Structure to be used in directional heat
+            structure (Structure): Structure to be used in directional heat
                 capacity determination, only necessary if temperature
                 is specified
             quad (dict): quadrature for integration, should be
@@ -637,11 +625,11 @@ class ElasticTensorExpansion(TensorCollection):
         num, denom, c = np.zeros((3, 3)), 0, 1
         for p, w in zip(points, weights):
             gk = ElasticTensor(self[0]).green_kristoffel(p)
-            rho_wsquareds, us = np.linalg.eigh(gk)
+            _rho_wsquareds, us = np.linalg.eigh(gk)
             us = [u / np.linalg.norm(u) for u in np.transpose(us)]
             for u in us:
                 # TODO: this should be benchmarked
-                if temperature:
+                if temperature and structure:
                     c = self.get_heat_capacity(temperature, structure, p, u)
                 num += c * self.get_ggt(p, u) * w
                 denom += c * w
@@ -690,7 +678,7 @@ class ElasticTensorExpansion(TensorCollection):
     def omega(self, structure: Structure, n, u):
         """
         Finds directional frequency contribution to the heat
-        capacity from direction and polarization
+        capacity from direction and polarization.
 
         Args:
             structure (Structure): Structure to be used in directional heat
@@ -706,7 +694,9 @@ class ElasticTensorExpansion(TensorCollection):
         vel = (1e9 * self[0].einsum_sequence([n, u, n, u]) / (weight / vol)) ** 0.5
         return vel / l0
 
-    def thermal_expansion_coeff(self, structure: Structure, temperature, mode="debye"):
+    def thermal_expansion_coeff(
+        self, structure: Structure, temperature: float, mode: Literal["dulong - petit", "debye"] = "debye"
+    ):
         """
         Gets thermal expansion coefficient from third-order constants.
 
@@ -720,7 +710,7 @@ class ElasticTensorExpansion(TensorCollection):
                 current supported modes are 'debye' and 'dulong-petit'
         """
         soec = ElasticTensor(self[0])
-        v0 = structure.volume * 1e-30 / structure.num_sites
+        v0 = structure.volume * 1e-30 / len(structure)
         if mode == "debye":
             td = soec.debye_temperature(structure)
             t_ratio = temperature / td
@@ -747,11 +737,11 @@ class ElasticTensorExpansion(TensorCollection):
         if not self.order <= 4:
             raise ValueError("Compliance tensor expansion only supported for fourth-order and lower")
         ce_exp = [ElasticTensor(self[0]).compliance_tensor]
-        einstring = "ijpq,pqrsuv,rskl,uvmn->ijklmn"
-        ce_exp.append(np.einsum(einstring, -ce_exp[-1], self[1], ce_exp[-1], ce_exp[-1]))
+        ein_string = "ijpq,pqrsuv,rskl,uvmn->ijklmn"
+        ce_exp.append(np.einsum(ein_string, -ce_exp[-1], self[1], ce_exp[-1], ce_exp[-1]))
         if self.order == 4:
             # Four terms in the Fourth-Order compliance tensor
-            # pylint: disable=E1130
+
             einstring_1 = "pqab,cdij,efkl,ghmn,abcdefgh"
             tensors_1 = [ce_exp[0]] * 4 + [self[-1]]
             temp = -np.einsum(einstring_1, *tensors_1)
@@ -841,7 +831,7 @@ class ElasticTensorExpansion(TensorCollection):
 
     def get_yield_stress(self, n):
         """
-        Gets the yield stress for a given direction
+        Gets the yield stress for a given direction.
 
         Args:
             n (3x1 array-like): direction for which to find the
@@ -868,7 +858,7 @@ def diff_fit(strains, stresses, eq_stress=None, order=2, tol: float = 1e-10):
     3. Find first, second .. nth derivatives of each stress
        with respect to scalar variable corresponding to
        the smallest perturbation in the strain.
-    4. Use the pseudoinverse of a matrix-vector expression
+    4. Use the pseudo-inverse of a matrix-vector expression
        corresponding to the parameterized stress-strain
        relationship and multiply that matrix by the respective
        calculated first or second derivatives from the
@@ -905,7 +895,7 @@ def diff_fit(strains, stresses, eq_stress=None, order=2, tol: float = 1e-10):
             coef = get_diff_coeff(hvec, i)
             dei_dsi[i - 1, :, n] = np.dot(coef, data["stresses"])
 
-    m, absent = generate_pseudo(list(strain_state_dict), order)
+    m, _absent = generate_pseudo(list(strain_state_dict), order)
     for i in range(1, order):
         cvec, carr = get_symbol_list(i + 1)
         svec = np.ravel(dei_dsi[i - 1].T)
@@ -916,7 +906,7 @@ def diff_fit(strains, stresses, eq_stress=None, order=2, tol: float = 1e-10):
 
 def find_eq_stress(strains, stresses, tol: float = 1e-10):
     """
-    Finds stress corresponding to zero strain state in stress-strain list
+    Finds stress corresponding to zero strain state in stress-strain list.
 
     Args:
         strains (Nx3x3 array-like): array corresponding to strains
@@ -944,28 +934,28 @@ def find_eq_stress(strains, stresses, tol: float = 1e-10):
 
 def get_strain_state_dict(strains, stresses, eq_stress=None, tol: float = 1e-10, add_eq=True, sort=True):
     """
-    Creates a dictionary of voigt-notation stress-strain sets
+    Creates a dictionary of voigt notation stress-strain sets
     keyed by "strain state", i. e. a tuple corresponding to
     the non-zero entries in ratios to the lowest nonzero value,
     e.g. [0, 0.1, 0, 0.2, 0, 0] -> (0,1,0,2,0,0)
     This allows strains to be collected in stencils as to
-    evaluate parameterized finite difference derivatives
+    evaluate parameterized finite difference derivatives.
 
     Args:
         strains (Nx3x3 array-like): strain matrices
         stresses (Nx3x3 array-like): stress matrices
         eq_stress (Nx3x3 array-like): equilibrium stress
         tol (float): tolerance for sorting strain states
-        add_eq (bool): flag for whether to add eq_strain
-            to stress-strain sets for each strain state
+        add_eq (bool): Whether to add eq_strain to stress-strain sets for each strain state.
+            Defaults to True.
         sort (bool): flag for whether to sort strain states
 
     Returns:
         dict: strain state keys and dictionaries with stress-strain data corresponding to strain state
     """
     # Recast stress/strains
-    vstrains = np.array([Strain(s).zeroed(tol).voigt for s in strains])  # pylint: disable=E1101
-    vstresses = np.array([Stress(s).zeroed(tol).voigt for s in stresses])  # pylint: disable=E1101
+    vstrains = np.array([Strain(s).zeroed(tol).voigt for s in strains])
+    vstresses = np.array([Stress(s).zeroed(tol).voigt for s in stresses])
     # Collect independent strain states:
     independent = {tuple(np.nonzero(vstrain)[0].tolist()) for vstrain in vstrains}
     strain_state_dict = {}
@@ -975,7 +965,7 @@ def get_strain_state_dict(strains, stresses, eq_stress=None, tol: float = 1e-10,
     for ind in independent:
         # match strains with templates
         template = np.zeros(6, dtype=bool)
-        np.put(template, ind, True)
+        np.put(template, ind, v=True)
         template = np.tile(template, [vstresses.shape[0], 1])
         mode = (template == (np.abs(vstrains) > 1e-10)).all(axis=1)
         mstresses = vstresses[mode]
@@ -999,26 +989,23 @@ def get_strain_state_dict(strains, stresses, eq_stress=None, tol: float = 1e-10,
 
 
 def generate_pseudo(strain_states, order=3):
-    """
-    Generates the pseudoinverse for a given set of strains.
+    """Generates the pseudo-inverse for a given set of strains.
 
     Args:
-        strain_states (6xN array like): a list of voigt-notation
-            "strain-states", i. e. perturbed indices of the strain
-            as a function of the smallest strain e. g. (0, 1, 0, 0, 1, 0)
-        order (int): order of pseudoinverse to calculate
+        strain_states (6xN array like): a list of Voigt-notation strain-states,
+            i. e. perturbed indices of the strain as a function of the smallest
+            strain e. g. (0, 1, 0, 0, 1, 0)
+        order (int): order of pseudo-inverse to calculate
 
     Returns:
-        mis: pseudo inverses for each order tensor, these can
-            be multiplied by the central difference derivative
-            of the stress with respect to the strain state
-        absent_syms: symbols of the tensor absent from the PI
-            expression
+        pseudo_inverses: for each order tensor, these can be multiplied by the central
+            difference derivative of the stress with respect to the strain state
+        absent_syms: symbols of the tensor absent from the PI expression
     """
-    s = sp.Symbol("s")
+    symb = sp.Symbol("s")
     nstates = len(strain_states)
-    ni = np.array(strain_states) * s
-    mis, absent_syms = [], []
+    ni = np.array(strain_states) * symb
+    pseudo_inverses, absent_symbols = [], []
     for degree in range(2, order + 1):
         cvec, carr = get_symbol_list(degree)
         sarr = np.zeros((nstates, 6), dtype=object)
@@ -1027,21 +1014,21 @@ def generate_pseudo(strain_states, order=3):
             exps = carr.copy()
             for _ in range(degree - 1):
                 exps = np.dot(exps, strain_v)
-            exps /= np.math.factorial(degree - 1)
-            sarr[n] = [sp.diff(exp, s, degree - 1) for exp in exps]
+            exps /= math.factorial(degree - 1)
+            sarr[n] = [sp.diff(exp, symb, degree - 1) for exp in exps]
         svec = sarr.ravel()
-        present_syms = set.union(*(exp.atoms(sp.Symbol) for exp in svec))
-        absent_syms += [set(cvec) - present_syms]
-        m = np.zeros((6 * nstates, len(cvec)))
+        present_symbols = set.union(*(exp.atoms(sp.Symbol) for exp in svec))
+        absent_symbols += [set(cvec) - present_symbols]
+        pseudo_mat = np.zeros((6 * nstates, len(cvec)))
         for n, c in enumerate(cvec):
-            m[:, n] = v_diff(svec, c)
-        mis.append(np.linalg.pinv(m))
-    return mis, absent_syms
+            pseudo_mat[:, n] = v_diff(svec, c)
+        pseudo_inverses.append(np.linalg.pinv(pseudo_mat))
+    return pseudo_inverses, absent_symbols
 
 
 def get_symbol_list(rank, dim=6):
     """
-    Returns a symbolic representation of the voigt-notation
+    Returns a symbolic representation of the Voigt-notation
     tensor that places identical symbols for entries related
     by index transposition, i. e. C_1121 = C_1211 etc.
 
@@ -1068,7 +1055,7 @@ def get_symbol_list(rank, dim=6):
 def subs(entry, cmap):
     """
     Sympy substitution function, primarily for the purposes
-    of numpy vectorization
+    of numpy vectorization.
 
     Args:
         entry (symbol or exp): sympy expr to undergo subs
