@@ -1,5 +1,4 @@
-"""
-This module implements various equation of states.
+"""This module implements various equation of states.
 
 Note: Most of the code were initially adapted from ASE and deltafactor by
 @gmatteo but has since undergone major refactoring.
@@ -11,12 +10,16 @@ import logging
 import warnings
 from abc import ABCMeta, abstractmethod
 from copy import deepcopy
+from typing import TYPE_CHECKING
 
 import numpy as np
 from scipy.optimize import leastsq, minimize
 
 from pymatgen.core.units import FloatWithUnit
-from pymatgen.util.plotting import add_fig_kwargs, get_ax_fig_plt, pretty_plot
+from pymatgen.util.plotting import add_fig_kwargs, get_ax_fig, pretty_plot
+
+if TYPE_CHECKING:
+    import matplotlib.pyplot as plt
 
 __author__ = "Kiran Mathew, gmatteo"
 __credits__ = "Cormac Toher"
@@ -34,15 +37,15 @@ class EOSBase(metaclass=ABCMeta):
         """
         Args:
             volumes (list/numpy.array): volumes in Ang^3
-            energies (list/numpy.array): energy in eV
+            energies (list/numpy.array): energy in eV.
         """
         self.volumes = np.array(volumes)
         self.energies = np.array(energies)
         # minimum energy(e0), buk modulus(b0),
-        # derivative of bulk modulus wrt pressure(b1), minimum volume(v0)
+        # derivative of bulk modulus w.r.t. pressure(b1), minimum volume(v0)
         self._params = None
         # the eos function parameters. It is the same as _params except for
-        # equation of states that uses polynomial fits(deltafactor and
+        # equation of states that uses polynomial fits(delta_factor and
         # numerical_eos)
         self.eos_params = None
 
@@ -61,10 +64,10 @@ class EOSBase(metaclass=ABCMeta):
         b0 = 2 * a * v0
         b1 = 4  # b1 is usually a small number like 4
 
-        vmin, vmax = min(self.volumes), max(self.volumes)
+        vol_min, vol_max = min(self.volumes), max(self.volumes)
 
-        if not vmin < v0 and v0 < vmax:
-            raise EOSError("The minimum volume of a fitted parabola is not in the input volumes\n.")
+        if not vol_min < v0 and v0 < vol_max:
+            raise EOSError("The minimum volume of a fitted parabola is not in the input volumes.")
 
         return e0, b0, b1, v0
 
@@ -73,8 +76,7 @@ class EOSBase(metaclass=ABCMeta):
         Do the fitting. Does least square fitting. If you want to use custom
         fitting, must override this.
         """
-        # the objective function that will be minimized in the least square
-        # fitting
+        # the objective function that will be minimized in the least square fitting
         self._params = self._initial_guess()
         self.eos_params, ierr = leastsq(
             lambda pars, x, y: y - self._func(x, pars),
@@ -83,7 +85,7 @@ class EOSBase(metaclass=ABCMeta):
         )
         # e0, b0, b1, v0
         self._params = self.eos_params
-        if ierr not in [1, 2, 3, 4]:
+        if ierr not in (1, 2, 3, 4):
             raise EOSError("Optimal parameters not found")
 
     @abstractmethod
@@ -93,8 +95,8 @@ class EOSBase(metaclass=ABCMeta):
         that derive from this abstract class.
 
         Args:
-            volume (float/numpy.array)
-             params (list/tuple): values for the parameters other than the
+            volume (float | list[float])
+            params (list | tuple): values for the parameters other than the
                 volume used by the eos.
         """
 
@@ -104,17 +106,17 @@ class EOSBase(metaclass=ABCMeta):
         to the ones obtained from fitting.
 
         Args:
-             volume (list/numpy.array)
+            volume (float | list[float]): volumes in Ang^3
 
         Returns:
             numpy.array
         """
         return self._func(np.array(volume), self.eos_params)
 
-    def __call__(self, volume):
+    def __call__(self, volume: float) -> float:
         """
         Args:
-            volume (): Volume
+            volume (float | list[float]): volume(s) in Ang^3
 
         Returns:
             Compute EOS with this volume.
@@ -123,9 +125,7 @@ class EOSBase(metaclass=ABCMeta):
 
     @property
     def e0(self):
-        """
-        Returns the min energy.
-        """
+        """Returns the min energy."""
         return self._params[0]
 
     @property
@@ -141,22 +141,18 @@ class EOSBase(metaclass=ABCMeta):
         """
         Returns the bulk modulus in GPa.
         Note: This assumes that the energy and volumes are in eV and Ang^3
-            respectively
+            respectively.
         """
         return FloatWithUnit(self.b0, "eV ang^-3").to("GPa")
 
     @property
     def b1(self):
-        """
-        Returns the derivative of bulk modulus wrt pressure(dimensionless)
-        """
+        """Returns the derivative of bulk modulus w.r.t. pressure(dimensionless)."""
         return self._params[2]
 
     @property
     def v0(self):
-        """
-        Returns the minimum or the reference volume in Ang^3.
-        """
+        """Returns the minimum or the reference volume in Ang^3."""
         return self._params[3]
 
     @property
@@ -169,7 +165,7 @@ class EOSBase(metaclass=ABCMeta):
         """
         return {"e0": self.e0, "b0": self.b0, "b1": self.b1, "v0": self.v0}
 
-    def plot(self, width=8, height=None, plt=None, dpi=None, **kwargs):
+    def plot(self, width=8, height=None, ax: plt.Axes = None, dpi=None, **kwargs):
         """
         Plot the equation of state.
 
@@ -177,17 +173,16 @@ class EOSBase(metaclass=ABCMeta):
             width (float): Width of plot in inches. Defaults to 8in.
             height (float): Height of plot in inches. Defaults to width *
                 golden ratio.
-            plt (matplotlib.pyplot): If plt is supplied, changes will be made
-                to an existing plot. Otherwise, a new plot will be created.
+            ax (plt.Axes): If supplied, changes will be made to the existing Axes.
+                Otherwise, new Axes will be created.
             dpi:
             kwargs (dict): additional args fed to pyplot.plot.
                 supported keys: style, color, text, label
 
         Returns:
-            Matplotlib plot object.
+            plt.Axes: The matplotlib axes.
         """
-        # pylint: disable=E1307
-        plt = pretty_plot(width=width, height=height, plt=plt, dpi=dpi)
+        ax = pretty_plot(width=width, height=height, ax=ax, dpi=dpi)
 
         color = kwargs.get("color", "r")
         label = kwargs.get("label", f"{type(self).__name__} fit")
@@ -196,56 +191,7 @@ class EOSBase(metaclass=ABCMeta):
             f"Minimum energy = {self.e0:1.2f} eV",
             f"Minimum or reference volume = {self.v0:1.2f} Ang^3",
             f"Bulk modulus = {self.b0:1.2f} eV/Ang^3 = {self.b0_GPa:1.2f} GPa",
-            f"Derivative of bulk modulus wrt pressure = {self.b1:1.2f}",
-        ]
-        text = "\n".join(lines)
-        text = kwargs.get("text", text)
-
-        # Plot input data.
-        plt.plot(self.volumes, self.energies, linestyle="None", marker="o", color=color)
-
-        # Plot eos fit.
-        vmin, vmax = min(self.volumes), max(self.volumes)
-        vmin, vmax = (vmin - 0.01 * abs(vmin), vmax + 0.01 * abs(vmax))
-        vfit = np.linspace(vmin, vmax, 100)
-
-        plt.plot(vfit, self.func(vfit), linestyle="dashed", color=color, label=label)
-
-        plt.grid(True)
-        plt.xlabel("Volume $\\AA^3$")
-        plt.ylabel("Energy (eV)")
-        plt.legend(loc="best", shadow=True)
-        # Add text with fit parameters.
-        plt.text(0.4, 0.5, text, transform=plt.gca().transAxes)
-
-        return plt
-
-    @add_fig_kwargs
-    def plot_ax(self, ax=None, fontsize=12, **kwargs):
-        """
-        Plot the equation of state on axis `ax`
-
-        Args:
-            ax: matplotlib :class:`Axes` or None if a new figure should be created.
-            fontsize: Legend fontsize.
-            color (str): plot color.
-            label (str): Plot label
-            text (str): Legend text (options)
-
-        Returns:
-            Matplotlib figure object.
-        """
-        # pylint: disable=E1307
-        ax, fig, plt = get_ax_fig_plt(ax=ax)
-
-        color = kwargs.get("color", "r")
-        label = kwargs.get("label", f"{type(self).__name__} fit")
-        lines = [
-            f"Equation of State: {type(self).__name__}",
-            f"Minimum energy = {self.e0:1.2f} eV",
-            f"Minimum or reference volume = {self.v0:1.2f} Ang^3",
-            f"Bulk modulus = {self.b0:1.2f} eV/Ang^3 = {self.b0_GPa:1.2f} GPa",
-            f"Derivative of bulk modulus wrt pressure = {self.b1:1.2f}",
+            f"Derivative of bulk modulus w.r.t. pressure = {self.b1:1.2f}",
         ]
         text = "\n".join(lines)
         text = kwargs.get("text", text)
@@ -260,7 +206,55 @@ class EOSBase(metaclass=ABCMeta):
 
         ax.plot(vfit, self.func(vfit), linestyle="dashed", color=color, label=label)
 
-        ax.grid(True)
+        ax.grid(visible=True)
+        ax.set_xlabel("Volume $\\AA^3$")
+        ax.set_ylabel("Energy (eV)")
+        ax.legend(loc="best", shadow=True)
+        # Add text with fit parameters.
+        ax.text(0.4, 0.5, text, transform=ax.transAxes)
+
+        return ax
+
+    @add_fig_kwargs
+    def plot_ax(self, ax: plt.Axes = None, fontsize=12, **kwargs):
+        """
+        Plot the equation of state on axis `ax`.
+
+        Args:
+            ax: matplotlib Axes or None if a new figure should be created.
+            fontsize: Legend fontsize.
+            color (str): plot color.
+            label (str): Plot label
+            text (str): Legend text (options)
+
+        Returns:
+            plt.Figure: matplotlib figure.
+        """
+        ax, fig = get_ax_fig(ax=ax)
+
+        color = kwargs.get("color", "r")
+        label = kwargs.get("label", f"{type(self).__name__} fit")
+        lines = [
+            f"Equation of State: {type(self).__name__}",
+            f"Minimum energy = {self.e0:1.2f} eV",
+            f"Minimum or reference volume = {self.v0:1.2f} Ang^3",
+            f"Bulk modulus = {self.b0:1.2f} eV/Ang^3 = {self.b0_GPa:1.2f} GPa",
+            f"Derivative of bulk modulus w.r.t. pressure = {self.b1:1.2f}",
+        ]
+        text = "\n".join(lines)
+        text = kwargs.get("text", text)
+
+        # Plot input data.
+        ax.plot(self.volumes, self.energies, linestyle="None", marker="o", color=color)
+
+        # Plot eos fit.
+        vmin, vmax = min(self.volumes), max(self.volumes)
+        vmin, vmax = (vmin - 0.01 * abs(vmin), vmax + 0.01 * abs(vmax))
+        vfit = np.linspace(vmin, vmax, 100)
+
+        ax.plot(vfit, self.func(vfit), linestyle="dashed", color=color, label=label)
+
+        ax.grid(visible=True)
         ax.set_xlabel("Volume $\\AA^3$")
         ax.set_ylabel("Energy (eV)")
         ax.legend(loc="best", shadow=True)
@@ -279,29 +273,23 @@ class EOSBase(metaclass=ABCMeta):
 
 
 class Murnaghan(EOSBase):
-    """
-    Murnaghan EOS.
-    """
+    """Murnaghan EOS."""
 
     def _func(self, volume, params):
-        """
-        From PRB 28,5480 (1983)
-        """
+        """From PRB 28,5480 (1983)."""
         e0, b0, b1, v0 = tuple(params)
         return e0 + b0 * volume / b1 * (((v0 / volume) ** b1) / (b1 - 1.0) + 1.0) - v0 * b0 / (b1 - 1.0)
 
 
 class Birch(EOSBase):
-    """
-    Birch EOS.
-    """
+    """Birch EOS."""
 
     def _func(self, volume, params):
         """
         From Intermetallic compounds: Principles and Practice, Vol. I:
         Principles Chapter 9 pages 195-210 by M. Mehl. B. Klein,
         D. Papaconstantopoulos.
-        case where n=0
+        case where n=0.
         """
         e0, b0, b1, v0 = tuple(params)
         return (
@@ -312,28 +300,20 @@ class Birch(EOSBase):
 
 
 class BirchMurnaghan(EOSBase):
-    """
-    BirchMurnaghan EOS
-    """
+    """BirchMurnaghan EOS."""
 
     def _func(self, volume, params):
-        """
-        BirchMurnaghan equation from PRB 70, 224107
-        """
+        """BirchMurnaghan equation from PRB 70, 224107."""
         e0, b0, b1, v0 = tuple(params)
         eta = (v0 / volume) ** (1 / 3)
         return e0 + 9 * b0 * v0 / 16 * (eta**2 - 1) ** 2 * (6 + b1 * (eta**2 - 1.0) - 4 * eta**2)
 
 
 class PourierTarantola(EOSBase):
-    """
-    PourierTarantola EOS
-    """
+    """PourierTarantola EOS."""
 
     def _func(self, volume, params):
-        """
-        Pourier-Tarantola equation from PRB 70, 224107
-        """
+        """Pourier-Tarantola equation from PRB 70, 224107."""
         e0, b0, b1, v0 = tuple(params)
         eta = (volume / v0) ** (1 / 3)
         squiggle = -3 * np.log(eta)
@@ -341,14 +321,10 @@ class PourierTarantola(EOSBase):
 
 
 class Vinet(EOSBase):
-    """
-    Vinet EOS.
-    """
+    """Vinet EOS."""
 
     def _func(self, volume, params):
-        """
-        Vinet equation from PRB 70, 224107
-        """
+        """Vinet equation from PRB 70, 224107."""
         e0, b0, b1, v0 = tuple(params)
         eta = (volume / v0) ** (1 / 3)
         return e0 + 2 * b0 * v0 / (b1 - 1.0) ** 2 * (
@@ -370,7 +346,7 @@ class PolynomialEOS(EOSBase):
         Do polynomial fitting and set the parameters. Uses numpy polyfit.
 
         Args:
-             order (int): order of the fit polynomial
+            order (int): order of the fit polynomial
         """
         self.eos_params = np.polyfit(self.volumes, self.energies, order)
         self._set_params()
@@ -381,8 +357,7 @@ class PolynomialEOS(EOSBase):
         and set to the _params attribute.
         """
         fit_poly = np.poly1d(self.eos_params)
-        # the volume at min energy, used as the initial guess for the
-        # optimization wrt volume.
+        # the volume at min energy, used as the initial guess for the optimization w.r.t. volume.
         v_e_min = self.volumes[np.argmin(self.energies)]
         # evaluate e0, v0, b0 and b1
         min_wrt_v = minimize(fit_poly, v_e_min)
@@ -397,18 +372,14 @@ class PolynomialEOS(EOSBase):
 
 
 class DeltaFactor(PolynomialEOS):
-    """
-    Fitting a polynomial EOS using delta factor.
-    """
+    """Fitting a polynomial EOS using delta factor."""
 
     def _func(self, volume, params):
         x = volume ** (-2 / 3.0)
         return np.poly1d(list(params))(x)
 
     def fit(self, order=3):
-        """
-        Overridden since this eos works with volume**(2/3) instead of volume.
-        """
+        """Overridden since this eos works with volume**(2/3) instead of volume."""
         x = self.volumes ** (-2 / 3.0)
         self.eos_params = np.polyfit(x, self.energies, order)
         self._set_params()
@@ -440,9 +411,7 @@ class DeltaFactor(PolynomialEOS):
 
 
 class NumericalEOS(PolynomialEOS):
-    """
-    A numerical EOS.
-    """
+    """A numerical EOS."""
 
     def fit(self, min_ndata_factor=3, max_poly_order_factor=5, min_poly_order=2):
         """
@@ -455,12 +424,11 @@ class NumericalEOS(PolynomialEOS):
         Args:
             min_ndata_factor (int): parameter that controls the minimum number
                 of data points that will be used for fitting.
-                minimum number of data points =
-                    total data points-2*min_ndata_factor
+                minimum number of data points = total data points-2*min_ndata_factor
             max_poly_order_factor (int): parameter that limits the max order
                 of the polynomial used for fitting.
                 max_poly_order = number of data points used for fitting -
-                                 max_poly_order_factor
+                max_poly_order_factor
             min_poly_order (int): minimum order of the polynomial to be
                 considered for fitting.
         """
@@ -489,11 +457,11 @@ class NumericalEOS(PolynomialEOS):
         # sort by volume
         e_v = sorted(e_v, key=lambda x: x[1])
         # index of minimum energy tuple in the volume sorted list
-        emin_idx = e_v.index(e_min)
+        e_min_idx = e_v.index(e_min)
         # the volume lower than the volume corresponding to minimum energy
-        v_before = e_v[emin_idx - 1][1]
+        v_before = e_v[e_min_idx - 1][1]
         # the volume higher than the volume corresponding to minimum energy
-        v_after = e_v[emin_idx + 1][1]
+        v_after = e_v[e_min_idx + 1][1]
         e_v_work = deepcopy(e_v)
 
         # loop over the data points.
@@ -502,18 +470,18 @@ class NumericalEOS(PolynomialEOS):
             e = [ei[0] for ei in e_v_work]
             v = [ei[1] for ei in e_v_work]
             # loop over polynomial order
-            for i in range(min_poly_order, max_poly_order + 1):
-                coeffs = np.polyfit(v, e, i)
+            for idx in range(min_poly_order, max_poly_order + 1):
+                coeffs = np.polyfit(v, e, idx)
                 pder = np.polyder(coeffs)
                 a = np.poly1d(pder)(v_before)
                 b = np.poly1d(pder)(v_after)
                 if a * b < 0:
                     rms = get_rms(e, np.poly1d(coeffs)(v))
-                    rms_min = min(rms_min, rms * i / ndata_fit)
-                    all_coeffs[(i, ndata_fit)] = [coeffs.tolist(), rms]
+                    rms_min = min(rms_min, rms * idx / ndata_fit)
+                    all_coeffs[(idx, ndata_fit)] = [coeffs.tolist(), rms]
                     # store the fit coefficients small to large,
                     # i.e a0, a1, .. an
-                    all_coeffs[(i, ndata_fit)][0].reverse()
+                    all_coeffs[(idx, ndata_fit)][0].reverse()
             # remove 1 data point from each end.
             e_v_work.pop()
             e_v_work.pop(0)
@@ -578,15 +546,15 @@ class EOS:
        eos_fit.plot()
     """
 
-    MODELS = {
-        "murnaghan": Murnaghan,
-        "birch": Birch,
-        "birch_murnaghan": BirchMurnaghan,
-        "pourier_tarantola": PourierTarantola,
-        "vinet": Vinet,
-        "deltafactor": DeltaFactor,
-        "numerical_eos": NumericalEOS,
-    }
+    MODELS = dict(
+        murnaghan=Murnaghan,
+        birch=Birch,
+        birch_murnaghan=BirchMurnaghan,
+        pourier_tarantola=PourierTarantola,
+        vinet=Vinet,
+        deltafactor=DeltaFactor,
+        numerical_eos=NumericalEOS,
+    )
 
     def __init__(self, eos_name="murnaghan"):
         """
@@ -618,6 +586,4 @@ class EOS:
 
 
 class EOSError(Exception):
-    """
-    Error class for EOS fitting.
-    """
+    """Error class for EOS fitting."""
