@@ -1,6 +1,4 @@
-"""
-Perform fragmentation of molecules.
-"""
+"""Perform fragmentation of molecules."""
 
 from __future__ import annotations
 
@@ -25,9 +23,7 @@ logger = logging.getLogger(__name__)
 
 
 class Fragmenter(MSONable):
-    """
-    Molecule fragmenter class.
-    """
+    """Molecule fragmenter class."""
 
     def __init__(
         self,
@@ -41,7 +37,7 @@ class Fragmenter(MSONable):
         assume_previous_thoroughness=True,
     ):
         """
-        Standard constructor for molecule fragmentation
+        Standard constructor for molecule fragmentation.
 
         Args:
             molecule (Molecule): The molecule to fragment.
@@ -109,12 +105,9 @@ class Fragmenter(MSONable):
             for level in range(depth):
                 # If on the first level, perform one level of fragmentation on the principle molecule graph:
                 if level == 0:
+                    alph_formula = self.mol_graph.molecule.composition.alphabetical_formula
                     self.fragments_by_level["0"] = self._fragment_one_level(
-                        {
-                            str(self.mol_graph.molecule.composition.alphabetical_formula)
-                            + " E"
-                            + str(len(self.mol_graph.graph.edges())): [self.mol_graph]
-                        }
+                        {f"{alph_formula} E{len(self.mol_graph.graph.edges())}": [self.mol_graph]}
                     )
                 else:
                     num_frags_prev_level = 0
@@ -158,8 +151,7 @@ class Fragmenter(MSONable):
             self.unique_frag_dict = copy.deepcopy(self.prev_unique_frag_dict)
             for frag_key in self.new_unique_frag_dict:
                 if frag_key in self.unique_frag_dict:
-                    for new_frag in self.new_unique_frag_dict[frag_key]:
-                        self.unique_frag_dict[frag_key].append(new_frag)
+                    self.unique_frag_dict[frag_key] += [*self.new_unique_frag_dict[frag_key]]
                 else:
                     self.unique_frag_dict[frag_key] = copy.deepcopy(self.new_unique_frag_dict[frag_key])
 
@@ -188,11 +180,8 @@ class Fragmenter(MSONable):
                         if self.open_rings:
                             fragments = [open_ring(old_frag, bond, self.opt_steps)]
                     for fragment in fragments:
-                        new_frag_key = (
-                            str(fragment.molecule.composition.alphabetical_formula)
-                            + " E"
-                            + str(len(fragment.graph.edges()))
-                        )
+                        alph_formula = fragment.molecule.composition.alphabetical_formula
+                        new_frag_key = f"{alph_formula} E{len(fragment.graph.edges())}"
                         proceed = True
                         if (
                             self.assume_previous_thoroughness
@@ -229,11 +218,8 @@ class Fragmenter(MSONable):
         we find. We also temporarily add the principle molecule graph to self.unique_fragments
         so that its rings are opened as well.
         """
-        mol_key = (
-            str(self.mol_graph.molecule.composition.alphabetical_formula)
-            + " E"
-            + str(len(self.mol_graph.graph.edges()))
-        )
+        alph_formula = self.mol_graph.molecule.composition.alphabetical_formula
+        mol_key = f"{alph_formula} E{len(self.mol_graph.graph.edges())}"
         self.all_unique_frag_dict[mol_key] = [self.mol_graph]
         new_frag_keys = {"0": []}
         new_frag_key_dict = {}
@@ -243,11 +229,8 @@ class Fragmenter(MSONable):
                 if ring_edges != []:
                     for bond in ring_edges[0]:
                         new_fragment = open_ring(fragment, [bond], self.opt_steps)
-                        frag_key = (
-                            str(new_fragment.molecule.composition.alphabetical_formula)
-                            + " E"
-                            + str(len(new_fragment.graph.edges()))
-                        )
+                        alph_formula = new_fragment.molecule.composition.alphabetical_formula
+                        frag_key = f"{alph_formula} E{len(new_fragment.graph.edges())}"
                         if frag_key not in self.all_unique_frag_dict:
                             if frag_key not in new_frag_keys["0"]:
                                 new_frag_keys["0"].append(copy.deepcopy(frag_key))
@@ -281,11 +264,8 @@ class Fragmenter(MSONable):
                     if ring_edges != []:
                         for bond in ring_edges[0]:
                             new_fragment = open_ring(fragment, [bond], self.opt_steps)
-                            frag_key = (
-                                str(new_fragment.molecule.composition.alphabetical_formula)
-                                + " E"
-                                + str(len(new_fragment.graph.edges()))
-                            )
+                            alph_formula = new_fragment.molecule.composition.alphabetical_formula
+                            frag_key = f"{alph_formula} E{len(new_fragment.graph.edges())}"
                             if frag_key not in self.all_unique_frag_dict:
                                 if frag_key not in new_frag_keys[str(idx)]:
                                     new_frag_keys[str(idx)].append(copy.deepcopy(frag_key))
@@ -319,7 +299,7 @@ def open_ring(mol_graph, bond, opt_steps):
     self.steps, and then convert the resulting structure back into a molecule graph
     to be returned.
     """
-    obmol = BabelMolAdaptor.from_molecule_graph(mol_graph)
-    obmol.remove_bond(bond[0][0] + 1, bond[0][1] + 1)
-    obmol.localopt(steps=opt_steps, forcefield="uff")
-    return MoleculeGraph.with_local_env_strategy(obmol.pymatgen_mol, OpenBabelNN())
+    ob_mol = BabelMolAdaptor.from_molecule_graph(mol_graph)
+    ob_mol.remove_bond(bond[0][0] + 1, bond[0][1] + 1)
+    ob_mol.localopt(steps=opt_steps, forcefield="uff")
+    return MoleculeGraph.with_local_env_strategy(ob_mol.pymatgen_mol, OpenBabelNN())
