@@ -1,6 +1,4 @@
-"""
-This module provides classes to store, generate, and manipulate material interfaces.
-"""
+"""This module provides classes to store, generate, and manipulate material interfaces."""
 
 from __future__ import annotations
 
