@@ -1,6 +1,4 @@
-"""
-JahnTeller distortion analysis.
-"""
+"""JahnTeller distortion analysis."""
 
 from __future__ import annotations
 
@@ -12,7 +10,7 @@ import numpy as np
 
 from pymatgen.analysis.bond_valence import BVAnalyzer
 from pymatgen.analysis.local_env import LocalStructOrderParams, get_neighbors_of_site_with_index
-from pymatgen.core.periodic_table import Species, get_el_sp
+from pymatgen.core import Species, get_el_sp
 from pymatgen.symmetry.analyzer import SpacegroupAnalyzer
 
 if TYPE_CHECKING:
@@ -32,9 +30,7 @@ class JahnTellerAnalyzer:
     """
 
     def __init__(self):
-        """
-        Init for JahnTellerAnalyzer.
-        """
+        """Init for JahnTellerAnalyzer."""
         self.spin_configs = {
             "oct": {  # key is number of d electrons
                 0: {"high": {"e_g": 0, "t_2g": 0}, "default": "high"},
@@ -162,9 +158,7 @@ class JahnTellerAnalyzer:
                         ligand_bond_length_spread = max(ligand_bond_lengths) - min(ligand_bond_lengths)
 
                         def trim(f):
-                            """
-                            Avoid storing to unreasonable precision, hurts readability.
-                            """
+                            """Avoid storing to unreasonable precision, hurts readability."""
                             return float(f"{f:.4f}")
 
                         # to be Jahn-Teller active, all ligands have to be the same
@@ -197,7 +191,7 @@ class JahnTellerAnalyzer:
                         {
                             "site_indices": indices,
                             "strength": "none",
-                            "reason": f"motif is {motif}",
+                            "reason": f"{motif=}",
                         }
                     )
 
@@ -342,9 +336,10 @@ class JahnTellerAnalyzer:
         Get number of d electrons of a species.
 
         Args:
-          species: Species object
+            species: Species object
 
-        Returns: Number of d electrons.
+        Returns:
+            int: Number of d electrons.
         """
         # TODO: replace with more generic Hund's rule algorithm?
 
@@ -352,22 +347,23 @@ class JahnTellerAnalyzer:
         elec = species.full_electronic_structure
         if len(elec) < 4 or elec[-1][1] != "s" or elec[-2][1] != "d":
             raise AttributeError(f"Invalid element {species.symbol} for crystal field calculation.")
-        nelectrons = int(elec[-1][2] + elec[-2][2] - species.oxi_state)
-        if nelectrons < 0 or nelectrons > 10:
+        n_electrons = int(elec[-1][2] + elec[-2][2] - species.oxi_state)
+        if n_electrons < 0 or n_electrons > 10:
             raise AttributeError(f"Invalid oxidation state {species.oxi_state} for element {species.symbol}")
 
-        return nelectrons
+        return n_electrons
 
     def get_magnitude_of_effect_from_species(self, species: str | Species, spin_state: str, motif: str) -> str:
         """
         Get magnitude of Jahn-Teller effect from provided species, spin state and motif.
 
         Args:
-          species: e.g. Fe2+
-          spin_state: "high" or "low"
-          motif: "oct" or "tet"
+            species: e.g. Fe2+
+            spin_state: "high" or "low"
+            motif: "oct" or "tet"
 
-        Returns: "none", "weak" or "strong
+        Returns:
+            str: "none", "weak" or "strong"
         """
         magnitude = "none"
 
@@ -394,14 +390,14 @@ class JahnTellerAnalyzer:
         * in octahedral environments, strong if e_g orbitals
         unevenly occupied but weak if t_2g orbitals unevenly
         occupied
-        * in tetrahedral environments always weaker
+        * in tetrahedral environments always weaker.
 
         Args:
-          motif: "oct" or "tet"
-          spin_config: dict of 'e' (e_g) and 't' (t2_g)
-            with number of electrons in each state
+            motif: "oct" or "tet"
+            spin_config: dict of 'e' (e_g) and 't' (t2_g) with number of electrons in each state
 
-        Returns:  "none", "weak" or "strong"
+        Returns:
+            str: "none", "weak" or "strong"
         """
         magnitude = "none"
         if motif == "oct":
