@@ -1,23 +1,24 @@
-"""
-This module provides classes to perform fitting of structures.
-"""
+"""This module provides classes to perform fitting of structures."""
+
 from __future__ import annotations
 
 import abc
 import itertools
-from typing import Literal, Mapping, Sequence
+from typing import TYPE_CHECKING, Literal
 
 import numpy as np
 from monty.json import MSONable
 
-from pymatgen.core.composition import Composition, SpeciesLike
-from pymatgen.core.lattice import Lattice
-from pymatgen.core.periodic_table import get_el_sp
-from pymatgen.core.structure import Structure
+from pymatgen.core import Composition, Lattice, Structure, get_el_sp
 from pymatgen.optimization.linear_assignment import LinearAssignment
 from pymatgen.util.coord import lattice_points_in_supercell
 from pymatgen.util.coord_cython import is_coord_subset_pbc, pbc_shortest_vectors
 
+if TYPE_CHECKING:
+    from collections.abc import Mapping, Sequence
+
+    from pymatgen.util.typing import SpeciesLike
+
 __author__ = "William Davidson Richards, Stephen Dacek, Shyue Ping Ong"
 __copyright__ = "Copyright 2011, The Materials Project"
 __version__ = "1.0"
@@ -77,11 +78,13 @@ class AbstractComparator(MSONable, metaclass=abc.ABCMeta):
     def from_dict(cls, d):
         """
         :param d: Dict representation
-        :return: Comparator.
+
+        Returns:
+            Comparator.
         """
         for trans_modules in ["structure_matcher"]:
             mod = __import__(
-                "pymatgen.analysis." + trans_modules,
+                f"pymatgen.analysis.{trans_modules}",
                 globals(),
                 locals(),
                 [d["@class"]],
@@ -93,9 +96,7 @@ class AbstractComparator(MSONable, metaclass=abc.ABCMeta):
         raise ValueError("Invalid Comparator dict")
 
     def as_dict(self):
-        """
-        :return: MSONable dict
-        """
+        """MSONable dict"""
         return {
             "version": __version__,
             "@module": type(self).__module__,
@@ -104,9 +105,7 @@ class AbstractComparator(MSONable, metaclass=abc.ABCMeta):
 
 
 class SpeciesComparator(AbstractComparator):
-    """
-    A Comparator that matches species exactly. The default used in StructureMatcher.
-    """
+    """A Comparator that matches species exactly. The default used in StructureMatcher."""
 
     def are_equal(self, sp1, sp2) -> bool:
         """
@@ -123,10 +122,8 @@ class SpeciesComparator(AbstractComparator):
         """
         return sp1 == sp2
 
-    def get_hash(self, composition):
-        """
-        Returns: Fractional composition
-        """
+    def get_hash(self, composition: Composition):
+        """Returns: Fractional composition."""
         return composition.fractional_composition
 
 
@@ -153,10 +150,10 @@ class SpinComparator(AbstractComparator):
             Boolean indicating whether species are equal.
         """
         for s1 in sp1:
-            spin1 = getattr(s1, "spin", 0)
+            spin1 = getattr(s1, "spin", 0) or 0
             oxi1 = getattr(s1, "oxi_state", 0)
             for s2 in sp2:
-                spin2 = getattr(s2, "spin", 0)
+                spin2 = getattr(s2, "spin", 0) or 0
                 oxi2 = getattr(s2, "oxi_state", 0)
                 if s1.symbol == s2.symbol and oxi1 == oxi2 and spin2 == -spin1:
                     break
@@ -165,9 +162,7 @@ class SpinComparator(AbstractComparator):
         return True
 
     def get_hash(self, composition):
-        """
-        Returns: Fractional composition
-        """
+        """Returns: Fractional composition."""
         return composition.fractional_composition
 
 
@@ -197,20 +192,15 @@ class ElementComparator(AbstractComparator):
         return comp1.get_el_amt_dict() == comp2.get_el_amt_dict()
 
     def get_hash(self, composition):
-        """
-        Returns: Fractional element composition
-        """
+        """Returns: Fractional element composition."""
         return composition.element_composition.fractional_composition
 
 
 class FrameworkComparator(AbstractComparator):
-    """
-    A Comparator that matches sites, regardless of species.
-    """
+    """A Comparator that matches sites, regardless of species."""
 
     def are_equal(self, sp1, sp2) -> bool:
-        """
-        True if there are atoms on both sites.
+        """True if there are atoms on both sites.
 
         Args:
             sp1: First species. A dict of {specie/element: amt} as per the
@@ -224,21 +214,19 @@ class FrameworkComparator(AbstractComparator):
         return True
 
     def get_hash(self, composition):
-        """
-        No hash possible
-        """
+        """No hash possible."""
         return 1
 
 
 class OrderDisorderElementComparator(AbstractComparator):
     """
     A Comparator that matches sites, given some overlap in the element
-    composition
+    composition.
     """
 
     def are_equal(self, sp1, sp2) -> bool:
         """
-        True if there is some overlap in composition between the species
+        True if there is some overlap in composition between the species.
 
         Args:
             sp1: First species. A dict of {specie/element: amt} as per the
@@ -254,9 +242,7 @@ class OrderDisorderElementComparator(AbstractComparator):
         return set1.issubset(set2) or set2.issubset(set1)
 
     def get_hash(self, composition):
-        """
-        Returns: Fractional composition
-        """
+        """Returns: Fractional composition."""
         return composition.fractional_composition
 
 
@@ -275,14 +261,16 @@ class OccupancyComparator(AbstractComparator):
                 definition in Site and PeriodicSite.
 
         Returns:
-            True if sets of occupancies (amt) are equal on both sites.
+            bool: True if sets of occupancies (amt) are equal on both sites.
         """
         return set(sp1.element_composition.values()) == set(sp2.element_composition.values())
 
     def get_hash(self, composition):
         """
         :param composition: Composition.
-        :return: 1. Difficult to define sensible hash
+
+        Returns:
+            1. Difficult to define sensible hash
         """
         return 1
 
@@ -404,7 +392,7 @@ class StructureMatcher(MSONable):
         If fu == 1, s1_supercell is returned as true, to avoid ambiguity.
         """
         if self._supercell_size == "num_sites":
-            fu = s2.num_sites / s1.num_sites
+            fu = len(s2) / len(s1)
         elif self._supercell_size == "num_atoms":
             fu = s2.composition.num_atoms / s1.composition.num_atoms
         elif self._supercell_size == "volume":
@@ -432,7 +420,7 @@ class StructureMatcher(MSONable):
         """
         Yields lattices for s with lengths and angles close to the lattice of target_s. If
         supercell_size is specified, the returned lattice will have that number of primitive
-        cells in it
+        cells in it.
 
         Args:
             target_lattice (Lattice): target lattice.
@@ -454,7 +442,7 @@ class StructureMatcher(MSONable):
         Computes all supercells of one structure close to the lattice of the
         other
         if s1_supercell is True, it makes the supercells of struct1, otherwise
-        it makes them of s2
+        it makes them of s2.
 
         yields: s1, s2, supercell_matrix, average_lattice, supercell_matrix
         """
@@ -492,10 +480,10 @@ class StructureMatcher(MSONable):
     def _cmp_fstruct(cls, s1, s2, frac_tol, mask):
         """
         Returns true if a matching exists between s2 and s2
-        under frac_tol. s2 should be a subset of s1
+        under frac_tol. s2 should be a subset of s1.
         """
         if len(s2) > len(s1):
-            raise ValueError("s1 must be larger than s2")
+            raise ValueError(f"{len(s1)=} must be larger than {len(s2)=}")
         if mask.shape != (len(s2), len(s1)):
             raise ValueError("mask has incorrect shape")
 
@@ -505,7 +493,7 @@ class StructureMatcher(MSONable):
     def _cart_dists(cls, s1, s2, avg_lattice, mask, normalization, lll_frac_tol=None):
         """
         Finds a matching in Cartesian space. Finds an additional
-        fractional translation vector to minimize RMS distance
+        fractional translation vector to minimize RMS distance.
 
         Args:
             s1: numpy array of fractional coordinates.
@@ -522,42 +510,42 @@ class StructureMatcher(MSONable):
             Mapping from s1 to s2, i.e. with numpy slicing, s1[mapping] => s2
         """
         if len(s2) > len(s1):
-            raise ValueError("s1 must be larger than s2")
+            raise ValueError(f"{len(s1)=} must be larger than {len(s2)=}")
         if mask.shape != (len(s2), len(s1)):
             raise ValueError("mask has incorrect shape")
 
         # vectors are from s2 to s1
         vecs, d_2 = pbc_shortest_vectors(avg_lattice, s2, s1, mask, return_d2=True, lll_frac_tol=lll_frac_tol)
         lin = LinearAssignment(d_2)
-        s = lin.solution  # pylint: disable=E1101
-        short_vecs = vecs[np.arange(len(s)), s]
+        sol = lin.solution
+        short_vecs = vecs[np.arange(len(sol)), sol]
         translation = np.average(short_vecs, axis=0)
         f_translation = avg_lattice.get_fractional_coords(translation)
         new_d2 = np.sum((short_vecs - translation) ** 2, axis=-1)
 
-        return new_d2**0.5 * normalization, f_translation, s
+        return new_d2**0.5 * normalization, f_translation, sol
 
     def _get_mask(self, struct1, struct2, fu, s1_supercell):
         """
         Returns mask for matching struct2 to struct1. If struct1 has sites
         a b c, and fu = 2, assumes supercells of struct2 will be ordered
-        aabbcc (rather than abcabc)
+        aabbcc (rather than abcabc).
 
         Returns:
-        mask, struct1 translation indices, struct2 translation index
+            mask, struct1 translation indices, struct2 translation index
         """
         mask = np.zeros((len(struct2), len(struct1), fu), dtype=bool)
 
         inner = []
-        for sp2, i in itertools.groupby(enumerate(struct2.species_and_occu), key=lambda x: x[1]):
-            i = list(i)
-            inner.append((sp2, slice(i[0][0], i[-1][0] + 1)))
+        for sp2, group_1 in itertools.groupby(enumerate(struct2.species_and_occu), key=lambda x: x[1]):
+            group_1 = list(group_1)
+            inner.append((sp2, slice(group_1[0][0], group_1[-1][0] + 1)))
 
-        for sp1, j in itertools.groupby(enumerate(struct1.species_and_occu), key=lambda x: x[1]):
-            j = list(j)
-            j = slice(j[0][0], j[-1][0] + 1)
-            for sp2, i in inner:
-                mask[i, j, :] = not self._comparator.are_equal(sp1, sp2)
+        for sp1, group_2 in itertools.groupby(enumerate(struct1.species_and_occu), key=lambda x: x[1]):
+            group_2 = list(group_2)
+            group_2 = slice(group_2[0][0], group_2[-1][0] + 1)
+            for sp2, group_1 in inner:
+                mask[group_1, group_2, :] = not self._comparator.are_equal(sp1, sp2)
 
         if s1_supercell:
             mask = mask.reshape((len(struct2), -1))
@@ -568,12 +556,12 @@ class StructureMatcher(MSONable):
             mask = mask.reshape((-1, len(struct1)))
 
         # find the best translation indices
-        i = np.argmax(np.sum(mask, axis=-1))
-        inds = np.where(np.invert(mask[i]))[0]
+        idx = np.argmax(np.sum(mask, axis=-1))
+        inds = np.where(np.invert(mask[idx]))[0]
         if s1_supercell:
             # remove the symmetrically equivalent s1 indices
             inds = inds[::fu]
-        return np.array(mask, dtype=int), inds, i
+        return np.array(mask, dtype=int), inds, idx
 
     def fit(
         self, struct1: Structure, struct2: Structure, symmetric: bool = False, skip_structure_reduction: bool = False
@@ -626,7 +614,7 @@ class StructureMatcher(MSONable):
 
     def get_rms_dist(self, struct1, struct2):
         """
-        Calculate RMS displacement between two structures
+        Calculate RMS displacement between two structures.
 
         Args:
             struct1 (Structure): 1st structure
@@ -698,9 +686,7 @@ class StructureMatcher(MSONable):
         use_rms=False,
         break_on_match=False,
     ) -> tuple[float, float, np.ndarray, float, Mapping] | None:
-        """
-        Matches one struct onto the other
-        """
+        """Matches one struct onto the other."""
         ratio = fu if s1_supercell else 1 / fu
         if len(struct1) * ratio >= len(struct2):
             return self._strict_match(
@@ -757,7 +743,7 @@ class StructureMatcher(MSONable):
         if (not self._subset) and mask.shape[1] != mask.shape[0]:
             return None
 
-        if LinearAssignment(mask).min_cost > 0:  # pylint: disable=E1101
+        if LinearAssignment(mask).min_cost > 0:
             return None
 
         best_match = None
@@ -776,7 +762,7 @@ class StructureMatcher(MSONable):
                     lll_frac_tol = inv_lll_abc * self.stol / (np.pi * normalization)
                     dist, t_adj, mapping = self._cart_dists(s1fc, t_s2fc, avg_l, mask, normalization, lll_frac_tol)
                     val = np.linalg.norm(dist) / len(dist) ** 0.5 if use_rms else max(dist)
-                    # pylint: disable=E1136
+
                     if best_match is None or val < best_match[0]:
                         total_t = t + t_adj
                         total_t -= np.round(total_t)
@@ -850,9 +836,7 @@ class StructureMatcher(MSONable):
         return all_groups
 
     def as_dict(self):
-        """
-        :return: MSONable dict
-        """
+        """MSONable dict"""
         return {
             "version": __version__,
             "@module": type(self).__module__,
@@ -873,7 +857,9 @@ class StructureMatcher(MSONable):
     def from_dict(cls, d):
         """
         :param d: Dict representation
-        :return: StructureMatcher
+
+        Returns:
+            StructureMatcher
         """
         return cls(
             ltol=d["ltol"],
@@ -917,8 +903,8 @@ class StructureMatcher(MSONable):
             raise ValueError("Anonymous fitting currently requires SpeciesComparator")
 
         # check that species lists are comparable
-        sp1 = struct1.composition.elements
-        sp2 = struct2.composition.elements
+        sp1 = struct1.elements
+        sp2 = struct2.elements
         if len(sp1) != len(sp2):
             return None
 
@@ -937,7 +923,7 @@ class StructureMatcher(MSONable):
                 continue
 
             mapped_struct = struct1.copy()
-            mapped_struct.replace_species(sp_mapping)
+            mapped_struct.replace_species(sp_mapping)  # type: ignore[arg-type]
             if swapped:
                 m = self._strict_match(
                     struct2,
@@ -957,9 +943,7 @@ class StructureMatcher(MSONable):
 
     @classmethod
     def _get_reduced_structure(cls, struct: Structure, primitive_cell: bool = True, niggli: bool = True) -> Structure:
-        """
-        Helper method to find a reduced structure
-        """
+        """Helper method to find a reduced structure."""
         reduced = struct.copy()
         if niggli:
             reduced = reduced.get_reduced_structure(reduction_algo="niggli")
@@ -1031,7 +1015,7 @@ class StructureMatcher(MSONable):
         """
         Performs an anonymous fitting, which allows distinct species in one
         structure to map to another. Returns a dictionary of species
-        substitutions that are within tolerance
+        substitutions that are within tolerance.
 
         Args:
             struct1 (Structure): 1st structure
@@ -1069,7 +1053,7 @@ class StructureMatcher(MSONable):
                 If True, skip to get a primitive structure and perform Niggli reduction for struct1 and struct2
 
         Returns:
-            True/False: Whether a species mapping can map struct1 to stuct2
+            bool: Whether a species mapping can map struct1 to struct2
         """
         struct1, struct2 = self._process_species([struct1, struct2])
         struct1, struct2, fu, s1_supercell = self._preprocess(struct1, struct2, niggli, skip_structure_reduction)
@@ -1082,7 +1066,7 @@ class StructureMatcher(MSONable):
         """
         Returns the matrix for transforming struct to supercell. This
         can be used for very distorted 'supercells' where the primitive cell
-        is impossible to find
+        is impossible to find.
         """
         if self._primitive_cell:
             raise ValueError("get_supercell_matrix cannot be used with the primitive cell option")
@@ -1108,9 +1092,9 @@ class StructureMatcher(MSONable):
             struct2 (Structure): Structure to transform.
 
         Returns:
-            supercell (numpy.ndarray(3, 3)): supercell matrix
-            vector (numpy.ndarray(3)): fractional translation vector
-            mapping (list(int or None)):
+            supercell (np.array(3, 3)): supercell matrix
+            vector (np.array(3)): fractional translation vector
+            mapping (list[int | None]):
                 The first len(struct1) items of the mapping vector are the
                 indices of struct1's corresponding sites in struct2 (or None
                 if there is no corresponding site), and the other items are
@@ -1148,7 +1132,7 @@ class StructureMatcher(MSONable):
     def get_s2_like_s1(self, struct1, struct2, include_ignored_species=True):
         """
         Performs transformations on struct2 to put it in a basis similar to
-        struct1 (without changing any of the inter-site distances)
+        struct1 (without changing any of the inter-site distances).
 
         Args:
             struct1 (Structure): Reference structure
