@@ -21,8 +21,10 @@ import logging
 import warnings
 from typing import TYPE_CHECKING
 
+import matplotlib as mpl
+import matplotlib.pyplot as plt
 import numpy as np
-import plotly.graph_objs as go
+import plotly.graph_objects as go
 from scipy.spatial import ConvexHull
 
 from pymatgen.core.structure import Structure
@@ -44,19 +46,13 @@ logger = logging.getLogger(__name__)
 
 def hkl_tuple_to_str(hkl):
     """
-    Prepare for display on plots
-    "(hkl)" for surfaces
-    Agrs:
-        hkl: in the form of [h, k, l] or (h, k, l)
+    Prepare for display on plots "(hkl)" for surfaces
+
+    Args:
+        hkl: in the form of [h, k, l] or (h, k, l).
     """
-    str_format = "($"
-    for x in hkl:
-        if x < 0:
-            str_format += "\\overline{" + str(-x) + "}"
-        else:
-            str_format += str(x)
-    str_format += "$)"
-    return str_format
+    out = "".join(f"\\overline{{{-x}}}" if x < 0 else str(x) for x in hkl)
+    return f"(${out}$)"
 
 
 def get_tri_area(pts):
@@ -67,17 +63,14 @@ def get_tri_area(pts):
     Args:
         pts: [a, b, c] three points
     """
-    a, b, c = pts[0], pts[1], pts[2]
+    a, b, c = pts
     v1 = np.array(b) - np.array(a)
     v2 = np.array(c) - np.array(a)
-    area_tri = abs(np.linalg.norm(np.cross(v1, v2)) / 2)
-    return area_tri
+    return abs(np.linalg.norm(np.cross(v1, v2)) / 2)
 
 
 class WulffFacet:
-    """
-    Helper container for each Wulff plane.
-    """
+    """Helper container for each Wulff plane."""
 
     def __init__(self, normal, e_surf, normal_pt, dual_pt, index, m_ind_orig, miller):
         """
@@ -111,61 +104,30 @@ class WulffShape:
     http://scipy.github.io/devdocs/generated/scipy.spatial.ConvexHull.html
 
     Process:
-        1. get wulff simplices
+        1. get Wulff simplices
         2. label with color
         3. get wulff_area and other properties
 
-    .. attribute:: debug (bool)
-
-    .. attribute:: alpha
-        transparency
-
-    .. attribute:: color_set
-
-    .. attribute:: grid_off (bool)
-
-    .. attribute:: axis_off (bool)
-
-    .. attribute:: show_area
-
-    .. attribute:: off_color
-        color of facets off wulff
-
-    .. attribute:: structure
-        Structure object, input conventional unit cell (with H ) from lattice
-
-    .. attribute:: miller_list
-        list of input miller index, for hcp in the form of hkil
-
-    .. attribute:: hkl_list
-        modify hkill to hkl, in the same order with input_miller
-
-    .. attribute:: e_surf_list
-        list of input surface energies, in the same order with input_miller
-
-    .. attribute:: lattice
-        Lattice object, the input lattice for the conventional unit cell
-
-    .. attribute:: facets
-        [WulffFacet] for all facets considering symm
-
-    .. attribute:: dual_cv_simp
-        simplices from the dual convex hull (dual_pt)
-
-    .. attribute:: wulff_pt_list
-
-    .. attribute:: wulff_cv_simp
-        simplices from the convex hull of wulff_pt_list
-
-    .. attribute:: on_wulff
-        list for all input_miller, True is on wulff.
-
-    .. attribute:: color_area
-        list for all input_miller, total area on wulff, off_wulff = 0.
-
-    .. attribute:: miller_area
-        ($hkl$): area for all input_miller
-
+    Attributes:
+        debug (bool): Whether to print debug information.
+        alpha (float): Transparency of the Wulff shape.
+        color_set (list): colors to use for facets.
+        grid_off (bool): Whether to turn off the grid.
+        axis_off (bool): Whether to turn off the axis.
+        show_area (bool): Whether to show the area of each facet.
+        off_color (str): Color of facets not on the Wulff shape.
+        structure (Structure): Input conventional unit cell (with H) from lattice.
+        miller_list (list): input Miller indices, for hcp in the form of hkil.
+        hkl_list (list): Modified Miller indices in the same order as input_miller.
+        e_surf_list (list): input surface energies in the same order as input_miller.
+        lattice (Lattice): Input lattice for the conventional unit cell.
+        facets (list): WulffFacet objects considering symmetry.
+        dual_cv_simp (list): Simplices from the dual convex hull (dual_pt).
+        wulff_pt_list (list): Wulff points.
+        wulff_cv_simp (list): Simplices from the convex hull of wulff_pt_list.
+        on_wulff (list): List for all input_miller, True if on the Wulff shape.
+        color_area (list): List for all input_miller, total area on the Wulff shape, off_wulff = 0.
+        miller_area (dict): Dictionary of Miller indices and their corresponding areas.
     """
 
     def __init__(self, lattice: Lattice, miller_list, e_surf_list, symprec=1e-5):
@@ -174,7 +136,7 @@ class WulffShape:
             lattice: Lattice object of the conventional unit cell
             miller_list ([(hkl), ...]: list of hkl or hkil for hcp
             e_surf_list ([float]): list of corresponding surface energies
-            symprec (float): for recp_operation, default is 1e-5.
+            symprec (float): for reciprocal lattice operation, default is 1e-5.
         """
         if any(se < 0 for se in e_surf_list):
             warnings.warn("Unphysical (negative) surface energy detected.")
@@ -199,8 +161,8 @@ class WulffShape:
         dual_pts = [x.dual_pt for x in self.facets]
         dual_convex = ConvexHull(dual_pts)
         dual_cv_simp = dual_convex.simplices
-        # simplices	(ndarray of ints, shape (nfacet, ndim))
-        # list of [i, j, k] , ndim = 3
+        # simplices	(ndarray of ints, shape (n_facet, n_dim))
+        # list of [i, j, k] , n_dim = 3
         # i, j, k: ind for normal_e_m
         # recalculate the dual of dual, get the Wulff shape.
         # corner <-> surface
@@ -221,15 +183,15 @@ class WulffShape:
 
         miller_area = []
         for m, in_mill_fig in enumerate(self.input_miller_fig):
-            miller_area.append(in_mill_fig + " : " + str(round(self.color_area[m], 4)))
+            miller_area.append(f"{in_mill_fig} : {round(self.color_area[m], 4)}")
         self.miller_area = miller_area
 
     def _get_all_miller_e(self):
         """
-        From self: get miller_list(unique_miller), e_surf_list and symmetry operations(symmops)
-        according to lattice apply symmops to get all the miller index, then get normal, get
+        From self: get miller_list(unique_miller), e_surf_list and symmetry operations(symm_ops)
+        according to lattice apply symm_ops to get all the miller index, then get normal, get
         all the facets functions for Wulff shape calculation: |normal| = 1, e_surf is plane's
-        distance to (0, 0, 0), normal[0]x + normal[1]y + normal[2]z = e_surf
+        distance to (0, 0, 0), normal[0]x + normal[1]y + normal[2]z = e_surf.
 
         Returns:
             [WulffFacet]
@@ -238,10 +200,10 @@ class WulffShape:
         color_ind = self.color_ind
         planes = []
         recp = self.structure.lattice.reciprocal_lattice_crystallographic
-        recp_symmops = self.lattice.get_recp_symmetry_operation(self.symprec)
+        recp_symm_ops = self.lattice.get_recp_symmetry_operation(self.symprec)
 
         for i, (hkl, energy) in enumerate(zip(self.hkl_list, self.e_surf_list)):
-            for op in recp_symmops:
+            for op in recp_symm_ops:
                 miller = tuple(int(x) for x in op.operate(hkl))
                 if miller not in all_hkl:
                     all_hkl.append(miller)
@@ -260,7 +222,7 @@ class WulffShape:
         """
         |normal| = 1, e_surf is plane's distance to (0, 0, 0),
         plane function:
-            normal[0]x + normal[1]y + normal[2]z = e_surf
+            normal[0]x + normal[1]y + normal[2]z = e_surf.
 
         from self:
             normal_e_m to get the plane functions
@@ -269,8 +231,7 @@ class WulffShape:
         """
         matrix_surfs = [self.facets[dual_simp[i]].normal for i in range(3)]
         matrix_e = [self.facets[dual_simp[i]].e_surf for i in range(3)]
-        cross_pt = np.dot(np.linalg.inv(matrix_surfs), matrix_e)
-        return cross_pt
+        return np.dot(np.linalg.inv(matrix_surfs), matrix_e)
 
     def _get_simpx_plane(self):
         """
@@ -308,8 +269,6 @@ class WulffShape:
             tuple: color_list, color_proxy, color_proxy_on_wulff, miller_on_wulff,
             e_surf_on_wulff_list
         """
-        import matplotlib as mpl
-        import matplotlib.pyplot as plt
 
         color_list = [off_color] * len(self.hkl_list)
         color_proxy_on_wulff = []
@@ -357,9 +316,7 @@ class WulffShape:
         self.get_plot(*args, **kwargs).show()
 
     def get_line_in_facet(self, facet):
-        """
-        Returns the sorted pts in a facet used to draw a line
-        """
+        """Returns the sorted pts in a facet used to draw a line."""
         lines = list(facet.outer_lines)
         pt = []
         prev = None
@@ -375,8 +332,7 @@ class WulffShape:
                         break
             # make sure the lines are connected one by one.
             # find the way covering all pts and facets
-            pt.append(self.wulff_pt_list[line[0]].tolist())
-            pt.append(self.wulff_pt_list[line[1]].tolist())
+            pt.extend((self.wulff_pt_list[line[0]].tolist(), self.wulff_pt_list[line[1]].tolist()))
             prev = line[1]
 
         return pt
@@ -412,7 +368,7 @@ class WulffShape:
             bar_on (bool): default is False
             legend_on (bool): default is True
             aspect_ratio: default is (8, 8)
-            custom_colors ({(h,k,l}: [r,g,b,alpha}): Customize color of each
+            custom_colors ({(h,k,l}: [r,g,b,alpha]}): Customize color of each
                 facet with a dictionary. The key is the corresponding Miller
                 index and value is the color. Undefined facets will use default
                 color site. Note: If you decide to set your own colors, it
@@ -423,9 +379,7 @@ class WulffShape:
         Return:
             (matplotlib.pyplot)
         """
-        import matplotlib as mpl
-        import matplotlib.pyplot as plt
-        from mpl_toolkits.mplot3d import Axes3D, art3d
+        from mpl_toolkits.mplot3d import art3d
 
         colors = self._get_colors(color_set, alpha, off_color, custom_colors=custom_colors or {})
         color_list, color_proxy, color_proxy_on_wulff, miller_on_wulff, e_surf_on_wulff = colors
@@ -441,8 +395,9 @@ class WulffShape:
 
         wulff_pt_list = self.wulff_pt_list
 
-        ax = Axes3D(fig, azim=azim, elev=elev)
-        fig.add_axes(ax)
+        ax_3d = fig.add_subplot(projection="3d")
+        ax_3d.view_init(azim=azim, elev=elev)
+        fig.add_axes(ax_3d)
 
         for plane in self.facets:
             # check whether [pts] is empty
@@ -457,20 +412,19 @@ class WulffShape:
             tri = art3d.Poly3DCollection([pt])
             tri.set_color(plane_color)
             tri.set_edgecolor("#808080")
-            ax.add_collection3d(tri)
+            ax_3d.add_collection3d(tri)
 
         # set ranges of x, y, z
         # find the largest distance between on_wulff pts and the origin,
         # to ensure complete and consistent display for all directions
         r_range = max(np.linalg.norm(x) for x in wulff_pt_list)
-        ax.set_xlim([-r_range * 1.1, r_range * 1.1])
-        ax.set_ylim([-r_range * 1.1, r_range * 1.1])
-        ax.set_zlim([-r_range * 1.1, r_range * 1.1])  # pylint: disable=E1101
+        ax_3d.set_xlim([-r_range * 1.1, r_range * 1.1])
+        ax_3d.set_ylim([-r_range * 1.1, r_range * 1.1])
+        ax_3d.set_zlim([-r_range * 1.1, r_range * 1.1])
         # add legend
         if legend_on:
-            color_proxy = color_proxy
             if show_area:
-                ax.legend(
+                ax_3d.legend(
                     color_proxy,
                     self.miller_area,
                     loc="upper left",
@@ -479,7 +433,7 @@ class WulffShape:
                     shadow=False,
                 )
             else:
-                ax.legend(
+                ax_3d.legend(
                     color_proxy_on_wulff,
                     miller_on_wulff,
                     loc="upper center",
@@ -488,7 +442,7 @@ class WulffShape:
                     fancybox=True,
                     shadow=False,
                 )
-        ax.set(xlabel="x", ylabel="y", zlabel="z")
+        ax_3d.set(xlabel="x", ylabel="y", zlabel="z")
 
         # Add color bar
         if bar_on:
@@ -514,9 +468,9 @@ class WulffShape:
             cbar.set_label(f"Surface Energies ({units})", fontsize=25)
 
         if grid_off:
-            ax.grid("off")
+            ax_3d.grid("off")
         if axis_off:
-            ax.axis("off")
+            ax_3d.axis("off")
         return plt
 
     def get_plotly(
@@ -543,16 +497,12 @@ class WulffShape:
                 Joules per square meter (True)
 
         Return:
-            (plotly.graph_objs.Figure)
+            (plotly.graph_objects.Figure)
         """
         units = "Jm⁻²" if units_in_JPERM2 else "eVÅ⁻²"
-        (
-            color_list,
-            color_proxy,
-            color_proxy_on_wulff,
-            miller_on_wulff,
-            e_surf_on_wulff,
-        ) = self._get_colors(color_set, alpha, off_color, custom_colors=custom_colors or {})
+        color_list, _color_proxy, _color_proxy_on_wulff, _miller_on_wulff, e_surf_on_wulff = self._get_colors(
+            color_set, alpha, off_color, custom_colors=custom_colors or {}
+        )
 
         planes_data, color_scale, ticktext, tickvals = [], [], [], []
         for plane in self.facets:
@@ -572,7 +522,7 @@ class WulffShape:
 
             # remove duplicate x y z pts to save time
             all_xyz = []
-            # pylint: disable=E1133,E1136
+
             [all_xyz.append(list(coord)) for coord in np.array([x_pts, y_pts, z_pts]).T if list(coord) not in all_xyz]
             all_xyz = np.array(all_xyz).T
             x_pts, y_pts, z_pts = all_xyz[0], all_xyz[1], all_xyz[2]
@@ -580,7 +530,7 @@ class WulffShape:
 
             tri_indices = np.array(list(itertools.combinations(index_list, 3))).T
             hkl = self.miller_list[plane.index]
-            hkl = unicodeify_spacegroup("(" + "%s" * len(hkl) % hkl + ")")
+            hkl = unicodeify_spacegroup(f"({'%s' * len(hkl) % hkl})")
             cs = tuple(np.array(plane_color) * 255)
             color = f"rgba({cs[0]:.5f}, {cs[1]:.5f}, {cs[2]:.5f}, {cs[3]:.5f})"
 
@@ -659,7 +609,7 @@ class WulffShape:
     def _get_azimuth_elev(self, miller_index):
         """
         Args:
-            miller_index: viewing direction
+            miller_index: viewing direction.
 
         Returns:
             azim, elev for plotting
@@ -674,37 +624,29 @@ class WulffShape:
 
     @property
     def volume(self):
-        """
-        Volume of the Wulff shape
-        """
+        """Volume of the Wulff shape."""
         return self.wulff_convex.volume
 
     @property
     def miller_area_dict(self):
-        """
-        Returns {hkl: area_hkl on wulff}
-        """
+        """Returns {hkl: area_hkl on wulff}."""
         return dict(zip(self.miller_list, self.color_area))
 
     @property
     def miller_energy_dict(self):
-        """
-        Returns {hkl: surface energy_hkl}
-        """
+        """Returns {hkl: surface energy_hkl}."""
         return dict(zip(self.miller_list, self.e_surf_list))
 
     @property
     def surface_area(self):
-        """
-        Total surface area of Wulff shape.
-        """
+        """Total surface area of Wulff shape."""
         return sum(self.miller_area_dict.values())
 
     @property
     def weighted_surface_energy(self):
         """
         Returns:
-            sum(surface_energy_hkl * area_hkl)/ sum(area_hkl)
+            sum(surface_energy_hkl * area_hkl)/ sum(area_hkl).
         """
         return self.total_surface_energy / self.surface_area
 
@@ -712,7 +654,7 @@ class WulffShape:
     def area_fraction_dict(self):
         """
         Returns:
-            (dict): {hkl: area_hkl/total area on wulff}
+            dict: {hkl: area_hkl/total area on wulff}.
         """
         return {hkl: area / self.surface_area for hkl, area in self.miller_area_dict.items()}
 
@@ -738,7 +680,7 @@ class WulffShape:
         This is useful for determining the critical nucleus size.
         A large shape factor indicates great anisotropy.
         See Ballufi, R. W., Allen, S. M. & Carter, W. C. Kinetics
-            of Materials. (John Wiley & Sons, 2005), p.461
+            of Materials. (John Wiley & Sons, 2005), p.461.
 
         Returns:
             (float) Shape factor.
@@ -789,7 +731,7 @@ class WulffShape:
             pt = self.get_line_in_facet(facet)
 
             lines = []
-            for idx, _ in enumerate(pt):
+            for idx in range(len(pt)):
                 if idx == len(pt) / 2:
                     break
                 lines.append(tuple(sorted((tuple(pt[idx * 2]), tuple(pt[idx * 2 + 1])))))
