@@ -11,9 +11,13 @@ from glob import glob
 from typing import TYPE_CHECKING, Literal
 from urllib.request import urlretrieve
 
+from monty.json import jsanitize
 from monty.serialization import dumpfn, loadfn
+from ruamel import yaml
 
-from pymatgen.core import OLD_SETTINGS_FILE, SETTINGS_FILE
+from pymatgen.core import OLD_SETTINGS_FILE, SETTINGS_FILE, Element
+from pymatgen.io.cp2k.inputs import GaussianTypeOrbitalBasisSet, GthPotential
+from pymatgen.io.cp2k.utils import chunk
 
 if TYPE_CHECKING:
     from argparse import Namespace
@@ -31,15 +35,8 @@ def setup_cp2k_data(cp2k_data_dirs: list[str]) -> None:
             raise SystemExit(0)
     print("Generating pymatgen resource directory for CP2K...")
 
-    from monty.json import jsanitize
-    from ruamel import yaml
-
-    from pymatgen.core import Element
-    from pymatgen.io.cp2k.inputs import GaussianTypeOrbitalBasisSet, GthPotential
-    from pymatgen.io.cp2k.utils import chunk
-
-    basis_files = glob(os.path.join(data_dir, "*BASIS*"))
-    potential_files = glob(os.path.join(data_dir, "*POTENTIAL*"))
+    basis_files = glob(f"{data_dir}/*BASIS*")
+    potential_files = glob(f"{data_dir}/*POTENTIAL*")
 
     settings: dict[str, dict] = {str(el): {"potentials": {}, "basis_sets": {}} for el in Element}
 
@@ -52,7 +49,7 @@ def setup_cp2k_data(cp2k_data_dirs: list[str]) -> None:
                 continue
         for chk in chunks:
             try:
-                potential = GthPotential.from_string(chk)
+                potential = GthPotential.from_str(chk)
                 potential.filename = os.path.basename(potential_file)
                 potential.version = None
                 settings[potential.element.symbol]["potentials"][potential.get_hash()] = jsanitize(
@@ -74,7 +71,7 @@ def setup_cp2k_data(cp2k_data_dirs: list[str]) -> None:
                 continue
         for chk in chunks:
             try:
-                basis = GaussianTypeOrbitalBasisSet.from_string(chk)
+                basis = GaussianTypeOrbitalBasisSet.from_str(chk)
                 basis.filename = os.path.basename(basis_file)
                 settings[basis.element.symbol]["basis_sets"][basis.get_hash()] = jsanitize(  # type: ignore
                     basis, strict=True
@@ -90,7 +87,7 @@ def setup_cp2k_data(cp2k_data_dirs: list[str]) -> None:
 
     for el in settings:
         print(f"Writing {el} settings file")
-        with open(os.path.join(target_dir, el), "w") as file:
+        with open(os.path.join(target_dir, el), mode="w") as file:
             yaml.dump(settings.get(el), file, default_flow_style=False)
 
     print(
@@ -143,8 +140,7 @@ def setup_potcars(potcar_dirs: list[str]):
             if len(filenames) > 0:
                 try:
                     base_dir = os.path.join(target_dir, basename)
-                    if not os.path.exists(base_dir):
-                        os.makedirs(base_dir)
+                    os.makedirs(base_dir, exist_ok=True)
                     fname = filenames[0]
                     dest = os.path.join(base_dir, os.path.basename(fname))
                     shutil.copy(fname, dest)
@@ -158,11 +154,11 @@ def setup_potcars(potcar_dirs: list[str]):
                     if subdir == "Osmium":
                         subdir = "Os"
                     dest = os.path.join(base_dir, f"POTCAR.{subdir}")
-                    shutil.move(os.path.join(base_dir, "POTCAR"), dest)
+                    shutil.move(f"{base_dir}/POTCAR", dest)
                     with subprocess.Popen(["gzip", "-f", dest]) as p:
                         p.communicate()
-                except Exception as ex:
-                    print(f"An error has occurred. Message is {ex}. Trying to continue... ")
+                except Exception as exc:
+                    print(f"An error has occurred. Message is {exc}. Trying to continue... ")
 
     print(
         "\nPSP resources directory generated. It is recommended that you "
@@ -172,8 +168,7 @@ def setup_potcars(potcar_dirs: list[str]):
 
 
 def build_enum(fortran_command: str = "gfortran") -> bool:
-    """
-    Build enum.
+    """Build enum.
 
     :param fortran_command:
     """
@@ -181,17 +176,16 @@ def build_enum(fortran_command: str = "gfortran") -> bool:
     state = True
     try:
         subprocess.call(["git", "clone", "--recursive", "https://github.com/msg-byu/enumlib.git"])
-        os.chdir(os.path.join(cwd, "enumlib", "symlib", "src"))
+        os.chdir(f"{cwd}/enumlib/symlib/src")
         os.environ["F90"] = fortran_command
         subprocess.call(["make"])
-        enumpath = os.path.join(cwd, "enumlib", "src")
+        enumpath = f"{cwd}/enumlib/src"
         os.chdir(enumpath)
         subprocess.call(["make"])
-        for f in ["enum.x", "makestr.x"]:
-            subprocess.call(["make", f])
-            shutil.copy(f, os.path.join("..", ".."))
-    except Exception as ex:
-        print(ex)
+        subprocess.call(["make", "enum.x"])
+        shutil.copy("enum.x", os.path.join("..", ".."))
+    except Exception as exc:
+        print(exc)
         state = False
     finally:
         os.chdir(cwd)
@@ -200,8 +194,7 @@ def build_enum(fortran_command: str = "gfortran") -> bool:
 
 
 def build_bader(fortran_command="gfortran"):
-    """
-    Build bader package.
+    """Build bader package.
 
     :param fortran_command:
     """
@@ -238,8 +231,8 @@ def install_software(install: Literal["enumlib", "bader"]):
             subprocess.call(["gfortran", "--version"])
             print("Found gfortran")
             fortran_command = "gfortran"
-        except Exception as ex:
-            print(str(ex))
+        except Exception as exc:
+            print(str(exc))
             raise SystemExit("No fortran compiler found.")
 
     enum = bader = None
@@ -260,27 +253,28 @@ def install_software(install: Literal["enumlib", "bader"]):
 
 def add_config_var(tokens: list[str], backup_suffix: str) -> None:
     """Add/update keys in .pmgrc.yaml config file."""
-    if os.path.exists(SETTINGS_FILE):
-        # read and write new config file if exists
-        fpath = SETTINGS_FILE
-    elif os.path.exists(OLD_SETTINGS_FILE):
-        # else use old config file if exists
-        fpath = OLD_SETTINGS_FILE
-    else:
-        # if neither exists, create new config file
-        fpath = SETTINGS_FILE
-    dct = {}
-    if os.path.exists(fpath):
-        if backup_suffix:
-            shutil.copy(fpath, fpath + backup_suffix)
-            print(f"Existing {fpath} backed up to {fpath}{backup_suffix}")
-        dct = loadfn(fpath)
     if len(tokens) % 2 != 0:
         raise ValueError(f"Uneven number {len(tokens)} of tokens passed to pmg config. Needs a value for every key.")
+    if os.path.exists(SETTINGS_FILE):
+        # read and write new config file if exists
+        rc_path = SETTINGS_FILE
+    elif os.path.exists(OLD_SETTINGS_FILE):
+        # else use old config file if exists
+        rc_path = OLD_SETTINGS_FILE
+    else:
+        # if neither exists, create new config file
+        rc_path = SETTINGS_FILE
+    dct = {}
+    if os.path.exists(rc_path):
+        if backup_suffix:
+            shutil.copy(rc_path, rc_path + backup_suffix)
+            print(f"Existing {rc_path} backed up to {rc_path}{backup_suffix}")
+        dct = loadfn(rc_path)
+    special_vals = {"true": True, "false": False, "none": None, "null": None}
     for key, val in zip(tokens[0::2], tokens[1::2]):
-        dct[key] = val
-    dumpfn(dct, fpath)
-    print(f"New {fpath} written!")
+        dct[key] = special_vals.get(val.lower(), val)
+    dumpfn(dct, rc_path)
+    print(f"New {rc_path} written!")
 
 
 def configure_pmg(args: Namespace):
