@@ -1,5 +1,4 @@
-"""
-This module implements an interface to the critic2 Bader analysis code.
+"""This module implements an interface to the critic2 Bader analysis code.
 
 For most Bader analysis purposes, users are referred to
 pymatgen.command_line.bader_caller instead, this module is for advanced
@@ -26,7 +25,7 @@ appropriate (e.g. the two nucleus critical points linked to
  a bond critical point)
 * critic2 can do many other things besides
 
-If you use this module, please cite the following:
+If you use this module, please cite:
 
 A. Otero-de-la-Roza, E. R. Johnson and V. Luaña,
 Comput. Phys. Communications 185, 1007-1018 (2014)
@@ -56,9 +55,10 @@ from monty.tempfile import ScratchDir
 from scipy.spatial import KDTree
 
 from pymatgen.analysis.graphs import StructureGraph
-from pymatgen.core.periodic_table import DummySpecies
+from pymatgen.core import DummySpecies
 from pymatgen.io.vasp.inputs import Potcar
 from pymatgen.io.vasp.outputs import Chgcar, VolumetricData
+from pymatgen.util.due import Doi, due
 
 if TYPE_CHECKING:
     from pymatgen.core import Structure
@@ -66,6 +66,15 @@ if TYPE_CHECKING:
 logging.basicConfig(level=logging.INFO)
 logger = logging.getLogger(__name__)
 
+due.cite(
+    Doi("10.1016/j.cpc.2008.07.018"),
+    description="Critic: a new program for the topological analysis of solid-state electron densities",
+)
+due.cite(
+    Doi("10.1016/j.cpc.2013.10.026"),
+    description="Critic2: A program for real-space analysis of quantum chemical interactions in solids",
+)
+
 
 class Critic2Caller:
     """Class to call critic2 and store standard output for further processing."""
@@ -76,8 +85,7 @@ class Critic2Caller:
         "Please follow the instructions at https://github.com/aoterodelaroza/critic2.",
     )
     def __init__(self, input_script):
-        """
-        Run Critic2 on a given input script.
+        """Run Critic2 on a given input script.
 
         :param input_script: string defining the critic2 input
         """
@@ -85,8 +93,8 @@ class Critic2Caller:
         # not otherwise used
         self._input_script = input_script
 
-        with open("input_script.cri", "w") as f:
-            f.write(input_script)
+        with open("input_script.cri", mode="w") as file:
+            file.write(input_script)
 
         args = ["critic2", "input_script.cri"]
         with subprocess.Popen(args, stdout=subprocess.PIPE, stdin=subprocess.PIPE, close_fds=True) as rs:
@@ -103,8 +111,8 @@ class Critic2Caller:
         self._stdout = stdout
         self._stderr = stderr
 
-        cpreport = loadfn("cpreport.json") if os.path.exists("cpreport.json") else None
-        self._cpreport = cpreport
+        cp_report = loadfn("cpreport.json") if os.path.exists("cpreport.json") else None
+        self._cp_report = cp_report
 
         yt = loadfn("yt.json") if os.path.exists("yt.json") else None
         self._yt = yt
@@ -120,8 +128,7 @@ class Critic2Caller:
         write_json=True,
         zpsp=None,
     ):
-        """
-        Run Critic2 in automatic mode on a supplied structure, charge
+        """Run Critic2 in automatic mode on a supplied structure, charge
         density (chgcar) and reference charge density (chgcar_ref).
 
         The reason for a separate reference field is that in
@@ -188,7 +195,7 @@ class Critic2Caller:
         if chgcar:
             input_script += ["load int.CHGCAR id chg_int", "integrable chg_int"]
             if zpsp:
-                zpsp_str = " zpsp " + " ".join(f"{symbol} {zval}" for symbol, zval in zpsp.items())
+                zpsp_str = f" zpsp {' '.join(f'{symbol} {int(zval)}' for symbol, zval in zpsp.items())}"
                 input_script[-2] += zpsp_str
 
         # Command to run automatic analysis
@@ -233,7 +240,7 @@ class Critic2Caller:
                 structure,
                 stdout=caller._stdout,
                 stderr=caller._stderr,
-                cpreport=caller._cpreport,
+                cpreport=caller._cp_report,
                 yt=caller._yt,
                 zpsp=zpsp,
             )
@@ -242,8 +249,7 @@ class Critic2Caller:
 
     @classmethod
     def from_path(cls, path, suffix="", zpsp=None):
-        """
-        Convenience method to run critic2 analysis on a folder with typical VASP output files.
+        """Convenience method to run critic2 analysis on a folder with typical VASP output files.
 
         This method will:
 
@@ -260,7 +266,6 @@ class Critic2Caller:
         :param suffix: specific suffix to look for (e.g. '.relax1' for
             'CHGCAR.relax1.gz')
         :param zpsp: manually specify ZPSP if POTCAR not present
-        :return:
         """
         chgcar_path = get_filepath("CHGCAR", "Could not find CHGCAR!", path, suffix)
         chgcar = Chgcar.from_file(chgcar_path)
@@ -330,8 +335,7 @@ def get_filepath(filename, warning, path, suffix):
         # however, better to use 'suffix' kwarg to avoid this!
         paths.sort(reverse=True)
         warnings.warn(f"Multiple files detected, using {os.path.basename(path)}")
-    path = paths[0]
-    return path
+    return paths[0]
 
 
 class CriticalPoint(MSONable):
@@ -349,8 +353,7 @@ class CriticalPoint(MSONable):
         coords=None,
         field_hessian=None,
     ):
-        """
-        Class to characterise a critical point from a topological
+        """Class to characterize a critical point from a topological
         analysis of electron charge density.
 
         Note this class is usually associated with a Structure, so
@@ -385,18 +388,17 @@ class CriticalPoint(MSONable):
         return f"Critical Point: {self.type.name} ({self.frac_coords})"
 
     @property
-    def laplacian(self):
+    def laplacian(self) -> float:
         """Returns: The Laplacian of the field at the critical point."""
         return np.trace(self.field_hessian)
 
     @property
     def ellipticity(self):
-        """
-        Most meaningful for bond critical points,
-        can be physically interpreted as e.g. degree
-        of pi-bonding in organic molecules. Consult
-        literature for more information.
-        Returns: The ellpiticity of the field at the critical point.
+        """Most meaningful for bond critical points, can be physically interpreted as e.g.
+        degree of pi-bonding in organic molecules. Consult literature for more info.
+
+        Returns:
+            float: The ellipticity of the field at the critical point.
         """
         eig, _ = np.linalg.eig(self.field_hessian)
         eig.sort()
@@ -406,9 +408,16 @@ class CriticalPoint(MSONable):
 class Critic2Analysis(MSONable):
     """Class to process the standard output from critic2 into pymatgen-compatible objects."""
 
-    def __init__(self, structure: Structure, stdout=None, stderr=None, cpreport=None, yt=None, zpsp=None):
-        """
-        This class is used to store results from the Critic2Caller.
+    def __init__(
+        self,
+        structure: Structure,
+        stdout: str | None = None,
+        stderr: str | None = None,
+        cpreport: dict | None = None,
+        yt: dict | None = None,
+        zpsp: dict | None = None,
+    ) -> None:
+        """This class is used to store results from the Critic2Caller.
 
         To explore the bond graph, use the "structure_graph"
         method, which returns a user-friendly StructureGraph
@@ -442,6 +451,18 @@ class Critic2Analysis(MSONable):
         :param zpsp (dict): Dict of element/symbol name to number of electrons
         (ZVAL in VASP pseudopotential), with which to calculate charge transfer.
         Optional.
+
+        Args:
+            structure (Structure): Associated Structure.
+            stdout (str, optional): stdout from running critic2 in automatic mode.
+            stderr (str, optional): stderr from running critic2 in automatic mode.
+            cpreport (dict, optional): JSON output from CPREPORT command. Either this or stdout required.
+            yt (dict, optional): JSON output from YT command.
+            zpsp (dict, optional): Dict of element/symbol name to number of electrons (ZVAL in VASP pseudopotential),
+                with which to calculate charge transfer. Optional.
+
+        Raises:
+            ValueError: If one of cpreport or stdout is not provided.
         """
         self.structure = structure
 
@@ -467,17 +488,14 @@ class Critic2Analysis(MSONable):
         self._remap_indices()
 
     def structure_graph(self, include_critical_points=("bond", "ring", "cage")):
-        """
-        A StructureGraph object describing bonding information
-        in the crystal.
+        """A StructureGraph object describing bonding information in the crystal.
 
         Args:
-            include_critical_points: add DummySpecies for
-            the critical points themselves, a list of
-            "nucleus", "bond", "ring", "cage", set to None
-            to disable
+            include_critical_points: add DummySpecies for the critical points themselves, a list of
+                "nucleus", "bond", "ring", "cage", set to None to disable
 
-        Returns: a StructureGraph
+        Returns:
+            StructureGraph
         """
         structure = self.structure.copy()
 
@@ -589,22 +607,22 @@ class Critic2Analysis(MSONable):
         Args:
             n (int): Site index.
 
-        Returns: A CriticalPoint instance
+        Returns:
+            CriticalPoint
         """
         return self.critical_points[self.nodes[n]["unique_idx"]]
 
-    def get_volume_and_charge_for_site(self, n):
+    def get_volume_and_charge_for_site(self, idx):
         """
         Args:
-            n: Site index n.
+            idx: Site index.
 
-        Returns: A dict containing "volume" and "charge" keys,
-        or None if YT integration not performed
+        Returns:
+            dict: with "volume" and "charge" keys, or None if YT integration not performed
         """
-        # pylint: disable=E1101
         if not self._node_values:
             return None
-        return self._node_values[n]
+        return self._node_values[idx]
 
     def _parse_cpreport(self, cpreport):
         def get_type(signature: int, is_nucleus: bool):
@@ -655,8 +673,7 @@ class Critic2Analysis(MSONable):
                 )
 
     def _remap_indices(self):
-        """
-        Re-maps indices on self.nodes and self.edges such that node indices match
+        """Re-maps indices on self.nodes and self.edges such that node indices match
         that of structure, and then sorts self.nodes by index.
         """
         # Order of nuclei provided by critic2 doesn't
@@ -848,20 +865,17 @@ class Critic2Analysis(MSONable):
                     )
 
     def _add_node(self, idx, unique_idx, frac_coords):
-        """
-        Add information about a node describing a critical point.
+        """Add information about a node describing a critical point.
 
         :param idx: index
         :param unique_idx: index of unique CriticalPoint,
             used to look up more information of point (field etc.)
         :param frac_coord: fractional coordinates of point
-        :return:
         """
         self.nodes[idx] = {"unique_idx": unique_idx, "frac_coords": frac_coords}
 
     def _add_edge(self, idx, from_idx, from_lvec, to_idx, to_lvec):
-        """
-        Add information about an edge linking two critical points.
+        """Add information about an edge linking two critical points.
 
         This actually describes two edges:
 
@@ -878,9 +892,8 @@ class Critic2Analysis(MSONable):
         :param from_lvec: vector of lattice image the from node is in
             as tuple of ints
         :param to_idx: to index of node
-        :param to_lvec:  vector of lattice image the to node is in as
+        :param to_lvec: vector of lattice image the to node is in as
             tuple of ints
-        :return:
         """
         self.edges[idx] = {
             "from_idx": from_idx,
