@@ -5,6 +5,7 @@ from __future__ import annotations
 from itertools import chain, combinations, product
 
 import numpy as np
+from numpy.testing import assert_allclose
 from scipy.cluster.hierarchy import fcluster, linkage
 from scipy.spatial.distance import squareform
 
@@ -17,9 +18,8 @@ from pymatgen.symmetry.analyzer import SpacegroupAnalyzer
 
 
 class Interface(Structure):
-    """
-    This class stores data for defining an interface between two structures.
-    It is a subclass of pymatgen.core.structure.Structure.
+    """This class stores data for defining an interface between two structures.
+    It is a subclass of pymatgen Structure.
     """
 
     def __init__(
@@ -35,14 +35,13 @@ class Interface(Structure):
         gap: float = 0,
         vacuum_over_film: float = 0,
         interface_properties: dict | None = None,
-    ):
-        """
-        Makes an interface structure, a structure object with additional information
+    ) -> None:
+        """Makes an interface structure, a structure object with additional information
         and methods pertaining to interfaces.
 
         Args:
             lattice (Lattice/3x3 array): The lattice, either as a
-                :class:`pymatgen.core.lattice.Lattice` or
+                pymatgen.core.Lattice or
                 simply as any 2D array. Each row should correspond to a lattice
                 vector. E.g., [[10,0,0], [20,10,0], [0,0,30]] specifies a
                 lattice with lattice vectors [10,0,0], [20,10,0] and [0,0,30].
@@ -97,8 +96,7 @@ class Interface(Structure):
 
     @property
     def in_plane_offset(self) -> np.ndarray:
-        """
-        The shift between the film and substrate in fractional
+        """The shift between the film and substrate in fractional
         coordinates.
         """
         return self._in_plane_offset
@@ -125,7 +123,7 @@ class Interface(Structure):
         delta = new_gap - self.gap
         self._gap = new_gap
 
-        self.__update_c(self.lattice.c + delta)
+        self._update_c(self.lattice.c + delta)
         self.translate_sites(self.film_indices, [0, 0, delta], frac_coords=False, to_unit_cell=True)
 
     @property
@@ -141,19 +139,17 @@ class Interface(Structure):
         delta = new_vacuum - self.vacuum_over_film
         self._vacuum_over_film = new_vacuum
 
-        self.__update_c(self.lattice.c + delta)
+        self._update_c(self.lattice.c + delta)
 
     @property
     def substrate_indices(self) -> list[int]:
         """Site indices for the substrate atoms."""
-        sub_indices = [i for i, tag in enumerate(self.site_properties["interface_label"]) if "substrate" in tag]
-        return sub_indices
+        return [i for i, tag in enumerate(self.site_properties["interface_label"]) if "substrate" in tag]
 
     @property
     def substrate_sites(self) -> list[Site]:
         """The site objects in the substrate."""
-        sub_sites = [site for site, tag in zip(self, self.site_properties["interface_label"]) if "substrate" in tag]
-        return sub_sites
+        return [site for site, tag in zip(self, self.site_properties["interface_label"]) if "substrate" in tag]
 
     @property
     def substrate(self) -> Structure:
@@ -163,14 +159,12 @@ class Interface(Structure):
     @property
     def film_indices(self) -> list[int]:
         """Site indices of the film sites."""
-        f_indices = [i for i, tag in enumerate(self.site_properties["interface_label"]) if "film" in tag]
-        return f_indices
+        return [i for i, tag in enumerate(self.site_properties["interface_label"]) if "film" in tag]
 
     @property
     def film_sites(self) -> list[Site]:
         """Return the film sites of the interface."""
-        film_sites = [site for site, tag in zip(self, self.site_properties["interface_label"]) if "film" in tag]
-        return film_sites
+        return [site for site, tag in zip(self, self.site_properties["interface_label"]) if "film" in tag]
 
     @property
     def film(self) -> Structure:
@@ -185,8 +179,7 @@ class Interface(Structure):
         return Interface.from_dict(self.as_dict())
 
     def get_sorted_structure(self, key=None, reverse=False) -> Structure:
-        """
-        Get a sorted structure for the interface. The parameters have the same
+        """Get a sorted structure for the interface. The parameters have the same
         meaning as in list.sort. By default, sites are sorted by the
         electronegativity of the species.
 
@@ -202,15 +195,13 @@ class Interface(Structure):
         return struct_copy
 
     def get_shifts_based_on_adsorbate_sites(self, tolerance: float = 0.1) -> list[tuple[float, float]]:
-        """
-        Computes possible in-plane shifts based on an adsorbate site  algorithm.
+        """Computes possible in-plane shifts based on an adsorbate site  algorithm.
 
         Args:
             tolerance: tolerance for "uniqueness" for shifts in Cartesian unit
                 This is usually Angstroms.
         """
-        substrate = self.substrate
-        film = self.film
+        substrate, film = self.substrate, self.film
 
         substrate_surface_sites = np.dot(
             list(chain.from_iterable(AdsorbateSiteFinder(substrate).find_adsorption_sites().values())),
@@ -266,40 +257,40 @@ class Interface(Structure):
         )
         return count_layers(self.substrate, sorted_element_list[0][0])
 
-    def __update_c(self, new_c: float) -> None:
-        """
-        Modifies the c-direction of the lattice without changing the site Cartesian coordinates
+    def _update_c(self, new_c: float) -> None:
+        """Modifies the c-direction of the lattice without changing the site Cartesian coordinates
         Be careful you can mess up the interface by setting a c-length that can't accommodate all the sites.
         """
         if new_c <= 0:
             raise ValueError("New c-length must be greater than 0")
 
         new_latt_matrix = [*self.lattice.matrix[:2].tolist(), [0, 0, new_c]]
-        new_latice = Lattice(new_latt_matrix)
-        self._lattice = new_latice
+        new_lattice = Lattice(new_latt_matrix)
+        self._lattice = new_lattice
 
         for site, c_coords in zip(self, self.cart_coords):
-            site._lattice = new_latice  # Update the lattice
+            site._lattice = new_lattice  # Update the lattice
             site.coords = c_coords  # Put back into original Cartesian space
 
     def as_dict(self):
-        """:return: MSONable dict"""
-        d = super().as_dict()
-        d["in_plane_offset"] = self.in_plane_offset.tolist()
-        d["gap"] = self.gap
-        d["vacuum_over_film"] = self.vacuum_over_film
-        d["interface_properties"] = self.interface_properties
-        return d
+        """MSONable dict."""
+        dct = super().as_dict()
+        dct["in_plane_offset"] = self.in_plane_offset.tolist()
+        dct["gap"] = self.gap
+        dct["vacuum_over_film"] = self.vacuum_over_film
+        dct["interface_properties"] = self.interface_properties
+        return dct
 
     @classmethod
     def from_dict(cls, d):
-        """
-        :param d: dict
-        :return: Creates slab from dict.
+        """:param d: dict
+
+        Returns:
+            Creates slab from dict.
         """
         lattice = Lattice.from_dict(d["lattice"])
         sites = [PeriodicSite.from_dict(sd, lattice) for sd in d["sites"]]
-        s = Structure.from_sites(sites)
+        struct = Structure.from_sites(sites)
 
         optional = {
             "in_plane_offset": d.get("in_plane_offset"),
@@ -309,9 +300,9 @@ class Interface(Structure):
         }
         return Interface(
             lattice=lattice,
-            species=s.species_and_occu,
-            coords=s.frac_coords,
-            site_properties=s.site_properties,
+            species=struct.species_and_occu,
+            coords=struct.frac_coords,
+            site_properties=struct.site_properties,
             **{k: v for k, v in optional.items() if v is not None},
         )
 
@@ -326,8 +317,7 @@ class Interface(Structure):
         interface_properties: dict | None = None,
         center_slab: bool = True,
     ) -> Interface:
-        """
-        Makes an interface structure by merging a substrate and film slabs
+        """Makes an interface structure by merging a substrate and film slabs
         The film a- and b-vectors will be forced to be the substrate slab's
         a- and b-vectors.
 
@@ -352,10 +342,10 @@ class Interface(Structure):
             substrate_slab = substrate_slab.get_orthogonal_c_slab()
         if isinstance(film_slab, Slab):
             film_slab = film_slab.get_orthogonal_c_slab()
-        assert np.allclose(film_slab.lattice.alpha, 90, 0.1)
-        assert np.allclose(film_slab.lattice.beta, 90, 0.1)
-        assert np.allclose(substrate_slab.lattice.alpha, 90, 0.1)
-        assert np.allclose(substrate_slab.lattice.beta, 90, 0.1)
+        assert_allclose(film_slab.lattice.alpha, 90, 0.1)
+        assert_allclose(film_slab.lattice.beta, 90, 0.1)
+        assert_allclose(substrate_slab.lattice.alpha, 90, 0.1)
+        assert_allclose(substrate_slab.lattice.beta, 90, 0.1)
 
         # Ensure sub is right-handed
         # IE sub has surface facing "up"
@@ -406,10 +396,7 @@ class Interface(Structure):
         site_props_in_both = set(substrate_slab.site_properties) & set(film_slab.site_properties)
 
         for key in site_props_in_both:
-            site_properties[key] = [
-                *substrate_slab.site_properties[key],
-                *film_slab.site_properties[key],
-            ]
+            site_properties[key] = [*substrate_slab.site_properties[key], *film_slab.site_properties[key]]
 
         site_properties["interface_label"] = ["substrate"] * len(substrate_slab) + ["film"] * len(film_slab)
 
@@ -475,7 +462,7 @@ def label_termination(slab: Structure) -> str:
 
 def count_layers(struct: Structure, el=None) -> int:
     """Counts the number of 'layers' along the c-axis."""
-    el = el or struct.composition.elements[0]
+    el = el or struct.elements[0]
     frac_coords = [site.frac_coords for site in struct if site.species_string == str(el)]
     n = len(frac_coords)
 
