@@ -7,34 +7,34 @@ import string
 import typing
 import warnings
 from math import cos, pi, sin, sqrt
-from typing import TYPE_CHECKING, Any
+from typing import TYPE_CHECKING
 
 import numpy as np
 from monty.json import MSONable
 
 from pymatgen.electronic_structure.core import Magmom
+from pymatgen.util.due import Doi, due
 from pymatgen.util.string import transformation_to_string
 
 if TYPE_CHECKING:
+    from typing import Any
+
     from numpy.typing import ArrayLike
 
 __author__ = "Shyue Ping Ong, Shyam Dwaraknath, Matthew Horton"
 
 
 class SymmOp(MSONable):
-    """
-    A symmetry operation in Cartesian space. Consists of a rotation plus a
+    """A symmetry operation in Cartesian space. Consists of a rotation plus a
     translation. Implementation is as an affine transformation matrix of rank 4
-    for efficiency. Read: http://en.wikipedia.org/wiki/Affine_transformation.
+    for efficiency. Read: http://wikipedia.org/wiki/Affine_transformation.
 
-    .. attribute:: affine_matrix
-
-        A 4x4 numpy.array representing the symmetry operation.
+    Attributes:
+        affine_matrix (np.ndarray): A 4x4 array representing the symmetry operation.
     """
 
     def __init__(self, affine_transformation_matrix: ArrayLike, tol: float = 0.01) -> None:
-        """
-        Initializes the SymmOp from a 4x4 affine transformation matrix.
+        """Initializes the SymmOp from a 4x4 affine transformation matrix.
         In general, this constructor should not be used unless you are
         transferring rotations. Use the static constructors instead to
         generate a SymmOp from proper rotations and translation.
@@ -42,7 +42,7 @@ class SymmOp(MSONable):
         Args:
             affine_transformation_matrix (4x4 array): Representing an
                 affine transformation.
-            tol (float): Tolerance for determining if matrices are equal.
+            tol (float): Tolerance for determining if matrices are equal. Defaults to 0.01.
 
         Raises:
             ValueError: if matrix is not 4x4.
@@ -60,8 +60,7 @@ class SymmOp(MSONable):
         translation_vec: ArrayLike = (0, 0, 0),
         tol: float = 0.1,
     ) -> SymmOp:
-        """
-        Creates a symmetry operation from a rotation matrix and a translation
+        """Creates a symmetry operation from a rotation matrix and a translation
         vector.
 
         Args:
@@ -92,20 +91,15 @@ class SymmOp(MSONable):
         return 7
 
     def __repr__(self) -> str:
-        return str(self)
+        affine_matrix = self.affine_matrix
+        return f"{type(self).__name__}({affine_matrix=})"
 
     def __str__(self) -> str:
-        output = [
-            "Rot:",
-            str(self.affine_matrix[0:3][:, 0:3]),
-            "tau",
-            str(self.affine_matrix[0:3][:, 3]),
-        ]
+        output = ["Rot:", str(self.affine_matrix[0:3][:, 0:3]), "tau", str(self.affine_matrix[0:3][:, 3])]
         return "\n".join(output)
 
     def operate(self, point: ArrayLike) -> np.ndarray:
-        """
-        Apply the operation on a point.
+        """Apply the operation on a point.
 
         Args:
             point: Cartesian coordinate.
@@ -117,8 +111,7 @@ class SymmOp(MSONable):
         return np.dot(self.affine_matrix, affine_point)[0:3]
 
     def operate_multi(self, points: ArrayLike) -> np.ndarray:
-        """
-        Apply the operation on a list of points.
+        """Apply the operation on a list of points.
 
         Args:
             points: List of Cartesian coordinates
@@ -131,8 +124,7 @@ class SymmOp(MSONable):
         return np.inner(affine_points, self.affine_matrix)[..., :-1]
 
     def apply_rotation_only(self, vector: ArrayLike) -> np.ndarray:
-        """
-        Vectors should only be operated by the rotation matrix and not the
+        """Vectors should only be operated by the rotation matrix and not the
         translation vector.
 
         Args:
@@ -141,12 +133,11 @@ class SymmOp(MSONable):
         return np.dot(self.rotation_matrix, vector)
 
     def transform_tensor(self, tensor: np.ndarray) -> np.ndarray:
-        """
-        Applies rotation portion to a tensor. Note that tensor has to be in
+        """Applies rotation portion to a tensor. Note that tensor has to be in
         full form, not the Voigt form.
 
         Args:
-            tensor (numpy array): a rank n tensor
+            tensor (numpy array): A rank n tensor
 
         Returns:
             Transformed tensor.
@@ -164,22 +155,17 @@ class SymmOp(MSONable):
         return np.einsum(einsum_string, *einsum_args)
 
     def are_symmetrically_related(self, point_a: ArrayLike, point_b: ArrayLike, tol: float = 0.001) -> bool:
-        """
-        Checks if two points are symmetrically related.
+        """Checks if two points are symmetrically related.
 
         Args:
             point_a (3x1 array): First point.
             point_b (3x1 array): Second point.
-            tol (float): Absolute tolerance for checking distance.
+            tol (float): Absolute tolerance for checking distance. Defaults to 0.001.
 
         Returns:
-            True if self.operate(point_a) == point_b or vice versa.
+            bool: True if self.operate(point_a) == point_b or vice versa.
         """
-        if np.allclose(self.operate(point_a), point_b, atol=tol):
-            return True
-        if np.allclose(self.operate(point_b), point_a, atol=tol):
-            return True
-        return False
+        return any(np.allclose(self.operate(p1), p2, atol=tol) for p1, p2 in [(point_a, point_b), (point_b, point_a)])
 
     def are_symmetrically_related_vectors(
         self,
@@ -191,8 +177,7 @@ class SymmOp(MSONable):
         r_b: ArrayLike,
         tol: float = 0.001,
     ) -> tuple[bool, bool]:
-        """
-        Checks if two vectors, or rather two vectors that connect two points
+        """Checks if two vectors, or rather two vectors that connect two points
         each are symmetrically related. r_a and r_b give the change of unit
         cells. Two vectors are also considered symmetrically equivalent if starting
         and end point are exchanged.
@@ -237,8 +222,7 @@ class SymmOp(MSONable):
         return self.affine_matrix[0:3][:, 3]
 
     def __mul__(self, other):
-        """
-        Returns a new SymmOp which is equivalent to apply the "other" SymmOp
+        """Returns a new SymmOp which is equivalent to apply the "other" SymmOp
         followed by this one.
         """
         new_matrix = np.dot(self.affine_matrix, other.affine_matrix)
@@ -254,8 +238,7 @@ class SymmOp(MSONable):
     def from_axis_angle_and_translation(
         axis: ArrayLike, angle: float, angle_in_radians: bool = False, translation_vec: ArrayLike = (0, 0, 0)
     ) -> SymmOp:
-        """
-        Generates a SymmOp for a rotation about a given axis plus translation.
+        """Generates a SymmOp for a rotation about a given axis plus translation.
 
         Args:
             axis: The axis of rotation in Cartesian space. For example,
@@ -295,8 +278,7 @@ class SymmOp(MSONable):
     def from_origin_axis_angle(
         origin: ArrayLike, axis: ArrayLike, angle: float, angle_in_radians: bool = False
     ) -> SymmOp:
-        """
-        Generates a SymmOp for a rotation about a given axis through an
+        """Generates a SymmOp for a rotation about a given axis through an
         origin.
 
         Args:
@@ -355,8 +337,7 @@ class SymmOp(MSONable):
 
     @staticmethod
     def reflection(normal: ArrayLike, origin: ArrayLike = (0, 0, 0)) -> SymmOp:
-        """
-        Returns reflection symmetry operation.
+        """Returns reflection symmetry operation.
 
         Args:
             normal (3x1 array): Vector of the normal to the plane of
@@ -389,8 +370,7 @@ class SymmOp(MSONable):
 
     @staticmethod
     def inversion(origin: ArrayLike = (0, 0, 0)) -> SymmOp:
-        """
-        Inversion symmetry operation about axis.
+        """Inversion symmetry operation about axis.
 
         Args:
             origin (3x1 array): Origin of the inversion operation. Defaults
@@ -406,8 +386,7 @@ class SymmOp(MSONable):
 
     @staticmethod
     def rotoreflection(axis: ArrayLike, angle: float, origin: ArrayLike = (0, 0, 0)) -> SymmOp:
-        """
-        Returns a roto-reflection symmetry operation.
+        """Returns a roto-reflection symmetry operation.
 
         Args:
             axis (3x1 array): Axis of rotation / mirror normal
@@ -424,7 +403,7 @@ class SymmOp(MSONable):
         return SymmOp(m)
 
     def as_dict(self) -> dict[str, Any]:
-        """:return: MSONable dict."""
+        """MSONable dict."""
         return {
             "@module": type(self).__module__,
             "@class": type(self).__name__,
@@ -432,10 +411,9 @@ class SymmOp(MSONable):
             "tolerance": self.tol,
         }
 
-    def as_xyz_string(self) -> str:
-        """
-        Returns a string of the form 'x, y, z', '-x, -y, z',
-        '-y+1/2, x+1/2, z+1/2', etc. Only works for integer rotation matrices.
+    def as_xyz_str(self) -> str:
+        """Returns a string of the form 'x, y, z', '-x, -y, z', '-y+1/2, x+1/2, z+1/2', etc.
+        Only works for integer rotation matrices.
         """
         # test for invalid rotation matrix
         if not np.all(np.isclose(self.rotation_matrix, np.round(self.rotation_matrix))):
@@ -443,22 +421,21 @@ class SymmOp(MSONable):
 
         return transformation_to_string(self.rotation_matrix, translation_vec=self.translation_vector, delim=", ")
 
-    @staticmethod
-    def from_xyz_string(xyz_string: str) -> SymmOp:
+    @classmethod
+    def from_xyz_str(cls, xyz_str: str) -> SymmOp:
         """
         Args:
-            xyz_string: string of the form 'x, y, z', '-x, -y, z',
-                '-2y+1/2, 3x+1/2, z-y+1/2', etc.
+            xyz_str: string of the form 'x, y, z', '-x, -y, z', '-2y+1/2, 3x+1/2, z-y+1/2', etc.
 
         Returns:
             SymmOp
         """
         rot_matrix = np.zeros((3, 3))
         trans = np.zeros(3)
-        toks = xyz_string.strip().replace(" ", "").lower().split(",")
+        tokens = xyz_str.strip().replace(" ", "").lower().split(",")
         re_rot = re.compile(r"([+-]?)([\d\.]*)/?([\d\.]*)([x-z])")
         re_trans = re.compile(r"([+-]?)([\d\.]+)/?([\d\.]*)(?![x-z])")
-        for i, tok in enumerate(toks):
+        for i, tok in enumerate(tokens):
             # build the rotation matrix
             for m in re_rot.finditer(tok):
                 factor = -1.0 if m.group(1) == "-" else 1.0
@@ -471,28 +448,27 @@ class SymmOp(MSONable):
                 factor = -1 if m.group(1) == "-" else 1
                 num = float(m.group(2)) / float(m.group(3)) if m.group(3) != "" else float(m.group(2))
                 trans[i] = num * factor
-        return SymmOp.from_rotation_and_translation(rot_matrix, trans)
+        return cls.from_rotation_and_translation(rot_matrix, trans)
 
     @classmethod
     def from_dict(cls, d) -> SymmOp:
-        """
-        :param d: dict
-        :return: SymmOp from dict representation.
+        """:param d: dict
+
+        Returns:
+            SymmOp from dict representation.
         """
         return cls(d["matrix"], d["tolerance"])
 
 
 class MagSymmOp(SymmOp):
-    """
-    Thin wrapper around SymmOp to extend it to support magnetic symmetry by including a time
+    """Thin wrapper around SymmOp to extend it to support magnetic symmetry by including a time
     reversal operator. Magnetic symmetry is similar to conventional crystal symmetry, except
     symmetry is reduced by the addition of a time reversal operator which acts on an atom's magnetic
     moment.
     """
 
-    def __init__(self, affine_transformation_matrix: ArrayLike, time_reversal: int, tol: float = 0.01):
-        """
-        Initializes the MagSymmOp from a 4x4 affine transformation matrix and time reversal
+    def __init__(self, affine_transformation_matrix: ArrayLike, time_reversal: int, tol: float = 0.01) -> None:
+        """Initializes the MagSymmOp from a 4x4 affine transformation matrix and time reversal
         operator. In general, this constructor should not be used unless you are transferring
         rotations. Use the static constructors instead to generate a SymmOp from proper rotations
         and translation.
@@ -515,10 +491,10 @@ class MagSymmOp(SymmOp):
             self.time_reversal == other.time_reversal
         )
 
-    def __str__(self):
-        return self.as_xyzt_string()
+    def __str__(self) -> str:
+        return self.as_xyzt_str()
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         output = [
             "Rot:",
             str(self.affine_matrix[0:3][:, 0:3]),
@@ -529,14 +505,17 @@ class MagSymmOp(SymmOp):
         ]
         return "\n".join(output)
 
-    def __hash__(self):
+    def __hash__(self) -> int:
         # useful for obtaining a set of unique MagSymmOps
         hashable_value = (*tuple(self.affine_matrix.flatten()), self.time_reversal)
         return hash(hashable_value)
 
+    @due.dcite(
+        Doi("10.1051/epjconf/20122200010"),
+        description="Symmetry and magnetic structures",
+    )
     def operate_magmom(self, magmom):
-        """
-        Apply time reversal operator on the magnetic moment. Note that
+        """Apply time reversal operator on the magnetic moment. Note that
         magnetic moments transform as axial vectors, not polar vectors.
 
         See 'Symmetry and magnetic structures', Rodríguez-Carvajal and
@@ -560,8 +539,7 @@ class MagSymmOp(SymmOp):
 
     @classmethod
     def from_symmop(cls, symmop: SymmOp, time_reversal) -> MagSymmOp:
-        """
-        Initialize a MagSymmOp from a SymmOp and time reversal operator.
+        """Initialize a MagSymmOp from a SymmOp and time reversal operator.
 
         Args:
             symmop (SymmOp): SymmOp
@@ -570,8 +548,7 @@ class MagSymmOp(SymmOp):
         Returns:
             MagSymmOp object
         """
-        mag_symmop = cls(symmop.affine_matrix, time_reversal, symmop.tol)
-        return mag_symmop
+        return cls(symmop.affine_matrix, time_reversal, symmop.tol)
 
     @staticmethod
     def from_rotation_and_translation_and_time_reversal(
@@ -580,8 +557,7 @@ class MagSymmOp(SymmOp):
         time_reversal: int = 1,
         tol: float = 0.1,
     ) -> MagSymmOp:
-        """
-        Creates a symmetry operation from a rotation matrix, translation
+        """Creates a symmetry operation from a rotation matrix, translation
         vector and time reversal operator.
 
         Args:
@@ -598,33 +574,32 @@ class MagSymmOp(SymmOp):
         )
         return MagSymmOp.from_symmop(symm_op, time_reversal)
 
-    @staticmethod
-    def from_xyzt_string(xyzt_string: str) -> MagSymmOp:
+    @classmethod
+    def from_xyzt_str(cls, xyzt_str: str) -> MagSymmOp:
         """
         Args:
-            xyzt_string (str): of the form 'x, y, z, +1', '-x, -y, z, -1',
+            xyzt_str (str): of the form 'x, y, z, +1', '-x, -y, z, -1',
                 '-2y+1/2, 3x+1/2, z-y+1/2, +1', etc.
 
         Returns:
             MagSymmOp object
         """
-        symm_op = SymmOp.from_xyz_string(xyzt_string.rsplit(",", 1)[0])
+        symm_op = SymmOp.from_xyz_str(xyzt_str.rsplit(",", 1)[0])
         try:
-            time_reversal = int(xyzt_string.rsplit(",", 1)[1])
+            time_reversal = int(xyzt_str.rsplit(",", 1)[1])
         except Exception:
             raise Exception("Time reversal operator could not be parsed.")
-        return MagSymmOp.from_symmop(symm_op, time_reversal)
+        return cls.from_symmop(symm_op, time_reversal)
 
-    def as_xyzt_string(self) -> str:
-        """
-        Returns a string of the form 'x, y, z, +1', '-x, -y, z, -1',
+    def as_xyzt_str(self) -> str:
+        """Returns a string of the form 'x, y, z, +1', '-x, -y, z, -1',
         '-y+1/2, x+1/2, z+1/2, +1', etc. Only works for integer rotation matrices.
         """
-        xyzt_string = SymmOp.as_xyz_string(self)
+        xyzt_string = SymmOp.as_xyz_str(self)
         return f"{xyzt_string}, {self.time_reversal:+}"
 
     def as_dict(self) -> dict[str, Any]:
-        """:return: MSONABle dict"""
+        """MSONable dict."""
         return {
             "@module": type(self).__module__,
             "@class": type(self).__name__,
@@ -635,8 +610,9 @@ class MagSymmOp(SymmOp):
 
     @classmethod
     def from_dict(cls, d: dict) -> MagSymmOp:
-        """
-        :param d: dict
-        :return: MagneticSymmOp from dict representation.
+        """:param d: dict
+
+        Returns:
+            MagneticSymmOp from dict representation.
         """
         return cls(d["matrix"], tol=d["tolerance"], time_reversal=d["time_reversal"])
