@@ -21,8 +21,7 @@ if TYPE_CHECKING:
 
 
 class Site(collections.abc.Hashable, MSONable):
-    """
-    A generalized *non-periodic* site. This is essentially a composition
+    """A generalized *non-periodic* site. This is essentially a composition
     at a point in space, with some optional properties associated with it. A
     Composition is used to represent the atoms and occupancy, which allows for
     disordered site representation. Coords are given in standard Cartesian
@@ -36,10 +35,10 @@ class Site(collections.abc.Hashable, MSONable):
         species: SpeciesLike | CompositionLike,
         coords: ArrayLike,
         properties: dict | None = None,
+        label: str | None = None,
         skip_checks: bool = False,
     ) -> None:
-        """
-        Creates a non-periodic Site.
+        """Creates a non-periodic Site.
 
         :param species: Species on the site. Can be:
             i.  A Composition-type object (preferred)
@@ -52,6 +51,7 @@ class Site(collections.abc.Hashable, MSONable):
         :param coords: Cartesian coordinates of site.
         :param properties: Properties associated with the site as a dict, e.g.
             {"magmom": 5}. Defaults to None.
+        :param label: Label for the site. Defaults to None.
         :param skip_checks: Whether to ignore all the usual checks and just
             create the site. Use this if the Site is created in a controlled
             manner and speed is desired.
@@ -59,7 +59,7 @@ class Site(collections.abc.Hashable, MSONable):
         if not skip_checks:
             if not isinstance(species, Composition):
                 try:
-                    species = Composition({get_el_sp(species): 1})
+                    species = Composition({get_el_sp(species): 1})  # type: ignore
                 except TypeError:
                     species = Composition(species)
             total_occu = species.num_atoms
@@ -69,6 +69,7 @@ class Site(collections.abc.Hashable, MSONable):
         self._species: Composition = species  # type: ignore
         self.coords: np.ndarray = coords  # type: ignore
         self.properties: dict = properties or {}
+        self._label = label
 
     def __getattr__(self, attr):
         # overriding getattr doesn't play nicely with pickle, so we can't use self._properties
@@ -79,14 +80,14 @@ class Site(collections.abc.Hashable, MSONable):
 
     @property
     def species(self) -> Composition:
-        """:return: The species on the site as a composition, e.g., Fe0.5Mn0.5."""
+        """The species on the site as a composition, e.g., Fe0.5Mn0.5."""
         return self._species
 
     @species.setter
-    def species(self, species: SpeciesLike | CompositionLike):
+    def species(self, species: SpeciesLike | CompositionLike) -> None:
         if not isinstance(species, Composition):
             try:
-                species = Composition({get_el_sp(species): 1})
+                species = Composition({get_el_sp(species): 1})  # type: ignore
             except TypeError:
                 species = Composition(species)
         total_occu = species.num_atoms
@@ -94,13 +95,22 @@ class Site(collections.abc.Hashable, MSONable):
             raise ValueError("Species occupancies sum to more than 1!")
         self._species = species
 
+    @property
+    def label(self) -> str:
+        """Site label."""
+        return self._label if self._label is not None else self.species_string
+
+    @label.setter
+    def label(self, label: str) -> None:
+        self._label = label
+
     @property
     def x(self) -> float:
         """Cartesian x coordinate."""
         return self.coords[0]
 
     @x.setter
-    def x(self, x: float):
+    def x(self, x: float) -> None:
         self.coords[0] = x
 
     @property
@@ -109,7 +119,7 @@ class Site(collections.abc.Hashable, MSONable):
         return self.coords[1]
 
     @y.setter
-    def y(self, y: float):
+    def y(self, y: float) -> None:
         self.coords[1] = y
 
     @property
@@ -118,12 +128,11 @@ class Site(collections.abc.Hashable, MSONable):
         return self.coords[2]
 
     @z.setter
-    def z(self, z: float):
+    def z(self, z: float) -> None:
         self.coords[2] = z
 
     def distance(self, other) -> float:
-        """
-        Get distance between two sites.
+        """Get distance between two sites.
 
         Args:
             other: Other site.
@@ -134,8 +143,7 @@ class Site(collections.abc.Hashable, MSONable):
         return float(np.linalg.norm(other.coords - self.coords))
 
     def distance_from_point(self, pt) -> float:
-        """
-        Returns distance between the site and a point in space.
+        """Returns distance between the site and a point in space.
 
         Args:
             pt: Cartesian coordinates of point.
@@ -149,14 +157,13 @@ class Site(collections.abc.Hashable, MSONable):
     def species_string(self) -> str:
         """String representation of species on the site."""
         if self.is_ordered:
-            return str(list(self.species)[0])
+            return str(next(iter(self.species)))
         sorted_species = sorted(self.species)
         return ", ".join(f"{sp}:{self.species[sp]:.3f}" for sp in sorted_species)
 
     @property
     def specie(self) -> Element | Species | DummySpecies:
-        """
-        The Species/Element at the site. Only works for ordered sites. Otherwise
+        """The Species/Element at the site. Only works for ordered sites. Otherwise
         an AttributeError is raised. Use this property sparingly.  Robust
         design should make use of the property species instead. Note that the
         singular of species is also species. So the choice of this variable
@@ -167,24 +174,22 @@ class Site(collections.abc.Hashable, MSONable):
         """
         if not self.is_ordered:
             raise AttributeError("specie property only works for ordered sites!")
-        return list(self.species)[0]
+        return next(iter(self.species))
 
     @property
     def is_ordered(self) -> bool:
-        """
-        True if site is an ordered site, i.e., with a single species with
+        """True if site is an ordered site, i.e., with a single species with
         occupancy 1.
         """
         total_occu = self.species.num_atoms
-        return total_occu == 1 and len(self.species) == 1
+        return total_occu == len(self.species) == 1
 
     def __getitem__(self, el):
         """Get the occupancy for element."""
         return self.species[el]
 
     def __eq__(self, other: object) -> bool:
-        """
-        Site is equal to another site if the species and occupancies are the
+        """Site is equal to another site if the species and occupancies are the
         same, and the coordinates are the same to some tolerance.  numpy
         function `allclose` is used to determine if coordinates are close.
         """
@@ -197,22 +202,25 @@ class Site(collections.abc.Hashable, MSONable):
             and self.properties == other.properties
         )
 
-    def __hash__(self):
-        """
-        Minimally effective hash function that just distinguishes between Sites
+    def __hash__(self) -> int:
+        """Minimally effective hash function that just distinguishes between Sites
         with different elements.
         """
         return sum(el.Z for el in self.species)
 
-    def __contains__(self, el):
+    def __contains__(self, el) -> bool:
         return el in self.species
 
-    def __repr__(self):
-        return f"Site: {self.species_string} ({self.coords[0]:.4f}, {self.coords[1]:.4f}, {self.coords[2]:.4f})"
+    def __repr__(self) -> str:
+        name = self.species_string
+
+        if self.label != name:
+            name = f"{self.label} ({name})"
+
+        return f"Site: {name} ({self.coords[0]:.4f}, {self.coords[1]:.4f}, {self.coords[2]:.4f})"
 
     def __lt__(self, other):
-        """
-        Sets a default sort order for atomic species by electronegativity. Very
+        """Sets a default sort order for atomic species by electronegativity. Very
         useful for getting correct formulas. For example, FeO4PLi is
         automatically sorted in LiFePO4.
         """
@@ -226,7 +234,7 @@ class Site(collections.abc.Hashable, MSONable):
             return False
         return False
 
-    def __str__(self):
+    def __str__(self) -> str:
         return f"{self.coords} {self.species_string}"
 
     def as_dict(self) -> dict:
@@ -248,6 +256,9 @@ class Site(collections.abc.Hashable, MSONable):
         }
         if self.properties:
             dct["properties"] = self.properties
+
+        dct["label"] = self.label
+
         return dct
 
     @classmethod
@@ -266,12 +277,12 @@ class Site(collections.abc.Hashable, MSONable):
         if props is not None:
             for key in props:
                 props[key] = json.loads(json.dumps(props[key], cls=MontyEncoder), cls=MontyDecoder)
-        return cls(atoms_n_occu, dct["xyz"], properties=props)
+        label = dct.get("label")
+        return cls(atoms_n_occu, dct["xyz"], properties=props, label=label)
 
 
 class PeriodicSite(Site, MSONable):
-    """
-    Extension of generic Site object to periodic systems.
+    """Extension of generic Site object to periodic systems.
     PeriodicSite includes a lattice system.
     """
 
@@ -283,10 +294,10 @@ class PeriodicSite(Site, MSONable):
         to_unit_cell: bool = False,
         coords_are_cartesian: bool = False,
         properties: dict | None = None,
+        label: str | None = None,
         skip_checks: bool = False,
-    ):
-        """
-        Create a periodic site.
+    ) -> None:
+        """Create a periodic site.
 
         :param species: Species on the site. Can be:
             i.  A Composition-type object (preferred)
@@ -296,7 +307,8 @@ class PeriodicSite(Site, MSONable):
             iii.Dict of elements/species and occupancies, e.g.,
                 {"Fe" : 0.5, "Mn":0.5}. This allows the setup of
                 disordered structures.
-        :param coords: Cartesian coordinates of site.
+        :param coords: Coordinates of site, fractional coordinates
+            by default. See ``coords_are_cartesian`` for more details.
         :param lattice: Lattice associated with the site.
         :param to_unit_cell: Translates fractional coordinate to the
             basic unit cell, i.e. all fractional coordinates satisfy 0
@@ -305,6 +317,7 @@ class PeriodicSite(Site, MSONable):
             Cartesian coordinates. Defaults to False.
         :param properties: Properties associated with the site as a dict, e.g.
             {"magmom": 5}. Defaults to None.
+        :param label: Label for the site. Defaults to None.
         :param skip_checks: Whether to ignore all the usual checks and just
             create the site. Use this if the PeriodicSite is created in a
             controlled manner and speed is desired.
@@ -318,7 +331,7 @@ class PeriodicSite(Site, MSONable):
             frac_coords = np.array(frac_coords)
             if not isinstance(species, Composition):
                 try:
-                    species = Composition({get_el_sp(species): 1})
+                    species = Composition({get_el_sp(species): 1})  # type: ignore
                 except TypeError:
                     species = Composition(species)
 
@@ -327,14 +340,14 @@ class PeriodicSite(Site, MSONable):
                 raise ValueError("Species occupancies sum to more than 1!")
 
         self._lattice: Lattice = lattice
-        self._frac_coords: ArrayLike = frac_coords
+        self._frac_coords: np.ndarray = np.asarray(frac_coords)
         self._species: Composition = species  # type: ignore
         self._coords: np.ndarray | None = None
         self.properties: dict = properties or {}
+        self._label = label
 
-    def __hash__(self):
-        """
-        Minimally effective hash function that just distinguishes between Sites
+    def __hash__(self) -> int:
+        """Minimally effective hash function that just distinguishes between Sites
         with different elements.
         """
         return sum(el.Z for el in self.species)
@@ -345,20 +358,20 @@ class PeriodicSite(Site, MSONable):
         return self._lattice
 
     @lattice.setter
-    def lattice(self, lattice: Lattice):
+    def lattice(self, lattice: Lattice) -> None:
         """Sets Lattice associated with PeriodicSite."""
         self._lattice = lattice
         self._coords = self._lattice.get_cartesian_coords(self._frac_coords)
 
-    @property  # type: ignore
-    def coords(self) -> np.ndarray:  # type: ignore
+    @property
+    def coords(self) -> np.ndarray:
         """Cartesian coordinates."""
         if self._coords is None:
             self._coords = self._lattice.get_cartesian_coords(self._frac_coords)
         return self._coords
 
     @coords.setter
-    def coords(self, coords):
+    def coords(self, coords) -> None:
         """Set Cartesian coordinates."""
         self._coords = np.array(coords)
         self._frac_coords = self._lattice.get_fractional_coords(self._coords)
@@ -366,10 +379,10 @@ class PeriodicSite(Site, MSONable):
     @property
     def frac_coords(self) -> np.ndarray:
         """Fractional coordinates."""
-        return self._frac_coords  # type: ignore
+        return self._frac_coords
 
     @frac_coords.setter
-    def frac_coords(self, frac_coords):
+    def frac_coords(self, frac_coords) -> None:
         """Set fractional coordinates."""
         self._frac_coords = np.array(frac_coords)
         self._coords = self._lattice.get_cartesian_coords(self._frac_coords)
@@ -377,31 +390,31 @@ class PeriodicSite(Site, MSONable):
     @property
     def a(self) -> float:
         """Fractional a coordinate."""
-        return self._frac_coords[0]  # type: ignore
+        return self._frac_coords[0]
 
     @a.setter
-    def a(self, a: float):
-        self._frac_coords[0] = a  # type: ignore
+    def a(self, a: float) -> None:
+        self._frac_coords[0] = a
         self._coords = self._lattice.get_cartesian_coords(self._frac_coords)
 
     @property
     def b(self) -> float:
         """Fractional b coordinate."""
-        return self._frac_coords[1]  # type: ignore
+        return self._frac_coords[1]
 
     @b.setter
-    def b(self, b: float):
-        self._frac_coords[1] = b  # type: ignore
+    def b(self, b: float) -> None:
+        self._frac_coords[1] = b
         self._coords = self._lattice.get_cartesian_coords(self._frac_coords)
 
     @property
     def c(self) -> float:
         """Fractional c coordinate."""
-        return self._frac_coords[2]  # type: ignore
+        return self._frac_coords[2]
 
     @c.setter
-    def c(self, c: float):
-        self._frac_coords[2] = c  # type: ignore
+    def c(self, c: float) -> None:
+        self._frac_coords[2] = c
         self._coords = self._lattice.get_cartesian_coords(self._frac_coords)
 
     @property
@@ -410,7 +423,7 @@ class PeriodicSite(Site, MSONable):
         return self.coords[0]
 
     @x.setter
-    def x(self, x: float):
+    def x(self, x: float) -> None:
         self.coords[0] = x
         self._frac_coords = self._lattice.get_fractional_coords(self.coords)
 
@@ -420,7 +433,7 @@ class PeriodicSite(Site, MSONable):
         return self.coords[1]
 
     @y.setter
-    def y(self, y: float):
+    def y(self, y: float) -> None:
         self.coords[1] = y
         self._frac_coords = self._lattice.get_fractional_coords(self.coords)
 
@@ -430,7 +443,7 @@ class PeriodicSite(Site, MSONable):
         return self.coords[2]
 
     @z.setter
-    def z(self, z: float):
+    def z(self, z: float) -> None:
         self.coords[2] = z
         self._frac_coords = self._lattice.get_fractional_coords(self.coords)
 
@@ -440,11 +453,10 @@ class PeriodicSite(Site, MSONable):
         if in_place:
             self.frac_coords = np.array(frac_coords)
             return None
-        return PeriodicSite(self.species, frac_coords, self.lattice, properties=self.properties)
+        return PeriodicSite(self.species, frac_coords, self.lattice, properties=self.properties, label=self.label)
 
     def is_periodic_image(self, other: PeriodicSite, tolerance: float = 1e-8, check_lattice: bool = True) -> bool:
-        """
-        Returns True if sites are periodic images of each other.
+        """Returns True if sites are periodic images of each other.
 
         Args:
             other (PeriodicSite): Other site
@@ -477,8 +489,7 @@ class PeriodicSite(Site, MSONable):
     def distance_and_image_from_frac_coords(
         self, fcoords: ArrayLike, jimage: ArrayLike | None = None
     ) -> tuple[float, np.ndarray]:
-        """
-        Gets distance between site and a fractional coordinate assuming
+        """Gets distance between site and a fractional coordinate assuming
         periodic boundary conditions. If the index jimage of two sites atom j
         is not specified it selects the j image nearest to the i atom and
         returns the distance and jimage indices in terms of lattice vector
@@ -500,8 +511,7 @@ class PeriodicSite(Site, MSONable):
         return self.lattice.get_distance_and_image(self.frac_coords, fcoords, jimage=jimage)
 
     def distance_and_image(self, other: PeriodicSite, jimage: ArrayLike | None = None) -> tuple[float, np.ndarray]:
-        """
-        Gets distance and instance between two sites assuming periodic boundary
+        """Gets distance and instance between two sites assuming periodic boundary
         conditions. If the index jimage of two sites atom j is not specified it
         selects the j image nearest to the i atom and returns the distance and
         jimage indices in terms of lattice vector translations. If the index
@@ -522,8 +532,7 @@ class PeriodicSite(Site, MSONable):
         return self.distance_and_image_from_frac_coords(other.frac_coords, jimage)
 
     def distance(self, other: PeriodicSite, jimage: ArrayLike | None = None):
-        """
-        Get distance between two sites assuming periodic boundary conditions.
+        """Get distance between two sites assuming periodic boundary conditions.
 
         Args:
             other (PeriodicSite): Other site to get distance from.
@@ -537,21 +546,23 @@ class PeriodicSite(Site, MSONable):
         """
         return self.distance_and_image(other, jimage)[0]
 
-    def __repr__(self):
-        return (
-            f"PeriodicSite: {self.species_string} "
-            f"({self.coords[0]:.4f}, {self.coords[1]:.4f}, {self.coords[2]:.4f}) "
-            f"[{self._frac_coords[0]:.4f}, {self._frac_coords[1]:.4f}, {self._frac_coords[2]:.4f}]"
-        )
+    def __repr__(self) -> str:
+        name = self.species_string
+
+        if self.label != name:
+            name = f"{self.label} ({name})"
+
+        x, y, z = self.coords
+        x_frac, y_frac, z_frac = map(float, self.frac_coords)
+        cls_name = type(self).__name__
+        return f"{cls_name}: {name} ({x:.4}, {y:.4}, {z:.4}) [{x_frac:.4}, {y_frac:.4}, {z_frac:.4}]"
 
     def as_dict(self, verbosity: int = 0) -> dict:
-        """
-        JSON-serializable dict representation of PeriodicSite.
+        """JSON-serializable dict representation of PeriodicSite.
 
         Args:
-            verbosity (int): Verbosity level. Default of 0 only includes the
-                matrix representation. Set to 1 for more details such as
-                Cartesian coordinates, etc.
+            verbosity (int): Verbosity level. Default of 0 only includes the matrix
+                representation. Set to 1 for more details such as Cartesian coordinates, etc.
         """
         species_list = []
         for spec, occu in self._species.items():
@@ -571,19 +582,18 @@ class PeriodicSite(Site, MSONable):
 
         if verbosity > 0:
             dct["xyz"] = [float(c) for c in self.coords]
-            dct["label"] = self.species_string
 
         dct["properties"] = self.properties
+        dct["label"] = self.label
 
         return dct
 
     @classmethod
-    def from_dict(cls, d, lattice=None) -> PeriodicSite:
-        """
-        Create PeriodicSite from dict representation.
+    def from_dict(cls, dct, lattice=None) -> PeriodicSite:
+        """Create PeriodicSite from dict representation.
 
         Args:
-            d (dict): dict representation of PeriodicSite
+            dct (dict): dict representation of PeriodicSite
             lattice: Optional lattice to override lattice specified in d.
                 Useful for ensuring all sites in a structure share the same
                 lattice.
@@ -592,7 +602,7 @@ class PeriodicSite(Site, MSONable):
             PeriodicSite
         """
         species = {}
-        for sp_occu in d["species"]:
+        for sp_occu in dct["species"]:
             if "oxidation_state" in sp_occu and Element.is_valid_symbol(sp_occu["element"]):
                 sp = Species.from_dict(sp_occu)
             elif "oxidation_state" in sp_occu:
@@ -600,9 +610,10 @@ class PeriodicSite(Site, MSONable):
             else:
                 sp = Element(sp_occu["element"])  # type: ignore
             species[sp] = sp_occu["occu"]
-        props = d.get("properties")
+        props = dct.get("properties")
         if props is not None:
             for key in props:
                 props[key] = json.loads(json.dumps(props[key], cls=MontyEncoder), cls=MontyDecoder)
-        lattice = lattice or Lattice.from_dict(d["lattice"])
-        return cls(species, d["abc"], lattice, properties=props)
+        label = dct.get("label")
+        lattice = lattice or Lattice.from_dict(dct["lattice"])
+        return cls(species, dct["abc"], lattice, properties=props, label=label)
