@@ -1,7 +1,11 @@
-"""
-This module defines classes to represent crystal orbital Hamilton
+"""This module defines classes to represent crystal orbital Hamilton
 populations (COHP) and integrated COHP (ICOHP), but can also be used
-for crystal orbital overlap populations (COOP).
+for crystal orbital overlap populations (COOP) or crystal orbital bond indices (COBIs).
+If you use this module, please cite:
+J. George, G. Petretto, A. Naik, M. Esters, A. J. Jackson, R. Nelson, R. Dronskowski, G.-M. Rignanese, G. Hautier,
+"Automated Bonding Analysis with Crystal Orbital Hamilton Populations",
+ChemPlusChem 2022, e202200123,
+DOI: 10.1002/cplu.202200123.
 """
 
 from __future__ import annotations
@@ -20,20 +24,26 @@ from pymatgen.electronic_structure.core import Orbital, Spin
 from pymatgen.io.lmto import LMTOCopl
 from pymatgen.io.lobster import Cohpcar
 from pymatgen.util.coord import get_linear_interpolated_value
+from pymatgen.util.due import Doi, due
 from pymatgen.util.num import round_to_sigfigs
 
 __author__ = "Marco Esters, Janine George"
 __copyright__ = "Copyright 2017, The Materials Project"
 __version__ = "0.2"
-__maintainer__ = "Marco Esters, Janine George"
-__email__ = "esters@uoregon.edu, janine.george@uclouvain.be"
+__maintainer__ = "Janine George"
+__email__ = "janinegeorge.ulfen@gmail.com"
 __date__ = "Dec 13, 2017"
 
+due.cite(
+    Doi("10.1002/cplu.202200123"),
+    description="Automated Bonding Analysis with Crystal Orbital Hamilton Populations",
+)
+
 
 class Cohp(MSONable):
     """Basic COHP object."""
 
-    def __init__(self, efermi, energies, cohp, are_coops=False, are_cobis=False, icohp=None):
+    def __init__(self, efermi, energies, cohp, are_coops=False, are_cobis=False, icohp=None) -> None:
         """
         Args:
             are_coops: Indicates whether this object describes COOPs.
@@ -50,38 +60,35 @@ class Cohp(MSONable):
         self.cohp = cohp
         self.icohp = icohp
 
-    def __repr__(self):
-        return str(self)
-
-    def __str__(self):
+    def __repr__(self) -> str:
         """Returns a string that can be easily plotted (e.g. using gnuplot)."""
         if self.are_coops:
-            cohpstring = "COOP"
+            cohp_str = "COOP"
         elif self.are_cobis:
-            cohpstring = "COBI"
+            cohp_str = "COBI"
         else:
-            cohpstring = "COHP"
-        header = ["Energy", cohpstring + "Up"]
+            cohp_str = "COHP"
+        header = ["Energy", f"{cohp_str}Up"]
         data = [self.energies, self.cohp[Spin.up]]
         if Spin.down in self.cohp:
-            header.append(cohpstring + "Down")
+            header.append(f"{cohp_str}Down")
             data.append(self.cohp[Spin.down])
         if self.icohp:
-            header.append("I" + cohpstring + "Up")
+            header.append(f"I{cohp_str}Up")
             data.append(self.icohp[Spin.up])
             if Spin.down in self.cohp:
-                header.append("I" + cohpstring + "Down")
+                header.append(f"I{cohp_str}Down")
                 data.append(self.icohp[Spin.down])
-        formatheader = "#" + " ".join("{:15s}" for __ in header)
-        formatdata = " ".join("{:.5f}" for __ in header)
-        stringarray = [formatheader.format(*header)]
-        for i, __ in enumerate(self.energies):
-            stringarray.append(formatdata.format(*(d[i] for d in data)))
-        return "\n".join(stringarray)
+        format_header = "#" + " ".join("{:15s}" for __ in header)
+        format_data = " ".join("{:.5f}" for __ in header)
+        str_arr = [format_header.format(*header)]
+        for idx in range(len(self.energies)):
+            str_arr.append(format_data.format(*(d[idx] for d in data)))
+        return "\n".join(str_arr)
 
     def as_dict(self):
         """JSON-serializable dict representation of COHP."""
-        d = {
+        dct = {
             "@module": type(self).__module__,
             "@class": type(self).__name__,
             "are_coops": self.are_coops,
@@ -91,12 +98,11 @@ class Cohp(MSONable):
             "COHP": {str(spin): pops.tolist() for spin, pops in self.cohp.items()},
         }
         if self.icohp:
-            d["ICOHP"] = {str(spin): pops.tolist() for spin, pops in self.icohp.items()}
-        return d
+            dct["ICOHP"] = {str(spin): pops.tolist() for spin, pops in self.icohp.items()}
+        return dct
 
     def get_cohp(self, spin=None, integrated=False):
-        """
-        Returns the COHP or ICOHP for a particular spin.
+        """Returns the COHP or ICOHP for a particular spin.
 
         Args:
             spin: Spin. Can be parsed as spin object, integer (-1/1)
@@ -117,8 +123,7 @@ class Cohp(MSONable):
         if isinstance(spin, int):
             spin = Spin(spin)
         elif isinstance(spin, str):
-            s = {"up": 1, "down": -1}[spin.lower()]
-            spin = Spin(s)
+            spin = Spin({"up": 1, "down": -1}[spin.lower()])
         return {spin: populations[spin]}
 
     def get_icohp(self, spin=None):
@@ -126,8 +131,7 @@ class Cohp(MSONable):
         return self.get_cohp(spin=spin, integrated=True)
 
     def get_interpolated_value(self, energy, integrated=False):
-        """
-        Returns the COHP for a particular energy.
+        """Returns the COHP for a particular energy.
 
         Args:
             energy: Energy to return the COHP value for.
@@ -144,13 +148,10 @@ class Cohp(MSONable):
         return inter
 
     def has_antibnd_states_below_efermi(self, spin=None, limit=0.01):
+        """Returns dict indicating if there are antibonding states below the Fermi level depending on the spin
+        spin: Spin
+        limit: -COHP smaller -limit will be considered.
         """
-        Returns dict indicating if there are antibonding states below the Fermi level depending on the spin
-            spin: Spin
-            limit: -COHP smaller -limit will be considered.
-        """
-        warnings.warn("This method has not been tested on many examples. Check the parameter limit, pls!")
-
         populations = self.cohp
         number_energies_below_efermi = len([x for x in self.energies if x <= self.efermi])
 
@@ -181,7 +182,7 @@ class Cohp(MSONable):
     def from_dict(cls, dct):
         """Returns a COHP object from a dict representation of the COHP."""
         icohp = {Spin(int(key)): np.array(val) for key, val in dct["ICOHP"].items()} if "ICOHP" in dct else None
-        are_cobis = False if "are_cobis" not in dct else dct["are_cobis"]
+        are_cobis = dct.get("are_cobis", False)
         return Cohp(
             dct["efermi"],
             dct["energies"],
@@ -193,42 +194,18 @@ class Cohp(MSONable):
 
 
 class CompleteCohp(Cohp):
-    """
-    A wrapper class that defines an average COHP, and individual COHPs.
+    """A wrapper class that defines an average COHP, and individual COHPs.
 
-    .. attribute: are_coops
-
-         Indicates whether the object is consisting of COOPs.
-
-
-    .. attribute: are_cobis
-
-         Indicates whether the object is consisting of COBIs.
-
-
-    .. attribute: efermi
-
-         Fermi energy
-
-    .. attribute: energies
-
-         Sequence of energies
-
-    .. attribute: structure
-
-         Structure associated with the COHPs.
-
-    .. attribute: cohp, icohp
-
-         The average COHP/ICOHP.
-
-    .. attribute: all_cohps
-
-         A dict of COHPs for individual bonds of the form {label: COHP}
-
-    .. attribute: orb_res_cohp
-
-        Orbital-resolved COHPs.
+    Attributes:
+        are_coops (bool): Indicates whether the object is consisting of COOPs.
+        are_cobis (bool): Indicates whether the object is consisting of COBIs.
+        efermi (float): Fermi energy.
+        energies (Sequence[float]): Sequence of energies.
+        structure (pymatgen.Structure): Structure associated with the COHPs.
+        cohp (Sequence[float]): The average COHP.
+        icohp (Sequence[float]): The average ICOHP.
+        all_cohps (dict[str, Sequence[float]]): A dict of COHPs for individual bonds of the form {label: COHP}.
+        orb_res_cohp (dict[str, Dict[str, Sequence[float]]]): Orbital-resolved COHPs.
     """
 
     def __init__(
@@ -240,7 +217,7 @@ class CompleteCohp(Cohp):
         are_coops=False,
         are_cobis=False,
         orb_res_cohp=None,
-    ):
+    ) -> None:
         """
         Args:
             structure: Structure associated with this COHP.
@@ -273,21 +250,18 @@ class CompleteCohp(Cohp):
         self.are_cobis = are_cobis
         self.all_cohps = cohp_dict
         self.orb_res_cohp = orb_res_cohp
-        if bonds is None:
-            self.bonds = {label: {} for label in self.all_cohps}
-        else:
-            self.bonds = bonds
+        self.bonds = bonds or {label: {} for label in self.all_cohps}
 
-    def __str__(self):
+    def __str__(self) -> str:
         if self.are_coops:
-            return "Complete COOPs for " + str(self.structure)
+            return f"Complete COOPs for {self.structure}"
         if self.are_cobis:
-            return "Complete COBIs for " + str(self.structure)
-        return "Complete COHPs for " + str(self.structure)
+            return f"Complete COBIs for {self.structure}"
+        return f"Complete COHPs for {self.structure}"
 
     def as_dict(self):
         """JSON-serializable dict representation of CompleteCohp."""
-        d = {
+        dct = {
             "@module": type(self).__module__,
             "@class": type(self).__name__,
             "are_coops": self.are_coops,
@@ -299,21 +273,21 @@ class CompleteCohp(Cohp):
         }
 
         if self.icohp is not None:
-            d["ICOHP"] = {"average": {str(spin): pops.tolist() for spin, pops in self.icohp.items()}}
+            dct["ICOHP"] = {"average": {str(spin): pops.tolist() for spin, pops in self.icohp.items()}}
 
         for label in self.all_cohps:
-            d["COHP"].update({label: {str(spin): pops.tolist() for spin, pops in self.all_cohps[label].cohp.items()}})
+            dct["COHP"].update({label: {str(spin): pops.tolist() for spin, pops in self.all_cohps[label].cohp.items()}})
             if self.all_cohps[label].icohp is not None:
-                if "ICOHP" not in d:
-                    d["ICOHP"] = {
+                if "ICOHP" not in dct:
+                    dct["ICOHP"] = {
                         label: {str(spin): pops.tolist() for spin, pops in self.all_cohps[label].icohp.items()}
                     }
                 else:
-                    d["ICOHP"].update(
+                    dct["ICOHP"].update(
                         {label: {str(spin): pops.tolist() for spin, pops in self.all_cohps[label].icohp.items()}}
                     )
         if False in [bond_dict == {} for bond_dict in self.bonds.values()]:
-            d["bonds"] = {
+            dct["bonds"] = {
                 bond: {
                     "length": self.bonds[bond]["length"],
                     "sites": [site.as_dict() for site in self.bonds[bond]["sites"]],
@@ -331,13 +305,12 @@ class CompleteCohp(Cohp):
                     orb_dict[label][orbs]["ICOHP"] = icohp
                     orbitals = [[orb[0], orb[1].name] for orb in self.orb_res_cohp[label][orbs]["orbitals"]]
                     orb_dict[label][orbs]["orbitals"] = orbitals
-            d["orb_res_cohp"] = orb_dict
+            dct["orb_res_cohp"] = orb_dict
 
-        return d
+        return dct
 
     def get_cohp_by_label(self, label, summed_spin_channels=False):
-        """
-        Get specific COHP object.
+        """Get specific COHP object.
 
         Args:
             label: string (for newer Lobster versions: a number)
@@ -373,13 +346,13 @@ class CompleteCohp(Cohp):
         )
 
     def get_summed_cohp_by_label_list(self, label_list, divisor=1, summed_spin_channels=False):
-        """
-        Returns a COHP object that includes a summed COHP divided by divisor.
+        """Returns a COHP object that includes a summed COHP divided by divisor.
 
         Args:
             label_list: list of labels for the COHP that should be included in the summed cohp
             divisor: float/int, the summed cohp will be divided by this divisor
             summed_spin_channels: bool, will sum the spin channels and return the sum in Spin.up if true
+
         Returns:
             Returns a COHP object including a summed COHP
         """
@@ -428,8 +401,7 @@ class CompleteCohp(Cohp):
     def get_summed_cohp_by_label_and_orbital_list(
         self, label_list, orbital_list, divisor=1, summed_spin_channels=False
     ):
-        """
-        Returns a COHP object that includes a summed COHP divided by divisor.
+        """Returns a COHP object that includes a summed COHP divided by divisor.
 
         Args:
             label_list: list of labels for the COHP that should be included in the summed cohp
@@ -485,8 +457,7 @@ class CompleteCohp(Cohp):
         )
 
     def get_orbital_resolved_cohp(self, label, orbitals, summed_spin_channels=False):
-        """
-        Get orbital-resolved COHP.
+        """Get orbital-resolved COHP.
 
         Args:
             label: bond label (Lobster: labels as in ICOHPLIST/ICOOPLIST.lobster).
@@ -648,7 +619,7 @@ class CompleteCohp(Cohp):
                 icohp = None
             avg_cohp = Cohp(efermi, energies, cohp, icohp=icohp)
 
-        are_cobis = False if "are_cobis" not in d else d["are_cobis"]
+        are_cobis = d.get("are_cobis", False)
 
         return CompleteCohp(
             structure,
@@ -662,8 +633,7 @@ class CompleteCohp(Cohp):
 
     @classmethod
     def from_file(cls, fmt, filename=None, structure_file=None, are_coops=False, are_cobis=False):
-        """
-        Creates a CompleteCohp object from an output file of a COHP
+        """Creates a CompleteCohp object from an output file of a COHP
         calculation. Valid formats are either LMTO (for the Stuttgart
         LMTO-ASA code) or LOBSTER (for the LOBSTER code).
 
@@ -732,10 +702,9 @@ class CompleteCohp(Cohp):
             # may not be present when the cohpgenerator keyword is used
             # in LOBSTER versions 2.2.0 and earlier.
             # TODO: Test this more extensively
-            # pylint: disable=E1133,E1136
+
             for label in orb_res_cohp:
                 if cohp_file.cohp_data[label]["COHP"] is None:
-                    # print(label)
                     cohp_data[label]["COHP"] = {
                         sp: np.sum(
                             [orb_res_cohp[label][orbs]["COHP"][sp] for orbs in orb_res_cohp[label]],
@@ -756,7 +725,7 @@ class CompleteCohp(Cohp):
             # Calculate the average COHP for the LMTO file to be
             # consistent with LOBSTER output.
             avg_data = {"COHP": {}, "ICOHP": {}}
-            for i in avg_data:  # pylint: disable=C0206
+            for i in avg_data:
                 for spin in spins:
                     rows = np.array([v[i][spin] for v in cohp_data.values()])
                     avg = np.average(rows, axis=0)
@@ -799,29 +768,22 @@ class CompleteCohp(Cohp):
 
 
 class IcohpValue(MSONable):
-    """
-    Class to store information on an ICOHP or ICOOP value.
-
-    .. attribute:: num_bonds
-            number of bonds used for the average cohp (relevant for Lobster versions <3.0) (int)
-
-    .. attribute:: are_coops
-            Boolean to indicates ICOOPs
-
-    .. attribute:: are_cobis
-            Boolean to indicates ICOBIs
-
-    .. attribute:: icohp
-            dict={Spin.up: icohpvalue for spin.up, Spin.down: icohpvalue for spin.down}
-
-    .. attribute:: summed_icohp:
-            sum of icohp/icoop of both spin channels
+    """Class to store information on an ICOHP or ICOOP value.
 
+    Attributes:
+        energies (ndarray): Energy values for the COHP/ICOHP/COOP/ICOOP.
+        densities (ndarray): Density of states values for the COHP/ICOHP/COOP/ICOOP.
+        energies_are_cartesian (bool): Whether the energies are cartesian or not.
+        are_coops (bool): Whether the object is a COOP/ICOOP or not.
+        are_cobis (bool): Whether the object is a COBIS/ICOBIS or not.
+        icohp (dict): A dictionary of the ICOHP/COHP values. The keys are Spin.up and Spin.down.
+        summed_icohp (float): The summed ICOHP/COHP values.
+        num_bonds (int): The number of bonds used for the average COHP (relevant for Lobster versions <3.0).
     """
 
     def __init__(
         self, label, atom1, atom2, length, translation, num, icohp, are_coops=False, are_cobis=False, orbitals=None
-    ):
+    ) -> None:
         """
         Args:
             label: label for the icohp
@@ -891,8 +853,8 @@ class IcohpValue(MSONable):
 
     @property
     def num_bonds(self):
-        """
-        tells the number of bonds for which the ICOHP value is an average
+        """Tells the number of bonds for which the ICOHP value is an average.
+
         Returns:
             Int.
         """
@@ -900,8 +862,8 @@ class IcohpValue(MSONable):
 
     @property
     def are_coops(self) -> bool:
-        """
-        tells if ICOOPs or not
+        """Tells if ICOOPs or not.
+
         Returns:
             Boolean.
         """
@@ -909,8 +871,8 @@ class IcohpValue(MSONable):
 
     @property
     def are_cobis(self) -> bool:
-        """
-        tells if ICOBIs or not
+        """Tells if ICOBIs or not.
+
         Returns:
             Boolean.
         """
@@ -918,8 +880,8 @@ class IcohpValue(MSONable):
 
     @property
     def is_spin_polarized(self) -> bool:
-        """
-        tells if spin polarized calculation or not
+        """Tells if spin polarized calculation or not.
+
         Returns:
             Boolean.
         """
@@ -928,7 +890,8 @@ class IcohpValue(MSONable):
     def icohpvalue(self, spin=Spin.up):
         """
         Args:
-            spin: Spin.up or Spin.down
+            spin: Spin.up or Spin.down.
+
         Returns:
             icohpvalue (float) corresponding to chosen spin.
         """
@@ -941,20 +904,20 @@ class IcohpValue(MSONable):
         """
         Args:
             orbitals: List of Orbitals or "str(Orbital1)-str(Orbital2)"
-            spin: Spin.up or Spin.down
+            spin: Spin.up or Spin.down.
+
         Returns:
             icohpvalue (float) corresponding to chosen spin.
         """
         if not self.is_spin_polarized and spin == Spin.down:
             raise ValueError("The calculation was not performed with spin polarization")
         if isinstance(orbitals, list):
-            orbitals = str(orbitals[0]) + "-" + str(orbitals[1])
+            orbitals = f"{orbitals[0]}-{orbitals[1]}"
         return self._orbitals[orbitals]["icohp"][spin]
 
     @property
     def icohp(self):
-        """
-        dict with icohps for spinup and spindown
+        """Dict with icohps for spinup and spindown
         Return:
             dict={Spin.up: icohpvalue for spin.up, Spin.down: icohpvalue for spin.down}.
         """
@@ -962,18 +925,17 @@ class IcohpValue(MSONable):
 
     @property
     def summed_icohp(self):
-        """
-        Sums ICOHPs of both spin channels for spin polarized compounds
+        """Sums ICOHPs of both spin channels for spin polarized compounds.
+
         Returns:
-             icohp value in eV.
+            float: icohp value in eV.
         """
-        sum_icohp = self._icohp[Spin.down] + self._icohp[Spin.up] if self._is_spin_polarized else self._icohp[Spin.up]
-        return sum_icohp
+        return self._icohp[Spin.down] + self._icohp[Spin.up] if self._is_spin_polarized else self._icohp[Spin.up]
 
     @property
     def summed_orbital_icohp(self):
-        """
-        Sums orbitals-resolved ICOHPs of both spin channels for spin-plarized compounds
+        """Sums orbitals-resolved ICOHPs of both spin channels for spin-plarized compounds.
+
         Returns:
             {"str(Orbital1)-str(Ortibal2)": icohp value in eV}.
 
@@ -987,18 +949,12 @@ class IcohpValue(MSONable):
 
 
 class IcohpCollection(MSONable):
-    """
-    Class to store IcohpValues.
-
-    .. attribute:: are_coops
-        Boolean to indicate if these are ICOOPs
-
-    .. attribute:: are_cobis
-        Boolean to indicate if these are ICOOPs
-
-    .. attribute:: is_spin_polarized
-        Boolean to indicate if the Lobster calculation was done spin polarized or not
+    """Class to store IcohpValues.
 
+    Attributes:
+        are_coops (bool): Boolean to indicate if these are ICOOPs.
+        are_cobis (bool): Boolean to indicate if these are ICOOPs.
+        is_spin_polarized (bool): Boolean to indicate if the Lobster calculation was done spin polarized or not.
     """
 
     def __init__(
@@ -1014,7 +970,7 @@ class IcohpCollection(MSONable):
         list_orb_icohp=None,
         are_coops=False,
         are_cobis=False,
-    ):
+    ) -> None:
         """
         Args:
             list_labels: list of labels for ICOHP/ICOOP values
@@ -1060,15 +1016,14 @@ class IcohpCollection(MSONable):
                 orbitals=None if list_orb_icohp is None else list_orb_icohp[ilist],
             )
 
-    def __str__(self):
+    def __str__(self) -> str:
         joinstr = []
         for value in self._icohplist.values():
             joinstr.append(str(value))
         return "\n".join(joinstr)
 
     def get_icohp_by_label(self, label, summed_spin_channels=True, spin=Spin.up, orbitals=None):
-        """
-        get an icohp value for a certain bond as indicated by the label (bond labels starting by "1" as in
+        """Get an icohp value for a certain bond as indicated by the label (bond labels starting by "1" as in
         ICOHPLIST/ICOOPLIST).
 
         Args:
@@ -1076,6 +1031,7 @@ class IcohpCollection(MSONable):
             summed_spin_channels: Boolean to indicate whether the ICOHPs/ICOOPs of both spin channels should be summed
             spin: if summed_spin_channels is equal to False, this spin indicates which spin channel should be returned
             orbitals: List of Orbital or "str(Orbital1)-str(Orbital2)"
+
         Returns:
             float describing ICOHP/ICOOP value
         """
@@ -1086,16 +1042,15 @@ class IcohpCollection(MSONable):
             return icohp_here.icohpvalue(spin)
 
         if isinstance(orbitals, list):
-            orbitals = str(orbitals[0]) + "-" + str(orbitals[1])
+            orbitals = f"{orbitals[0]}-{orbitals[1]}"
         if summed_spin_channels:
             return icohp_here.summed_orbital_icohp[orbitals]
 
         return icohp_here.icohpvalue_orbital(spin=spin, orbitals=orbitals)
 
     def get_summed_icohp_by_label_list(self, label_list, divisor=1.0, summed_spin_channels=True, spin=Spin.up):
-        """
-        get the sum of several ICOHP values that are indicated by a list of labels (labels of the bonds are the same as
-        in ICOHPLIST/ICOOPLIST).
+        """Get the sum of several ICOHP values that are indicated by a list of labels
+        (labels of the bonds are the same as in ICOHPLIST/ICOOPLIST).
 
         Args:
             label_list: list of labels of the ICOHPs/ICOOPs that should be summed
@@ -1104,14 +1059,13 @@ class IcohpCollection(MSONable):
             spin: if summed_spin_channels is equal to False, this spin indicates which spin channel should be returned
 
         Returns:
-             float that is a sum of all ICOHPs/ICOOPs as indicated with label_list
+            float that is a sum of all ICOHPs/ICOOPs as indicated with label_list
         """
         sum_icohp = 0
         for label in label_list:
             icohp_here = self._icohplist[label]
             if icohp_here.num_bonds != 1:
                 warnings.warn("One of the ICOHP values is an average over bonds. This is currently not considered.")
-            # prints warning if num_bonds is not equal to 1
             if icohp_here._is_spin_polarized:
                 if summed_spin_channels:
                     sum_icohp = sum_icohp + icohp_here.summed_icohp
@@ -1122,19 +1076,20 @@ class IcohpCollection(MSONable):
         return sum_icohp / divisor
 
     def get_icohp_dict_by_bondlengths(self, minbondlength=0.0, maxbondlength=8.0):
-        """
-        get a dict of IcohpValues corresponding to certain bond lengths
+        """Get a dict of IcohpValues corresponding to certain bond lengths.
+
         Args:
             minbondlength: defines the minimum of the bond lengths of the bonds
-            maxbondlength: defines the maximum of the bond lengths of the bonds
+            maxbondlength: defines the maximum of the bond lengths of the bonds.
+
         Returns:
-             dict of IcohpValues, the keys correspond to the values from the initial list_labels.
+            dict of IcohpValues, the keys correspond to the values from the initial list_labels.
         """
-        newicohp_dict = {}
+        new_icohp_dict = {}
         for value in self._icohplist.values():
             if value._length >= minbondlength and value._length <= maxbondlength:
-                newicohp_dict[value._label] = value
-        return newicohp_dict
+                new_icohp_dict[value._label] = value
+        return new_icohp_dict
 
     def get_icohp_dict_of_site(
         self,
@@ -1145,8 +1100,7 @@ class IcohpCollection(MSONable):
         maxbondlength=8.0,
         only_bonds_to=None,
     ):
-        """
-        get a dict of IcohpValue for a certain site (indicated by integer).
+        """Get a dict of IcohpValue for a certain site (indicated by integer).
 
         Args:
             site: integer describing the site of interest, order as in Icohplist.lobster/Icooplist.lobster, starts at 0
@@ -1159,9 +1113,9 @@ class IcohpCollection(MSONable):
             only_bonds_to: list of strings describing the bonding partners that are allowed, e.g. ['O']
 
         Returns:
-             dict of IcohpValues, the keys correspond to the values from the initial list_labels
+            dict of IcohpValues, the keys correspond to the values from the initial list_labels
         """
-        newicohp_dict = {}
+        new_icohp_dict = {}
         for key, value in self._icohplist.items():
             atomnumber1 = int(re.split(r"(\d+)", value._atom1)[1]) - 1
             atomnumber2 = int(re.split(r"(\d+)", value._atom2)[1]) - 1
@@ -1178,24 +1132,25 @@ class IcohpCollection(MSONable):
                         if value.summed_icohp >= minsummedicohp:
                             if maxsummedicohp is not None:
                                 if value.summed_icohp <= maxsummedicohp:
-                                    newicohp_dict[key] = value
+                                    new_icohp_dict[key] = value
                             else:
-                                newicohp_dict[key] = value
+                                new_icohp_dict[key] = value
                     elif maxsummedicohp is not None:
                         if value.summed_icohp <= maxsummedicohp:
-                            newicohp_dict[key] = value
+                            new_icohp_dict[key] = value
                     else:
-                        newicohp_dict[key] = value
+                        new_icohp_dict[key] = value
 
-        return newicohp_dict
+        return new_icohp_dict
 
     def extremum_icohpvalue(self, summed_spin_channels=True, spin=Spin.up):
-        """
-        get ICOHP/ICOOP of strongest bond
+        """Get ICOHP/ICOOP of strongest bond.
+
         Args:
             summed_spin_channels: Boolean to indicate whether the ICOHPs/ICOOPs of both spin channels should be summed.
 
             spin: if summed_spin_channels is equal to False, this spin indicates which spin channel should be returned
+
         Returns:
             lowest ICOHP/largest ICOOP value (i.e. ICOHP/ICOOP value of strongest bond)
         """
@@ -1222,25 +1177,24 @@ class IcohpCollection(MSONable):
 
     @property
     def is_spin_polarized(self) -> bool:
-        """:return: Whether it is spin polarized."""
+        """Whether it is spin polarized."""
         return self._is_spin_polarized
 
     @property
     def are_coops(self) -> bool:
-        """:return: Whether this is a coop."""
+        """Whether this is a coop."""
         return self._are_coops
 
     @property
     def are_cobis(self) -> bool:
-        """:return: Whether this a cobi."""
+        """Whether this a cobi."""
         return self._are_cobis
 
 
 def get_integrated_cohp_in_energy_range(
     cohp, label, orbital=None, energy_range=None, relative_E_Fermi=True, summed_spin_channels=True
 ):
-    """
-    Method that can integrate completecohp objects which include data on integrated COHPs
+    """Method that can integrate completecohp objects which include data on integrated COHPs
     Args:
         cohp: CompleteCOHP object
         label: label of the COHP data
