@@ -5,20 +5,22 @@ from __future__ import annotations
 import functools
 import warnings
 from collections import namedtuple
-from typing import TYPE_CHECKING, Mapping, NamedTuple
+from typing import TYPE_CHECKING, NamedTuple
 
 import numpy as np
 from monty.json import MSONable
 from scipy.constants import value as _cd
+from scipy.ndimage import gaussian_filter1d
 from scipy.signal import hilbert
 
-from pymatgen.core.periodic_table import get_el_sp
+from pymatgen.core import Structure, get_el_sp
 from pymatgen.core.spectrum import Spectrum
-from pymatgen.core.structure import Structure
 from pymatgen.electronic_structure.core import Orbital, OrbitalType, Spin
 from pymatgen.util.coord import get_linear_interpolated_value
 
 if TYPE_CHECKING:
+    from collections.abc import Mapping
+
     from numpy.typing import ArrayLike
 
     from pymatgen.core.sites import PeriodicSite
@@ -26,27 +28,19 @@ if TYPE_CHECKING:
 
 
 class DOS(Spectrum):
-    """
-    Replacement basic DOS object. All other DOS objects are extended versions
+    """Replacement basic DOS object. All other DOS objects are extended versions
     of this object. Work in progress.
 
-    .. attribute: energies
-
-        The sequence of energies
-
-    .. attribute: densities
-
-        A dict of spin densities, e.g., {Spin.up: [...], Spin.down: [...]}
-
-    .. attribute: efermi
-
-        Fermi level
+    Attributes:
+        energies (Sequence[float]): The sequence of energies.
+        densities (dict[Spin, Sequence[float]]): A dict of spin densities, e.g., {Spin.up: [...], Spin.down: [...]}.
+        efermi (float): Fermi level.
     """
 
     XLABEL = "Energy"
     YLABEL = "Density"
 
-    def __init__(self, energies: ArrayLike, densities: ArrayLike, efermi: float):
+    def __init__(self, energies: ArrayLike, densities: ArrayLike, efermi: float) -> None:
         """
         Args:
             energies: A sequence of energies
@@ -59,8 +53,7 @@ class DOS(Spectrum):
         self.efermi = efermi
 
     def get_interpolated_gap(self, tol: float = 0.001, abs_tol: bool = False, spin: Spin | None = None):
-        """
-        Expects a DOS object and finds the gap.
+        """Expects a DOS object and finds the gap.
 
         Args:
             tol: tolerance in occupations for determining the gap
@@ -100,8 +93,7 @@ class DOS(Spectrum):
         return end - start, end, start
 
     def get_cbm_vbm(self, tol: float = 0.001, abs_tol: bool = False, spin=None):
-        """
-        Expects a DOS object and finds the cbm and vbm.
+        """Expects a DOS object and finds the cbm and vbm.
 
         Args:
             tol: tolerance in occupations for determining the gap
@@ -142,8 +134,7 @@ class DOS(Spectrum):
         return self.x[i_gap_end], self.x[i_gap_start]
 
     def get_gap(self, tol: float = 0.001, abs_tol: bool = False, spin: Spin | None = None):
-        """
-        Expects a DOS object and finds the gap.
+        """Expects a DOS object and finds the gap.
 
         Args:
             tol: tolerance in occupations for determining the gap
@@ -155,38 +146,30 @@ class DOS(Spectrum):
         Returns:
             gap in eV
         """
-        (cbm, vbm) = self.get_cbm_vbm(tol, abs_tol, spin)
+        cbm, vbm = self.get_cbm_vbm(tol, abs_tol, spin)
         return max(cbm - vbm, 0.0)
 
-    def __str__(self):
+    def __str__(self) -> str:
         """Returns a string which can be easily plotted (using gnuplot)."""
         if Spin.down in self.densities:
-            stringarray = [f"#{'Energy':30s} {'DensityUp':30s} {'DensityDown':30s}"]
+            str_arr = [f"#{'Energy':30s} {'DensityUp':30s} {'DensityDown':30s}"]
             for i, energy in enumerate(self.energies):
-                stringarray.append(f"{energy:.5f} {self.densities[Spin.up][i]:.5f} {self.densities[Spin.down][i]:.5f}")
+                str_arr.append(f"{energy:.5f} {self.densities[Spin.up][i]:.5f} {self.densities[Spin.down][i]:.5f}")
         else:
-            stringarray = [f"#{'Energy':30s} {'DensityUp':30s}"]
+            str_arr = [f"#{'Energy':30s} {'DensityUp':30s}"]
             for i, energy in enumerate(self.energies):
-                stringarray.append(f"{energy:.5f} {self.densities[Spin.up][i]:.5f}")
-        return "\n".join(stringarray)
+                str_arr.append(f"{energy:.5f} {self.densities[Spin.up][i]:.5f}")
+        return "\n".join(str_arr)
 
 
 class Dos(MSONable):
-    """
-    Basic DOS object. All other DOS objects are extended versions of this
+    """Basic DOS object. All other DOS objects are extended versions of this
     object.
 
-    .. attribute: energies
-
-        The sequence of energies
-
-    .. attribute: densities
-
-        A dict of spin densities, e.g., {Spin.up: [...], Spin.down: [...]}
-
-    .. attribute: efermi
-
-        Fermi level
+    Attributes:
+        energies (Sequence[float]): The sequence of energies.
+        densities (dict[Spin, Sequence[float]]): A dict of spin densities, e.g., {Spin.up: [...], Spin.down: [...]}.
+        efermi (float): Fermi level.
     """
 
     def __init__(
@@ -208,8 +191,7 @@ class Dos(MSONable):
         self.densities = {k: np.array(d) / vol for k, d in densities.items()}
 
     def get_densities(self, spin: Spin | None = None):
-        """
-        Returns the density of states for a particular spin.
+        """Returns the density of states for a particular spin.
 
         Args:
             spin: Spin
@@ -230,8 +212,7 @@ class Dos(MSONable):
         return result
 
     def get_smeared_densities(self, sigma: float):
-        """
-        Returns the Dict representation of the densities, {Spin: densities},
+        """Returns the Dict representation of the densities, {Spin: densities},
         but with a Gaussian smearing of std dev sigma.
 
         Args:
@@ -240,18 +221,15 @@ class Dos(MSONable):
         Returns:
             Dict of Gaussian-smeared densities.
         """
-        from scipy.ndimage import gaussian_filter1d
-
         smeared_dens = {}
         diff = [self.energies[i + 1] - self.energies[i] for i in range(len(self.energies) - 1)]
-        avgdiff = sum(diff) / len(diff)
+        avg_diff = sum(diff) / len(diff)
         for spin, dens in self.densities.items():
-            smeared_dens[spin] = gaussian_filter1d(dens, sigma / avgdiff)
+            smeared_dens[spin] = gaussian_filter1d(dens, sigma / avg_diff)
         return smeared_dens
 
     def __add__(self, other):
-        """
-        Adds two DOS together. Checks that energy scales are the same.
+        """Adds two DOS together. Checks that energy scales are the same.
         Otherwise, a ValueError is thrown.
 
         Args:
@@ -265,21 +243,22 @@ class Dos(MSONable):
         densities = {spin: self.densities[spin] + other.densities[spin] for spin in self.densities}
         return Dos(self.efermi, self.energies, densities)
 
-    def get_interpolated_value(self, energy: float):
-        """
-        Returns interpolated density for a particular energy.
+    def get_interpolated_value(self, energy: float) -> dict[Spin, float]:
+        """Returns interpolated density for a particular energy.
 
         Args:
-            energy: Energy to return the density for.
+            energy (float): Energy to return the density for.
+
+        Returns:
+            dict[Spin, float]: Density for energy for each spin.
         """
-        f = {}
+        energies = {}
         for spin in self.densities:
-            f[spin] = get_linear_interpolated_value(self.energies, self.densities[spin], energy)
-        return f
+            energies[spin] = get_linear_interpolated_value(self.energies, self.densities[spin], energy)
+        return energies
 
     def get_interpolated_gap(self, tol: float = 0.001, abs_tol: bool = False, spin: Spin | None = None):
-        """
-        Expects a DOS object and finds the gap.
+        """Expects a DOS object and finds the gap.
 
         Args:
             tol: tolerance in occupations for determining the gap
@@ -290,8 +269,7 @@ class Dos(MSONable):
                 Down - finds the gap in the down spin channel.
 
         Returns:
-            (gap, cbm, vbm):
-                Tuple of floats in eV corresponding to the gap, cbm and vbm.
+            (gap, cbm, vbm): Tuple of floats in eV corresponding to the gap, cbm and vbm.
         """
         tdos = self.get_densities(spin)
         if not abs_tol:
@@ -314,8 +292,7 @@ class Dos(MSONable):
         return end - start, end, start
 
     def get_cbm_vbm(self, tol: float = 0.001, abs_tol: bool = False, spin: Spin | None = None):
-        """
-        Expects a DOS object and finds the cbm and vbm.
+        """Expects a DOS object and finds the cbm and vbm.
 
         Args:
             tol: tolerance in occupations for determining the gap
@@ -350,8 +327,7 @@ class Dos(MSONable):
         return self.energies[i_gap_end], self.energies[i_gap_start]
 
     def get_gap(self, tol: float = 0.001, abs_tol: bool = False, spin: Spin | None = None):
-        """
-        Expects a DOS object and finds the gap.
+        """Expects a DOS object and finds the gap.
 
         Args:
             tol: tolerance in occupations for determining the gap
@@ -366,17 +342,17 @@ class Dos(MSONable):
         (cbm, vbm) = self.get_cbm_vbm(tol, abs_tol, spin)
         return max(cbm - vbm, 0.0)
 
-    def __str__(self):
+    def __str__(self) -> str:
         """Returns a string which can be easily plotted (using gnuplot)."""
         if Spin.down in self.densities:
-            stringarray = [f"#{'Energy':30s} {'DensityUp':30s} {'DensityDown':30s}"]
+            str_arr = [f"#{'Energy':30s} {'DensityUp':30s} {'DensityDown':30s}"]
             for i, energy in enumerate(self.energies):
-                stringarray.append(f"{energy:.5f} {self.densities[Spin.up][i]:.5f} {self.densities[Spin.down][i]:.5f}")
+                str_arr.append(f"{energy:.5f} {self.densities[Spin.up][i]:.5f} {self.densities[Spin.down][i]:.5f}")
         else:
-            stringarray = [f"#{'Energy':30s} {'DensityUp':30s}"]
+            str_arr = [f"#{'Energy':30s} {'DensityUp':30s}"]
             for i, energy in enumerate(self.energies):
-                stringarray.append(f"{energy:.5f} {self.densities[Spin.up][i]:.5f}")
-        return "\n".join(stringarray)
+                str_arr.append(f"{energy:.5f} {self.densities[Spin.up][i]:.5f}")
+        return "\n".join(str_arr)
 
     @classmethod
     def from_dict(cls, d) -> Dos:
@@ -399,8 +375,7 @@ class Dos(MSONable):
 
 
 class FermiDos(Dos, MSONable):
-    """
-    This wrapper class helps relate the density of states, doping levels
+    """This wrapper class helps relate the density of states, doping levels
     (i.e. carrier concentrations) and corresponding fermi levels. A negative
     doping concentration indicates the majority carriers are electrons
     (n-type doping); a positive doping concentration indicates holes are the
@@ -413,7 +388,7 @@ class FermiDos(Dos, MSONable):
         structure: Structure | None = None,
         nelecs: float | None = None,
         bandgap: float | None = None,
-    ):
+    ) -> None:
         """
         Args:
             dos: Pymatgen Dos object.
@@ -467,9 +442,8 @@ class FermiDos(Dos, MSONable):
             self.energies[idx_fermi:] += (bandgap - (ecbm - evbm)) / 2.0
 
     def get_doping(self, fermi_level: float, temperature: float) -> float:
-        """
-        Calculate the doping (majority carrier concentration) at a given
-        fermi level  and temperature. A simple Left Riemann sum is used for
+        """Calculate the doping (majority carrier concentration) at a given
+        Fermi level  and temperature. A simple Left Riemann sum is used for
         integrating the density of states over energy & equilibrium Fermi-Dirac
         distribution.
 
@@ -500,10 +474,9 @@ class FermiDos(Dos, MSONable):
     def get_fermi_interextrapolated(
         self, concentration: float, temperature: float, warn: bool = True, c_ref: float = 1e10, **kwargs
     ) -> float:
-        """
-        Similar to get_fermi except that when get_fermi fails to converge,
+        """Similar to get_fermi except that when get_fermi fails to converge,
         an interpolated or extrapolated fermi is returned with the assumption
-        that the fermi level changes linearly with log(abs(concentration)).
+        that the Fermi level changes linearly with log(abs(concentration)).
 
         Args:
             concentration: The doping concentration in 1/cm^3. Negative values
@@ -546,9 +519,9 @@ class FermiDos(Dos, MSONable):
             f_ref = self.get_fermi_interextrapolated(np.sign(concentration) * c_ref, temperature, warn=False, **kwargs)
             f_new = self.get_fermi_interextrapolated(concentration / 10.0, temperature, warn=False, **kwargs)
             clog = np.sign(concentration) * np.log(abs(concentration))
-            c_newlog = np.sign(concentration) * np.log(abs(self.get_doping(f_new, temperature)))
-            slope = (f_new - f_ref) / (c_newlog - np.sign(concentration) * 10.0)
-            return f_new + slope * (clog - c_newlog)
+            c_new_log = np.sign(concentration) * np.log(abs(self.get_doping(f_new, temperature)))
+            slope = (f_new - f_ref) / (c_new_log - np.sign(concentration) * 10.0)
+            return f_new + slope * (clog - c_new_log)
 
     def get_fermi(
         self,
@@ -559,8 +532,7 @@ class FermiDos(Dos, MSONable):
         step: float = 0.1,
         precision: int = 8,
     ) -> float:
-        """
-        Finds the fermi level at which the doping concentration at the given
+        """Finds the Fermi level at which the doping concentration at the given
         temperature (T) is equal to concentration. A greedy algorithm is used
         where the relative error is minimized by calculating the doping at a
         grid which continually becomes finer.
@@ -571,7 +543,7 @@ class FermiDos(Dos, MSONable):
                 doping.
             temperature: The temperature in Kelvin.
             rtol: The maximum acceptable relative error.
-            nstep: THe number of steps checked around a given fermi level.
+            nstep: The number of steps checked around a given Fermi level.
             step: Initial step in energy when searching for the Fermi level.
             precision: Essentially the decimal places of calculated Fermi level.
 
@@ -579,16 +551,16 @@ class FermiDos(Dos, MSONable):
             ValueError: If the Fermi level cannot be found.
 
         Returns:
-            The fermi level in eV. Note that this is different from the default
+            The Fermi level in eV. Note that this is different from the default
             dos.efermi.
         """
         fermi = self.efermi  # initialize target fermi
         relative_error = [float("inf")]
         for _ in range(precision):
-            frange = np.arange(-nstep, nstep + 1) * step + fermi
-            calc_doping = np.array([self.get_doping(f, temperature) for f in frange])
+            f_range = np.arange(-nstep, nstep + 1) * step + fermi
+            calc_doping = np.array([self.get_doping(f, temperature) for f in f_range])
             relative_error = np.abs(calc_doping / concentration - 1.0)  # type: ignore
-            fermi = frange[np.argmin(relative_error)]
+            fermi = f_range[np.argmin(relative_error)]
             step /= 10.0
 
         if min(relative_error) > rtol:
@@ -619,19 +591,14 @@ class FermiDos(Dos, MSONable):
 
 
 class CompleteDos(Dos):
-    """
-    This wrapper class defines a total dos, and also provides a list of PDos.
+    """This wrapper class defines a total dos, and also provides a list of PDos.
     Mainly used by pymatgen.io.vasp.Vasprun to create a complete Dos from
     a vasprun.xml file. You are unlikely to try to generate this object
     manually.
 
-    .. attribute:: structure
-
-        Structure associated with the CompleteDos.
-
-    .. attribute:: pdos
-
-        Dict of partial densities of the form {Site:{Orbital:{Spin:Densities}}}
+    Attributes:
+        structure (Structure): Structure associated with the CompleteDos.
+        pdos (dict): Dict of partial densities of the form {Site:{Orbital:{Spin:Densities}}}.
     """
 
     def __init__(
@@ -672,8 +639,7 @@ class CompleteDos(Dos):
         )
 
     def get_site_orbital_dos(self, site: PeriodicSite, orbital: Orbital) -> Dos:
-        """
-        Get the Dos for a particular orbital of a particular site.
+        """Get the Dos for a particular orbital of a particular site.
 
         Args:
             site: Site in Structure associated with CompleteDos.
@@ -685,8 +651,7 @@ class CompleteDos(Dos):
         return Dos(self.efermi, self.energies, self.pdos[site][orbital])
 
     def get_site_dos(self, site: PeriodicSite) -> Dos:
-        """
-        Get the total Dos for a site (all orbitals).
+        """Get the total Dos for a site (all orbitals).
 
         Args:
             site: Site in Structure associated with CompleteDos.
@@ -698,8 +663,7 @@ class CompleteDos(Dos):
         return Dos(self.efermi, self.energies, site_dos)
 
     def get_site_spd_dos(self, site: PeriodicSite) -> dict[OrbitalType, Dos]:
-        """
-        Get orbital projected Dos of a particular site.
+        """Get orbital projected Dos of a particular site.
 
         Args:
             site: Site in Structure associated with CompleteDos.
@@ -717,8 +681,7 @@ class CompleteDos(Dos):
         return {orb: Dos(self.efermi, self.energies, densities) for orb, densities in spd_dos.items()}
 
     def get_site_t2g_eg_resolved_dos(self, site: PeriodicSite) -> dict[str, Dos]:
-        """
-        Get the t2g, eg projected DOS for a particular site.
+        """Get the t2g, eg projected DOS for a particular site.
 
         Args:
             site: Site in Structure associated with CompleteDos.
@@ -741,11 +704,10 @@ class CompleteDos(Dos):
         }
 
     def get_spd_dos(self) -> dict[OrbitalType, Dos]:
-        """
-        Get orbital projected Dos.
+        """Get orbital projected Dos.
 
         Returns:
-            dict of {OrbitalType: Dos}, e.g. {OrbitalType.s: Dos object, ...}
+            dict[OrbitalType, Dos]: e.g. {OrbitalType.s: Dos object, ...}
         """
         spd_dos = {}
         for atom_dos in self.pdos.values():
@@ -758,11 +720,10 @@ class CompleteDos(Dos):
         return {orb: Dos(self.efermi, self.energies, densities) for orb, densities in spd_dos.items()}
 
     def get_element_dos(self) -> dict[SpeciesLike, Dos]:
-        """
-        Get element projected Dos.
+        """Get element projected Dos.
 
         Returns:
-            dict of {Element: Dos}
+            dict[Element, Dos]
         """
         el_dos = {}
         for site, atom_dos in self.pdos.items():
@@ -775,14 +736,13 @@ class CompleteDos(Dos):
         return {el: Dos(self.efermi, self.energies, densities) for el, densities in el_dos.items()}
 
     def get_element_spd_dos(self, el: SpeciesLike) -> dict[OrbitalType, Dos]:
-        """
-        Get element and spd projected Dos.
+        """Get element and spd projected Dos.
 
         Args:
             el: Element in Structure.composition associated with CompleteDos
 
         Returns:
-            dict of {OrbitalType: Dos}, e.g. {OrbitalType.s: Dos object, ...}
+            dict[OrbitalType, Dos]: e.g. {OrbitalType.s: Dos object, ...}
         """
         el = get_el_sp(el)
         el_dos = {}
@@ -799,17 +759,14 @@ class CompleteDos(Dos):
 
     @property
     def spin_polarization(self) -> float | None:
-        """
-        Calculates spin polarization at Fermi level. If the
-        calculation is not spin-polarized, None will be
-        returned.
+        """Calculates spin polarization at Fermi level. If the
+        calculation is not spin-polarized, None will be returned.
 
-        See Sanvito et al., doi: 10.1126/sciadv.1602241 for
-        an example usage.
+        See Sanvito et al., doi: 10.1126/sciadv.1602241 for an example usage.
 
-        :return (float): spin polarization in range [0, 1],
-        will also return NaN if spin polarization ill-defined
-        (e.g. for insulator)
+        Returns:
+            float: spin polarization in range [0, 1], will also return NaN if spin
+                polarization ill-defined (e.g. for insulator).
         """
         n_F = self.get_interpolated_value(self.efermi)
 
@@ -833,8 +790,7 @@ class CompleteDos(Dos):
         sites: list[PeriodicSite] | None = None,
         spin: Spin | None = None,
     ) -> float:
-        """
-        Compute the orbital-projected band filling, defined as the zeroth moment
+        """Compute the orbital-projected band filling, defined as the zeroth moment
         up to the Fermi level.
 
         Args:
@@ -844,7 +800,7 @@ class CompleteDos(Dos):
             spin: Spin channel to use. By default, the spin channels will be combined.
 
         Returns:
-            band filling in eV, often denoted f_d for the d-band
+            float: band filling in eV, often denoted f_d for the d-band
         """
         # Get the projected DOS
         if elements and sites:
@@ -873,11 +829,7 @@ class CompleteDos(Dos):
 
         # Only consider up to Fermi level in numerator
         energies = dos.energies - dos.efermi
-        band_filling = np.trapz(dos_densities[energies < 0], x=energies[energies < 0]) / np.trapz(
-            dos_densities, x=energies
-        )
-
-        return band_filling
+        return np.trapz(dos_densities[energies < 0], x=energies[energies < 0]) / np.trapz(dos_densities, x=energies)
 
     def get_band_center(
         self,
@@ -887,8 +839,7 @@ class CompleteDos(Dos):
         spin: Spin | None = None,
         erange: list[float] | None = None,
     ) -> float:
-        """
-        Compute the orbital-projected band center, defined as the first moment
+        """Compute the orbital-projected band center, defined as the first moment
         relative to the Fermi level
             int_{-inf}^{+inf} rho(E)*E dE/int_{-inf}^{+inf} rho(E) dE
         based on the work of Hammer and Norskov, Surf. Sci., 343 (1995) where the
@@ -905,13 +856,9 @@ class CompleteDos(Dos):
                 Default is None, which means all energies are considered.
 
         Returns:
-            band center in eV, often denoted epsilon_d for the d-band center
+            float: band center in eV, often denoted epsilon_d for the d-band center
         """
-        band_center = self.get_n_moment(
-            1, elements=elements, sites=sites, band=band, spin=spin, erange=erange, center=False
-        )
-
-        return band_center
+        return self.get_n_moment(1, elements=elements, sites=sites, band=band, spin=spin, erange=erange, center=False)
 
     def get_band_width(
         self,
@@ -921,8 +868,7 @@ class CompleteDos(Dos):
         spin: Spin | None = None,
         erange: list[float] | None = None,
     ) -> float:
-        """
-        Get the orbital-projected band width, defined as the square root of the second moment
+        """Get the orbital-projected band width, defined as the square root of the second moment
             sqrt(int_{-inf}^{+inf} rho(E)*(E-E_center)^2 dE/int_{-inf}^{+inf} rho(E) dE)
         where E_center is the orbital-projected band center, the limits of the integration can be
         modified by erange, and E is the set of energies taken with respect to the Fermi level.
@@ -937,11 +883,9 @@ class CompleteDos(Dos):
                 Default is None, which means all energies are considered.
 
         Returns:
-            Orbital-projected band width in eV
+            float: Orbital-projected band width in eV
         """
-        band_width = np.sqrt(self.get_n_moment(2, elements=elements, sites=sites, band=band, spin=spin, erange=erange))
-
-        return band_width
+        return np.sqrt(self.get_n_moment(2, elements=elements, sites=sites, band=band, spin=spin, erange=erange))
 
     def get_band_skewness(
         self,
@@ -951,8 +895,7 @@ class CompleteDos(Dos):
         spin: Spin | None = None,
         erange: list[float] | None = None,
     ) -> float:
-        """
-        Get the orbital-projected skewness, defined as the third standardized moment
+        """Get the orbital-projected skewness, defined as the third standardized moment
             int_{-inf}^{+inf} rho(E)*(E-E_center)^3 dE/int_{-inf}^{+inf} rho(E) dE)
             /
             (int_{-inf}^{+inf} rho(E)*(E-E_center)^2 dE/int_{-inf}^{+inf} rho(E) dE))^(3/2)
@@ -969,13 +912,10 @@ class CompleteDos(Dos):
                 Default is None, which means all energies are considered.
 
         Returns:
-            Orbital-projected skewness in eV
+            float: orbital-projected skewness (dimensionless)
         """
-        skewness = self.get_n_moment(
-            3, elements=elements, sites=sites, band=band, spin=spin, erange=erange
-        ) / self.get_n_moment(2, elements=elements, sites=sites, band=band, spin=spin, erange=erange) ** (3 / 2)
-
-        return skewness
+        kwds: dict = dict(elements=elements, sites=sites, band=band, spin=spin, erange=erange)
+        return self.get_n_moment(3, **kwds) / self.get_n_moment(2, **kwds) ** (3 / 2)
 
     def get_band_kurtosis(
         self,
@@ -985,8 +925,7 @@ class CompleteDos(Dos):
         spin: Spin | None = None,
         erange: list[float] | None = None,
     ) -> float:
-        """
-        Get the orbital-projected kurtosis, defined as the fourth standardized moment
+        """Get the orbital-projected kurtosis, defined as the fourth standardized moment
             int_{-inf}^{+inf} rho(E)*(E-E_center)^4 dE/int_{-inf}^{+inf} rho(E) dE)
             /
             (int_{-inf}^{+inf} rho(E)*(E-E_center)^2 dE/int_{-inf}^{+inf} rho(E) dE))^2
@@ -1003,14 +942,10 @@ class CompleteDos(Dos):
                 Default is None, which means all energies are considered.
 
         Returns:
-            Orbital-projected kurtosis in eV
+            float: orbital-projected kurtosis (dimensionless)
         """
-        kurtosis = (
-            self.get_n_moment(4, elements=elements, sites=sites, band=band, spin=spin, erange=erange)
-            / self.get_n_moment(2, elements=elements, sites=sites, band=band, spin=spin, erange=erange) ** 2
-        )
-
-        return kurtosis
+        kwds: dict = dict(elements=elements, sites=sites, band=band, spin=spin, erange=erange)
+        return self.get_n_moment(4, **kwds) / self.get_n_moment(2, **kwds) ** 2
 
     def get_n_moment(
         self,
@@ -1022,8 +957,7 @@ class CompleteDos(Dos):
         erange: list[float] | None = None,
         center: bool = True,
     ) -> float:
-        """
-        Get the nth moment of the DOS centered around the orbital-projected band center, defined as
+        """Get the nth moment of the DOS centered around the orbital-projected band center, defined as
             int_{-inf}^{+inf} rho(E)*(E-E_center)^n dE/int_{-inf}^{+inf} rho(E) dE
         where n is the order, E_center is the orbital-projected band center, the limits of the integration can be
         modified by erange, and E is the set of energies taken with respect to the Fermi level. If center is False,
@@ -1048,14 +982,14 @@ class CompleteDos(Dos):
 
         densities: Mapping[Spin, ArrayLike] = {}
         if elements:
-            for i, el in enumerate(elements):
+            for idx, el in enumerate(elements):
                 spd_dos = self.get_element_spd_dos(el)[band]
-                densities = spd_dos.densities if i == 0 else add_densities(densities, spd_dos.densities)
+                densities = spd_dos.densities if idx == 0 else add_densities(densities, spd_dos.densities)
             dos = Dos(self.efermi, self.energies, densities)
         elif sites:
-            for i, site in enumerate(sites):
+            for idx, site in enumerate(sites):
                 spd_dos = self.get_site_spd_dos(site)[band]
-                densities = spd_dos.densities if i == 0 else add_densities(densities, spd_dos.densities)
+                densities = spd_dos.densities if idx == 0 else add_densities(densities, spd_dos.densities)
             dos = Dos(self.efermi, self.energies, densities)
         else:
             dos = self.get_spd_dos()[band]
@@ -1076,9 +1010,7 @@ class CompleteDos(Dos):
             p = energies
 
         # Take the nth moment
-        nth_moment = np.trapz(p**n * dos_densities, x=energies) / np.trapz(dos_densities, x=energies)
-
-        return nth_moment
+        return np.trapz(p**n * dos_densities, x=energies) / np.trapz(dos_densities, x=energies)
 
     def get_hilbert_transform(
         self,
@@ -1130,8 +1062,7 @@ class CompleteDos(Dos):
         spin: Spin | None = None,
         erange: list[float] | None = None,
     ) -> float:
-        """
-        Get the orbital-projected upper band edge. The definition by Xin et al.
+        """Get the orbital-projected upper band edge. The definition by Xin et al.
         Phys. Rev. B, 89, 115114 (2014) is used, which is the highest peak position of the
         Hilbert transform of the orbital-projected DOS.
 
@@ -1158,8 +1089,7 @@ class CompleteDos(Dos):
             energies = energies[(energies >= erange[0]) & (energies <= erange[1])]
 
         # Calculate the upper band edge
-        upper_band_edge = energies[np.argmax(densities)]
-        return upper_band_edge
+        return energies[np.argmax(densities)]
 
     def get_dos_fp(
         self,
@@ -1170,13 +1100,14 @@ class CompleteDos(Dos):
         n_bins: int = 256,
         normalize: bool = True,
     ) -> NamedTuple:
-        """
-        Generates the DOS fingerprint based on work of
+        """Generates the DOS fingerprint.
+
+        Based on work of:
+
         F. Knoop, T. A. r Purcell, M. Scheffler, C. Carbogno, J. Open Source Softw. 2020, 5, 2671.
         Source - https://gitlab.com/vibes-developers/vibes/-/tree/master/vibes/materials_fp
         Copyright (c) 2020 Florian Knoop, Thomas A.R.Purcell, Matthias Scheffler, Christian Carbogno.
 
-
         Args:
             type (str): Specify fingerprint type needed can accept '{s/p/d/f/}summed_{pdos/tdos}'
             (default is summed_pdos)
@@ -1192,7 +1123,7 @@ class CompleteDos(Dos):
 
         Returns:
             Fingerprint(namedtuple) : The electronic density of states fingerprint
-            of format (energies, densities, type, n_bins)
+                of format (energies, densities, type, n_bins)
         """
         fingerprint = namedtuple("fingerprint", "energies densities type n_bins bin_width")
         energies = self.energies - self.efermi
@@ -1287,7 +1218,7 @@ class CompleteDos(Dos):
             ValueError: If both tanimoto and normalize are set to True.
 
         Returns:
-        Similarity index (float): The value of dot product
+            float: Similarity index given by the dot product
         """
         fp1_dict = CompleteDos.fp_to_dict(fp1) if not isinstance(fp1, dict) else fp1
 
@@ -1333,7 +1264,7 @@ class CompleteDos(Dos):
 
     def as_dict(self) -> dict:
         """JSON-serializable dict representation of CompleteDos."""
-        d = {
+        dct = {
             "@module": type(self).__module__,
             "@class": type(self).__name__,
             "efermi": self.efermi,
@@ -1349,21 +1280,20 @@ class CompleteDos(Dos):
                     dd[str(orb)] = {
                         "densities": {str(int(spin)): list(dens) for spin, dens in pdos.items()}  # type: ignore
                     }
-                d["pdos"].append(dd)
-            d["atom_dos"] = {str(at): dos.as_dict() for at, dos in self.get_element_dos().items()}
-            d["spd_dos"] = {str(orb): dos.as_dict() for orb, dos in self.get_spd_dos().items()}
-        return d
+                dct["pdos"].append(dd)
+            dct["atom_dos"] = {str(at): dos.as_dict() for at, dos in self.get_element_dos().items()}
+            dct["spd_dos"] = {str(orb): dos.as_dict() for orb, dos in self.get_spd_dos().items()}
+        return dct
 
-    def __str__(self):
-        return "Complete DOS for " + str(self.structure)
+    def __str__(self) -> str:
+        return f"Complete DOS for {self.structure}"
 
 
 class LobsterCompleteDos(CompleteDos):
     """Extended CompleteDOS for Lobster."""
 
     def get_site_orbital_dos(self, site: PeriodicSite, orbital: str) -> Dos:  # type: ignore
-        """
-        Get the Dos for a particular orbital of a particular site.
+        """Get the Dos for a particular orbital of a particular site.
 
         Args:
             site: Site in Structure associated with CompleteDos.
@@ -1398,8 +1328,7 @@ class LobsterCompleteDos(CompleteDos):
         return Dos(self.efermi, self.energies, self.pdos[site][orbital])  # type: ignore
 
     def get_site_t2g_eg_resolved_dos(self, site: PeriodicSite) -> dict[str, Dos]:
-        """
-        Get the t2g, eg projected DOS for a particular site.
+        """Get the t2g, eg projected DOS for a particular site.
 
         Args:
             site: Site in Structure associated with CompleteDos.
@@ -1424,8 +1353,7 @@ class LobsterCompleteDos(CompleteDos):
         }
 
     def get_spd_dos(self) -> dict[str, Dos]:  # type: ignore
-        """
-        Get orbital projected Dos.
+        """Get orbital projected Dos.
         For example, if 3s and 4s are included in the basis of some element, they will be both summed in the orbital
         projected DOS.
 
@@ -1444,9 +1372,7 @@ class LobsterCompleteDos(CompleteDos):
         return {orb: Dos(self.efermi, self.energies, densities) for orb, densities in spd_dos.items()}  # type: ignore
 
     def get_element_spd_dos(self, el: SpeciesLike) -> dict[str, Dos]:  # type: ignore
-        """
-        Get element and spd projected Dos.
-
+        """Get element and spd projected Dos.
 
         Args:
             el: Element in Structure.composition associated with LobsterCompleteDos
@@ -1508,7 +1434,7 @@ def f0(E, fermi, T) -> float:
 
     Args:
         E (float): energy in eV
-        fermi (float): the fermi level in eV
+        fermi (float): the Fermi level in eV
         T (float): the temperature in kelvin
 
     Returns:
@@ -1539,9 +1465,10 @@ def _get_orb_type_lobster(orb) -> OrbitalType | None:
 def _get_orb_lobster(orb):
     """
     Args:
-        orb: string representation of orbital
+        orb: string representation of orbital.
+
     Returns:
-         Orbital.
+        Orbital.
     """
     orb_labs = [
         "s",
@@ -1563,8 +1490,7 @@ def _get_orb_lobster(orb):
     ]
 
     try:
-        orbital = Orbital(orb_labs.index(orb[1:]))
-        return orbital
+        return Orbital(orb_labs.index(orb[1:]))
     except AttributeError:
         print("Orb not in list")
     return None
