@@ -1,5 +1,4 @@
-"""
-This module implements Compatibility corrections for mixing runs of different
+"""This module implements Compatibility corrections for mixing runs of different
 functionals.
 """
 
@@ -10,7 +9,7 @@ import copy
 import os
 import warnings
 from collections import defaultdict
-from typing import Literal, Sequence, Union
+from typing import TYPE_CHECKING, Literal, Union
 
 import numpy as np
 from monty.design_patterns import cached_class
@@ -20,7 +19,7 @@ from tqdm import tqdm
 from uncertainties import ufloat
 
 from pymatgen.analysis.structure_analyzer import oxide_type, sulfide_type
-from pymatgen.core.periodic_table import Element
+from pymatgen.core import SETTINGS, Element
 from pymatgen.entries.computed_entries import (
     CompositionEnergyAdjustment,
     ComputedEntry,
@@ -29,7 +28,11 @@ from pymatgen.entries.computed_entries import (
     EnergyAdjustment,
     TemperatureEnergyAdjustment,
 )
-from pymatgen.io.vasp.sets import MITRelaxSet, MPRelaxSet
+from pymatgen.io.vasp.sets import MITRelaxSet, MPRelaxSet, VaspInputSet
+from pymatgen.util.due import Doi, due
+
+if TYPE_CHECKING:
+    from collections.abc import Sequence
 
 __author__ = "Amanda Wang, Ryan Kingsbury, Shyue Ping Ong, Anubhav Jain, Stephen Dacek, Sai Jayaraman"
 __copyright__ = "Copyright 2012-2020, The Materials Project"
@@ -45,15 +48,13 @@ AnyComputedEntry = Union[ComputedEntry, ComputedStructureEntry]
 
 
 class CompatibilityError(Exception):
-    """
-    Exception class for Compatibility. Raised by attempting correction
+    """Exception class for Compatibility. Raised by attempting correction
     on incompatible calculation.
     """
 
 
 class Correction(metaclass=abc.ABCMeta):
-    """
-    A Correction class is a pre-defined scheme for correction a computed
+    """A Correction class is a pre-defined scheme for correction a computed
     entry based on the type and chemistry of the structure and the
     calculation parameters. All Correction classes must implement a
     correct_entry method.
@@ -61,8 +62,7 @@ class Correction(metaclass=abc.ABCMeta):
 
     @abc.abstractmethod
     def get_correction(self, entry: AnyComputedEntry) -> EnergyAdjustment:
-        """
-        Returns correction and uncertainty for a single entry.
+        """Returns correction and uncertainty for a single entry.
 
         Args:
             entry: A ComputedEntry object.
@@ -76,8 +76,7 @@ class Correction(metaclass=abc.ABCMeta):
         raise NotImplementedError
 
     def correct_entry(self, entry):
-        """
-        Corrects a single entry.
+        """Corrects a single entry.
 
         Args:
             entry: A ComputedEntry object.
@@ -105,8 +104,7 @@ class Correction(metaclass=abc.ABCMeta):
 
 
 class PotcarCorrection(Correction):
-    """
-    Checks that POTCARs are valid within a pre-defined input set. This
+    """Checks that POTCARs are valid within a pre-defined input set. This
     ensures that calculations performed using different InputSets are not
     compared against each other.
 
@@ -117,26 +115,24 @@ class PotcarCorrection(Correction):
     'PAW_PBE O 08Apr2002'].
     """
 
-    def __init__(self, input_set, check_hash=False):
+    def __init__(self, input_set: type[VaspInputSet], check_potcar: bool = True, check_hash: bool = False) -> None:
         """
         Args:
-            input_set: InputSet object used to generate the runs (used to check
+            input_set (InputSet): object used to generate the runs (used to check
                 for correct potcar symbols).
-
-            check_hash (bool): If true, uses the potcar hash to check for valid
-                potcars. If false, uses the potcar symbol (Less reliable).
-                Defaults to True
+            check_potcar (bool): If False, bypass the POTCAR check altogether. Defaults to True.
+                Can also be disabled globally by running `pmg config --add PMG_POTCAR_CHECKS false`.
+            check_hash (bool): If True, uses the potcar hash to check for valid
+                potcars. If false, uses the potcar symbol (less reliable). Defaults to False.
 
         Raises:
-            ValueError if entry do not contain "potcar_symbols" key.
-            CompatibilityError if wrong potcar symbols
+            ValueError: if check_potcar=True and entry does not contain "potcar_symbols" key.
         """
         potcar_settings = input_set.CONFIG["POTCAR"]
         if isinstance(list(potcar_settings.values())[-1], dict):
-            if check_hash:
-                self.valid_potcars = {k: d["hash"] for k, d in potcar_settings.items()}
-            else:
-                self.valid_potcars = {k: d["symbol"] for k, d in potcar_settings.items()}
+            self.valid_potcars = {
+                key: dct.get("hash" if check_hash else "symbol") for key, dct in potcar_settings.items()
+            }
         else:
             if check_hash:
                 raise ValueError("Cannot check hashes of potcars, since hashes are not included in the entry.")
@@ -144,24 +140,37 @@ class PotcarCorrection(Correction):
 
         self.input_set = input_set
         self.check_hash = check_hash
+        self.check_potcar = check_potcar
 
     def get_correction(self, entry: AnyComputedEntry) -> ufloat:
         """
-        :param entry: A ComputedEntry/ComputedStructureEntry
-        :return: Correction, Uncertainty.
+        Args:
+            entry (AnyComputedEntry): ComputedEntry or ComputedStructureEntry.
+
+        Raises:
+            ValueError: If entry does not contain "potcar_symbols" key.
+            CompatibilityError: If entry has wrong potcar hash/symbols.
+
+        Returns:
+            ufloat: 0.0 +/- 0.0 (from uncertainties package)
         """
+        if SETTINGS.get("PMG_POTCAR_CHECKS") is False or not self.check_potcar:
+            return ufloat(0.0, 0.0)
+
+        potcar_spec = entry.parameters.get("potcar_spec")
         if self.check_hash:
-            if entry.parameters.get("potcar_spec"):
-                psp_settings = {d.get("hash") for d in entry.parameters["potcar_spec"] if d}
+            if potcar_spec:
+                psp_settings = {dct.get("hash") for dct in potcar_spec if dct}
             else:
                 raise ValueError("Cannot check hash without potcar_spec field")
-        elif entry.parameters.get("potcar_spec"):
-            psp_settings = {d.get("titel").split()[1] for d in entry.parameters["potcar_spec"] if d}
+        elif potcar_spec:
+            psp_settings = {dct.get("titel").split()[1] for dct in potcar_spec if dct}
         else:
             psp_settings = {sym.split()[1] for sym in entry.parameters["potcar_symbols"] if sym}
 
-        if {self.valid_potcars.get(str(el)) for el in entry.composition.elements} != psp_settings:
-            raise CompatibilityError("Incompatible potcar")
+        expected_psp = {self.valid_potcars.get(el.symbol) for el in entry.elements}
+        if expected_psp != psp_settings:
+            raise CompatibilityError(f"Incompatible POTCAR {psp_settings}, expected {expected_psp}")
         return ufloat(0.0, 0.0)
 
     def __str__(self) -> str:
@@ -170,8 +179,7 @@ class PotcarCorrection(Correction):
 
 @cached_class
 class GasCorrection(Correction):
-    """
-    Correct gas energies to obtain the right formation energies. Note that
+    """Correct gas energies to obtain the right formation energies. Note that
     this depends on calculations being run within the same input set.
     Used by legacy MaterialsProjectCompatibility and MITCompatibility.
     """
@@ -186,19 +194,14 @@ class GasCorrection(Correction):
         self.cpd_energies = c["Advanced"]["CompoundEnergies"]
 
     def get_correction(self, entry) -> ufloat:
-        """
-        :param entry: A ComputedEntry/ComputedStructureEntry
-        :return: Correction.
+        """:param entry: A ComputedEntry/ComputedStructureEntry
+
+        Returns:
+            Correction.
         """
         comp = entry.composition
-
-        correction = ufloat(0.0, 0.0)
-
         # set error to 0 because old MPCompatibility doesn't have errors
-
-        # only correct GGA or GGA+U entries
-        if entry.parameters.get("run_type") not in ["GGA", "GGA+U"]:
-            return ufloat(0.0, 0.0)
+        correction = ufloat(0.0, 0.0)
 
         rform = entry.composition.reduced_formula
         if rform in self.cpd_energies:
@@ -212,8 +215,7 @@ class GasCorrection(Correction):
 
 @cached_class
 class AnionCorrection(Correction):
-    """
-    Correct anion energies to obtain the right formation energies. Note that
+    """Correct anion energies to obtain the right formation energies. Note that
     this depends on calculations being run within the same input set.
 
     Used by legacy MaterialsProjectCompatibility and MITCompatibility.
@@ -233,9 +235,10 @@ class AnionCorrection(Correction):
         self.correct_peroxide = correct_peroxide
 
     def get_correction(self, entry) -> ufloat:
-        """
-        :param entry: A ComputedEntry/ComputedStructureEntry
-        :return: Correction.
+        """:param entry: A ComputedEntry/ComputedStructureEntry
+
+        Returns:
+            Correction.
         """
         comp = entry.composition
         if len(comp) == 1:  # Skip element entry
@@ -243,10 +246,6 @@ class AnionCorrection(Correction):
 
         correction = ufloat(0.0, 0.0)
 
-        # only correct GGA or GGA+U entries
-        if entry.parameters.get("run_type") not in ["GGA", "GGA+U"]:
-            return ufloat(0.0, 0.0)
-
         # Check for sulfide corrections
         if Element("S") in comp:
             sf_type = "sulfide"
@@ -306,8 +305,7 @@ class AnionCorrection(Correction):
 
 @cached_class
 class AqueousCorrection(Correction):
-    """
-    This class implements aqueous phase compound corrections for elements
+    """This class implements aqueous phase compound corrections for elements
     and H2O.
 
     Used only by MITAqueousCompatibility.
@@ -334,20 +332,15 @@ class AqueousCorrection(Correction):
             self.cpd_errors = defaultdict(float)
 
     def get_correction(self, entry) -> ufloat:
-        """
-        :param entry: A ComputedEntry/ComputedStructureEntry
-        :return: Correction, Uncertainty.
-        """
-        from pymatgen.analysis.pourbaix_diagram import MU_H2O
+        """:param entry: A ComputedEntry/ComputedStructureEntry
 
+        Returns:
+            Correction, Uncertainty.
+        """
         comp = entry.composition
         rform = comp.reduced_formula
         cpd_energies = self.cpd_energies
 
-        # only correct GGA or GGA+U entries
-        if entry.parameters.get("run_type") not in ["GGA", "GGA+U"]:
-            return ufloat(0.0, 0.0)
-
         correction = ufloat(0.0, 0.0)
 
         if rform in cpd_energies:
@@ -399,8 +392,7 @@ class AqueousCorrection(Correction):
 
 @cached_class
 class UCorrection(Correction):
-    """
-    This class implements the GGA/GGA+U mixing scheme, which allows mixing of
+    """This class implements the GGA/GGA+U mixing scheme, which allows mixing of
     entries. Entry.parameters must contain a "hubbards" key which is a dict
     of all non-zero Hubbard U values used in the calculation. For example,
     if you ran a Fe2O3 calculation with Materials Project parameters,
@@ -454,27 +446,18 @@ class UCorrection(Correction):
             self.u_errors = {}
 
     def get_correction(self, entry) -> ufloat:
-        """
-        :param entry: A ComputedEntry/ComputedStructureEntry
-        :return: Correction, Uncertainty.
-        """
-        if entry.parameters.get("run_type") not in ["GGA", "GGA+U"]:
-            raise CompatibilityError(
-                f"Entry {entry.entry_id} has invalid run type {entry.parameters.get('run_type')}. Discarding."
-            )
+        """:param entry: A ComputedEntry/ComputedStructureEntry
 
-        calc_u = entry.parameters.get("hubbards")
-        calc_u = defaultdict(int) if calc_u is None else calc_u
+        Returns:
+            Correction, Uncertainty.
+        """
+        calc_u = entry.parameters.get("hubbards") or defaultdict(int)
         comp = entry.composition
 
         elements = sorted((el for el in comp.elements if comp[el] > 0), key=lambda el: el.X)
         most_electroneg = elements[-1].symbol
         correction = ufloat(0.0, 0.0)
 
-        # only correct GGA or GGA+U entries
-        if entry.parameters.get("run_type") not in ["GGA", "GGA+U"]:
-            return ufloat(0.0, 0.0)
-
         u_corr = self.u_corrections.get(most_electroneg, {})
         u_settings = self.u_settings.get(most_electroneg, {})
         u_errors = self.u_errors.get(most_electroneg, defaultdict(float))
@@ -494,16 +477,14 @@ class UCorrection(Correction):
 
 
 class Compatibility(MSONable, metaclass=abc.ABCMeta):
-    """
-    Abstract Compatibility class, not intended for direct use.
+    """Abstract Compatibility class, not intended for direct use.
     Compatibility classes are used to correct the energies of an entry or a set
     of entries. All Compatibility classes must implement get_adjustments() method.
     """
 
     @abc.abstractmethod
     def get_adjustments(self, entry: AnyComputedEntry) -> list[EnergyAdjustment]:
-        """
-        Get the energy adjustments for a ComputedEntry.
+        """Get the energy adjustments for a ComputedEntry.
 
         This method must generate a list of EnergyAdjustment objects
         of the appropriate type (constant, composition-based, or temperature-based)
@@ -523,8 +504,7 @@ class Compatibility(MSONable, metaclass=abc.ABCMeta):
         raise NotImplementedError
 
     def process_entry(self, entry: ComputedEntry, **kwargs) -> ComputedEntry | None:
-        """
-        Process a single entry with the chosen Corrections. Note
+        """Process a single entry with the chosen Corrections. Note
         that this method will change the data of the original entry.
 
         Args:
@@ -545,9 +525,9 @@ class Compatibility(MSONable, metaclass=abc.ABCMeta):
         clean: bool = True,
         verbose: bool = False,
         inplace: bool = True,
+        on_error: Literal["ignore", "warn", "raise"] = "ignore",
     ) -> list[AnyComputedEntry]:
-        """
-        Process a sequence of entries with the chosen Compatibility scheme.
+        """Process a sequence of entries with the chosen Compatibility scheme.
 
         Warning: This method changes entries in place! All changes can be undone and original entries
         restored by setting entry.energy_adjustments = [].
@@ -561,6 +541,8 @@ class Compatibility(MSONable, metaclass=abc.ABCMeta):
             verbose (bool): Whether to display progress bar for processing multiple entries.
                 Defaults to False.
             inplace (bool): Whether to adjust input entries in place. Defaults to True.
+            on_error ('ignore' | 'warn' | 'raise'): What to do when get_adjustments(entry)
+                raises CompatibilityError. Defaults to 'ignore'.
 
         Returns:
             list[AnyComputedEntry]: Adjusted entries. Entries in the original list incompatible with
@@ -584,7 +566,11 @@ class Compatibility(MSONable, metaclass=abc.ABCMeta):
 
             try:  # get the energy adjustments
                 adjustments = self.get_adjustments(entry)
-            except CompatibilityError:
+            except CompatibilityError as exc:
+                if on_error == "raise":
+                    raise exc
+                if on_error == "warn":
+                    warnings.warn(str(exc))
                 continue
 
             for ea in adjustments:
@@ -612,8 +598,7 @@ class Compatibility(MSONable, metaclass=abc.ABCMeta):
 
     @staticmethod
     def explain(entry):
-        """
-        Prints an explanation of the energy adjustments applied by the
+        """Prints an explanation of the energy adjustments applied by the
         Compatibility class. Inspired by the "explain" methods in many database
         methodologies.
 
@@ -636,8 +621,7 @@ class Compatibility(MSONable, metaclass=abc.ABCMeta):
 
 
 class CorrectionsList(Compatibility):
-    """
-    The CorrectionsList class combines a list of corrections to be applied to
+    """The CorrectionsList class combines a list of corrections to be applied to
     an entry or a set of entries. Note that some of the Corrections have
     interdependencies. For example, PotcarCorrection must always be used
     before any other compatibility. Also, AnionCorrection("MP") must be used
@@ -646,17 +630,30 @@ class CorrectionsList(Compatibility):
     MITCompatibility subclasses instead.
     """
 
-    def __init__(self, corrections: Sequence[Correction]):
+    def __init__(self, corrections: Sequence[Correction], run_types: list[str] | None = None):
         """
         Args:
             corrections (list[Correction]): Correction objects to apply.
+            run_types: Valid DFT run_types for this correction scheme. Entries with run_type
+                other than those in this list will be excluded from the list returned
+                by process_entries. The default value captures both GGA and GGA+U run types
+                historically used by the Materials Project, for example in.
         """
+        if run_types is None:
+            run_types = ["GGA", "GGA+U", "PBE", "PBE+U"]
         self.corrections = corrections
+        self.run_types = run_types
         super().__init__()
 
     def get_adjustments(self, entry: AnyComputedEntry) -> list[EnergyAdjustment]:
         """Get the list of energy adjustments to be applied to an entry."""
         adjustment_list = []
+        if entry.parameters.get("run_type") not in self.run_types:
+            raise CompatibilityError(
+                f"Entry {entry.entry_id} has invalid run type {entry.parameters.get('run_type')}. "
+                f"Must be GGA or GGA+U. Discarding."
+            )
+
         corrections, uncertainties = self.get_corrections_dict(entry)
 
         for k, v in corrections.items():
@@ -666,8 +663,7 @@ class CorrectionsList(Compatibility):
         return adjustment_list
 
     def get_corrections_dict(self, entry: AnyComputedEntry) -> tuple[dict[str, float], dict[str, float]]:
-        """
-        Returns the correction values and uncertainties applied to a particular entry.
+        """Returns the correction values and uncertainties applied to a particular entry.
 
         Args:
             entry: A ComputedEntry object.
@@ -686,8 +682,7 @@ class CorrectionsList(Compatibility):
         return corrections, uncertainties
 
     def get_explanation_dict(self, entry):
-        """
-        Provides an explanation dict of the corrections that are being applied
+        """Provides an explanation dict of the corrections that are being applied
         for a given compatibility scheme. Inspired by the "explain" methods
         in many database methodologies.
 
@@ -708,7 +703,7 @@ class CorrectionsList(Compatibility):
         corrected_energy = corr_entry.energy if corr_entry else None
         correction_uncertainty = corr_entry.correction_uncertainty if corr_entry else None
 
-        d = {
+        dct = {
             "compatibility": type(self).__name__,
             "uncorrected_energy": uncorrected_energy,
             "corrected_energy": corrected_energy,
@@ -728,12 +723,11 @@ class CorrectionsList(Compatibility):
                 "uncertainty": uncer,
             }
             corrections.append(cd)
-        d["corrections"] = corrections
-        return d
+        dct["corrections"] = corrections
+        return dct
 
     def explain(self, entry):
-        """
-        Prints an explanation of the corrections that are being applied for a
+        """Prints an explanation of the corrections that are being applied for a
         given compatibility scheme. Inspired by the "explain" methods in many
         database methodologies.
 
@@ -756,8 +750,7 @@ class CorrectionsList(Compatibility):
 
 
 class MaterialsProjectCompatibility(CorrectionsList):
-    """
-    This class implements the GGA/GGA+U mixing scheme, which allows mixing of
+    """This class implements the GGA/GGA+U mixing scheme, which allows mixing of
     entries. Note that this should only be used for VASP calculations using the
     MaterialsProject parameters (see pymatgen.io.vasp.sets.MPVaspInputSet).
     Using this compatibility scheme on runs with different parameters is not
@@ -789,7 +782,7 @@ class MaterialsProjectCompatibility(CorrectionsList):
         self.compat_type = compat_type
         self.correct_peroxide = correct_peroxide
         self.check_potcar_hash = check_potcar_hash
-        fp = os.path.join(MODULE_DIR, "MPCompatibility.yaml")
+        fp = f"{MODULE_DIR}/MPCompatibility.yaml"
         super().__init__(
             [
                 PotcarCorrection(MPRelaxSet, check_hash=check_potcar_hash),
@@ -814,8 +807,7 @@ having to create a list of separate correction classes.
 
 @cached_class
 class MaterialsProject2020Compatibility(Compatibility):
-    """
-    This class implements the Materials Project 2020 energy correction scheme, which
+    """This class implements the Materials Project 2020 energy correction scheme, which
     incorporates uncertainty quantification and allows for mixing of GGA and GGA+U entries
     (see References).
 
@@ -836,6 +828,7 @@ class MaterialsProject2020Compatibility(Compatibility):
         self,
         compat_type: str = "Advanced",
         correct_peroxide: bool = True,
+        check_potcar: bool = True,
         check_potcar_hash: bool = False,
         config_file: str | None = None,
     ) -> None:
@@ -857,15 +850,16 @@ class MaterialsProject2020Compatibility(Compatibility):
                 entry.parameters["hubbards"] = {"Fe": 5.3}. If the "hubbards" key
                 is missing, a GGA run is assumed. Entries obtained from the
                 MaterialsProject database will automatically have these fields
-                populated.
-
-                (Default: "Advanced")
+                populated. Default: "Advanced"
             correct_peroxide: Specify whether peroxide/superoxide/ozonide
                 corrections are to be applied or not. If false, all oxygen-containing
-                compounds are assigned the 'oxide' correction. (Default: True)
+                compounds are assigned the 'oxide' correction. Default: True
+            check_potcar (bool): Check that the POTCARs used in the calculation are consistent
+                with the Materials Project parameters. False bypasses this check altogether. Default: True
+                Can also be disabled globally by running `pmg config --add PMG_POTCAR_CHECKS false`.
             check_potcar_hash (bool): Use potcar hash to verify POTCAR settings are
                 consistent with MPRelaxSet. If False, only the POTCAR symbols will
-                be used. (Default: False)
+                be used. Default: False
             config_file (Path): Path to the selected compatibility.yaml config file.
                 If None, defaults to `MP2020Compatibility.yaml` distributed with
                 pymatgen.
@@ -884,6 +878,7 @@ class MaterialsProject2020Compatibility(Compatibility):
 
         self.compat_type = compat_type
         self.correct_peroxide = correct_peroxide
+        self.check_potcar = check_potcar
         self.check_potcar_hash = check_potcar_hash
 
         # load corrections and uncertainties
@@ -895,7 +890,7 @@ class MaterialsProject2020Compatibility(Compatibility):
                 raise ValueError(f"Custom MaterialsProject2020Compatibility {config_file=} does not exist.")
         else:
             self.config_file = None
-            c = loadfn(os.path.join(MODULE_DIR, "MP2020Compatibility.yaml"))
+            c = loadfn(f"{MODULE_DIR}/MP2020Compatibility.yaml")
 
         self.name = c["Name"]
         self.comp_correction = c["Corrections"].get("CompositionCorrections", defaultdict(float))
@@ -911,8 +906,7 @@ class MaterialsProject2020Compatibility(Compatibility):
             self.u_errors = {}
 
     def get_adjustments(self, entry: AnyComputedEntry) -> list[EnergyAdjustment]:
-        """
-        Get the energy adjustments for a ComputedEntry or ComputedStructureEntry.
+        """Get the energy adjustments for a ComputedEntry or ComputedStructureEntry.
 
         Energy corrections are implemented directly in this method instead of in
         separate AnionCorrection, GasCorrection, or UCorrection classes which
@@ -927,7 +921,7 @@ class MaterialsProject2020Compatibility(Compatibility):
         Raises:
             CompatibilityError if the entry is not compatible
         """
-        if entry.parameters.get("run_type") not in ["GGA", "GGA+U"]:
+        if entry.parameters.get("run_type") not in ("GGA", "GGA+U"):
             raise CompatibilityError(
                 f"Entry {entry.entry_id} has invalid run type {entry.parameters.get('run_type')}. "
                 f"Must be GGA or GGA+U. Discarding."
@@ -936,7 +930,7 @@ class MaterialsProject2020Compatibility(Compatibility):
         # check the POTCAR symbols
         # this should return ufloat(0, 0) or raise a CompatibilityError or ValueError
         if entry.parameters.get("software", "vasp") == "vasp":
-            pc = PotcarCorrection(MPRelaxSet, check_hash=self.check_potcar_hash)
+            pc = PotcarCorrection(MPRelaxSet, check_hash=self.check_potcar_hash, check_potcar=self.check_potcar)
             pc.get_correction(entry)
 
         # apply energy adjustments
@@ -1027,12 +1021,9 @@ class MaterialsProject2020Compatibility(Compatibility):
             try:
                 oxi_states = entry.composition.oxi_state_guesses(max_sites=-20)
             except ValueError:
-                oxi_states = []
+                oxi_states = ({},)
 
-            if oxi_states == []:
-                entry.data["oxidation_states"] = {}
-            else:
-                entry.data["oxidation_states"] = oxi_states[0]
+            entry.data["oxidation_states"] = (oxi_states or ({},))[0]
 
         if entry.data["oxidation_states"] == {}:
             warnings.warn(
@@ -1073,17 +1064,19 @@ class MaterialsProject2020Compatibility(Compatibility):
         u_errors = self.u_errors.get(most_electroneg, defaultdict(float))
 
         for el in comp.elements:
-            sym = el.symbol
+            symbol = el.symbol
             # Check for bad U values
-            if calc_u.get(sym, 0) != u_settings.get(sym, 0):
-                raise CompatibilityError(f"Invalid U value of {calc_u.get(sym, 0):.1f} on {sym}")
-            if sym in u_corrections:
+            expected_u = u_settings.get(symbol, 0)
+            actual_u = calc_u.get(symbol, 0)
+            if actual_u != expected_u:
+                raise CompatibilityError(f"Invalid U value of {actual_u:.1f} on {symbol}, expected {expected_u:.1f}")
+            if symbol in u_corrections:
                 adjustments.append(
                     CompositionEnergyAdjustment(
-                        u_corrections[sym],
+                        u_corrections[symbol],
                         comp[el],
-                        uncertainty_per_atom=u_errors[sym],
-                        name=f"MP2020 GGA/GGA+U mixing correction ({sym})",
+                        uncertainty_per_atom=u_errors[symbol],
+                        name=f"MP2020 GGA/GGA+U mixing correction ({symbol})",
                         cls=self.as_dict(),
                     )
                 )
@@ -1092,8 +1085,7 @@ class MaterialsProject2020Compatibility(Compatibility):
 
 
 class MITCompatibility(CorrectionsList):
-    """
-    This class implements the GGA/GGA+U mixing scheme, which allows mixing of
+    """This class implements the GGA/GGA+U mixing scheme, which allows mixing of
     entries. Note that this should only be used for VASP calculations using the
     MIT parameters (see pymatgen.io.vasp.sets MITVaspInputSet). Using
     this compatibility scheme on runs with different parameters is not valid.
@@ -1121,7 +1113,7 @@ class MITCompatibility(CorrectionsList):
         self.compat_type = compat_type
         self.correct_peroxide = correct_peroxide
         self.check_potcar_hash = check_potcar_hash
-        fp = os.path.join(MODULE_DIR, "MITCompatibility.yaml")
+        fp = f"{MODULE_DIR}/MITCompatibility.yaml"
         super().__init__(
             [
                 PotcarCorrection(MITRelaxSet, check_hash=check_potcar_hash),
@@ -1133,8 +1125,7 @@ class MITCompatibility(CorrectionsList):
 
 
 class MITAqueousCompatibility(CorrectionsList):
-    """
-    This class implements the GGA/GGA+U mixing scheme, which allows mixing of
+    """This class implements the GGA/GGA+U mixing scheme, which allows mixing of
     entries. Note that this should only be used for VASP calculations using the
     MIT parameters (see pymatgen.io.vasp.sets MITVaspInputSet). Using
     this compatibility scheme on runs with different parameters is not valid.
@@ -1162,7 +1153,7 @@ class MITAqueousCompatibility(CorrectionsList):
         self.compat_type = compat_type
         self.correct_peroxide = correct_peroxide
         self.check_potcar_hash = check_potcar_hash
-        fp = os.path.join(MODULE_DIR, "MITCompatibility.yaml")
+        fp = f"{MODULE_DIR}/MITCompatibility.yaml"
         super().__init__(
             [
                 PotcarCorrection(MITRelaxSet, check_hash=check_potcar_hash),
@@ -1175,9 +1166,9 @@ class MITAqueousCompatibility(CorrectionsList):
 
 
 @cached_class
+@due.dcite(Doi("10.1103/PhysRevB.85.235438", "Pourbaix scheme to combine calculated and experimental data"))
 class MaterialsProjectAqueousCompatibility(Compatibility):
-    """
-    This class implements the Aqueous energy referencing scheme for constructing
+    """This class implements the Aqueous energy referencing scheme for constructing
     Pourbaix diagrams from DFT energies, as described in Persson et al.
 
     This scheme applies various energy adjustments to convert DFT energies into
@@ -1209,8 +1200,7 @@ class MaterialsProjectAqueousCompatibility(Compatibility):
         h2o_energy: float | None = None,
         h2o_adjustments: float | None = None,
     ) -> None:
-        """
-        Initialize the MaterialsProjectAqueousCompatibility class.
+        """Initialize the MaterialsProjectAqueousCompatibility class.
 
         Note that this class requires as inputs the ground-state DFT energies of O2 and H2O, plus the value of any
         energy adjustments applied to an H2O molecule. If these parameters are not provided in __init__, they can
@@ -1271,8 +1261,7 @@ class MaterialsProjectAqueousCompatibility(Compatibility):
         super().__init__()
 
     def get_adjustments(self, entry: ComputedEntry) -> list[EnergyAdjustment]:
-        """
-        Returns the corrections applied to a particular entry.
+        """Returns the corrections applied to a particular entry.
 
         Args:
             entry: A ComputedEntry object.
@@ -1392,10 +1381,14 @@ class MaterialsProjectAqueousCompatibility(Compatibility):
         return adjustments
 
     def process_entries(
-        self, entries: list[AnyComputedEntry], clean: bool = False, verbose: bool = False, inplace: bool = True
+        self,
+        entries: list[AnyComputedEntry],
+        clean: bool = False,
+        verbose: bool = False,
+        inplace: bool = True,
+        on_error: Literal["ignore", "warn", "raise"] = "ignore",
     ) -> list[AnyComputedEntry]:
-        """
-        Process a sequence of entries with the chosen Compatibility scheme.
+        """Process a sequence of entries with the chosen Compatibility scheme.
 
         Args:
             entries (list[ComputedEntry | ComputedStructureEntry]): Entries to be processed.
@@ -1406,6 +1399,8 @@ class MaterialsProjectAqueousCompatibility(Compatibility):
                 Default is False.
             inplace (bool): Whether to modify the entries in place. If False, a copy of the
                 entries is made and processed. Default is True.
+            on_error ('ignore' | 'warn' | 'raise'): What to do when get_adjustments(entry)
+                raises CompatibilityError. Defaults to 'ignore'.
 
         Returns:
             list[AnyComputedEntry]: Adjusted entries. Entries in the original list incompatible with
@@ -1455,4 +1450,4 @@ class MaterialsProjectAqueousCompatibility(Compatibility):
             h2_entries = sorted(h2_entries, key=lambda e: e.energy_per_atom)
             self.h2_energy = h2_entries[0].energy_per_atom  # type: ignore[assignment]
 
-        return super().process_entries(entries, clean=clean, verbose=verbose, inplace=inplace)
+        return super().process_entries(entries, clean=clean, verbose=verbose, inplace=inplace, on_error=on_error)
