@@ -1,5 +1,4 @@
-"""
-This module calculates corrections for the species listed below, fitted to the experimental and computed
+"""This module calculates corrections for the species listed below, fitted to the experimental and computed
 entries given to the CorrectionCalculator constructor.
 """
 
@@ -16,13 +15,11 @@ from scipy.optimize import curve_fit
 
 from pymatgen.analysis.reaction_calculator import ComputedReaction
 from pymatgen.analysis.structure_analyzer import sulfide_type
-from pymatgen.core.composition import Composition
-from pymatgen.core.periodic_table import Element
+from pymatgen.core import Composition, Element
 
 
 class CorrectionCalculator:
-    """
-    A CorrectionCalculator contains experimental and computed entries which it uses to compute corrections.
+    """A CorrectionCalculator contains experimental and computed entries which it uses to compute corrections.
 
     It graphs residual errors after applying the computed corrections and creates the MPCompatibility.yaml
     file the Correction classes use.
@@ -43,8 +40,7 @@ class CorrectionCalculator:
         allow_unstable: float | bool = 0.1,
         exclude_polyanions: list[str] | None = None,
     ) -> None:
-        """
-        Initializes a CorrectionCalculator.
+        """Initializes a CorrectionCalculator.
 
         Args:
             species: list of species to calculate corrections for
@@ -101,8 +97,7 @@ class CorrectionCalculator:
         return self.compute_corrections(exp_entries, calc_entries)
 
     def compute_corrections(self, exp_entries: list, calc_entries: dict) -> dict:
-        """
-        Computes the corrections and fills in correction, corrections_std_error, and corrections_dict.
+        """Computes the corrections and fills in correction, corrections_std_error, and corrections_dict.
 
         Args:
             exp_entries: list of dictionary objects with the following keys/values:
@@ -216,7 +211,7 @@ class CorrectionCalculator:
                         try:
                             coeff.append(comp[specie])
                         except ValueError:
-                            raise ValueError(f"We can't detect this specie: {specie}")
+                            raise ValueError(f"We can't detect this {specie=} in {name=}")
 
                 self.names.append(name)
                 self.diffs.append((cmpd_info["exp energy"] - energy) / comp.num_atoms)
@@ -228,14 +223,13 @@ class CorrectionCalculator:
         sigma[sigma == 0] = np.nan
 
         with warnings.catch_warnings():
-            warnings.simplefilter(
-                "ignore", category=RuntimeWarning
-            )  # numpy raises warning if the entire array is nan values
-            mean_uncer = np.nanmean(sigma)
+            # numpy raises warning if the entire array is nan values
+            warnings.simplefilter("ignore", category=RuntimeWarning)
+            mean_uncert = np.nanmean(sigma)
 
-        sigma = np.where(np.isnan(sigma), mean_uncer, sigma)
+        sigma = np.where(np.isnan(sigma), mean_uncert, sigma)
 
-        if np.isnan(mean_uncer):
+        if np.isnan(mean_uncert):
             # no uncertainty values for any compounds, don't try to weight
             popt, self.pcov = curve_fit(
                 lambda x, *m: np.dot(x, m), self.coeff_mat, self.diffs, p0=np.ones(len(self.species))
@@ -280,26 +274,22 @@ class CorrectionCalculator:
                 mode="markers",
                 text=labels_graph,
             ),
-            layout=go.Layout(
-                title=go.layout.Title(text="Residual Errors"),
-                yaxis=go.layout.YAxis(title=go.layout.yaxis.Title(text="Residual Error (eV/atom)")),
-            ),
+            layout=dict(title="Residual Errors", yaxis=dict(title="Residual Error (eV/atom)")),
         )
 
         print("Residual Error:")
-        print("Median = " + str(np.median(np.array(abs_errors))))
-        print("Mean = " + str(np.mean(np.array(abs_errors))))
-        print("Std Dev = " + str(np.std(np.array(abs_errors))))
+        print(f"Median = {np.median(abs_errors)}")
+        print(f"Mean = {np.mean(abs_errors)}")
+        print(f"Std Dev = {np.std(abs_errors)}")
         print("Original Error:")
-        print("Median = " + str(abs(np.median(np.array(self.diffs)))))
-        print("Mean = " + str(abs(np.mean(np.array(self.diffs)))))
-        print("Std Dev = " + str(np.std(np.array(self.diffs))))
+        print(f"Median = {abs(np.median(self.diffs))}")
+        print(f"Mean = {abs(np.mean(self.diffs))}")
+        print(f"Std Dev = {np.std(self.diffs)}")
 
         return fig
 
     def graph_residual_error_per_species(self, specie: str) -> go.Figure:
-        """
-        Graphs the residual errors for each compound that contains specie after applying computed corrections.
+        """Graphs the residual errors for each compound that contains specie after applying computed corrections.
 
         Args:
             specie: the specie/group that residual errors are being plotted for
@@ -327,18 +317,20 @@ class CorrectionCalculator:
                 compounds = self.superoxides
             else:
                 compounds = self.sulfides
-            for i in range(num):
-                if labels_species[num - i - 1] not in compounds:
-                    del labels_species[num - i - 1]
-                    del abs_errors[num - i - 1]
-                    del diffs_cpy[num - i - 1]
+            for idx in range(num):
+                if labels_species[num - idx - 1] not in compounds:
+                    del labels_species[num - idx - 1]
+                    del abs_errors[num - idx - 1]
+                    del diffs_cpy[num - idx - 1]
         else:
-            for i in range(num):
-                if not Composition(labels_species[num - i - 1])[specie]:
-                    del labels_species[num - i - 1]
-                    del abs_errors[num - i - 1]
-                    del diffs_cpy[num - i - 1]
-        abs_errors, labels_species = (list(t) for t in zip(*sorted(zip(abs_errors, labels_species))))  # sort by error
+            for idx in range(num):
+                if not Composition(labels_species[num - idx - 1])[specie]:
+                    del labels_species[num - idx - 1]
+                    del abs_errors[num - idx - 1]
+                    del diffs_cpy[num - idx - 1]
+        abs_errors, labels_species = (
+            list(tup) for tup in zip(*sorted(zip(abs_errors, labels_species)))
+        )  # sort by error
 
         num = len(abs_errors)
         fig = go.Figure(
@@ -348,26 +340,25 @@ class CorrectionCalculator:
                 mode="markers",
                 text=labels_species,
             ),
-            layout=go.Layout(
-                title=go.layout.Title(text="Residual Errors for " + specie),
-                yaxis=go.layout.YAxis(title=go.layout.yaxis.Title(text="Residual Error (eV/atom)")),
+            layout=dict(
+                title=dict(text=f"Residual Errors for {specie}"),
+                yaxis=dict(title="Residual Error (eV/atom)"),
             ),
         )
 
         print("Residual Error:")
-        print("Median = " + str(np.median(np.array(abs_errors))))
-        print("Mean = " + str(np.mean(np.array(abs_errors))))
-        print("Std Dev = " + str(np.std(np.array(abs_errors))))
+        print(f"Median = {np.median(np.array(abs_errors))}")
+        print(f"Mean = {np.mean(np.array(abs_errors))}")
+        print(f"Std Dev = {np.std(np.array(abs_errors))}")
         print("Original Error:")
-        print("Median = " + str(abs(np.median(np.array(diffs_cpy)))))
-        print("Mean = " + str(abs(np.mean(np.array(diffs_cpy)))))
-        print("Std Dev = " + str(np.std(np.array(diffs_cpy))))
+        print(f"Median = {abs(np.median(np.array(diffs_cpy)))}")
+        print(f"Mean = {abs(np.mean(np.array(diffs_cpy)))}")
+        print(f"Std Dev = {np.std(np.array(diffs_cpy))}")
 
         return fig
 
     def make_yaml(self, name: str = "MP2020", dir: str | None = None) -> None:
-        """
-        Creates the _name_Compatibility.yaml that stores corrections as well as _name_CompatibilityUncertainties.yaml
+        """Creates the _name_Compatibility.yaml that stores corrections as well as _name_CompatibilityUncertainties.yaml
         for correction uncertainties.
 
         Args:
@@ -445,5 +436,5 @@ class CorrectionCalculator:
         contents["Uncertainties"].yaml_set_start_comment(
             "Uncertainties corresponding to each energy correction (eV/atom)", indent=2
         )
-        with open(path, "w") as file:
+        with open(path, mode="w") as file:
             yml.dump(contents, file)
