@@ -1,19 +1,17 @@
 #
-# pylint: disable=no-member, chained-comparison
-"""
-Low-level objects providing an abstraction for the objects involved in the calculation.
-"""
+
+"""Low-level objects providing an abstraction for the objects involved in the calculation."""
 
 from __future__ import annotations
 
 import abc
 from collections import namedtuple
+from collections.abc import Iterable
 from enum import Enum
 from pprint import pformat
-from typing import Iterable, cast
+from typing import cast
 
 import numpy as np
-from frozendict import frozendict
 from monty.collections import AttrDict
 from monty.design_patterns import singleton
 from monty.json import MontyDecoder, MontyEncoder, MSONable
@@ -25,26 +23,26 @@ def lattice_from_abivars(cls=None, *args, **kwargs):
     """
     Returns a `Lattice` object from a dictionary
     with the Abinit variables `acell` and either `rprim` in Bohr or `angdeg`
-    If acell is not given, the Abinit default is used i.e. [1,1,1] Bohr
+    If acell is not given, the Abinit default is used i.e. [1,1,1] Bohr.
 
     Args:
-        cls: Lattice class to be instantiated. pymatgen.core.lattice.Lattice if `cls` is None
+        cls: Lattice class to be instantiated. Defaults to pymatgen.core.Lattice.
 
     Example:
         lattice_from_abivars(acell=3*[10], rprim=np.eye(3))
     """
-    cls = Lattice if cls is None else cls
+    cls = cls or Lattice
     kwargs.update(dict(*args))
 
-    rprim = kwargs.get("rprim")
+    r_prim = kwargs.get("rprim")
     ang_deg = kwargs.get("angdeg")
-    acell = kwargs["acell"]
+    a_cell = kwargs["acell"]
 
-    if rprim is not None:
+    if r_prim is not None:
         if ang_deg is not None:
             raise ValueError("angdeg and rprimd are mutually exclusive")
-        rprim = np.reshape(rprim, (3, 3))
-        rprimd = [float(acell[i]) * rprim[i] for i in range(3)]
+        r_prim = np.reshape(r_prim, (3, 3))
+        rprimd = [float(a_cell[i]) * r_prim[i] for i in range(3)]
         # Call pymatgen constructors (note that pymatgen uses Angstrom instead of Bohr).
         return cls(ArrayWithUnit(rprimd, "bohr").to("ang"))
 
@@ -60,89 +58,85 @@ def lattice_from_abivars(cls=None, *args, **kwargs):
         # See also http://www.abinit.org/doc/helpfiles/for-v7.8/input_variables/varbas.html#angdeg
         tol12 = 1e-12
         pi, sin, cos, sqrt = np.pi, np.sin, np.cos, np.sqrt
-        rprim = np.zeros((3, 3))
+        r_prim = np.zeros((3, 3))
         if (
             abs(ang_deg[0] - ang_deg[1]) < tol12
             and abs(ang_deg[1] - ang_deg[2]) < tol12
             and abs(ang_deg[0] - 90.0) + abs(ang_deg[1] - 90.0) + abs(ang_deg[2] - 90) > tol12
         ):
             # Treat the case of equal angles (except all right angles):
-            # generates trigonal symmetry wrt third axis
+            # generates trigonal symmetry w.r.t. third axis
             cos_ang = cos(pi * ang_deg[0] / 180.0)
             a2 = 2.0 / 3.0 * (1.0 - cos_ang)
             aa = sqrt(a2)
             cc = sqrt(1.0 - a2)
-            rprim[0, 0] = aa
-            rprim[0, 1] = 0.0
-            rprim[0, 2] = cc
-            rprim[1, 0] = -0.5 * aa
-            rprim[1, 1] = sqrt(3.0) * 0.5 * aa
-            rprim[1, 2] = cc
-            rprim[2, 0] = -0.5 * aa
-            rprim[2, 1] = -sqrt(3.0) * 0.5 * aa
-            rprim[2, 2] = cc
+            r_prim[0, 0] = aa
+            r_prim[0, 1] = 0.0
+            r_prim[0, 2] = cc
+            r_prim[1, 0] = -0.5 * aa
+            r_prim[1, 1] = sqrt(3.0) * 0.5 * aa
+            r_prim[1, 2] = cc
+            r_prim[2, 0] = -0.5 * aa
+            r_prim[2, 1] = -sqrt(3.0) * 0.5 * aa
+            r_prim[2, 2] = cc
         else:
             # Treat all the other cases
-            rprim[0, 0] = 1.0
-            rprim[1, 0] = cos(pi * ang_deg[2] / 180.0)
-            rprim[1, 1] = sin(pi * ang_deg[2] / 180.0)
-            rprim[2, 0] = cos(pi * ang_deg[1] / 180.0)
-            rprim[2, 1] = (cos(pi * ang_deg[0] / 180.0) - rprim[1, 0] * rprim[2, 0]) / rprim[1, 1]
-            rprim[2, 2] = sqrt(1.0 - rprim[2, 0] ** 2 - rprim[2, 1] ** 2)
+            r_prim[0, 0] = 1.0
+            r_prim[1, 0] = cos(pi * ang_deg[2] / 180.0)
+            r_prim[1, 1] = sin(pi * ang_deg[2] / 180.0)
+            r_prim[2, 0] = cos(pi * ang_deg[1] / 180.0)
+            r_prim[2, 1] = (cos(pi * ang_deg[0] / 180.0) - r_prim[1, 0] * r_prim[2, 0]) / r_prim[1, 1]
+            r_prim[2, 2] = sqrt(1.0 - r_prim[2, 0] ** 2 - r_prim[2, 1] ** 2)
 
         # Call pymatgen constructors (note that pymatgen uses Angstrom instead of Bohr).
-        rprimd = [float(acell[i]) * rprim[i] for i in range(3)]
+        rprimd = [float(a_cell[i]) * r_prim[i] for i in range(3)]
         return cls(ArrayWithUnit(rprimd, "bohr").to("ang"))
 
     raise ValueError(f"Don't know how to construct a Lattice from dict:\n{pformat(kwargs)}")
 
 
-def structure_from_abivars(cls=None, *args, **kwargs):
+def structure_from_abivars(cls=None, *args, **kwargs) -> Structure:
     """
-    Build a :class:`Structure` object from a dictionary with ABINIT variables.
+    Build a Structure object from a dictionary with ABINIT variables.
 
     Args:
-        cls: Structure class to be instantiated. pymatgen.core.structure.Structure if cls is None
+        cls: Structure class to be instantiated. Defaults to Structure.
 
     Example:
         al_structure = structure_from_abivars(
             acell=3*[7.5],
-            rprim=[0.0, 0.5, 0.5,
-                   0.5, 0.0, 0.5,
-                   0.5, 0.5, 0.0],
+            rprim=[0.0, 0.5, 0.5, 0.5, 0.0, 0.5, 0.5, 0.5, 0.0],
             typat=1,
             xred=[0.0, 0.0, 0.0],
             ntypat=1,
             znucl=13,
         )
 
-    `xred` can be replaced with `xcart` or `xangst`.
+    xred can be replaced with xcart or xangst.
     """
     kwargs.update(dict(*args))
-    d = kwargs
-
-    cls = Structure if cls is None else cls
+    cls = cls or Structure
 
     # lattice = Lattice.from_dict(d, fmt="abivars")
-    lattice = lattice_from_abivars(**d)
-    coords, coords_are_cartesian = d.get("xred"), False
+    lattice = lattice_from_abivars(**kwargs)
+    coords, coords_are_cartesian = kwargs.get("xred"), False
 
     if coords is None:
-        coords = d.get("xcart")
+        coords = kwargs.get("xcart")
         if coords is not None:
-            if "xangst" in d:
+            if "xangst" in kwargs:
                 raise ValueError("xangst and xcart are mutually exclusive")
             coords = ArrayWithUnit(coords, "bohr").to("ang")
         else:
-            coords = d.get("xangst")
+            coords = kwargs.get("xangst")
         coords_are_cartesian = True
 
     if coords is None:
-        raise ValueError(f"Cannot extract coordinates from:\n {d}")
+        raise ValueError(f"Cannot extract coordinates from:\n {kwargs}")
 
     coords = np.reshape(coords, (-1, 3))
 
-    znucl_type, typat = d["znucl"], d["typat"]
+    znucl_type, typat = kwargs["znucl"], kwargs["typat"]
 
     if not isinstance(znucl_type, Iterable):
         znucl_type = [znucl_type]
@@ -151,7 +145,7 @@ def structure_from_abivars(cls=None, *args, **kwargs):
         typat = [typat]
 
     if len(typat) != len(coords):
-        raise ValueError(f"len(typat) != len(coords):\ntypat: {typat}\ncoords: {coords}")
+        raise ValueError(f"{len(typat)=} must equal {len(coords)=}")
 
     # Note conversion to int and Fortran --> C indexing
     typat = np.array(typat, dtype=int)
@@ -164,6 +158,7 @@ def structure_from_abivars(cls=None, *args, **kwargs):
         validate_proximity=False,
         to_unit_cell=False,
         coords_are_cartesian=coords_are_cartesian,
+        properties=kwargs.get("properties"),
     )
 
 
@@ -190,28 +185,27 @@ def species_by_znucl(structure: Structure) -> list[Species]:
     return types
 
 
-def structure_to_abivars(structure, enforce_znucl=None, enforce_typat=None, **kwargs):
+def structure_to_abivars(
+    structure: Structure, enforce_znucl: list | None = None, enforce_typat: list | None = None, **kwargs
+):
     """
     Receives a structure and returns a dictionary with ABINIT variables.
 
     Args:
-        enforce_znucl: List of ntypat entries with the value of Z for each type of atom.
-            Used to change the default ordering.
-        enforce_typat: List with natom entries with the type index.
-            Fortran conventions: start to count from 1.
-            Used to change the default ordering.
+        enforce_znucl (list): ntypat entries with the value of Z for each type of atom.
+            Used to change the default ordering. Defaults to None.
+        enforce_typat (list): natom entries with the type index.
+            Fortran conventions: start to count from 1. Used to change the default ordering.
     """
     if not structure.is_ordered:
         raise ValueError(
-            """\
-Received disordered structure with partial occupancies that cannot be converted into an Abinit input.
-Please use OrderDisorderedStructureTransformation or EnumerateStructureTransformation
-to build an appropriate supercell from partial occupancies or, alternatively, use the Rigid Band Model
-or the Virtual Crystal Approximation."""
+            "Received disordered structure with partial occupancies that cannot be converted into an "
+            "Abinit input. Please use OrderDisorderedStructureTransformation or EnumerateStructureTransformation "
+            "to build an appropriate supercell from partial occupancies or, alternatively, use the Rigid Band Model "
+            "or the Virtual Crystal Approximation."
         )
 
-    natom = structure.num_sites
-    ntypat = structure.ntypesp
+    n_atoms = len(structure)
     enforce_order = False
 
     if enforce_znucl is not None or enforce_typat is not None:
@@ -222,97 +216,98 @@ or the Virtual Crystal Approximation."""
 
         if len(enforce_typat) != len(structure):
             raise ValueError(
-                f"enforce_typat contains {len(enforce_typat)} entries while it should be natom: {len(structure)}"
+                f"enforce_typat contains {len(enforce_typat)} entries while it should be {len(structure)=}"
             )
 
-        if len(enforce_znucl) != ntypat:
-            raise ValueError(f"enforce_znucl contains {len(enforce_znucl)} entries while it should be ntypat: {ntypat}")
+        if len(enforce_znucl) != structure.n_elems:
+            raise ValueError(
+                f"enforce_znucl contains {len(enforce_znucl)} entries while it should be {structure.n_elems=}"
+            )
 
-    if not enforce_order:
+    if enforce_order:
+        znucl_type = enforce_znucl
+        typat = enforce_typat or []  # or [] added for mypy
+    else:
         types_of_specie = species_by_znucl(structure)
 
-        # [ntypat] list
         znucl_type = [specie.number for specie in types_of_specie]
-        typat = np.zeros(natom, int)
+        typat = np.zeros(n_atoms, int)
         for atm_idx, site in enumerate(structure):
             typat[atm_idx] = types_of_specie.index(site.specie) + 1
-    else:
-        znucl_type = enforce_znucl
-        typat = enforce_typat
 
-    rprim = ArrayWithUnit(structure.lattice.matrix, "ang").to("bohr")
-    angdeg = structure.lattice.angles
-    xred = np.reshape([site.frac_coords for site in structure], (-1, 3))
+    r_prim = ArrayWithUnit(structure.lattice.matrix, "ang").to("bohr")
+    ang_deg = structure.lattice.angles
+    x_red = np.reshape([site.frac_coords for site in structure], (-1, 3))
 
     # Set small values to zero. This usually happens when the CIF file
     # does not give structure parameters with enough digits.
-    rprim = np.where(np.abs(rprim) > 1e-8, rprim, 0.0)
-    xred = np.where(np.abs(xred) > 1e-8, xred, 0.0)
+    r_prim = np.where(np.abs(r_prim) > 1e-8, r_prim, 0.0)
+    x_red = np.where(np.abs(x_red) > 1e-8, x_red, 0.0)
 
     # Info on atoms.
-    d = {
-        "natom": natom,
-        "ntypat": ntypat,
+    dct = {
+        "natom": n_atoms,
+        "ntypat": structure.n_elems,
         "typat": typat,
         "znucl": znucl_type,
-        "xred": xred,
+        "xred": x_red,
+        "properties": structure.properties,
     }
 
     # Add info on the lattice.
-    # Should we use (rprim, acell) or (angdeg, acell) to specify the lattice?
-    geomode = kwargs.pop("geomode", "rprim")
-    if geomode == "automatic":
-        geomode = "rprim"
-        if structure.lattice.is_hexagonal:  # or structure.lattice.is_rhombohedral
-            geomode = "angdeg"
-            angdeg = structure.lattice.angles
+    # Should we use (rprim, acell) or (ang_deg, acell) to specify the lattice?
+    geo_mode = kwargs.pop("geomode", "rprim")
+    if geo_mode == "automatic":
+        geo_mode = "rprim"
+        if structure.lattice.is_hexagonal():  # or structure.lattice.is_rhombohedral
+            geo_mode = "angdeg"
+            ang_deg = structure.lattice.angles
             # Here one could polish a bit the numerical values if they are not exact.
             # Note that in pmg the angles are 12, 20, 01 while in Abinit 12, 02, 01
             # One should make sure that the orientation is preserved (see Curtarolo's settings)
 
-    if geomode == "rprim":
-        d.update(
+    if geo_mode == "rprim":
+        dct.update(
             acell=3 * [1.0],
-            rprim=rprim,
+            rprim=r_prim,
         )
 
-    elif geomode == "angdeg":
-        d.update(
+    elif geo_mode == "angdeg":
+        dct.update(
             acell=ArrayWithUnit(structure.lattice.abc, "ang").to("bohr"),
-            angdeg=angdeg,
+            angdeg=ang_deg,
         )
     else:
-        raise ValueError(f"Wrong value for geomode: {geomode}")
+        raise ValueError(f"Wrong value for {geo_mode=}")
 
-    return d
+    return dct
 
 
-def contract(s):
+def contract(string):
     """
-    >>> assert contract("1 1 1 2 2 3") == "3*1 2*2 1*3"
-    >>> assert contract("1 1 3 2 3") == "2*1 1*3 1*2 1*3"
+    assert contract("1 1 1 2 2 3") == "3*1 2*2 1*3"
+    assert contract("1 1 3 2 3") == "2*1 1*3 1*2 1*3"
     """
-    if not s:
-        return s
+    if not string:
+        return string
 
-    tokens = s.split()
+    tokens = string.split()
     old = tokens[0]
     count = [[1, old]]
 
-    for t in tokens[1:]:
-        if t == old:
+    for tok in tokens[1:]:
+        if tok == old:
             count[-1][0] += 1
         else:
-            old = t
-            count.append([1, t])
+            old = tok
+            count.append([1, tok])
 
     return " ".join(f"{c}*{t}" for c, t in count)
 
 
 class AbivarAble(metaclass=abc.ABCMeta):
     """
-    An `AbivarAble` object provides a method `to_abivars`
-    that returns a dictionary with the abinit variables.
+    An AbivarAble object provides a method to_abivars that returns a dictionary with the abinit variables.
     """
 
     @abc.abstractmethod
@@ -337,10 +332,13 @@ class MandatoryVariable:
     the cool syntax: variable is MANDATORY!
     """
 
+    def as_dict(self):
+        return {}
+
 
 @singleton
 class DefaultVariable:
-    """Singleton used to tag variables that will have the default value"""
+    """Singleton used to tag variables that will have the default value."""
 
 
 MANDATORY = MandatoryVariable()
@@ -364,23 +362,19 @@ class SpinMode(namedtuple("SpinMode", "mode nsppol nspinor nspden"), AbivarAble,
 
     @classmethod
     def as_spinmode(cls, obj):
-        """Converts obj into a `SpinMode` instance"""
+        """Converts obj into a `SpinMode` instance."""
         if isinstance(obj, cls):
             return obj
 
         # Assume a string with mode
         try:
-            return _mode2spinvars[obj]
+            return _mode_to_spin_vars[obj]
         except KeyError:
             raise KeyError(f"Wrong value for spin_mode: {obj}")
 
     def to_abivars(self):
         """Dictionary with Abinit input variables."""
-        return {
-            "nsppol": self.nsppol,
-            "nspinor": self.nspinor,
-            "nspden": self.nspden,
-        }
+        return {"nsppol": self.nsppol, "nspinor": self.nspinor, "nspden": self.nspden}
 
     def as_dict(self):
         """Convert object to dict."""
@@ -395,7 +389,7 @@ class SpinMode(namedtuple("SpinMode", "mode nsppol nspinor nspden"), AbivarAble,
 
 
 # An handy Multiton
-_mode2spinvars = {
+_mode_to_spin_vars = {
     "unpolarized": SpinMode("unpolarized", 1, 1, 1),
     "polarized": SpinMode("polarized", 2, 1, 2),
     "afm": SpinMode("afm", 1, 1, 2),
@@ -407,21 +401,21 @@ _mode2spinvars = {
 class Smearing(AbivarAble, MSONable):
     """
     Variables defining the smearing technique. The preferred way to instantiate
-    a `Smearing` object is via the class method Smearing.as_smearing(string)
+    a `Smearing` object is via the class method Smearing.as_smearing(string).
     """
 
     #: Mapping string_mode --> occopt
-    _mode2occopt = {
-        "nosmearing": 1,
-        "fermi_dirac": 3,
-        "marzari4": 4,
-        "marzari5": 5,
-        "methfessel": 6,
-        "gaussian": 7,
-    }
+    _mode2occopt = dict(
+        nosmearing=1,
+        fermi_dirac=3,
+        marzari4=4,
+        marzari5=5,
+        methfessel=6,
+        gaussian=7,
+    )
 
     def __init__(self, occopt, tsmear):
-        """Build object with occopt and tsmear"""
+        """Build object with occopt and tsmear."""
         self.occopt = occopt
         self.tsmear = tsmear
 
@@ -495,7 +489,7 @@ class Smearing(AbivarAble, MSONable):
         return {"occopt": self.occopt, "tsmear": self.tsmear}
 
     def as_dict(self):
-        """JSON-friendly dict representation of Smearing"""
+        """JSON-friendly dict representation of Smearing."""
         return {
             "@module": type(self).__module__,
             "@class": type(self).__name__,
@@ -513,26 +507,26 @@ class ElectronsAlgorithm(dict, AbivarAble, MSONable):
     """Variables controlling the SCF/NSCF algorithm."""
 
     # None indicates that we use abinit defaults.
-    _DEFAULT = {
-        "iprcell": None,
-        "iscf": None,
-        "diemac": None,
-        "diemix": None,
-        "diemixmag": None,
-        "dielam": None,
-        "diegap": None,
-        "dielng": None,
-        "diecut": None,
-        "nstep": 50,
-    }
+    _DEFAULT = dict(
+        iprcell=None,
+        iscf=None,
+        diemac=None,
+        diemix=None,
+        diemixmag=None,
+        dielam=None,
+        diegap=None,
+        dielng=None,
+        diecut=None,
+        nstep=50,
+    )
 
     def __init__(self, *args, **kwargs):
         """Initialize object."""
         super().__init__(*args, **kwargs)
 
-        for k in self:
-            if k not in self._DEFAULT:
-                raise ValueError(f"{type(self).__name__}: No default value has been provided for key {k}")
+        for key in self:
+            if key not in self._DEFAULT:
+                raise ValueError(f"{type(self).__name__}: No default value has been provided for {key=}")
 
     def to_abivars(self):
         """Dictionary with Abinit input variables."""
@@ -552,7 +546,7 @@ class ElectronsAlgorithm(dict, AbivarAble, MSONable):
 
 
 class Electrons(AbivarAble, MSONable):
-    """The electronic degrees of freedom"""
+    """The electronic degrees of freedom."""
 
     def __init__(
         self,
@@ -597,7 +591,7 @@ class Electrons(AbivarAble, MSONable):
         return self.spin_mode.nspden
 
     def as_dict(self):
-        """Json friendly dict representation"""
+        """Json friendly dict representation."""
         dct = {}
         dct["@module"] = type(self).__module__
         dct["@class"] = type(self).__name__
@@ -611,16 +605,16 @@ class Electrons(AbivarAble, MSONable):
         return dct
 
     @classmethod
-    def from_dict(cls, d):
+    def from_dict(cls, dct):
         """Build object from dictionary."""
-        d = d.copy()
-        d.pop("@module", None)
-        d.pop("@class", None)
+        dct = dct.copy()
+        dct.pop("@module", None)
+        dct.pop("@class", None)
         dec = MontyDecoder()
-        d["spin_mode"] = dec.process_decoded(d["spin_mode"])
-        d["smearing"] = dec.process_decoded(d["smearing"])
-        d["algorithm"] = dec.process_decoded(d["algorithm"]) if d["algorithm"] else None
-        return cls(**d)
+        dct["spin_mode"] = dec.process_decoded(dct["spin_mode"])
+        dct["smearing"] = dec.process_decoded(dct["smearing"])
+        dct["algorithm"] = dec.process_decoded(dct["algorithm"]) if dct["algorithm"] else None
+        return cls(**dct)
 
     def to_abivars(self):
         """Return dictionary with Abinit variables."""
@@ -653,9 +647,7 @@ class KSamplingModes(Enum):
 
 
 class KSampling(AbivarAble, MSONable):
-    """
-    Input variables defining the K-point sampling.
-    """
+    """Input variables defining the K-point sampling."""
 
     def __init__(
         self,
@@ -690,8 +682,8 @@ class KSampling(AbivarAble, MSONable):
                 Number of division for the sampling of the smallest segment if mode is "path".
                 Not used for the other modes
             kpts: Number of divisions. Even when only a single specification is
-                  required, e.g. in the automatic scheme, the kpts should still
-                  be specified as a 2D array. e.g., [[20]] or [[2,2,2]].
+                required, e.g. in the automatic scheme, the kpts should still
+                be specified as a 2D array. e.g., [[20]] or [[2,2,2]].
             kpt_shifts: Shifts for Kpoints.
             use_symmetries: False if spatial symmetries should not be used
                 to reduce the number of independent k-points.
@@ -701,7 +693,7 @@ class KSampling(AbivarAble, MSONable):
             chksymbreak: Abinit input variable: check whether the BZ sampling preserves the symmetry of the crystal.
             comment: String comment for Kpoints
 
-        .. note::
+        Note:
             The default behavior of the constructor is monkhorst.
         """
         if isinstance(mode, str):
@@ -789,7 +781,7 @@ class KSampling(AbivarAble, MSONable):
 
     @classmethod
     def gamma_only(cls):
-        """Gamma-only sampling"""
+        """Gamma-only sampling."""
         return cls(kpt_shifts=(0.0, 0.0, 0.0), comment="Gamma-only sampling")
 
     @classmethod
@@ -805,7 +797,7 @@ class KSampling(AbivarAble, MSONable):
                 to reduce the number of independent k-points.
 
         Returns:
-            :class:`KSampling` object.
+            KSampling object.
         """
         return cls(
             kpts=[kpts],
@@ -835,7 +827,7 @@ class KSampling(AbivarAble, MSONable):
             use_time_reversal: Use time-reversal symmetry to reduce the number of k-points.
 
         Returns:
-            :class:`KSampling` object.
+            KSampling object.
         """
         return cls(
             kpts=[ngkpt],
@@ -860,13 +852,13 @@ class KSampling(AbivarAble, MSONable):
         Convenient static constructor for an automatic Monkhorst-Pack mesh.
 
         Args:
-            structure: :class:`Structure` object.
+            structure: Structure object.
             ngkpt: Subdivisions N_1, N_2 and N_3 along reciprocal lattice vectors.
             use_symmetries: Use spatial symmetries to reduce the number of k-points.
             use_time_reversal: Use time-reversal symmetry to reduce the number of k-points.
 
         Returns:
-            :class:`KSampling` object.
+            KSampling object.
         """
         # TODO
         shiftk = 3 * (0.5,)
@@ -890,13 +882,13 @@ class KSampling(AbivarAble, MSONable):
         Static constructor for path in k-space.
 
         Args:
-            structure: :class:`Structure` object.
+            structure: Structure object.
             kpath_bounds: List with the reduced coordinates of the k-points defining the path.
             ndivsm: Number of division for the smallest segment.
             comment: Comment string.
 
         Returns:
-            :class:`KSampling` object.
+            KSampling object.
         """
         if kpath_bounds is None:
             # Compute the boundaries from the input structure.
@@ -923,7 +915,7 @@ class KSampling(AbivarAble, MSONable):
 
     @classmethod
     def path_from_structure(cls, ndivsm, structure):
-        """See _path for the meaning of the variables"""
+        """See _path for the meaning of the variables."""
         return cls._path(
             ndivsm,
             structure=structure,
@@ -932,7 +924,7 @@ class KSampling(AbivarAble, MSONable):
 
     @classmethod
     def explicit_path(cls, ndivsm, kpath_bounds):
-        """See _path for the meaning of the variables"""
+        """See _path for the meaning of the variables."""
         return cls._path(ndivsm, kpath_bounds=kpath_bounds, comment="Explicit K-path")
 
     @classmethod
@@ -960,7 +952,7 @@ class KSampling(AbivarAble, MSONable):
         lattice = structure.lattice
         lengths = lattice.abc
         shifts = np.reshape(shifts, (-1, 3))
-        ngrid = kppa / structure.num_sites / len(shifts)
+        ngrid = kppa / len(structure) / len(shifts)
 
         mult = (ngrid * lengths[0] * lengths[1] * lengths[2]) ** (1 / 3.0)
 
@@ -1014,7 +1006,7 @@ class KSampling(AbivarAble, MSONable):
 
 
 class Constraints(AbivarAble):
-    """This object defines the constraints for structural relaxation"""
+    """This object defines the constraints for structural relaxation."""
 
     def to_abivars(self):
         """Dictionary with Abinit variables."""
@@ -1031,17 +1023,17 @@ class RelaxationMethod(AbivarAble, MSONable):
     The set of variables are constructed in to_abivars depending on ionmov and optcell.
     """
 
-    _default_vars = {
-        "ionmov": MANDATORY,
-        "optcell": MANDATORY,
-        "ntime": 80,
-        "dilatmx": 1.05,
-        "ecutsm": 0.5,
-        "strfact": None,
-        "tolmxf": None,
-        "strtarget": None,
-        "atoms_constraints": {},  # Constraints are stored in a dictionary. {} means if no constraint is enforced.
-    }
+    _default_vars = dict(
+        ionmov=MANDATORY,
+        optcell=MANDATORY,
+        ntime=80,
+        dilatmx=1.05,
+        ecutsm=0.5,
+        strfact=None,
+        tolmxf=None,
+        strtarget=None,
+        atoms_constraints={},  # Constraints are stored in a dictionary. {} means if no constraint is enforced.
+    )
 
     IONMOV_DEFAULT = 3
     OPTCELL_DEFAULT = 2
@@ -1049,20 +1041,20 @@ class RelaxationMethod(AbivarAble, MSONable):
     def __init__(self, *args, **kwargs):
         """Initialize object."""
         # Initialize abivars with the default values.
-        self.abivars = self._default_vars
+        self.abivars = {**self._default_vars}
 
         # Overwrite the keys with the args and kwargs passed to constructor.
         self.abivars.update(*args, **kwargs)
 
         self.abivars = AttrDict(self.abivars)
 
-        for k in self.abivars:
-            if k not in self._default_vars:
-                raise ValueError(f"{type(self).__name__}: No default value has been provided for key {k}")
+        for key in self.abivars:
+            if key not in self._default_vars:
+                raise ValueError(f"{type(self).__name__}: No default value has been provided for {key=}")
 
-        for k in self.abivars:
-            if k is MANDATORY:
-                raise ValueError(f"{type(self).__name__}: No default value has been provided for the mandatory key {k}")
+        for key in self.abivars:
+            if key is MANDATORY:
+                raise ValueError(f"{type(self).__name__}: No default value has been provided for the mandatory {key=}")
 
     @classmethod
     def atoms_only(cls, atoms_constraints=None):
@@ -1073,7 +1065,7 @@ class RelaxationMethod(AbivarAble, MSONable):
 
     @classmethod
     def atoms_and_cell(cls, atoms_constraints=None):
-        """Relax atomic positions as well as unit cell"""
+        """Relax atomic positions as well as unit cell."""
         if atoms_constraints is None:
             return cls(ionmov=cls.IONMOV_DEFAULT, optcell=cls.OPTCELL_DEFAULT)
         return cls(
@@ -1093,7 +1085,7 @@ class RelaxationMethod(AbivarAble, MSONable):
         return self.abivars.optcell != 0
 
     def to_abivars(self):
-        """Returns a dictionary with the abinit variables"""
+        """Returns a dictionary with the abinit variables."""
         # These variables are always present.
         out_vars = {
             "ionmov": self.abivars.ionmov,
@@ -1117,22 +1109,20 @@ class RelaxationMethod(AbivarAble, MSONable):
         # Cell relaxation.
         if self.move_cell:
             out_vars.update(
-                {
-                    "dilatmx": self.abivars.dilatmx,
-                    "ecutsm": self.abivars.ecutsm,
-                    "strfact": self.abivars.strfact,
-                    "strtarget": self.abivars.strtarget,
-                }
+                dilatmx=self.abivars.dilatmx,
+                ecutsm=self.abivars.ecutsm,
+                strfact=self.abivars.strfact,
+                strtarget=self.abivars.strtarget,
             )
 
         return out_vars
 
     def as_dict(self):
         """Convert object to dict."""
-        d = dict(self._default_vars)
-        d["@module"] = type(self).__module__
-        d["@class"] = type(self).__name__
-        return d
+        dct = dict(self._default_vars)
+        dct["@module"] = type(self).__module__
+        dct["@class"] = type(self).__name__
+        return dct
 
     @classmethod
     def from_dict(cls, d):
@@ -1157,7 +1147,7 @@ class PPModelModes(Enum):
 class PPModel(AbivarAble, MSONable):
     """
     Parameters defining the plasmon-pole technique.
-    The common way to instantiate a PPModel object is via the class method PPModel.as_ppmodel(string)
+    The common way to instantiate a PPModel object is via the class method PPModel.as_ppmodel(string).
     """
 
     @classmethod
@@ -1247,7 +1237,7 @@ class HilbertTransform(AbivarAble):
     """
     Parameters for the Hilbert-transform method (Screening code)
     i.e. the parameters defining the frequency mesh used for the spectral function
-    and the frequency mesh used for the polarizability
+    and the frequency mesh used for the polarizability.
     """
 
     def __init__(
@@ -1282,7 +1272,7 @@ class HilbertTransform(AbivarAble):
         self.nfreqim = nfreqim
 
     def to_abivars(self):
-        """Returns a dictionary with the abinit variables"""
+        """Returns a dictionary with the abinit variables."""
         return {
             # Spectral function
             "nomegasf": self.nomegasf,
@@ -1297,7 +1287,7 @@ class HilbertTransform(AbivarAble):
 
 
 class ModelDielectricFunction(AbivarAble):
-    """Model dielectric function used for BSE calculation"""
+    """Model dielectric function used for BSE calculation."""
 
     def __init__(self, mdf_epsinf):
         """
@@ -1323,10 +1313,10 @@ class Screening(AbivarAble):
     """
 
     # Approximations used for W
-    _WTYPES = frozendict(RPA=0)
+    _WTYPES = dict(RPA=0)
 
     # Self-consistecy modes
-    _SC_MODES = frozendict(one_shot=0, energy_only=1, wavefunctions=2)
+    _SC_MODES = dict(one_shot=0, energy_only=1, wavefunctions=2)
 
     def __init__(
         self,
@@ -1344,7 +1334,7 @@ class Screening(AbivarAble):
             nband Number of bands for the Green's function
             w_type: Screening type
             sc_mode: Self-consistency mode.
-            hilbert: Instance of :class:`HilbertTransform` defining the parameters for the Hilber transform method.
+            hilbert: Instance of HilbertTransform defining the parameters for the Hilber transform method.
             ecutwfn: Cutoff energy for the wavefunctions (Default: ecutwfn == ecut).
             inclvkb: Option for the treatment of the dipole matrix elements (NC pseudos).
         """
@@ -1386,7 +1376,7 @@ class Screening(AbivarAble):
     #    return dig1.strip() + dig0.strip()
 
     def to_abivars(self):
-        """Returns a dictionary with the abinit variables"""
+        """Returns a dictionary with the abinit variables."""
         abivars = {
             "ecuteps": self.ecuteps,
             "ecutwfn": self.ecutwfn,
@@ -1408,11 +1398,9 @@ class Screening(AbivarAble):
 
 
 class SelfEnergy(AbivarAble):
-    """
-    This object defines the parameters used for the computation of the self-energy.
-    """
+    """This object defines the parameters used for the computation of the self-energy."""
 
-    _SIGMA_TYPES = frozendict(
+    _SIGMA_TYPES = dict(
         gw=0,
         hartree_fock=5,
         sex=6,
@@ -1421,7 +1409,7 @@ class SelfEnergy(AbivarAble):
         model_gw_cd=9,
     )
 
-    _SC_MODES = frozendict(
+    _SC_MODES = dict(
         one_shot=0,
         energy_only=1,
         wavefunctions=2,
@@ -1446,11 +1434,11 @@ class SelfEnergy(AbivarAble):
             sc_mode: Self-consistency mode.
             nband: Number of bands for the Green's function
             ecutsigx: Cutoff energy for the exchange part of the self-energy (Ha units).
-            screening: :class:`Screening` instance.
+            screening: Screening instance.
             gw_qprange: Option for the automatic selection of k-points and bands for GW corrections.
                 See Abinit docs for more detail. The default value makes the code computie the
                 QP energies for all the point in the IBZ and one band above and one band below the Fermi level.
-            ppmodel: :class:`PPModel` instance with the parameters used for the plasmon-pole technique.
+            ppmodel: PPModel instance with the parameters used for the plasmon-pole technique.
             ecuteps: Cutoff energy for the screening (Ha units).
             ecutwfn: Cutoff energy for the wavefunctions (Default: ecutwfn == ecut).
         """
@@ -1546,14 +1534,14 @@ class ExcHamiltonian(AbivarAble):
     """This object contains the parameters for the solution of the Bethe-Salpeter equation."""
 
     # Types of excitonic Hamiltonian.
-    _EXC_TYPES = frozendict(
+    _EXC_TYPES = dict(
         TDA=0,  # Tamm-Dancoff approximation.
         coupling=1,  # Calculation with coupling.
     )
 
     # Algorithms used to compute the macroscopic dielectric function
     # and/or the exciton wavefunctions.
-    _ALGO2VAR = frozendict(direct_diago=1, haydock=2, cg=3)
+    _ALGO2VAR = dict(direct_diago=1, haydock=2, cg=3)
 
     # Options specifying the treatment of the Coulomb term.
     _COULOMB_MODES = ("diago", "full", "model_df")
@@ -1589,7 +1577,7 @@ class ExcHamiltonian(AbivarAble):
             bs_freq_mesh: Frequency mesh for the macroscopic dielectric function (start, stop, step) in Ha.
             zcut: Broadening parameter in Ha.
             **kwargs:
-                Extra keywords
+                Extra keywords.
         """
         spin_mode = SpinMode.as_spinmode(spin_mode)
 
@@ -1627,11 +1615,11 @@ class ExcHamiltonian(AbivarAble):
         if any(bs_loband < 0):
             raise ValueError(f"bs_loband <= 0 while it is {bs_loband}")
         if any(bs_loband >= nband):
-            raise ValueError(f"bs_loband ({bs_loband}) >= nband ({nband})")
+            raise ValueError(f"({bs_loband=}) >= ({nband=})")
 
     @property
     def inclvkb(self):
-        """Treatment of the dipole matrix element (NC pseudos, default is 2)"""
+        """Treatment of the dipole matrix element (NC pseudos, default is 2)."""
         return self.kwargs.get("inclvkb", 2)
 
     @property
