@@ -6,9 +6,9 @@ Atoms object and pymatgen Structure objects.
 
 from __future__ import annotations
 
-import sys
 import warnings
-from site import getsitepackages
+from collections.abc import Iterable
+from importlib.metadata import PackageNotFoundError
 from typing import TYPE_CHECKING
 
 import numpy as np
@@ -20,14 +20,11 @@ if TYPE_CHECKING:
 
     from pymatgen.core.structure import SiteCollection
 
-
-# ensure site packages have higher precedence than local modules so that this file
-# can't shadow the ase package
-sys.path.insert(0, getsitepackages()[0])
 try:
     from ase import Atoms
     from ase.calculators.singlepoint import SinglePointDFTCalculator
     from ase.constraints import FixAtoms
+    from ase.spacegroup import Spacegroup
 
     ase_loaded = True
 except ImportError:
@@ -41,12 +38,10 @@ __email__ = "shyuep@gmail.com"
 __date__ = "Mar 8, 2012"
 
 
-# NOTE: If making notable changes to this class, please ping @arosen93 on GitHub.
+# NOTE: If making notable changes to this class, please ping @Andrew-S-Rosen on GitHub.
 # There are some subtleties in here, particularly related to spins/charges.
 class AseAtomsAdaptor:
-    """
-    Adaptor serves as a bridge between ASE Atoms and pymatgen objects.
-    """
+    """Adaptor serves as a bridge between ASE Atoms and pymatgen objects."""
 
     @staticmethod
     def get_atoms(structure: SiteCollection, **kwargs) -> Atoms:
@@ -61,10 +56,7 @@ class AseAtomsAdaptor:
             Atoms: ASE Atoms object
         """
         if not ase_loaded:
-            raise ImportError(
-                "AseAtomsAdaptor requires the ASE package.\n"
-                "Use `pip install ase` or `conda install ase -c conda-forge`"
-            )
+            raise PackageNotFoundError("AseAtomsAdaptor requires the ASE package. Use `pip install ase`")
         if not structure.is_ordered:
             raise ValueError("ASE Atoms only supports ordered structures")
 
@@ -80,6 +72,9 @@ class AseAtomsAdaptor:
 
         atoms = Atoms(symbols=symbols, positions=positions, pbc=pbc, cell=cell, **kwargs)
 
+        if "tags" in structure.site_properties:
+            atoms.set_tags(structure.site_properties["tags"])
+
         # Set the site magmoms in the ASE Atoms object
         # Note: ASE distinguishes between initial and converged
         # magnetic moment site properties, whereas pymatgen does not. Therefore, we
@@ -116,20 +111,6 @@ class AseAtomsAdaptor:
             atoms.charge = structure.charge
             atoms.spin_multiplicity = structure.spin_multiplicity
 
-        # Set the Atoms final magnetic moments and charges if present.
-        # This uses the SinglePointDFTCalculator as the dummy calculator
-        # to store results.
-        charges = structure.site_properties.get("final_charge")
-        magmoms = structure.site_properties.get("final_magmom")
-        if magmoms or charges:
-            if magmoms and charges:
-                calc = SinglePointDFTCalculator(atoms, magmoms=magmoms, charges=charges)
-            elif magmoms:
-                calc = SinglePointDFTCalculator(atoms, magmoms=magmoms)
-            else:
-                calc = SinglePointDFTCalculator(atoms, charges=charges)
-            atoms.calc = calc
-
         # Get the oxidation states from the structure
         oxi_states: list[float | None] = [getattr(site.specie, "oxi_state", None) for site in structure]
 
@@ -140,8 +121,11 @@ class AseAtomsAdaptor:
             fix_atoms = []
             for site in structure:
                 selective_dynamics: ArrayLike = site.properties.get("selective_dynamics")  # type: ignore[assignment]
-                if not (np.all(selective_dynamics) or not np.any(selective_dynamics)):
-                    # should be [True, True, True] or [False, False, False]
+                if (
+                    isinstance(selective_dynamics, Iterable)
+                    and True in selective_dynamics
+                    and False in selective_dynamics
+                ):
                     raise ValueError(
                         "ASE FixAtoms constraint does not support selective dynamics in only some dimensions. "
                         f"Remove the {selective_dynamics=} and try again if you do not need them."
@@ -163,12 +147,28 @@ class AseAtomsAdaptor:
         if any(oxi_states):
             atoms.set_array("oxi_states", np.array(oxi_states))
 
-        # Add any .info/calc.results flags to the ASE Atoms object so we don't lose them during
-        # interconversion.
-        if info := getattr(structure, "info", None):
-            atoms.info = info
+        # Atoms.info <---> Structure.properties
+        if properties := getattr(structure, "properties"):  # noqa: B009
+            atoms.info = properties
+
+        # Regenerate Spacegroup object from `.todict()` representation
+        if isinstance(atoms.info.get("spacegroup"), dict):
+            atoms.info["spacegroup"] = Spacegroup(
+                atoms.info["spacegroup"]["number"], setting=atoms.info["spacegroup"].get("setting", 1)
+            )
+
+        # Atoms.calc <---> Structure.calc
         if calc := getattr(structure, "calc", None):
             atoms.calc = calc
+        else:
+            # Set the Atoms final magnetic moments and charges if present.
+            # This uses the SinglePointDFTCalculator as the dummy calculator
+            # to store results.
+            charges = structure.site_properties.get("final_charge")
+            magmoms = structure.site_properties.get("final_magmom")
+            if charges or magmoms:
+                calc = SinglePointDFTCalculator(atoms, magmoms=magmoms, charges=charges)
+                atoms.calc = calc
 
         return atoms
 
@@ -183,12 +183,15 @@ class AseAtomsAdaptor:
             **cls_kwargs: Any additional kwargs to pass to the cls
 
         Returns:
-            Equivalent pymatgen.core.structure.Structure
+            Structure: Equivalent pymatgen Structure
         """
         symbols = atoms.get_chemical_symbols()
         positions = atoms.get_positions()
         lattice = atoms.get_cell()
 
+        # Get the tags
+        tags = atoms.get_tags() if atoms.has("tags") else None
+
         # Get the (final) site magmoms and charges from the ASE Atoms object.
         if getattr(atoms, "calc", None) is not None and getattr(atoms.calc, "results", None) is not None:
             charges = atoms.calc.results.get("charges")
@@ -213,17 +216,27 @@ class AseAtomsAdaptor:
                 else:
                     unsupported_constraint_type = True
             if unsupported_constraint_type:
-                warnings.warn("Only FixAtoms is supported by Pymatgen. Other constraints will not be set.")
+                warnings.warn("Only FixAtoms is supported by Pymatgen. Other constraints will not be set.", UserWarning)
             sel_dyn = [[False] * 3 if atom.index in constraint_indices else [True] * 3 for atom in atoms]
         else:
             sel_dyn = None
 
+        # Atoms.info <---> Structure.properties
+        # But first make sure `spacegroup` is JSON serializable
+        if atoms.info.get("spacegroup") and isinstance(atoms.info["spacegroup"], Spacegroup):
+            atoms.info["spacegroup"] = atoms.info["spacegroup"].todict()
+        properties = getattr(atoms, "info", {})
+
         # Return a Molecule object if that was specifically requested;
         # otherwise return a Structure object as expected
         if cls == Molecule:
-            structure = cls(symbols, positions, **cls_kwargs)
+            structure = cls(symbols, positions, properties=properties, **cls_kwargs)
         else:
-            structure = cls(lattice, symbols, positions, coords_are_cartesian=True, **cls_kwargs)
+            structure = cls(lattice, symbols, positions, coords_are_cartesian=True, properties=properties, **cls_kwargs)
+
+        # Atoms.calc <---> Structure.calc
+        if calc := getattr(atoms, "calc", None):
+            structure.calc = calc
 
         # Set the site magmoms in the Pymatgen structure object
         # Note: ASE distinguishes between initial and converged
@@ -255,6 +268,8 @@ class AseAtomsAdaptor:
             structure.add_site_property("magmom", initial_magmoms)
         if sel_dyn is not None and ~np.all(sel_dyn):
             structure.add_site_property("selective_dynamics", sel_dyn)
+        if tags is not None:
+            structure.add_site_property("tags", tags)
 
         # Add oxidation states by site
         if oxi_states is not None:
@@ -275,13 +290,6 @@ class AseAtomsAdaptor:
             ]:
                 structure.add_site_property(prop, atoms.get_array(prop).tolist())
 
-        # Add any .info/calc.results flags to the Pymatgen structure object so we don't lose them
-        # during interconversion.
-        if info := getattr(atoms, "info", None):
-            structure.info = info
-        if calc := getattr(atoms, "calc", None):
-            structure.calc = calc
-
         return structure
 
     @staticmethod
