@@ -50,9 +50,7 @@ class AbstractFeffInputSet(MSONable, metaclass=abc.ABCMeta):
 
     @abc.abstractmethod
     def header(self):
-        """
-        Returns header to be used in feff.inp file from a pymatgen structure
-        """
+        """Returns header to be used in feff.inp file from a pymatgen structure."""
 
     @property
     @abc.abstractmethod
@@ -67,28 +65,22 @@ class AbstractFeffInputSet(MSONable, metaclass=abc.ABCMeta):
     @property
     @abc.abstractmethod
     def tags(self):
-        """
-        Returns standard calculation parameters.
-        """
+        """Returns standard calculation parameters."""
         return
 
     @property
     @abc.abstractmethod
     def potential(self):
-        """
-        Returns POTENTIAL section used in feff.inp from a structure.
-        """
+        """Returns POTENTIAL section used in feff.inp from a structure."""
 
     def all_input(self):
-        """
-        Returns all input files as a dict of {filename: feffio object}
-        """
-        d = {"HEADER": self.header(), "PARAMETERS": self.tags}
+        """Returns all input files as a dict of {filename: feffio object}."""
+        dct = {"HEADER": self.header(), "PARAMETERS": self.tags}
 
         if "RECIPROCAL" not in self.tags:
-            d.update({"POTENTIALS": self.potential, "ATOMS": self.atoms})
+            dct.update({"POTENTIALS": self.potential, "ATOMS": self.atoms})
 
-        return d
+        return dct
 
     def write_input(self, output_dir=".", make_dir_if_not_present=True):
         """
@@ -99,21 +91,23 @@ class AbstractFeffInputSet(MSONable, metaclass=abc.ABCMeta):
             make_dir_if_not_present: Set to True if you want the directory (
                 and the whole path) to be created if it is not present.
         """
-        if make_dir_if_not_present and not os.path.exists(output_dir):
-            os.makedirs(output_dir)
+        if make_dir_if_not_present:
+            os.makedirs(output_dir, exist_ok=True)
 
         feff = self.all_input()
 
-        feff_input = "\n\n".join(str(feff[k]) for k in ["HEADER", "PARAMETERS", "POTENTIALS", "ATOMS"] if k in feff)
+        feff_input = "\n\n".join(
+            str(feff[key]) for key in ["HEADER", "PARAMETERS", "POTENTIALS", "ATOMS"] if key in feff
+        )
 
         for k, v in feff.items():
-            with open(os.path.join(output_dir, k), "w") as f:
-                f.write(str(v))
+            with open(os.path.join(output_dir, k), mode="w") as file:
+                file.write(str(v))
 
-        with open(os.path.join(output_dir, "feff.inp"), "w") as f:
-            f.write(feff_input)
+        with open(f"{output_dir}/feff.inp", mode="w") as file:
+            file.write(feff_input)
 
-        # write the structure to cif file
+        # write the structure to CIF file
         if "ATOMS" not in feff:
             self.atoms.struct.to(fmt="cif", filename=os.path.join(output_dir, feff["PARAMETERS"]["CIF"]))
 
@@ -157,7 +151,7 @@ class FEFFDictSet(AbstractFeffInputSet):
                     of tuples where the first element is the unique potential value (ipot value)
                     and the second element is the charge to be applied to atoms associated
                     with that potential, e.g. {"IONS": [(0, 0.1), (1, 0.1), (2, 0.1)]}
-                    will result in
+                    will result in.
 
                     ION 0 0.1
                     ION 1 0.1
@@ -220,7 +214,7 @@ class FEFFDictSet(AbstractFeffInputSet):
 
     def header(self, source: str = "", comment: str = ""):
         """
-        Creates header string from structure object
+        Creates header string from structure object.
 
         Args:
             source: Source identifier used to create structure, can be defined
@@ -252,10 +246,7 @@ class FEFFDictSet(AbstractFeffInputSet):
                     mult = (self.nkpts * abc[0] * abc[1] * abc[2]) ** (1 / 3)
                     self.config_dict["KMESH"] = [int(round(mult / length)) for length in abc]
             else:
-                logger.warning(
-                    "Large system(>=14 atoms) or EXAFS calculation, \
-                                removing K-space settings"
-                )
+                logger.warning("Large system(>=14 atoms) or EXAFS calculation, removing K-space settings")
                 del self.config_dict["RECIPROCAL"]
                 self.config_dict.pop("CIF", None)
                 self.config_dict.pop("TARGET", None)
@@ -267,7 +258,7 @@ class FEFFDictSet(AbstractFeffInputSet):
     @property
     def potential(self) -> Potential:
         """
-        FEFF potential
+        FEFF potential.
 
         Returns:
             Potential
@@ -277,7 +268,7 @@ class FEFFDictSet(AbstractFeffInputSet):
     @property
     def atoms(self) -> Atoms:
         """
-        absorber + the rest
+        absorber + the rest.
 
         Returns:
             Atoms
@@ -290,16 +281,16 @@ class FEFFDictSet(AbstractFeffInputSet):
         output.append("")
         return "\n".join(output)
 
-    @staticmethod
-    def from_directory(input_dir):
+    @classmethod
+    def from_directory(cls, input_dir):
         """
         Read in a set of FEFF input files from a directory, which is
         useful when existing FEFF input needs some adjustment.
         """
         sub_d = {}
         for fname, ftype in [("HEADER", Header), ("PARAMETERS", Tags)]:
-            fullzpath = zpath(os.path.join(input_dir, fname))
-            sub_d[fname.lower()] = ftype.from_file(fullzpath)
+            full_zpath = zpath(os.path.join(input_dir, fname))
+            sub_d[fname.lower()] = ftype.from_file(full_zpath)
 
         # Generation of FEFFDict set requires absorbing atom, need to search
         # the index of absorption atom in the structure according to the
@@ -307,10 +298,10 @@ class FEFFDictSet(AbstractFeffInputSet):
 
         absorber_index = []
         radius = None
-        feffinp = zpath(os.path.join(input_dir, "feff.inp"))
+        feff_inp = zpath(f"{input_dir}/feff.inp")
 
         if "RECIPROCAL" not in sub_d["parameters"]:
-            input_atoms = Atoms.cluster_from_file(feffinp)
+            input_atoms = Atoms.cluster_from_file(feff_inp)
             shell_species = np.array([x.species_string for x in input_atoms])
 
             # First row of distance matrix represents the distance from the absorber to
@@ -321,18 +312,13 @@ class FEFFDictSet(AbstractFeffInputSet):
             from math import ceil
 
             radius = int(
-                ceil(
-                    input_atoms.get_distance(
-                        input_atoms.index(input_atoms[0]),
-                        input_atoms.index(input_atoms[-1]),
-                    )
-                )
+                ceil(input_atoms.get_distance(input_atoms.index(input_atoms[0]), input_atoms.index(input_atoms[-1])))
             )
 
             for site_index, site in enumerate(sub_d["header"].struct):
                 if site.specie == input_atoms[0].specie:
                     site_atoms = Atoms(sub_d["header"].struct, absorbing_atom=site_index, radius=radius)
-                    site_distance = np.array(site_atoms.get_lines())[:, 5].astype(np.float64)
+                    site_distance = np.array(site_atoms.get_lines())[:, 5].astype(float)
                     site_shell_species = np.array(site_atoms.get_lines())[:, 4]
                     shell_overlap = min(shell_species.shape[0], site_shell_species.shape[0])
 
@@ -347,10 +333,10 @@ class FEFFDictSet(AbstractFeffInputSet):
 
         # Generate the input set
         if "XANES" in sub_d["parameters"]:
-            CONFIG = loadfn(os.path.join(MODULE_DIR, "MPXANESSet.yaml"))
+            CONFIG = loadfn(f"{MODULE_DIR}/MPXANESSet.yaml")
             if radius is None:
                 radius = 10
-            return FEFFDictSet(
+            return cls(
                 absorber_index[0],
                 sub_d["header"].struct,
                 radius=radius,
@@ -364,11 +350,9 @@ class FEFFDictSet(AbstractFeffInputSet):
 
 
 class MPXANESSet(FEFFDictSet):
-    """
-    FeffDictSet for XANES spectroscopy.
-    """
+    """FeffDictSet for XANES spectroscopy."""
 
-    CONFIG = loadfn(os.path.join(MODULE_DIR, "MPXANESSet.yaml"))
+    CONFIG = loadfn(f"{MODULE_DIR}/MPXANESSet.yaml")
 
     def __init__(
         self,
@@ -389,7 +373,7 @@ class MPXANESSet(FEFFDictSet):
             nkpts (int): Total number of kpoints in the brillouin zone. Used
                 only when feff is run in the reciprocal space mode.
             user_tag_settings (dict): override default tag settings
-            **kwargs: Passthrough to FEFFDictSet
+            **kwargs: Passthrough to FEFFDictSet.
         """
         super().__init__(
             absorbing_atom,
@@ -405,11 +389,9 @@ class MPXANESSet(FEFFDictSet):
 
 
 class MPEXAFSSet(FEFFDictSet):
-    """
-    FeffDictSet for EXAFS spectroscopy.
-    """
+    """FeffDictSet for EXAFS spectroscopy."""
 
-    CONFIG = loadfn(os.path.join(MODULE_DIR, "MPEXAFSSet.yaml"))
+    CONFIG = loadfn(f"{MODULE_DIR}/MPEXAFSSet.yaml")
 
     def __init__(
         self,
@@ -430,7 +412,7 @@ class MPEXAFSSet(FEFFDictSet):
             nkpts (int): Total number of kpoints in the brillouin zone. Used
                 only when feff is run in the reciprocal space mode.
             user_tag_settings (dict): override default tag settings
-            **kwargs: Passthrough to FEFFDictSet
+            **kwargs: Passthrough to FEFFDictSet.
         """
         super().__init__(
             absorbing_atom,
@@ -446,9 +428,7 @@ class MPEXAFSSet(FEFFDictSet):
 
 
 class MPEELSDictSet(FEFFDictSet):
-    """
-    FeffDictSet for ELNES spectroscopy.
-    """
+    """FeffDictSet for ELNES spectroscopy."""
 
     def __init__(
         self,
@@ -484,7 +464,7 @@ class MPEELSDictSet(FEFFDictSet):
             nkpts (int): Total number of kpoints in the brillouin zone. Used
                 only when feff is run in the reciprocal space mode.
             user_tag_settings (dict): override default tag settings
-            **kwargs: Passthrough to FEFFDictSet
+            **kwargs: Passthrough to FEFFDictSet.
         """
         self.beam_energy = beam_energy
         self.beam_direction = beam_direction
@@ -519,11 +499,9 @@ class MPEELSDictSet(FEFFDictSet):
 
 
 class MPELNESSet(MPEELSDictSet):
-    """
-    FeffDictSet for ELNES spectroscopy.
-    """
+    """FeffDictSet for ELNES spectroscopy."""
 
-    CONFIG = loadfn(os.path.join(MODULE_DIR, "MPELNESSet.yaml"))
+    CONFIG = loadfn(f"{MODULE_DIR}/MPELNESSet.yaml")
 
     def __init__(
         self,
@@ -556,7 +534,7 @@ class MPELNESSet(MPEELSDictSet):
             nkpts (int): Total number of kpoints in the brillouin zone. Used
                 only when feff is run in the reciprocal space mode.
             user_tag_settings (dict): override default tag settings
-            **kwargs: Passthrough to FEFFDictSet
+            **kwargs: Passthrough to FEFFDictSet.
         """
         super().__init__(
             absorbing_atom,
@@ -577,11 +555,9 @@ class MPELNESSet(MPEELSDictSet):
 
 
 class MPEXELFSSet(MPEELSDictSet):
-    """
-    FeffDictSet for EXELFS spectroscopy.
-    """
+    """FeffDictSet for EXELFS spectroscopy."""
 
-    CONFIG = loadfn(os.path.join(MODULE_DIR, "MPEXELFSSet.yaml"))
+    CONFIG = loadfn(f"{MODULE_DIR}/MPEXELFSSet.yaml")
 
     def __init__(
         self,
@@ -614,7 +590,7 @@ class MPEXELFSSet(MPEELSDictSet):
             nkpts (int): Total number of kpoints in the brillouin zone. Used
                 only when feff is run in the reciprocal space mode.
             user_tag_settings (dict): override default tag settings
-            **kwargs: Passthrough to FEFFDictSet
+            **kwargs: Passthrough to FEFFDictSet.
         """
         super().__init__(
             absorbing_atom,
