@@ -3,13 +3,19 @@ This module provides classes to perform analyses of
 the local environments (e.g., finding near neighbors)
 of single sites in molecules and structures based on
 bonding analysis with Lobster.
+If you use this module, please cite:
+J. George, G. Petretto, A. Naik, M. Esters, A. J. Jackson, R. Nelson, R. Dronskowski, G.-M. Rignanese, G. Hautier,
+"Automated Bonding Analysis with Crystal Orbital Hamilton Populations",
+ChemPlusChem 2022, e202200123,
+DOI: 10.1002/cplu.202200123.
 """
+
 from __future__ import annotations
 
 import collections
 import copy
 import math
-import os
+import tempfile
 from typing import TYPE_CHECKING, NamedTuple
 
 import numpy as np
@@ -23,6 +29,7 @@ from pymatgen.electronic_structure.cohp import CompleteCohp
 from pymatgen.electronic_structure.core import Spin
 from pymatgen.electronic_structure.plotter import CohpPlotter
 from pymatgen.io.lobster import Charge, Icohplist
+from pymatgen.util.due import Doi, due
 
 if TYPE_CHECKING:
     from pymatgen.core import Structure
@@ -35,11 +42,16 @@ __email__ = "janinegeorge.ulfen@gmail.com"
 __status__ = "Production"
 __date__ = "February 2, 2021"
 
+due.cite(
+    Doi("10.1002/cplu.202200123"),
+    description="Automated Bonding Analysis with Crystal Orbital Hamilton Populations",
+)
+
 
 class LobsterNeighbors(NearNeighbors):
     """
     This class combines capabilities from LocalEnv and ChemEnv to determine coordination environments based on
-    bonding analysis
+    bonding analysis.
     """
 
     def __init__(
@@ -47,11 +59,13 @@ class LobsterNeighbors(NearNeighbors):
         structure: Structure,
         filename_ICOHP: str = "ICOHPLIST.lobster",
         are_coops: bool = False,
-        valences: list[int | float] | None = None,
+        are_cobis: bool = False,
+        valences: list[float] | None = None,
         limits: tuple[float, float] | None = None,
         additional_condition: int = 0,
         only_bonds_to: list[str] | None = None,
         perc_strength_ICOHP: float = 0.15,
+        noise_cutoff: float = 0.1,
         valences_from_charges: bool = False,
         filename_CHARGE: str | None = None,
         which_charge: str = "Mulliken",
@@ -65,12 +79,13 @@ class LobsterNeighbors(NearNeighbors):
         """
 
         Args:
-            filename_ICOHP: (str) Path to ICOHPLIST.lobster
-            structure: (Structure): typically constructed by Structure.from_file("POSCAR")
+            filename_ICOHP: (str) Path to ICOHPLIST.lobster or ICOOPLIST.lobster or ICOBILIST.lobster
+            structure: (Structure) typically constructed by Structure.from_file("POSCAR")
             are_coops: (bool) if True, the file is a ICOOPLIST.lobster and not a ICOHPLIST.lobster; only tested for
                 ICOHPLIST.lobster so far
-            valences: (list[int | float]): gives valence/charge for each element
-            limits (tuple[float, float] | None): limit to decide which ICOHPs should be considered
+            are_cobis: (bool) if True, the file is a ICOBILIST.lobster and not a ICOHPLIST.lobster
+            valences: (list[float]): gives valence/charge for each element
+            limits (tuple[float, float] | None): limit to decide which ICOHPs (ICOOP or ICOBI) should be considered
             additional_condition (int): Additional condition that decides which kind of bonds will be considered
                 NO_ADDITIONAL_CONDITION = 0
                 ONLY_ANION_CATION_BONDS = 1
@@ -82,7 +97,8 @@ class LobsterNeighbors(NearNeighbors):
             only_bonds_to: (list[str]) will only consider bonds to certain elements (e.g. ["O"] for oxygen)
             perc_strength_ICOHP: if no limits are given, this will decide which icohps will still be considered (
             relative to
-            the strongest ICOHP)
+            the strongest ICOHP (ICOOP or ICOBI)
+            noise_cutoff: if provided hardcodes the lower limit of icohps considered
             valences_from_charges: if True and path to CHARGE.lobster is provided, will use Lobster charges (
             Mulliken) instead of valences
             filename_CHARGE: (str) Path to Charge.lobster
@@ -91,22 +107,24 @@ class LobsterNeighbors(NearNeighbors):
             additional condition
             add_additional_data_sg: (bool) will add the information from filename_add_bondinglist_sg1,
             filename_blist_sg1: (str) Path to additional ICOOP, ICOBI data for structure graphs
-            filename_blist_sg2: (str) Path to dditional ICOOP, ICOBI data for structure graphs
+            filename_blist_sg2: (str) Path to additional ICOOP, ICOBI data for structure graphs
             id_blist_sg1: (str) Identity of data in filename_blist_sg1,
                 e.g., "icoop" or "icobi"
             id_blist_sg2: (str) Identity of data in filename_blist_sg2,
-                e.g., "icoop" or "icobi"
+                e.g., "icoop" or "icobi".
         """
-        self.ICOHP = Icohplist(are_coops=are_coops, filename=filename_ICOHP)
+        self.ICOHP = Icohplist(are_coops=are_coops, are_cobis=are_cobis, filename=filename_ICOHP)
         self.Icohpcollection = self.ICOHP.icohpcollection
         self.structure = structure
         self.limits = limits
         self.only_bonds_to = only_bonds_to
         self.adapt_extremum_to_add_cond = adapt_extremum_to_add_cond
         self.are_coops = are_coops
+        self.are_cobis = are_cobis
         self.add_additional_data_sg = add_additional_data_sg
         self.filename_blist_sg1 = filename_blist_sg1
         self.filename_blist_sg2 = filename_blist_sg2
+        self.noise_cutoff = noise_cutoff
 
         allowed_arguments = ["icoop", "icobi"]
         if id_blist_sg1.lower() not in allowed_arguments or id_blist_sg2.lower() not in allowed_arguments:
@@ -141,9 +159,6 @@ class LobsterNeighbors(NearNeighbors):
                 are_cobis=are_cobis_id2,
             )
 
-        if are_coops:
-            raise ValueError("Algorithm only works correctly for ICOHPLIST.lobster")
-
         # will check if the additional condition is correctly delivered
         if additional_condition not in range(7):
             raise ValueError(f"Unexpected {additional_condition=}, must be one of {list(range(7))}")
@@ -170,7 +185,7 @@ class LobsterNeighbors(NearNeighbors):
                         )
         else:
             self.valences = valences
-        if np.allclose(np.array(self.valences), np.zeros_like(self.valences)) and additional_condition in [1, 3, 5, 6]:
+        if np.allclose(self.valences or [], np.zeros_like(self.valences)) and additional_condition in [1, 3, 5, 6]:
             raise ValueError("All valences are equal to 0, additional_conditions 1, 3, 5 and 6 will not work")
 
         if limits is None:
@@ -190,25 +205,21 @@ class LobsterNeighbors(NearNeighbors):
 
     @property
     def structures_allowed(self):
-        """
-        Boolean property: can this NearNeighbors class be used with Structure
-        objects?
-        """
+        """Whether this NearNeighbors class can be used with Structure objects?"""
         return True
 
     @property
     def molecules_allowed(self):
-        """
-        Boolean property: can this NearNeighbors class be used with Molecule
-        objects?
-        """
+        """Whether this NearNeighbors class can be used with Molecule objects?"""
         return False
 
     @property
     def anion_types(self):
         """
         Return the types of anions present in crystal structure as a set
-        Returns: set of Element describing anions in the crystal structure
+
+        Returns:
+            set[Element]: describing anions in the crystal structure.
         """
         if self.valences is None:
             raise ValueError("No cations and anions defined")
@@ -236,6 +247,7 @@ class LobsterNeighbors(NearNeighbors):
                 or not (False, default: each coordinated site has equal
                 weight).
                 True is not implemented for LobsterNeighbors
+
         Returns:
             cn (integer or float): coordination number.
         """
@@ -248,12 +260,14 @@ class LobsterNeighbors(NearNeighbors):
     def get_light_structure_environment(self, only_cation_environments=False, only_indices=None):
         """
         Return a LobsterLightStructureEnvironments object
-        if the structure only contains coordination environments smaller 13
+        if the structure only contains coordination environments smaller 13.
 
         Args:
             only_cation_environments: only data for cations will be returned
             only_indices: will only evaluate the list of isites in this list
-        Returns: LobsterLightStructureEnvironments Object
+
+        Returns:
+            LobsterLightStructureEnvironments
         """
         lgf = LocalGeometryFinder()
         lgf.setup_structure(structure=self.structure)
@@ -353,13 +367,14 @@ class LobsterNeighbors(NearNeighbors):
         """
         This method returns information on the icohps of neighbors for certain sites as identified by their site id.
         This is useful for plotting the relevant cohps of a site in the structure.
+        (could be ICOOPLIST.lobster or ICOHPLIST.lobster or ICOBILIST.lobster)
 
         Args:
             isites: list of site ids. If isite==None, all isites will be used to add the icohps of the neighbors
             onlycation_isites: if True and if isite==None, it will only analyse the sites of the cations
 
-
-        Returns: ICOHPNeighborsInfo
+        Returns:
+            ICOHPNeighborsInfo
         """
         if self.valences is None and onlycation_isites:
             raise ValueError("No valences are provided")
@@ -404,7 +419,8 @@ class LobsterNeighbors(NearNeighbors):
         integrated=False,
     ):
         """
-        Will plot summed cohps (please be careful in the spin polarized case (plots might overlap (exactly!))
+        Will plot summed cohps or cobis or coops
+        (please be careful in the spin polarized case (plots might overlap (exactly!)).
 
         Args:
             isites: list of site ids, if isite==[], all isites will be used to add the icohps of the neighbors
@@ -418,12 +434,12 @@ class LobsterNeighbors(NearNeighbors):
             integrated: bool, if true will show integrated cohp instead of cohp
 
         Returns:
-            plt of the cohps
+            plt of the cohps or coops or cobis
         """
         # include COHPPlotter and plot a sum of these COHPs
         # might include option to add Spin channels
         # implement only_bonds_to
-        cp = CohpPlotter()
+        cp = CohpPlotter(are_cobis=self.are_cobis, are_coops=self.are_coops)
 
         plotlabel, summed_cohp = self.get_info_cohps_to_neighbors(
             path_to_COHPCAR,
@@ -435,14 +451,14 @@ class LobsterNeighbors(NearNeighbors):
         )
 
         cp.add_cohp(plotlabel, summed_cohp)
-        plot = cp.get_plot(integrated=integrated)
+        ax = cp.get_plot(integrated=integrated)
         if xlim is not None:
-            plot.xlim(xlim)
+            ax.set_xlim(xlim)
 
         if ylim is not None:
-            plot.ylim(ylim)
+            ax.set_ylim(ylim)
 
-        return plot
+        return ax
 
     def get_info_cohps_to_neighbors(
         self,
@@ -454,39 +470,39 @@ class LobsterNeighbors(NearNeighbors):
         summed_spin_channels=False,
     ):
         """
-        Return info about the cohps as a summed cohp object and a label
-         from all sites mentioned in isites with neighbors
+        Return info about the cohps (coops or cobis) as a summed cohp object and a label
+        from all sites mentioned in isites with neighbors.
 
         Args:
-            path_to_COHPCAR: str, path to COHPCAR
+            path_to_COHPCAR: str, path to COHPCAR or COOPCAR or COBICAR
             isites: list of int that indicate the number of the site
             only_bonds_to: list of str, e.g. ["O"] to only show cohps of anything to oxygen
             onlycation_isites: if isites=None, only cation sites will be returned
             per_bond: will normalize per bond
             summed_spin_channels: will sum all spin channels
 
-        Returns: label for cohp (str), CompleteCohp object which describes all cohps of the sites as given by isites
-        and the other parameters
+        Returns:
+            str: label for cohp (str), CompleteCohp object which describes all cohps (coops or cobis)
+                of the sites as given by isites and the other parameters
         """
         # TODO: add options for orbital-resolved cohps
-        (
-            summed_icohps,
-            list_icohps,
-            number_bonds,
-            labels,
-            atoms,
-            final_isites,
-        ) = self.get_info_icohps_to_neighbors(isites=isites, onlycation_isites=onlycation_isites)
-
-        import tempfile
+        _summed_icohps, _list_icohps, _number_bonds, labels, atoms, final_isites = self.get_info_icohps_to_neighbors(
+            isites=isites, onlycation_isites=onlycation_isites
+        )
 
         with tempfile.TemporaryDirectory() as t:
-            path = os.path.join(t, "POSCAR.vasp")
+            path = f"{t}/POSCAR.vasp"
 
             self.structure.to(filename=path, fmt="POSCAR")
 
             if not hasattr(self, "completecohp"):
-                self.completecohp = CompleteCohp.from_file(fmt="LOBSTER", filename=path_to_COHPCAR, structure_file=path)
+                self.completecohp = CompleteCohp.from_file(
+                    fmt="LOBSTER",
+                    filename=path_to_COHPCAR,
+                    structure_file=path,
+                    are_coops=self.are_coops,
+                    are_cobis=self.are_cobis,
+                )
 
         # will check that the number of bonds in ICOHPLIST and COHPCAR are identical
         # further checks could be implemented
@@ -512,8 +528,6 @@ class LobsterNeighbors(NearNeighbors):
             # iterate through labels and atoms and check which bonds can be included
             new_labels = []
             new_atoms = []
-            # print(labels)
-            # print(atoms)
             for label, atompair, isite in zip(labels, atoms, final_isites):
                 present = False
                 for atomtype in only_bonds_to:
@@ -533,7 +547,6 @@ class LobsterNeighbors(NearNeighbors):
                 if present:
                     new_labels.append(label)
                     new_atoms.append(atompair)
-            # print(new_labels)
             if len(new_labels) > 0:
                 divisor = len(new_labels) if per_bond else 1
 
@@ -553,19 +566,15 @@ class LobsterNeighbors(NearNeighbors):
     def _get_plot_label(self, atoms, per_bond):
         # count the types of bonds and append a label:
         all_labels = []
-        for atomsnames in atoms:
-            new = [
-                self._split_string(atomsnames[0])[0],
-                self._split_string(atomsnames[1])[0],
-            ]
+        for atoms_names in atoms:
+            new = [self._split_string(atoms_names[0])[0], self._split_string(atoms_names[1])[0]]
             new.sort()
-            # print(new2)
             string_here = new[0] + "-" + new[1]
             all_labels.append(string_here)
         count = collections.Counter(all_labels)
         plotlabels = []
         for key, item in count.items():
-            plotlabels.append(str(item) + " x " + str(key))
+            plotlabels.append(f"{item} x {key}")
         plotlabel = ", ".join(plotlabels)
         if per_bond:
             plotlabel = plotlabel + " (per bond)"
@@ -573,13 +582,14 @@ class LobsterNeighbors(NearNeighbors):
 
     def get_info_icohps_between_neighbors(self, isites=None, onlycation_isites=True):
         """
-        Return infos about interactions between neighbors of a certain atom
+        Return infos about interactions between neighbors of a certain atom.
 
         Args:
             isites: list of site ids, if isite==None, all isites will be used
             onlycation_isites: will only use cations, if isite==None
 
-        Returns: ICOHPNeighborsInfo
+        Returns
+            ICOHPNeighborsInfo
         """
         lowerlimit = self.lowerlimit
         upperlimit = self.upperlimit
@@ -674,7 +684,7 @@ class LobsterNeighbors(NearNeighbors):
         additional_condition=0,
         perc_strength_ICOHP=0.15,
         adapt_extremum_to_add_cond=False,
-    ):
+    ) -> None:
         """
         Args:
             lowerlimit: lower limit which determines the ICOHPs that are considered for the determination of the
@@ -684,11 +694,9 @@ class LobsterNeighbors(NearNeighbors):
             only_bonds_to: restricts the types of bonds that will be considered
             additional_condition: Additional condition for the evaluation
             perc_strength_ICOHP: will be used to determine how strong the ICOHPs (percentage*strongest ICOHP) will be
-            that are still considered for the evalulation
+            that are still considered for the evaluation
             adapt_extremum_to_add_cond: will recalculate the limit based on the bonding type and not on the overall
-            extremum
-
-        Returns:
+            extremum.
         """
         # get extremum
         if lowerlimit is None and upperlimit is None:
@@ -703,14 +711,9 @@ class LobsterNeighbors(NearNeighbors):
             raise ValueError("Please give two limits or leave them both at None")
 
         # find environments based on ICOHP values
-        (
-            list_icohps,
-            list_keys,
-            list_lengths,
-            list_neighisite,
-            list_neighsite,
-            list_coords,
-        ) = self._find_environments(additional_condition, lowerlimit, upperlimit, only_bonds_to)
+        list_icohps, list_keys, list_lengths, list_neighisite, list_neighsite, list_coords = self._find_environments(
+            additional_condition, lowerlimit, upperlimit, only_bonds_to
+        )
 
         self.list_icohps = list_icohps
         self.list_lengths = list_lengths
@@ -731,11 +734,11 @@ class LobsterNeighbors(NearNeighbors):
                             for i in (
                                 neighbor.frac_coords
                                 - self.structure[
-                                    [
+                                    next(
                                         isite
                                         for isite, site in enumerate(self.structure)
                                         if neighbor.is_periodic_image(site)
-                                    ][0]
+                                    )
                                 ].frac_coords
                             )
                         ),
@@ -754,9 +757,9 @@ class LobsterNeighbors(NearNeighbors):
                                 self.list_keys[ineighbors][ineighbor]
                             ),
                         },
-                        "site_index": [
+                        "site_index": next(
                             isite for isite, site in enumerate(self.structure) if neighbor.is_periodic_image(site)
-                        ][0],
+                        ),
                     }
                     for ineighbor, neighbor in enumerate(neighbors)
                 ]
@@ -772,11 +775,11 @@ class LobsterNeighbors(NearNeighbors):
                             for i in (
                                 neighbor.frac_coords
                                 - self.structure[
-                                    [
+                                    next(
                                         isite
                                         for isite, site in enumerate(self.structure)
                                         if neighbor.is_periodic_image(site)
-                                    ][0]
+                                    )
                                 ].frac_coords
                             )
                         ),
@@ -786,9 +789,9 @@ class LobsterNeighbors(NearNeighbors):
                             "bond_length": self.list_lengths[ineighbors][ineighbor],
                             "bond_label": self.list_keys[ineighbors][ineighbor],
                         },
-                        "site_index": [
+                        "site_index": next(
                             isite for isite, site in enumerate(self.structure) if neighbor.is_periodic_image(site)
-                        ][0],
+                        ),
                     }
                     for ineighbor, neighbor in enumerate(neighbors)
                 ]
@@ -797,7 +800,7 @@ class LobsterNeighbors(NearNeighbors):
 
     def _find_environments(self, additional_condition, lowerlimit, upperlimit, only_bonds_to):
         """
-        Will find all relevant neighbors based on certain restrictions
+        Will find all relevant neighbors based on certain restrictions.
 
         Args:
             additional_condition (int): additional condition (see above)
@@ -806,6 +809,7 @@ class LobsterNeighbors(NearNeighbors):
             only_bonds_to (list): list of str, e.g. ["O"] that will ensure that only bonds to "O" will be considered
 
         Returns:
+            tuple: list of icohps, list of keys, list of lengths, list of neighisite, list of neighsite, list of coords
         """
         # run over structure
         list_neighsite = []
@@ -823,12 +827,8 @@ class LobsterNeighbors(NearNeighbors):
                 only_bonds_to=only_bonds_to,
             )
 
-            (
-                keys_from_ICOHPs,
-                lengths_from_ICOHPs,
-                neighbors_from_ICOHPs,
-                selected_ICOHPs,
-            ) = self._find_relevant_atoms_additional_condition(idx, icohps, additional_condition)
+            additional_conds = self._find_relevant_atoms_additional_condition(idx, icohps, additional_condition)
+            keys_from_ICOHPs, lengths_from_ICOHPs, neighbors_from_ICOHPs, selected_ICOHPs = additional_conds
 
             if len(neighbors_from_ICOHPs) > 0:
                 centralsite = self.structure[idx]
@@ -913,7 +913,7 @@ class LobsterNeighbors(NearNeighbors):
 
     def _find_relevant_atoms_additional_condition(self, isite, icohps, additional_condition):
         """
-        Will find all relevant atoms that fulfill the additional_conditions
+        Will find all relevant atoms that fulfill the additional_conditions.
 
         Args:
             isite: number of site in structure (starts with 0)
@@ -921,6 +921,7 @@ class LobsterNeighbors(NearNeighbors):
             additional_condition (int): additional condition
 
         Returns:
+            tuple: keys, lengths and neighbors from selected ICOHPs and selected ICOHPs
         """
         neighbors_from_ICOHPs = []
         lengths_from_ICOHPs = []
@@ -981,11 +982,9 @@ class LobsterNeighbors(NearNeighbors):
 
             elif additional_condition == 3:
                 # ONLY_ANION_CATION_BONDS_AND_NO_ELEMENT_TO_SAME_ELEMENT_BONDS = 3
-                if (
-                    (val1 < 0.0 < val2)
-                    or (val2 < 0.0 < val1)
-                    and icohp._atom1.rstrip("0123456789") != icohp._atom2.rstrip("0123456789")
-                ):
+                if ((val1 < 0.0 < val2) or (val2 < 0.0 < val1)) and icohp._atom1.rstrip(
+                    "0123456789"
+                ) != icohp._atom2.rstrip("0123456789"):
                     if atomnr1 == isite:
                         neighbors_from_ICOHPs.append(atomnr2)
                         lengths_from_ICOHPs.append(icohp._length)
@@ -1042,17 +1041,11 @@ class LobsterNeighbors(NearNeighbors):
                     icohps_from_ICOHPs.append(icohp.summed_icohp)
                     keys_from_ICOHPs.append(key)
 
-        return (
-            keys_from_ICOHPs,
-            lengths_from_ICOHPs,
-            neighbors_from_ICOHPs,
-            icohps_from_ICOHPs,
-        )
+        return keys_from_ICOHPs, lengths_from_ICOHPs, neighbors_from_ICOHPs, icohps_from_ICOHPs
 
     @staticmethod
     def _get_icohps(icohpcollection, isite, lowerlimit, upperlimit, only_bonds_to):
-        """
-        Return icohp dict for certain site
+        """Return icohp dict for certain site.
 
         Args:
             icohpcollection: Icohpcollection object
@@ -1062,32 +1055,33 @@ class LobsterNeighbors(NearNeighbors):
             only_bonds_to (list): list of str, e.g. ["O"] that will ensure that only bonds to "O" will be considered
 
         Returns:
+            dict: of IcohpValues. The keys correspond to the values from the initial list_labels.
         """
-        icohps = icohpcollection.get_icohp_dict_of_site(
+        return icohpcollection.get_icohp_dict_of_site(
             site=isite,
             maxbondlength=6.0,
             minsummedicohp=lowerlimit,
             maxsummedicohp=upperlimit,
             only_bonds_to=only_bonds_to,
         )
-        return icohps
 
     @staticmethod
-    def _get_atomnumber(atomstring):
+    def _get_atomnumber(atomstring) -> int:
         """
-        Return the number of the atom within the initial POSCAR (e.g., Return 0 for "Na1")
+        Return the number of the atom within the initial POSCAR (e.g., Return 0 for "Na1").
 
         Args:
             atomstring: string such as "Na1"
 
-        Returns: integer indicating the position in the POSCAR
+        Returns:
+            int: indicating the position in the POSCAR
         """
         return int(LobsterNeighbors._split_string(atomstring)[1]) - 1
 
     @staticmethod
-    def _split_string(s):
+    def _split_string(s) -> tuple[str, str]:
         """
-        Will split strings such as "Na1" in "Na" and "1" and return "1"
+        Will split strings such as "Na1" in "Na" and "1" and return "1".
 
         Args:
             s (str): string
@@ -1099,7 +1093,7 @@ class LobsterNeighbors(NearNeighbors):
     @staticmethod
     def _determine_unit_cell(site):
         """
-        Based on the site it will determine the unit cell, in which this site is based
+        Based on the site it will determine the unit cell, in which this site is based.
 
         Args:
             site: site object
@@ -1111,6 +1105,20 @@ class LobsterNeighbors(NearNeighbors):
 
         return unitcell
 
+    def _adapt_extremum_to_add_cond(self, list_icohps, percentage):
+        """
+        Convinicence method for returning the extremum of the given icohps or icoops or icobis list
+
+        Args:
+            list_icohps: can be a list of icohps or icobis or icobis
+
+        Returns:
+            float: min value of input list of icohps / max value of input list of icobis or icobis
+        """
+
+        which_extr = min if not self.are_coops and not self.are_cobis else max
+        return which_extr(list_icohps) * percentage
+
     def _get_limit_from_extremum(
         self,
         icohpcollection,
@@ -1120,16 +1128,20 @@ class LobsterNeighbors(NearNeighbors):
     ):
         """
         Return limits for the evaluation of the icohp values from an icohpcollection
-        Return -float('inf'), min(max_icohp*0.15,-0.1). Currently only works for ICOHPs.
+        Return -float("inf"), min(max_icohp*0.15,-0.1). Currently only works for ICOHPs.
 
         Args:
             icohpcollection: icohpcollection object
-            percentage: will determine which ICOHPs will be considered (only 0.15 from the maximum value)
+            percentage: will determine which ICOHPs or ICOOP or ICOBI will be considered
+            (only 0.15 from the maximum value)
             adapt_extremum_to_add_cond: should the extrumum be adapted to the additional condition
             additional_condition: additional condition to determine which bonds are relevant
-        Returns: [-float('inf'), min(max_icohp*0.15,-0.1)]
+
+        Returns:
+            tuple[float, float]: [-inf, min(strongest_icohp*0.15,-noise_cutoff)] / [max(strongest_icohp*0.15,
+                noise_cutoff), inf]
         """
-        # TODO: make it work for COOPs/COBIs
+
         if not adapt_extremum_to_add_cond or additional_condition == 0:
             extremum_based = icohpcollection.extremum_icohpvalue(summed_spin_channels=True) * percentage
         elif additional_condition == 1:
@@ -1144,7 +1156,7 @@ class LobsterNeighbors(NearNeighbors):
                 if (val1 < 0.0 < val2) or (val2 < 0.0 < val1):
                     list_icohps.append(value.summed_icohp)
 
-            extremum_based = min(list_icohps) * percentage
+            extremum_based = self._adapt_extremum_to_add_cond(list_icohps, percentage)
 
         elif additional_condition == 2:
             # NO_ELEMENT_TO_SAME_ELEMENT_BONDS
@@ -1152,7 +1164,8 @@ class LobsterNeighbors(NearNeighbors):
             for value in icohpcollection._icohplist.values():
                 if value._atom1.rstrip("0123456789") != value._atom2.rstrip("0123456789"):
                     list_icohps.append(value.summed_icohp)
-            extremum_based = min(list_icohps) * percentage
+
+            extremum_based = self._adapt_extremum_to_add_cond(list_icohps, percentage)
 
         elif additional_condition == 3:
             # ONLY_ANION_CATION_BONDS_AND_NO_ELEMENT_TO_SAME_ELEMENT_BONDS = 3
@@ -1163,19 +1176,21 @@ class LobsterNeighbors(NearNeighbors):
                 val1 = self.valences[atomnr1]
                 val2 = self.valences[atomnr2]
 
-                if (
-                    (val1 < 0.0 < val2)
-                    or (val2 < 0.0 < val1)
-                    and value._atom1.rstrip("0123456789") != value._atom2.rstrip("0123456789")
-                ):
+                if ((val1 < 0.0 < val2) or (val2 < 0.0 < val1)) and value._atom1.rstrip(
+                    "0123456789"
+                ) != value._atom2.rstrip("0123456789"):
                     list_icohps.append(value.summed_icohp)
-            extremum_based = min(list_icohps) * percentage
+
+            extremum_based = self._adapt_extremum_to_add_cond(list_icohps, percentage)
+
         elif additional_condition == 4:
             list_icohps = []
             for value in icohpcollection._icohplist.values():
                 if value._atom1.rstrip("0123456789") == "O" or value._atom2.rstrip("0123456789") == "O":
                     list_icohps.append(value.summed_icohp)
-            extremum_based = min(list_icohps) * percentage
+
+            extremum_based = self._adapt_extremum_to_add_cond(list_icohps, percentage)
+
         elif additional_condition == 5:
             # DO_NOT_CONSIDER_ANION_CATION_BONDS=5
             list_icohps = []
@@ -1187,7 +1202,8 @@ class LobsterNeighbors(NearNeighbors):
 
                 if (val1 > 0.0 and val2 > 0.0) or (val1 < 0.0 and val2 < 0.0):
                     list_icohps.append(value.summed_icohp)
-            extremum_based = min(list_icohps) * percentage
+
+            extremum_based = self._adapt_extremum_to_add_cond(list_icohps, percentage)
 
         elif additional_condition == 6:
             # ONLY_CATION_CATION_BONDS=6
@@ -1200,19 +1216,21 @@ class LobsterNeighbors(NearNeighbors):
 
                 if val1 > 0.0 and val2 > 0.0:
                     list_icohps.append(value.summed_icohp)
-            extremum_based = min(list_icohps) * percentage
 
-        # if not self.are_coops:
-        max_here = min(extremum_based, -0.1)
-        return -float("inf"), max_here
-        # else:
-        #    return extremum_based, 100000
+            extremum_based = self._adapt_extremum_to_add_cond(list_icohps, percentage)
+
+        if not self.are_coops and not self.are_cobis:
+            max_here = min(extremum_based, -self.noise_cutoff) if self.noise_cutoff is not None else extremum_based
+            return -float("inf"), max_here
+        if self.are_coops or self.are_cobis:
+            min_here = max(extremum_based, self.noise_cutoff) if self.noise_cutoff is not None else extremum_based
+            return min_here, float("inf")
+
+        return None
 
 
 class LobsterLightStructureEnvironments(LightStructureEnvironments):
-    """
-    Class to store LightStructureEnvironments based on Lobster outputs
-    """
+    """Class to store LightStructureEnvironments based on Lobster outputs."""
 
     @classmethod
     def from_Lobster(
@@ -1226,7 +1244,7 @@ class LobsterLightStructureEnvironments(LightStructureEnvironments):
         valences=None,
     ):
         """
-        Will set up a LightStructureEnvironments from Lobster
+        Will set up a LightStructureEnvironments from Lobster.
 
         Args:
             structure: Structure object
@@ -1237,12 +1255,11 @@ class LobsterLightStructureEnvironments(LightStructureEnvironments):
             list_neighisite: list of neighboring isites (number of a site)
             valences: list of valences
 
-        Returns: LobsterLightStructureEnvironments
+        Returns:
+            LobsterLightStructureEnvironments
         """
         strategy = None
-        valences = valences
         valences_origin = "user-defined"
-        structure = structure
 
         coordination_environments = []
 
@@ -1250,7 +1267,7 @@ class LobsterLightStructureEnvironments(LightStructureEnvironments):
         all_nbs_sites_indices = []
         neighbors_sets = []
         counter = 0
-        for isite, _site in enumerate(structure):
+        for isite in range(len(structure)):
             # all_nbs_sites_here=[]
             all_nbs_sites_indices_here = []
             # Coordination environment
@@ -1321,15 +1338,15 @@ class LobsterLightStructureEnvironments(LightStructureEnvironments):
 
     @property
     def uniquely_determines_coordination_environments(self):
-        """
-        True if the coordination environments are uniquely determined.
-        """
+        """True if the coordination environments are uniquely determined."""
         return True
 
     def as_dict(self):
         """
         Bson-serializable dict representation of the LightStructureEnvironments object.
-        :return: Bson-serializable dict representation of the LightStructureEnvironments object.
+
+        Returns:
+            Bson-serializable dict representation of the LightStructureEnvironments object.
         """
         return {
             "@module": type(self).__module__,
@@ -1359,12 +1376,10 @@ class ICOHPNeighborsInfo(NamedTuple):
         total_icohp (float): sum of icohp values of neighbors to the selected sites [given by the id in structure]
         list_icohps (list): list of summed icohp values for all identified interactions with neighbors
         n_bonds (int): number of identified bonds to the selected sites
-        labels (list(str)): labels (from ICOHPLIST) for all identified bonds
-        atoms (list(list(str)): list of list describing the species present in the identified interactions
-            (names from ICOHPLIST), e.g., ['Ag3', 'O5']
-        central_isites (list(int)): list of the central isite for each identified interaction.
-
-
+        labels (list[str]): labels (from ICOHPLIST) for all identified bonds
+        atoms (list[list[str]]): list of list describing the species present in the identified interactions
+            (names from ICOHPLIST), e.g., ["Ag3", "O5"]
+        central_isites (list[int]): list of the central isite for each identified interaction.
     """
 
     total_icohp: float
