@@ -38,8 +38,7 @@ __date__ = "Nov 2021"
 
 class PackmolSet(InputSet):
     """
-    InputSet for the Packmol software. This class defines several attributes related
-    to
+    InputSet for the Packmol software. This class defines several attributes related to.
     """
 
     def run(self, path: str | Path, timeout=30):
@@ -56,11 +55,9 @@ class PackmolSet(InputSet):
         wd = os.getcwd()
         if not which("packmol"):
             raise RuntimeError(
-                "Running a PackmolSet requires the executable 'packmol' to be in "
-                "the path. Please download packmol from "
-                "https://github.com/leandromartinez98/packmol "
-                "and follow the instructions in the README to compile. "
-                "Don't forget to add the packmol binary to your path"
+                "Running a PackmolSet requires the executable 'packmol' to be in the path. Please "
+                "download packmol from https://github.com/leandromartinez98/packmol and follow the "
+                "instructions in the README to compile. Don't forget to add the packmol binary to your path"
             )
         try:
             os.chdir(path)
@@ -85,7 +82,7 @@ class PackmolSet(InputSet):
         except subprocess.CalledProcessError as exc:
             raise ValueError(f"Packmol failed with error code {exc.returncode} and stderr: {exc.stderr}") from exc
         else:
-            with open(Path(path, self.stdoutfile), "w") as out:
+            with open(Path(path, self.stdoutfile), mode="w") as out:
                 out.write(p.stdout.decode())
         finally:
             os.chdir(wd)
@@ -161,7 +158,7 @@ class PackmolBoxGen(InputGenerator):
         """
         mapping = {}
         file_contents = "# Packmol input generated by pymatgen.\n"
-        file_contents += "# " + " + ".join(str(d["number"]) + " " + d["name"] for d in molecules) + "\n"
+        file_contents += f"# {' + '.join(str(d['number']) + ' ' + d['name'] for d in molecules)}\n"
 
         for k, v in self.control_params.items():
             if isinstance(v, list):
