@@ -1,6 +1,4 @@
-"""
-Module for interfacing with phonopy, see https://atztogo.github.io/phonopy/
-"""
+"""Module for interfacing with phonopy, see https://atztogo.github.io/phonopy/."""
 
 from __future__ import annotations
 
@@ -36,13 +34,13 @@ def get_pmg_structure(phonopy_structure: PhonopyAtoms) -> Structure:
     frac_coords = phonopy_structure.scaled_positions
     symbols = phonopy_structure.symbols
     masses = phonopy_structure.masses
-    mms = getattr(phonopy_structure, "magnetic_moments", None) or [0] * len(symbols)
+    magmoms = getattr(phonopy_structure, "magnetic_moments", [0] * len(symbols))
 
     return Structure(
         lattice,
         symbols,
         frac_coords,
-        site_properties={"phonopy_masses": masses, "magnetic_moments": mms},
+        site_properties={"phonopy_masses": masses, "magnetic_moments": magmoms},
     )
 
 
@@ -60,10 +58,11 @@ def get_phonopy_structure(pmg_structure: Structure) -> PhonopyAtoms:
         symbols=symbols,
         cell=pmg_structure.lattice.matrix,
         scaled_positions=pmg_structure.frac_coords,
+        magnetic_moments=pmg_structure.site_properties.get("magmom"),
     )
 
 
-def get_structure_from_dict(d):
+def get_structure_from_dict(dct):
     """
     Extracts a structure from the dictionary extracted from the output
     files of phonopy like phonopy.yaml or band.yaml.
@@ -73,20 +72,20 @@ def get_structure_from_dict(d):
     species = []
     frac_coords = []
     masses = []
-    if "points" in d:
-        for p in d["points"]:
+    if "points" in dct:
+        for p in dct["points"]:
             species.append(p["symbol"])
             frac_coords.append(p["coordinates"])
             masses.append(p["mass"])
-    elif "atoms" in d:
-        for p in d["atoms"]:
+    elif "atoms" in dct:
+        for p in dct["atoms"]:
             species.append(p["symbol"])
             frac_coords.append(p["position"])
             masses.append(p["mass"])
     else:
         raise ValueError("The dict does not contain structural information")
 
-    return Structure(d["lattice"], species, frac_coords, site_properties={"phonopy_masses": masses})
+    return Structure(dct["lattice"], species, frac_coords, site_properties={"phonopy_masses": masses})
 
 
 def eigvec_to_eigdispl(v, q, frac_coords, mass):
@@ -131,13 +130,13 @@ def get_ph_bs_symm_line_from_dict(bands_dict, has_nac=False, labels_dict=None):
     """
     structure = get_structure_from_dict(bands_dict)
 
-    qpts = []
+    q_pts = []
     frequencies = []
-    eigendisplacements = []
+    eigen_displacements = []
     phonopy_labels_dict = {}
     for p in bands_dict["phonon"]:
         q = p["q-position"]
-        qpts.append(q)
+        q_pts.append(q)
         bands = []
         eig_q = []
         for b in p["band"]:
@@ -161,30 +160,28 @@ def get_ph_bs_symm_line_from_dict(bands_dict, has_nac=False, labels_dict=None):
         if "label" in p:
             phonopy_labels_dict[p["label"]] = p["q-position"]
         if eig_q:
-            eigendisplacements.append(eig_q)
+            eigen_displacements.append(eig_q)
 
-    qpts = np.array(qpts)
+    q_pts = np.array(q_pts)
     # transpose to match the convention in PhononBandStructure
     frequencies = np.transpose(frequencies)
-    if eigendisplacements:
-        eigendisplacements = np.transpose(eigendisplacements, (1, 0, 2, 3))
+    if eigen_displacements:
+        eigen_displacements = np.transpose(eigen_displacements, (1, 0, 2, 3))
 
-    rec_latt = Lattice(bands_dict["reciprocal_lattice"])
+    rec_lattice = Lattice(bands_dict["reciprocal_lattice"])
 
     labels_dict = labels_dict or phonopy_labels_dict
 
-    ph_bs = PhononBandStructureSymmLine(
-        qpts,
+    return PhononBandStructureSymmLine(
+        q_pts,
         frequencies,
-        rec_latt,
+        rec_lattice,
         has_nac=has_nac,
         labels_dict=labels_dict,
         structure=structure,
-        eigendisplacements=eigendisplacements,
+        eigendisplacements=eigen_displacements,
     )
 
-    return ph_bs
-
 
 def get_ph_bs_symm_line(bands_path, has_nac=False, labels_dict=None):
     r"""
@@ -199,7 +196,7 @@ def get_ph_bs_symm_line(bands_path, has_nac=False, labels_dict=None):
         bands_path: path to the band.yaml file
         has_nac: True if the data have been obtained with the option
             --nac option. Default False.
-        labels_dict: dict that links a qpoint in frac coords to a label.
+        labels_dict: dict that links a q-point in frac coords to a label.
     """
     return get_ph_bs_symm_line_from_dict(loadfn(bands_path), has_nac, labels_dict)
 
@@ -233,11 +230,11 @@ def get_complete_ph_dos(partial_dos_path, phonopy_yaml_path):
 
     total_dos = PhononDos(a[0], a[1:].sum(axis=0))
 
-    pdoss = {}
-    for site, pdos in zip(structure, a[1:]):
-        pdoss[site] = pdos.tolist()
+    partial_doses = {}
+    for site, p_dos in zip(structure, a[1:]):
+        partial_doses[site] = p_dos.tolist()
 
-    return CompletePhononDos(structure, total_dos, pdoss)
+    return CompletePhononDos(structure, total_dos, partial_doses)
 
 
 @requires(Phonopy, "phonopy not installed!")
@@ -258,7 +255,7 @@ def get_displaced_structures(pmg_structure, atom_disp=0.01, supercell_matrix=Non
         A list of symmetrically inequivalent structures with displacements, in
         which the first element is the perfect supercell structure.
     """
-    is_plusminus = kwargs.get("is_plusminus", "auto")
+    is_plus_minus = kwargs.get("is_plusminus", "auto")
     is_diagonal = kwargs.get("is_diagonal", True)
     is_trigonal = kwargs.get("is_trigonal", False)
 
@@ -270,7 +267,7 @@ def get_displaced_structures(pmg_structure, atom_disp=0.01, supercell_matrix=Non
     phonon = Phonopy(unitcell=ph_structure, supercell_matrix=supercell_matrix)
     phonon.generate_displacements(
         distance=atom_disp,
-        is_plusminus=is_plusminus,
+        is_plusminus=is_plus_minus,
         is_diagonal=is_diagonal,
         is_trigonal=is_trigonal,
     )
@@ -290,9 +287,9 @@ def get_displaced_structures(pmg_structure, atom_disp=0.01, supercell_matrix=Non
     # Structure list to be returned
     structure_list = [get_pmg_structure(init_supercell)]
 
-    for c in disp_supercells:
-        if c is not None:
-            structure_list.append(get_pmg_structure(c))
+    for cell in disp_supercells:
+        if cell is not None:
+            structure_list.append(get_pmg_structure(cell))
 
     return structure_list
 
@@ -341,10 +338,10 @@ def get_phonon_dos_from_fc(
     phonon.run_projected_dos(freq_min=freq_min, freq_max=freq_max, freq_pitch=freq_pitch)
 
     dos_raw = phonon.projected_dos.get_partial_dos()
-    pdoss = dict(zip(structure, dos_raw[1]))
+    p_doses = dict(zip(structure, dos_raw[1]))
 
     total_dos = PhononDos(dos_raw[0], dos_raw[1].sum(axis=0))
-    return CompletePhononDos(structure, total_dos, pdoss)
+    return CompletePhononDos(structure, total_dos, p_doses)
 
 
 @requires(Phonopy, "phonopy is required to calculate phonon band structures")
@@ -409,9 +406,9 @@ def get_phonon_band_structure_symm_line_from_fc(
     phonon = Phonopy(structure_phonopy, supercell_matrix=supercell_matrix, symprec=symprec, **kwargs)
     phonon.set_force_constants(force_constants)
 
-    kpath = HighSymmKpath(structure, symprec=symprec)
+    k_path = HighSymmKpath(structure, symprec=symprec)
 
-    kpoints, labels = kpath.get_kpoints(line_density=line_density, coords_are_cartesian=False)
+    kpoints, labels = k_path.get_kpoints(line_density=line_density, coords_are_cartesian=False)
 
     phonon.run_qpoints(kpoints)
     frequencies = phonon.qpoints.get_frequencies().T
@@ -433,8 +430,8 @@ def get_gruneisenparameter(gruneisen_path, structure=None, structure_path=None)
         structure: pymatgen Structure object
         structure_path: path to structure in a file (e.g., POSCAR)
 
-    Returns: GruneisenParameter object
-
+    Returns:
+        GruneisenParameter
     """
     gruneisen_dict = loadfn(gruneisen_path)
 
@@ -443,16 +440,16 @@ def get_gruneisenparameter(gruneisen_path, structure=None, structure_path=None)
     else:
         try:
             structure = get_structure_from_dict(gruneisen_dict)
-        except ValueError:
-            raise ValueError("\nPlease provide a structure.\n")
+        except ValueError as exc:
+            raise ValueError("Please provide a structure or structure path") from exc
 
-    qpts, multiplicities, frequencies, gruneisen = ([] for _ in range(4))
+    q_pts, multiplicities, frequencies, gruneisen = ([] for _ in range(4))
     phonopy_labels_dict = {}
 
     for p in gruneisen_dict["phonon"]:
         q = p["q-position"]
-        qpts.append(q)
-        m = p["multiplicity"] if "multiplicity" in p else 1
+        q_pts.append(q)
+        m = p.get("multiplicity", 1)
         multiplicities.append(m)
         bands, gruneisenband = [], []
         for b in p["band"]:
@@ -464,7 +461,7 @@ def get_gruneisenparameter(gruneisen_path, structure=None, structure_path=None)
         if "label" in p:
             phonopy_labels_dict[p["label"]] = p["q-position"]
 
-    qpts_np = np.array(qpts)
+    q_pts_np = np.array(q_pts)
     multiplicities_np = np.array(multiplicities)
     # transpose to match the convention in PhononBandStructure
     frequencies_np = np.transpose(frequencies)
@@ -472,7 +469,7 @@ def get_gruneisenparameter(gruneisen_path, structure=None, structure_path=None)
 
     return GruneisenParameter(
         gruneisen=gruneisen_np,
-        qpoints=qpts_np,
+        qpoints=q_pts_np,
         multiplicities=multiplicities_np,
         frequencies=frequencies_np,
         structure=structure,
@@ -512,8 +509,8 @@ def get_gs_ph_bs_symm_line_from_dict(
     else:
         try:
             structure = get_structure_from_dict(gruneisen_dict)
-        except ValueError:
-            raise ValueError("\nPlease provide a structure.\n")
+        except ValueError as exc:
+            raise ValueError("Please provide a structure or structure path") from exc
 
     q_points, frequencies, gruneisen_params = [], [], []
     phonopy_labels_dict: dict[str, dict[str, str]] = {}
@@ -525,7 +522,7 @@ def get_gs_ph_bs_symm_line_from_dict(
             end = pa["phonon"][-1]
 
             if start["q-position"] == [0, 0, 0]:  # Gamma at start of band
-                qpts_temp, frequencies_temp = [], []
+                q_pts_temp, frequencies_temp = [], []
                 gruneisen_temp: list[list[float]] = []
                 distance: list[float] = []
                 for i in range(pa["nqpoint"]):
@@ -537,7 +534,7 @@ def get_gs_ph_bs_symm_line_from_dict(
                         gruen = _extrapolate_grun(b, distance, gruneisen_temp, gruneisen_band, i, pa)
                         gruneisen_band.append(gruen)
                     q = phonon[pa["nqpoint"] - i - 1]["q-position"]
-                    qpts_temp.append(q)
+                    q_pts_temp.append(q)
                     d = phonon[pa["nqpoint"] - i - 1]["distance"]
                     distance.append(d)
                     frequencies_temp.append(bands)
@@ -547,7 +544,7 @@ def get_gs_ph_bs_symm_line_from_dict(
                             "q-position"
                         ]
 
-                q_points.extend(list(reversed(qpts_temp)))
+                q_points.extend(list(reversed(q_pts_temp)))
                 frequencies.extend(list(reversed(frequencies_temp)))
                 gruneisen_params.extend(list(reversed(gruneisen_temp)))
 
@@ -598,14 +595,14 @@ def get_gs_ph_bs_symm_line_from_dict(
                 if "label" in p:
                     phonopy_labels_dict[p["label"]] = p["q-position"]
 
-    rec_latt = structure.lattice.reciprocal_lattice
+    rec_lattice = structure.lattice.reciprocal_lattice
     labels_dict = labels_dict or phonopy_labels_dict
     return GruneisenPhononBandStructureSymmLine(
         qpoints=np.array(q_points),
         # transpose to match the convention in PhononBandStructure
         frequencies=np.transpose(frequencies),
         gruneisenparameters=np.transpose(gruneisen_params),
-        lattice=rec_latt,
+        lattice=rec_lattice,
         labels_dict=labels_dict,
         structure=structure,
         eigendisplacements=None,
@@ -664,16 +661,13 @@ def get_thermal_displacement_matrices(
     ThermalDisplacementMatrices objects
     Args:
         thermal_displacements_yaml: path to thermal_displacement_matrices.yaml
-        structure_path: path to POSCAR
+        structure_path: path to POSCAR.
 
     Returns:
     """
     thermal_displacements_dict = loadfn(thermal_displacements_yaml)
 
-    if structure_path:
-        structure = Structure.from_file(structure_path)
-    else:
-        raise ValueError("\nPlease provide a structure.\n")
+    structure = Structure.from_file(structure_path)
 
     thermal_displacement_objects_list = []
     for matrix in thermal_displacements_dict["thermal_displacement_matrices"]:
