@@ -1,19 +1,14 @@
-"""
-This module implements input and output processing from PWSCF.
-"""
+"""This module implements input and output processing from PWSCF."""
 
 from __future__ import annotations
 
 import re
 from collections import defaultdict
 
-from frozendict import frozendict
 from monty.io import zopen
 from monty.re import regrep
 
-from pymatgen.core.lattice import Lattice
-from pymatgen.core.periodic_table import Element
-from pymatgen.core.structure import Structure
+from pymatgen.core import Element, Lattice, Structure
 from pymatgen.util.io_utils import clean_lines
 
 
@@ -99,7 +94,7 @@ class PWInput:
                         name = k
 
                 if name is None:
-                    name = site.specie.symbol + str(c)
+                    name = f"{site.specie.symbol}{c}"
                     site_descriptions[name] = site.properties
                     c += 1
 
@@ -174,12 +169,12 @@ class PWInput:
 
     def as_dict(self):
         """
-        Create a dictionary representation of a PWInput object
+        Create a dictionary representation of a PWInput object.
 
         Returns:
             dict
         """
-        pwinput_dict = {
+        return {
             "structure": self.structure.as_dict(),
             "pseudo": self.pseudo,
             "sections": self.sections,
@@ -187,7 +182,6 @@ class PWInput:
             "kpoints_grid": self.kpoints_grid,
             "kpoints_shift": self.kpoints_shift,
         }
-        return pwinput_dict
 
     @classmethod
     def from_dict(cls, pwinput_dict):
@@ -200,7 +194,7 @@ class PWInput:
         Returns:
             PWInput object
         """
-        pwinput = cls(
+        return cls(
             structure=Structure.from_dict(pwinput_dict["structure"]),
             pseudo=pwinput_dict["pseudo"],
             control=pwinput_dict["sections"]["control"],
@@ -212,7 +206,6 @@ class PWInput:
             kpoints_grid=pwinput_dict["kpoints_grid"],
             kpoints_shift=pwinput_dict["kpoints_shift"],
         )
-        return pwinput
 
     def write_file(self, filename):
         """
@@ -221,11 +214,11 @@ class PWInput:
         Args:
             filename (str): The string filename to output to.
         """
-        with open(filename, "w") as f:
-            f.write(str(self))
+        with open(filename, mode="w") as file:
+            file.write(str(self))
 
-    @staticmethod
-    def from_file(filename):
+    @classmethod
+    def from_file(cls, filename):
         """
         Reads an PWInput object from a file.
 
@@ -235,11 +228,11 @@ class PWInput:
         Returns:
             PWInput object
         """
-        with zopen(filename, "rt") as f:
-            return PWInput.from_string(f.read())
+        with zopen(filename, mode="rt") as file:
+            return cls.from_str(file.read())
 
-    @staticmethod
-    def from_string(string):
+    @classmethod
+    def from_str(cls, string):
         """
         Reads an PWInput object from a string.
 
@@ -342,7 +335,7 @@ class PWInput:
             coords_are_cartesian=coords_are_cartesian,
             site_properties=site_properties,
         )
-        return PWInput(
+        return cls(
             structure=structure,
             control=sections["control"],
             pseudo=pseudo,
@@ -371,7 +364,7 @@ class PWInput:
             "conv_thr",
             "Hubbard_U",
             "Hubbard_J0",
-            "defauss",
+            "degauss",
             "starting_magnetization",
         )
 
@@ -482,8 +475,7 @@ class PWInput:
             pass
 
         try:
-            val = val.replace("d", "e")
-            return smart_int_or_float(val)
+            return smart_int_or_float(val.replace("d", "e"))
         except ValueError:
             pass
 
@@ -499,17 +491,13 @@ class PWInput:
 
 
 class PWInputError(BaseException):
-    """
-    Error for PWInput
-    """
+    """Error for PWInput."""
 
 
 class PWOutput:
-    """
-    Parser for PWSCF output file.
-    """
+    """Parser for PWSCF output file."""
 
-    patterns = frozendict(
+    patterns = dict(
         energies=r"total energy\s+=\s+([\d\.\-]+)\sRy",
         ecut=r"kinetic\-energy cutoff\s+=\s+([\d\.\-]+)\s+Ry",
         lattice_type=r"bravais\-lattice index\s+=\s+(\d+)",
@@ -525,7 +513,7 @@ class PWOutput:
     def __init__(self, filename):
         """
         Args:
-            filename (str): Filename
+            filename (str): Filename.
         """
         self.filename = filename
         self.data = defaultdict(list)
@@ -574,7 +562,7 @@ class PWOutput:
     def get_celldm(self, idx: int):
         """
         Args:
-            idx (int): index
+            idx (int): index.
 
         Returns:
             Cell dimension along index
@@ -583,14 +571,10 @@ class PWOutput:
 
     @property
     def final_energy(self):
-        """
-        Returns: Final energy
-        """
+        """Returns: Final energy."""
         return self.data["energies"][-1]
 
     @property
     def lattice_type(self):
-        """
-        Returns: Lattice type.
-        """
+        """Returns: Lattice type."""
         return self.data["lattice_type"]
