@@ -4,7 +4,6 @@ from __future__ import annotations
 
 import itertools
 from dataclasses import dataclass
-from pathlib import Path
 from typing import TYPE_CHECKING
 
 import numpy as np
@@ -17,6 +16,8 @@ from pymatgen.electronic_structure.core import Spin
 from pymatgen.io.vasp.outputs import Vasprun, Waveder
 
 if TYPE_CHECKING:
+    from pathlib import Path
+
     from numpy.typing import ArrayLike, NDArray
 
 __author__ = "Jimmy-Xuan Shen"
@@ -111,21 +112,19 @@ class DielectricFunctionCalculator(MSONable):
     @classmethod
     def from_directory(cls, directory: Path | str):
         """Construct a DielectricFunction from a directory containing vasprun.xml and WAVEDER files."""
-        d_ = Path(directory)
 
         def _try_reading(dtypes):
             """Return None if failed."""
             for dtype in dtypes:
                 try:
-                    waveder = Waveder.from_binary(d_ / "WAVEDER", data_type=dtype)
-                    return waveder
+                    return Waveder.from_binary(f"{directory}/WAVEDER", data_type=dtype)
                 except ValueError as e:
                     if "reshape" in str(e):
                         continue
                     raise e
             return None
 
-        vrun = Vasprun(d_ / "vasprun.xml")
+        vrun = Vasprun(f"{directory}/vasprun.xml")
         if "gamma" in vrun.generator["subversion"].lower():
             waveder = _try_reading(["float64", "float32"])  # large one first should give value error
         else:
@@ -252,7 +251,7 @@ def delta_methfessel_paxton(x, n):
     """
     D_n (x) = exp -x^2 * sum_i=0^n A_i H_2i(x)
     where H is a Hermite polynomial and
-    A_i = (-1)^i / ( i! 4^i sqrt(pi) )
+    A_i = (-1)^i / ( i! 4^i sqrt(pi) ).
     """
     ii = np.arange(0, n + 1)
     A = (-1) ** ii / (scipy.special.factorial(ii) * 4**ii * np.sqrt(np.pi))
@@ -264,7 +263,7 @@ def step_methfessel_paxton(x, n):
     """
     S_n (x) = (1 + erf x)/2 - exp -x^2 * sum_i=1^n A_i H_{2i-1}(x)
     where H is a Hermite polynomial and
-    A_i = (-1)^i / ( i! 4^i sqrt(pi) )
+    A_i = (-1)^i / ( i! 4^i sqrt(pi) ).
     """
     ii = np.arange(1, n + 1)
     A = (-1) ** ii / (scipy.special.factorial(ii) * 4**ii * np.sqrt(np.pi))
@@ -273,7 +272,7 @@ def step_methfessel_paxton(x, n):
 
 
 def delta_func(x, ismear):
-    """Replication of VASP's delta function"""
+    """Replication of VASP's delta function."""
     if ismear < -1:
         raise ValueError("Delta function not implemented for ismear < -1")
     if ismear == -1:
@@ -284,7 +283,7 @@ def delta_func(x, ismear):
 
 
 def step_func(x, ismear):
-    """Replication of VASP's step function"""
+    """Replication of VASP's step function."""
     if ismear < -1:
         raise ValueError("Delta function not implemented for ismear < -1")
     if ismear == -1:
@@ -309,9 +308,8 @@ def get_delta(x0: float, sigma: float, nx: int, dx: float, ismear: int = 3):
 
     Return:
         np.array: Array of size `nx` with delta function on the desired outputgrid.
-
     """
-    xgrid = np.arange(0, nx * dx, dx)
+    xgrid = np.linspace(0, nx * dx, nx, endpoint=False)
     xgrid -= x0
     x_scaled = (xgrid + (dx / 2)) / sigma
     sfun = step_func(x_scaled, ismear)
@@ -335,7 +333,7 @@ def get_step(x0, sigma, nx, dx, ismear):
     Return:
         np.array: Array of size `nx` with step function on the desired outputgrid.
     """
-    xgrid = np.arange(0, nx * dx, dx)
+    xgrid = np.linspace(0, nx * dx, nx, endpoint=False)
     xgrid -= x0
     x_scaled = (xgrid + (dx / 2)) / sigma
     return step_func(x_scaled, ismear)
@@ -371,10 +369,9 @@ def epsilon_imag(
 
     Return:
         np.array: Array of size `nedos` with the imaginary part of the dielectric function.
-
     """
     norm_kweights = np.array(kweights) / np.sum(kweights)
-    egrid = np.arange(0, nedos * deltae, deltae)
+    egrid = np.linspace(0, nedos * deltae, nedos, endpoint=False)
     eigs_shifted = eigs - efermi
     # np.subtract.outer results in a matrix of shape (nband, nband)
     rspin = 3 - cder.shape[3]
@@ -403,7 +400,6 @@ def epsilon_imag(
     num_ = (max_band0 - min_band0) * (max_band1 - min_band1) * nk * nspin
     epsdd = np.zeros_like(egrid, dtype=np.complex128)
     for ib, jb, ik, ispin in tqdm(itertools.product(*iter_idx), total=num_):
-        # print(f"{ib=}, {jb=}, {ik=}, {ispin=}")
         fermi_w_i = step_func((eigs_shifted[ib, ik, ispin]) / sigma, ismear)
         fermi_w_j = step_func((eigs_shifted[jb, ik, ispin]) / sigma, ismear)
         weight = (fermi_w_j - fermi_w_i) * rspin * norm_kweights[ik]
