@@ -1,5 +1,4 @@
-"""
-This module provides classes to handle the calculation of the IR spectra
+"""This module provides classes to handle the calculation of the IR spectra
 This implementation is adapted from Abipy
 https://github.com/abinit/abipy
 where it was originally done by Guido Petretto and Matteo Giantomassi.
@@ -7,6 +6,9 @@ where it was originally done by Guido Petretto and Matteo Giantomassi.
 
 from __future__ import annotations
 
+import json
+from typing import TYPE_CHECKING
+
 import numpy as np
 from monty.json import MSONable
 
@@ -15,6 +17,13 @@ from pymatgen.core.structure import Structure
 from pymatgen.util.plotting import add_fig_kwargs
 from pymatgen.vis.plotters import SpectrumPlotter
 
+if TYPE_CHECKING:
+    from collections.abc import Sequence
+    from os import PathLike
+
+    from matplotlib.axes import Axes
+    from numpy.typing import ArrayLike
+
 __author__ = "Henrique Miranda, Guido Petretto, Matteo Giantomassi"
 __copyright__ = "Copyright 2018, The Materials Project"
 __version__ = "0.1"
@@ -24,13 +33,18 @@ __date__ = "Oct 31, 2018"
 
 
 class IRDielectricTensor(MSONable):
-    """
-    Class to handle the Ionic Dielectric Tensor
+    """Class to handle the Ionic Dielectric Tensor
     The implementation is adapted from Abipy
     See the definitions Eq.(53-54) in :cite:`Gonze1997` PRB55, 10355 (1997).
     """
 
-    def __init__(self, oscillator_strength, ph_freqs_gamma, epsilon_infinity, structure):
+    def __init__(
+        self,
+        oscillator_strength: ArrayLike,
+        ph_freqs_gamma: ArrayLike,
+        epsilon_infinity: ArrayLike,
+        structure: Structure,
+    ) -> None:
         """
         Args:
             oscillator_strength: IR oscillator strengths as defined in Eq. 54 in
@@ -45,25 +59,25 @@ class IRDielectricTensor(MSONable):
         self.epsilon_infinity = np.array(epsilon_infinity)
 
     @classmethod
-    def from_dict(cls, d):
+    def from_dict(cls, dct: dict) -> IRDielectricTensor:
         """Returns IRDielectricTensor from dict representation."""
-        structure = Structure.from_dict(d["structure"])
-        oscillator_strength = d["oscillator_strength"]
-        ph_freqs_gamma = d["ph_freqs_gamma"]
-        epsilon_infinity = d["epsilon_infinity"]
+        structure = Structure.from_dict(dct["structure"])
+        oscillator_strength = dct["oscillator_strength"]
+        ph_freqs_gamma = dct["ph_freqs_gamma"]
+        epsilon_infinity = dct["epsilon_infinity"]
         return cls(oscillator_strength, ph_freqs_gamma, epsilon_infinity, structure)
 
     @property
-    def max_phfreq(self):
+    def max_phfreq(self) -> float:
         """Maximum phonon frequency."""
         return max(self.ph_freqs_gamma)
 
     @property
-    def nph_freqs(self):
+    def nph_freqs(self) -> int:
         """Number of phonon frequencies."""
         return len(self.ph_freqs_gamma)
 
-    def as_dict(self):
+    def as_dict(self) -> dict:
         """JSON-serializable dict representation of IRDielectricTensor."""
         return {
             "@module": type(self).__module__,
@@ -74,16 +88,15 @@ class IRDielectricTensor(MSONable):
             "epsilon_infinity": self.epsilon_infinity.tolist(),
         }
 
-    def write_json(self, filename):
+    def write_json(self, filename: str | PathLike) -> None:
         """Save a json file with this data."""
-        import json
+        with open(filename, mode="w") as file:
+            json.dump(self.as_dict(), file)
 
-        with open(filename, "w") as f:
-            json.dump(self.as_dict(), f)
-
-    def get_ir_spectra(self, broad=0.00005, emin=0, emax=None, divs=500):
-        """
-        The IR spectra is obtained for the different directions.
+    def get_ir_spectra(
+        self, broad: list | float = 0.00005, emin: float = 0, emax: float | None = None, divs: int = 500
+    ) -> tuple:
+        """The IR spectra is obtained for the different directions.
 
         Args:
             broad: a list of broadenings or a single broadening for the phonon peaks
@@ -118,9 +131,16 @@ class IRDielectricTensor(MSONable):
         return frequencies, dielectric_tensor
 
     @add_fig_kwargs
-    def plot(self, components=("xx",), reim="reim", show_phonon_frequencies=True, xlim=None, ylim=None, **kwargs):
-        """
-        Helper function to generate the Spectrum plotter and directly plot the results.
+    def plot(
+        self,
+        components: Sequence = ("xx",),
+        reim: str = "reim",
+        show_phonon_frequencies: bool = True,
+        xlim: float | None = None,
+        ylim: float | None = None,
+        **kwargs,
+    ) -> Axes:
+        """Helper function to generate the Spectrum plotter and directly plot the results.
 
         Arguments:
             components: A list with the components of the dielectric tensor to plot.
@@ -132,18 +152,26 @@ class IRDielectricTensor(MSONable):
             kwargs: keyword arguments passed to the plotter
         """
         plotter = self.get_plotter(components=components, reim=reim, **kwargs)
-        plt = plotter.get_plot(xlim=xlim, ylim=ylim)
+        ax = plotter.get_plot(xlim=xlim, ylim=ylim)
 
         if show_phonon_frequencies:
             ph_freqs_gamma = self.ph_freqs_gamma[3:]
-            plt.scatter(ph_freqs_gamma * 1000, np.zeros_like(ph_freqs_gamma))
-        plt.xlabel(r"$\epsilon(\omega)$")
-        plt.xlabel(r"Frequency (meV)")
-        return plt
+            ax.scatter(ph_freqs_gamma * 1000, np.zeros_like(ph_freqs_gamma))
+        ax.set_xlabel(r"$\epsilon(\omega)$")
+        ax.set_xlabel(r"Frequency (meV)")
+        return ax
 
-    def get_spectrum(self, component, reim, broad=0.00005, emin=0, emax=None, divs=500, label=None):
-        """
-        component: either two indexes or a string like 'xx' to plot the (0,0) component
+    def get_spectrum(
+        self,
+        component: Sequence | str,
+        reim: str,
+        broad: list | float = 0.00005,
+        emin: float = 0,
+        emax: float | None = None,
+        divs: int = 500,
+        label=None,
+    ) -> Spectrum:
+        """component: either two indexes or a string like 'xx' to plot the (0,0) component
         reim: only "re" or "im"
         broad: a list of broadenings or a single broadening for the phonon peaks.
         """
@@ -160,9 +188,17 @@ class IRDielectricTensor(MSONable):
 
         return Spectrum(frequencies * 1000, y, label=label)
 
-    def get_plotter(self, components=("xx",), reim="reim", broad=0.00005, emin=0, emax=None, divs=500, **kwargs):
-        """
-        Return an instance of the Spectrum plotter containing the different requested components.
+    def get_plotter(
+        self,
+        components: Sequence = ("xx",),
+        reim: str = "reim",
+        broad: list | float = 0.00005,
+        emin: float = 0,
+        emax: float | None = None,
+        divs: int = 500,
+        **kwargs,
+    ) -> SpectrumPlotter:
+        """Return an instance of the Spectrum plotter containing the different requested components.
 
         Arguments:
             components: A list with the components of the dielectric tensor to plot.
