@@ -1,5 +1,4 @@
-"""
-This module defines site transformations which transforms a structure into
+"""This module defines site transformations which transforms a structure into
 another structure. Site transformations differ from standard transformations
 in that they operate in a site-specific manner.
 All transformations should inherit the AbstractTransformation ABC.
@@ -48,8 +47,7 @@ class InsertSitesTransformation(AbstractTransformation):
         self.validate_proximity = validate_proximity
 
     def apply_transformation(self, structure: Structure):
-        """
-        Apply the transformation.
+        """Apply the transformation.
 
         Arg:
             structure (Structure): A structurally similar structure in
@@ -58,22 +56,19 @@ class InsertSitesTransformation(AbstractTransformation):
         Return:
             Returns a copy of structure with sites inserted.
         """
-        s = structure.copy()
-        for i, sp in enumerate(self.species):
-            s.insert(
-                i,
+        struct = structure.copy()
+        for idx, sp in enumerate(self.species):
+            struct.insert(
+                idx,
                 sp,
-                self.coords[i],
+                self.coords[idx],
                 coords_are_cartesian=self.coords_are_cartesian,
                 validate_proximity=self.validate_proximity,
             )
-        return s.get_sorted_structure()
-
-    def __str__(self):
-        return f"InsertSiteTransformation : species {self.species}, coords {self.coords}"
+        return struct.get_sorted_structure()
 
     def __repr__(self):
-        return str(self)
+        return f"InsertSiteTransformation : species {self.species}, coords {self.coords}"
 
     @property
     def inverse(self):
@@ -102,8 +97,7 @@ class ReplaceSiteSpeciesTransformation(AbstractTransformation):
         self.indices_species_map = indices_species_map
 
     def apply_transformation(self, structure: Structure):
-        """
-        Apply the transformation.
+        """Apply the transformation.
 
         Arg:
             structure (Structure): A structurally similar structure in
@@ -112,19 +106,16 @@ class ReplaceSiteSpeciesTransformation(AbstractTransformation):
         Return:
             Returns a copy of structure with sites replaced.
         """
-        s = structure.copy()
+        struct = structure.copy()
         for i, sp in self.indices_species_map.items():
-            s[int(i)] = sp
-        return s
+            struct[int(i)] = sp
+        return struct
 
-    def __str__(self):
+    def __repr__(self):
         return "ReplaceSiteSpeciesTransformation :" + ", ".join(
             [f"{k}->{v}" + v for k, v in self.indices_species_map.items()]
         )
 
-    def __repr__(self):
-        return str(self)
-
     @property
     def inverse(self):
         """Return: None."""
@@ -147,8 +138,7 @@ class RemoveSitesTransformation(AbstractTransformation):
         self.indices_to_remove = indices_to_remove
 
     def apply_transformation(self, structure: Structure):
-        """
-        Apply the transformation.
+        """Apply the transformation.
 
         Arg:
             structure (Structure): A structurally similar structure in
@@ -157,15 +147,12 @@ class RemoveSitesTransformation(AbstractTransformation):
         Return:
             Returns a copy of structure with sites removed.
         """
-        s = structure.copy()
-        s.remove_sites(self.indices_to_remove)
-        return s
-
-    def __str__(self):
-        return "RemoveSitesTransformation :" + ", ".join(map(str, self.indices_to_remove))
+        struct = structure.copy()
+        struct.remove_sites(self.indices_to_remove)
+        return struct
 
     def __repr__(self):
-        return str(self)
+        return "RemoveSitesTransformation :" + ", ".join(map(str, self.indices_to_remove))
 
     @property
     def inverse(self):
@@ -198,8 +185,7 @@ class TranslateSitesTransformation(AbstractTransformation):
         self.vector_in_frac_coords = vector_in_frac_coords
 
     def apply_transformation(self, structure: Structure):
-        """
-        Apply the transformation.
+        """Apply the transformation.
 
         Arg:
             structure (Structure): A structurally similar structure in
@@ -208,24 +194,21 @@ class TranslateSitesTransformation(AbstractTransformation):
         Return:
             Returns a copy of structure with sites translated.
         """
-        s = structure.copy()
+        struct = structure.copy()
         if self.translation_vector.shape == (len(self.indices_to_move), 3):
             for i, idx in enumerate(self.indices_to_move):
-                s.translate_sites(idx, self.translation_vector[i], self.vector_in_frac_coords)
+                struct.translate_sites(idx, self.translation_vector[i], self.vector_in_frac_coords)
         else:
-            s.translate_sites(self.indices_to_move, self.translation_vector, self.vector_in_frac_coords)
-        return s
+            struct.translate_sites(self.indices_to_move, self.translation_vector, self.vector_in_frac_coords)
+        return struct
 
-    def __str__(self):
+    def __repr__(self):
         return (
             f"TranslateSitesTransformation for indices {self.indices_to_move}, "
             f"vect {self.translation_vector} and "
             f"vect_in_frac_coords = {self.vector_in_frac_coords}"
         )
 
-    def __repr__(self):
-        return str(self)
-
     @property
     def inverse(self):
         """
@@ -241,14 +224,13 @@ class TranslateSitesTransformation(AbstractTransformation):
 
     def as_dict(self):
         """JSON-serializable dict representation."""
-        d = MSONable.as_dict(self)
-        d["translation_vector"] = self.translation_vector.tolist()
-        return d
+        dct = MSONable.as_dict(self)
+        dct["translation_vector"] = self.translation_vector.tolist()
+        return dct
 
 
 class PartialRemoveSitesTransformation(AbstractTransformation):
-    """
-    Remove fraction of specie from a structure.
+    """Remove fraction of specie from a structure.
     Requires an oxidation state decorated structure for Ewald sum to be
     computed.
 
@@ -313,70 +295,67 @@ class PartialRemoveSitesTransformation(AbstractTransformation):
         self.logger.debug("Performing best first ordering")
         start_time = time.perf_counter()
         self.logger.debug("Performing initial Ewald sum...")
-        ewaldsum = EwaldSummation(structure)
+        ewald_sum = EwaldSummation(structure)
         self.logger.debug(f"Ewald sum took {time.perf_counter() - start_time} seconds.")
         start_time = time.perf_counter()
 
-        ematrix = ewaldsum.total_energy_matrix
+        e_matrix = ewald_sum.total_energy_matrix
         to_delete = []
 
-        totalremovals = sum(num_remove_dict.values())
+        total_removals = sum(num_remove_dict.values())
         removed = {k: 0 for k in num_remove_dict}
-        for _ in range(totalremovals):
+        for _ in range(total_removals):
             max_idx = None
-            maxe = float("-inf")
-            maxindices = None
+            max_ene = float("-inf")
+            max_indices = None
             for indices in num_remove_dict:
                 if removed[indices] < num_remove_dict[indices]:
                     for ind in indices:
                         if ind not in to_delete:
-                            energy = sum(ematrix[:, ind]) + sum(ematrix[:, ind]) - ematrix[ind, ind]
-                            if energy > maxe:
+                            energy = sum(e_matrix[:, ind]) + sum(e_matrix[:, ind]) - e_matrix[ind, ind]
+                            if energy > max_ene:
                                 max_idx = ind
-                                maxe = energy
-                                maxindices = indices
-            removed[maxindices] += 1
+                                max_ene = energy
+                                max_indices = indices
+            removed[max_indices] += 1
             to_delete.append(max_idx)
-            ematrix[:, max_idx] = 0
-            ematrix[max_idx, :] = 0
-        s = structure.copy()
-        s.remove_sites(to_delete)
+            e_matrix[:, max_idx] = 0
+            e_matrix[max_idx, :] = 0
+        struct = structure.copy()
+        struct.remove_sites(to_delete)
         self.logger.debug(f"Minimizing Ewald took {time.perf_counter() - start_time} seconds.")
-        return [{"energy": sum(ematrix), "structure": s.get_sorted_structure()}]
+        return [{"energy": sum(e_matrix), "structure": struct.get_sorted_structure()}]
 
     def _complete_ordering(self, structure: Structure, num_remove_dict):
         self.logger.debug("Performing complete ordering...")
         all_structures: list[dict[str, float | Structure]] = []
         symprec = 0.2
-        s = SpacegroupAnalyzer(structure, symprec=symprec)
-        self.logger.debug(f"Symmetry of structure is determined to be {s.get_space_group_symbol()}.")
-        sg = s.get_space_group_operations()
+        spg_analyzer = SpacegroupAnalyzer(structure, symprec=symprec)
+        self.logger.debug(f"Symmetry of structure is determined to be {spg_analyzer.get_space_group_symbol()}.")
+        sg = spg_analyzer.get_space_group_operations()
         tested_sites: list[list[PeriodicSite]] = []
         start_time = time.perf_counter()
         self.logger.debug("Performing initial Ewald sum...")
-        ewaldsum = EwaldSummation(structure)
+        ewald_sum = EwaldSummation(structure)
         self.logger.debug(f"Ewald sum took {time.perf_counter() - start_time} seconds.")
         start_time = time.perf_counter()
 
-        allcombis = []
-        for ind, num in num_remove_dict.items():
-            allcombis.append(itertools.combinations(ind, num))
+        all_combis = [list(itertools.combinations(ind, num)) for ind, num in num_remove_dict.items()]
 
-        count = 0
-        for allindices in itertools.product(*allcombis):
+        for idx, all_indices in enumerate(itertools.product(*all_combis), 1):
             sites_to_remove = []
             indices_list = []
-            for indices in allindices:
+            for indices in all_indices:
                 sites_to_remove.extend([structure[i] for i in indices])
                 indices_list.extend(indices)
             s_new = structure.copy()
             s_new.remove_sites(indices_list)
-            energy = ewaldsum.compute_partial_energy(indices_list)
+            energy = ewald_sum.compute_partial_energy(indices_list)
             already_tested = False
-            for i, tsites in enumerate(tested_sites):
-                tenergy = all_structures[i]["energy"]
-                if abs((energy - tenergy) / len(s_new)) < 1e-5 and sg.are_symmetrically_equivalent(
-                    sites_to_remove, tsites, symm_prec=symprec
+            for ii, t_sites in enumerate(tested_sites):
+                t_energy = all_structures[ii]["energy"]
+                if abs((energy - t_energy) / len(s_new)) < 1e-5 and sg.are_symmetrically_equivalent(
+                    sites_to_remove, t_sites, symm_prec=symprec
                 ):
                     already_tested = True
 
@@ -384,20 +363,17 @@ class PartialRemoveSitesTransformation(AbstractTransformation):
                 tested_sites.append(sites_to_remove)
                 all_structures.append({"structure": s_new, "energy": energy})
 
-            count += 1
-            if count % 10 == 0:
-                timenow = time.perf_counter()
-                self.logger.debug(f"{count} structures, {timenow - start_time:.2f} seconds.")
-                self.logger.debug(f"Average time per combi = {(timenow - start_time) / count} seconds")
+            if idx % 10 == 0:
+                now = time.perf_counter()
+                self.logger.debug(f"{idx} structures, {now - start_time:.2f} seconds.")
+                self.logger.debug(f"Average time per combi = {(now - start_time) / idx} seconds")
                 self.logger.debug(f"{len(all_structures)} symmetrically distinct structures found.")
 
         self.logger.debug(f"Total symmetrically distinct structures found = {len(all_structures)}")
-        all_structures = sorted(all_structures, key=lambda s: s["energy"])
-        return all_structures
+        return sorted(all_structures, key=lambda s: s["energy"])
 
     def _fast_ordering(self, structure: Structure, num_remove_dict, num_to_return=1):
-        """
-        This method uses the matrix form of ewaldsum to calculate the ewald
+        """This method uses the matrix form of Ewald sum to calculate the ewald
         sums of the potential structures. This is on the order of 4 orders of
         magnitude faster when there are large numbers of permutations to
         consider. There are further optimizations possible (doing a smarter
@@ -408,15 +384,13 @@ class PartialRemoveSitesTransformation(AbstractTransformation):
         start_time = time.perf_counter()
         self.logger.debug("Performing initial Ewald sum...")
 
-        ewaldmatrix = EwaldSummation(structure).total_energy_matrix
+        ewald_matrix = EwaldSummation(structure).total_energy_matrix
         self.logger.debug(f"Ewald sum took {time.perf_counter() - start_time} seconds.")
         start_time = time.perf_counter()
-        m_list = []
-        for indices, num in num_remove_dict.items():
-            m_list.append([0, num, list(indices), None])
+        m_list = [[0, num, list(indices), None] for indices, num in num_remove_dict.items()]
 
         self.logger.debug("Calling EwaldMinimizer...")
-        minimizer = EwaldMinimizer(ewaldmatrix, m_list, num_to_return, PartialRemoveSitesTransformation.ALGO_FAST)
+        minimizer = EwaldMinimizer(ewald_matrix, m_list, num_to_return, PartialRemoveSitesTransformation.ALGO_FAST)
         self.logger.debug(f"Minimizing Ewald took {time.perf_counter() - start_time} seconds.")
 
         all_structures = []
@@ -425,16 +399,16 @@ class PartialRemoveSitesTransformation(AbstractTransformation):
         num_atoms = sum(structure.composition.values())
 
         for output in minimizer.output_lists:
-            s = structure.copy()
+            struct = structure.copy()
             del_indices = []
 
             for manipulation in output[1]:
                 if manipulation[1] is None:
                     del_indices.append(manipulation[0])
                 else:
-                    s.replace(manipulation[0], manipulation[1])
-            s.remove_sites(del_indices)
-            struct = s.get_sorted_structure()
+                    struct.replace(manipulation[0], manipulation[1])
+            struct.remove_sites(del_indices)
+            struct = struct.get_sorted_structure()
             all_structures.append(
                 {
                     "energy": output[0],
@@ -447,20 +421,19 @@ class PartialRemoveSitesTransformation(AbstractTransformation):
 
     def _enumerate_ordering(self, structure: Structure):
         # Generate the disordered structure first.
-        s = structure.copy()
+        struct = structure.copy()
         for indices, fraction in zip(self.indices, self.fractions):
             for ind in indices:
                 new_sp = {sp: occu * fraction for sp, occu in structure[ind].species.items()}
-                s[ind] = new_sp
+                struct[ind] = new_sp
         # Perform enumeration
         from pymatgen.transformations.advanced_transformations import EnumerateStructureTransformation
 
         trans = EnumerateStructureTransformation()
-        return trans.apply_transformation(s, 10000)
+        return trans.apply_transformation(struct, 10000)
 
     def apply_transformation(self, structure: Structure, return_ranked_list: bool | int = False):
-        """
-        Apply the transformation.
+        """Apply the transformation.
 
         Args:
             structure: input structure
@@ -515,11 +488,8 @@ class PartialRemoveSitesTransformation(AbstractTransformation):
         opt_s = all_structures[0]["structure"]
         return opt_s if not return_ranked_list else all_structures[0:num_to_return]
 
-    def __str__(self):
-        return f"PartialRemoveSitesTransformation : Indices and fraction to remove = {self.indices}, ALGO = {self.algo}"
-
     def __repr__(self):
-        return str(self)
+        return f"PartialRemoveSitesTransformation : Indices and fraction to remove = {self.indices}, ALGO = {self.algo}"
 
     @property
     def inverse(self):
@@ -543,8 +513,7 @@ class AddSitePropertyTransformation(AbstractTransformation):
         self.site_properties = site_properties
 
     def apply_transformation(self, structure: Structure):
-        """
-        Apply the transformation.
+        """Apply the transformation.
 
         Arg:
             structure (Structure): A structurally similar structure in
@@ -570,8 +539,7 @@ class AddSitePropertyTransformation(AbstractTransformation):
 
 
 class RadialSiteDistortionTransformation(AbstractTransformation):
-    """
-    Radially perturbs atoms around a site. Can be used to create spherical distortion due to a
+    """Radially perturbs atoms around a site. Can be used to create spherical distortion due to a
     point defect.
     """
 
@@ -594,8 +562,7 @@ class RadialSiteDistortionTransformation(AbstractTransformation):
         self.nn_only = nn_only
 
     def apply_transformation(self, structure: Structure):
-        """
-        Apply the transformation.
+        """Apply the transformation.
 
         Args:
             structure: Structure or Molecule to apply the transformation to
@@ -632,16 +599,14 @@ class RadialSiteDistortionTransformation(AbstractTransformation):
 
     @property
     def inverse(self):
-        """
-        Returns the inverse transformation if available.
+        """Returns the inverse transformation if available.
         Otherwise, should return None.
         """
         return False
 
     @property
     def is_one_to_many(self) -> bool:
-        """
-        Determines if a Transformation is a one-to-many transformation. If a
+        """Determines if a Transformation is a one-to-many transformation. If a
         Transformation is a one-to-many transformation, the
         apply_transformation method should have a keyword arg
         "return_ranked_list" which allows for the transformed structures to be
@@ -651,8 +616,7 @@ class RadialSiteDistortionTransformation(AbstractTransformation):
 
     @property
     def use_multiprocessing(self):
-        """
-        Indicates whether the transformation can be applied by a
+        """Indicates whether the transformation can be applied by a
         subprocessing pool. This should be overridden to return True for
         transformations that the transmuter can parallelize.
         """
