@@ -1,46 +1,58 @@
-"""
-Utilities for generating nicer plots.
-"""
+"""Utilities for generating nicer plots."""
+
 from __future__ import annotations
 
+import importlib
 import math
-from typing import Literal
+from functools import wraps
+from string import ascii_letters
+from typing import TYPE_CHECKING, Literal
 
+import matplotlib.pyplot as plt
 import numpy as np
+import palettable.colorbrewer.diverging
 from matplotlib import cm, colors
 
-from pymatgen.core.periodic_table import Element
+from pymatgen.core import Element
+
+if TYPE_CHECKING:
+    from collections.abc import Sequence
+
+    from matplotlib.axes import Axes
+    from matplotlib.figure import Figure
+    from mpl_toolkits.mplot3d.axes3d import Axes3D
+    from numpy.typing import ArrayLike
 
 
-def pretty_plot(width=8, height=None, plt=None, dpi=None, color_cycle=("qualitative", "Set1_9")):
-    """
-    Provides a publication quality plot, with nice defaults for font sizes etc.
+def pretty_plot(
+    width: float = 8,
+    height: float | None = None,
+    ax: Axes = None,
+    dpi: float | None = None,
+    color_cycle: tuple[str, str] = ("qualitative", "Set1_9"),
+) -> Axes:
+    """Provides a publication quality plot, with nice defaults for font sizes etc.
 
     Args:
         width (float): Width of plot in inches. Defaults to 8in.
         height (float): Height of plot in inches. Defaults to width * golden
             ratio.
-        plt (matplotlib.pyplot): If plt is supplied, changes will be made to an
+        ax (Axes): If ax is supplied, changes will be made to an
             existing plot. Otherwise, a new plot will be created.
-        dpi (int): Sets dot per inch for figure. Defaults to 300.
+        dpi (float): Sets dot per inch for figure. Defaults to 300.
         color_cycle (tuple): Set the color cycle for new plots to one of the
             color sets in palettable. Defaults to a qualitative Set1_9.
 
     Returns:
-        Matplotlib plot object with properly sized fonts.
+        Axes: matplotlib axes object with properly sized fonts.
     """
     tick_size = int(width * 2.5)
-
     golden_ratio = (math.sqrt(5) - 1) / 2
 
     if not height:
         height = int(width * golden_ratio)
 
-    if plt is None:
-        import importlib
-
-        import matplotlib.pyplot as plt
-
+    if ax is None:
         mod = importlib.import_module(f"palettable.colorbrewer.{color_cycle[0]}")
         colors = getattr(mod, color_cycle[1]).mpl_colors
         from cycler import cycler
@@ -51,25 +63,32 @@ def pretty_plot(width=8, height=None, plt=None, dpi=None, color_cycle=("qualitat
     else:
         fig = plt.gcf()
         fig.set_size_inches(width, height)
+
     plt.xticks(fontsize=tick_size)
     plt.yticks(fontsize=tick_size)
 
-    ax = plt.gca()
     ax.set_title(ax.get_title(), size=width * 4)
 
     label_size = int(width * 3)
-
     ax.set_xlabel(ax.get_xlabel(), size=label_size)
     ax.set_ylabel(ax.get_ylabel(), size=label_size)
 
-    return plt
+    return ax
 
 
 def pretty_plot_two_axis(
-    x, y1, y2, xlabel=None, y1label=None, y2label=None, width=8, height=None, dpi=300, **plot_kwargs
+    x,
+    y1,
+    y2,
+    xlabel=None,
+    y1label=None,
+    y2label=None,
+    width: float = 8,
+    height: float | None = None,
+    dpi=300,
+    **plot_kwargs,
 ):
-    """
-    Variant of pretty_plot that does a dual axis plot. Adapted from matplotlib
+    """Variant of pretty_plot that does a dual axis plot. Adapted from matplotlib
     examples. Makes it easier to create plots with different axes.
 
     Args:
@@ -91,9 +110,6 @@ def pretty_plot_two_axis(
     Returns:
         matplotlib.pyplot
     """
-    # pylint: disable=E1101
-    import palettable.colorbrewer.diverging
-
     colors = palettable.colorbrewer.diverging.RdYlBu_4.mpl_colors
     c1 = colors[0]
     c2 = colors[-1]
@@ -103,8 +119,6 @@ def pretty_plot_two_axis(
     if not height:
         height = int(width * golden_ratio)
 
-    import matplotlib.pyplot as plt
-
     width = 12
     labelsize = int(width * 3)
     ticksize = int(width * 2.5)
@@ -115,8 +129,8 @@ def pretty_plot_two_axis(
     if dpi:
         fig.set_dpi(dpi)
     if isinstance(y1, dict):
-        for i, (k, v) in enumerate(y1.items()):
-            ax1.plot(x, v, c=c1, marker="s", ls=styles[i % len(styles)], label=k, **plot_kwargs)
+        for idx, (key, val) in enumerate(y1.items()):
+            ax1.plot(x, val, c=c1, marker="s", ls=styles[idx % len(styles)], label=key, **plot_kwargs)
         ax1.legend(fontsize=labelsize)
     else:
         ax1.plot(x, y1, c=c1, marker="s", ls="-", **plot_kwargs)
@@ -133,8 +147,8 @@ def pretty_plot_two_axis(
 
     ax2 = ax1.twinx()
     if isinstance(y2, dict):
-        for i, (k, v) in enumerate(y2.items()):
-            ax2.plot(x, v, c=c2, marker="o", ls=styles[i % len(styles)], label=k)
+        for idx, (key, val) in enumerate(y2.items()):
+            ax2.plot(x, val, c=c2, marker="o", ls=styles[idx % len(styles)], label=key)
         ax2.legend(fontsize=labelsize)
     else:
         ax2.plot(x, y2, c=c2, marker="o", ls="-")
@@ -147,9 +161,8 @@ def pretty_plot_two_axis(
     return plt
 
 
-def pretty_polyfit_plot(x, y, deg=1, xlabel=None, ylabel=None, **kwargs):
-    """
-    Convenience method to plot data with trend lines based on polynomial fit.
+def pretty_polyfit_plot(x: ArrayLike, y: ArrayLike, deg: int = 1, xlabel=None, ylabel=None, **kwargs):
+    """Convenience method to plot data with trend lines based on polynomial fit.
 
     Args:
         x: Sequence of x data.
@@ -162,15 +175,15 @@ def pretty_polyfit_plot(x, y, deg=1, xlabel=None, ylabel=None, **kwargs):
     Returns:
         matplotlib.pyplot object.
     """
-    plt = pretty_plot(**kwargs)
+    ax = pretty_plot(**kwargs)
     pp = np.polyfit(x, y, deg)
     xp = np.linspace(min(x), max(x), 200)
-    plt.plot(xp, np.polyval(pp, xp), "k--", x, y, "o")
+    ax.plot(xp, np.polyval(pp, xp), "k--", x, y, "o")
     if xlabel:
-        plt.xlabel(xlabel)
+        ax.set_xlabel(xlabel)
     if ylabel:
-        plt.ylabel(ylabel)
-    return plt
+        ax.set_ylabel(ylabel)
+    return ax
 
 
 def _decide_fontcolor(rgba: tuple) -> Literal["black", "white"]:
@@ -182,10 +195,10 @@ def _decide_fontcolor(rgba: tuple) -> Literal["black", "white"]:
 
 
 def periodic_table_heatmap(
-    elemental_data,
+    elemental_data=None,
     cbar_label="",
     cbar_label_size=14,
-    show_plot=False,
+    show_plot: bool = False,
     cmap="YlOrRd",
     cmap_range=None,
     blank_color="grey",
@@ -193,41 +206,91 @@ def periodic_table_heatmap(
     value_format=None,
     value_fontsize=10,
     symbol_fontsize=14,
-    max_row=9,
+    max_row: int = 9,
     readable_fontcolor=False,
+    pymatviz: bool = True,
+    **kwargs,
 ):
-    """
-    A static method that generates a heat map overlaid on a periodic table.
+    """A static method that generates a heat map overlaid on a periodic table.
 
     Args:
-         elemental_data (dict): A dictionary with the element as a key and a
+        elemental_data (dict): A dictionary with the element as a key and a
             value assigned to it, e.g. surface energy and frequency, etc.
             Elements missing in the elemental_data will be grey by default
             in the final table elemental_data={"Fe": 4.2, "O": 5.0}.
-         cbar_label (str): Label of the color bar. Default is "".
-         cbar_label_size (float): Font size for the color bar label. Default is 14.
-         cmap_range (tuple): Minimum and maximum value of the color map scale.
+        cbar_label (str): Label of the color bar. Default is "".
+        cbar_label_size (float): Font size for the color bar label. Default is 14.
+        cmap_range (tuple): Minimum and maximum value of the color map scale.
             If None, the color map will automatically scale to the range of the
             data.
-         show_plot (bool): Whether to show the heatmap. Default is False.
-         value_format (str): Formatting string to show values. If None, no value
+        show_plot (bool): Whether to show the heatmap. Default is False.
+        value_format (str): Formatting string to show values. If None, no value
             is shown. Example: "%.4f" shows float to four decimals.
-         value_fontsize (float): Font size for values. Default is 10.
-         symbol_fontsize (float): Font size for element symbols. Default is 14.
-         cmap (str): Color scheme of the heatmap. Default is 'YlOrRd'.
+        value_fontsize (float): Font size for values. Default is 10.
+        symbol_fontsize (float): Font size for element symbols. Default is 14.
+        cmap (str): Color scheme of the heatmap. Default is 'YlOrRd'.
             Refer to the matplotlib documentation for other options.
-         blank_color (str): Color assigned for the missing elements in
+        blank_color (str): Color assigned for the missing elements in
             elemental_data. Default is "grey".
-         edge_color (str): Color assigned for the edge of elements in the
+        edge_color (str): Color assigned for the edge of elements in the
             periodic table. Default is "white".
-         max_row (int): Maximum number of rows of the periodic table to be
+        max_row (int): Maximum number of rows of the periodic table to be
             shown. Default is 9, which means the periodic table heat map covers
             the standard 7 rows of the periodic table + 2 rows for the lanthanides
             and actinides. Use a value of max_row = 7 to exclude the lanthanides and
             actinides.
-         readable_fontcolor (bool): Whether to use readable font color depending
+        readable_fontcolor (bool): Whether to use readable font color depending
             on background color. Default is False.
+        pymatviz (bool): Whether to use pymatviz to generate the heatmap. Defaults to True.
+            See https://github.com/janosh/pymatviz.
+        kwargs: Passed to pymatviz.ptable_heatmap_plotly
     """
+    if pymatviz:
+        try:
+            from pymatviz import ptable_heatmap_plotly
+
+            if elemental_data:
+                kwargs.setdefault("elem_values", elemental_data)
+                print('elemental_data is deprecated, use elem_values={"Fe": 4.2, "O": 5.0} instead')
+            if cbar_label:
+                kwargs.setdefault("color_bar", {}).setdefault("title", cbar_label)
+                print('cbar_label is deprecated, use color_bar={"title": cbar_label} instead')
+            if cbar_label_size != 14:
+                kwargs.setdefault("color_bar", {}).setdefault("titlefont", {}).setdefault("size", cbar_label_size)
+                print('cbar_label_size is deprecated, use color_bar={"titlefont": {"size": cbar_label_size}} instead')
+            if cmap:
+                kwargs.setdefault("colorscale", cmap)
+                print("cmap is deprecated, use colorscale=cmap instead")
+            if cmap_range:
+                kwargs.setdefault("cscale_range", cmap_range)
+                print("cmap_range is deprecated, use cscale_range instead")
+            if value_format:
+                kwargs.setdefault("precision", value_format)
+                print("value_format is deprecated, use precision instead")
+            if blank_color != "grey":
+                print("blank_color is deprecated")
+            if edge_color != "white":
+                print("edge_color is deprecated")
+            if symbol_fontsize != 14:
+                print("symbol_fontsize is deprecated, use font_size instead")
+                kwargs.setdefault("font_size", symbol_fontsize)
+            if value_fontsize != 10:
+                print("value_fontsize is deprecated, use font_size instead")
+                kwargs.setdefault("font_size", value_fontsize)
+            if max_row != 9:
+                print("max_row is deprecated, use max_row instead")
+            if readable_fontcolor:
+                print("readable_fontcolor is deprecated, use font_colors instead, e.g. ('black', 'white')")
+
+            return ptable_heatmap_plotly(**kwargs)
+        except ImportError:
+            print(
+                "You're using a deprecated version of periodic_table_heatmap(). Consider `pip install pymatviz` which "
+                "offers an interactive plotly periodic table heatmap. You can keep calling this same function from "
+                "pymatgen. Some of the arguments have changed which you'll be warned about. "
+                "To disable this warning, pass pymatviz=False."
+            )
+
     # Convert primitive_elemental data in the form of numpy array for plotting.
     if cmap_range is not None:
         max_val = cmap_range[1]
@@ -259,9 +322,6 @@ def periodic_table_heatmap(
             continue
         value_table[plot_row - 1, plot_group - 1] = value
 
-    # Initialize the plt object
-    import matplotlib.pyplot as plt
-
     fig, ax = plt.subplots()
     plt.gcf().set_size_inches(12, 8)
 
@@ -288,7 +348,7 @@ def periodic_table_heatmap(
     ax.axis("off")
     ax.invert_yaxis()
 
-    # Set the scalermap for fontcolor
+    # Set the scalarmap for fontcolor
     norm = colors.Normalize(vmin=min_val, vmax=max_val)
     scalar_cmap = cm.ScalarMappable(norm=norm, cmap=cmap)
 
@@ -327,22 +387,21 @@ def periodic_table_heatmap(
     return plt
 
 
-def format_formula(formula):
-    """
-    Converts str of chemical formula into
-    latex format for labelling purposes
+def format_formula(formula: str) -> str:
+    """Converts str of chemical formula into
+    latex format for labelling purposes.
 
     Args:
         formula (str): Chemical formula
     """
     formatted_formula = ""
     number_format = ""
-    for i, s in enumerate(formula):
-        if s.isdigit():
+    for idx, char in enumerate(formula):
+        if char.isdigit():
             if not number_format:
                 number_format = "_{"
-            number_format += s
-            if i == len(formula) - 1:
+            number_format += char
+            if idx == len(formula) - 1:
                 number_format += "}"
                 formatted_formula += number_format
         else:
@@ -350,14 +409,13 @@ def format_formula(formula):
                 number_format += "}"
                 formatted_formula += number_format
                 number_format = ""
-            formatted_formula += s
+            formatted_formula += char
 
     return f"${formatted_formula}$"
 
 
-def van_arkel_triangle(list_of_materials, annotate=True):
-    """
-    A static method that generates a binary van Arkel-Ketelaar triangle to
+def van_arkel_triangle(list_of_materials: Sequence, annotate: bool = True):
+    """A static method that generates a binary van Arkel-Ketelaar triangle to
         quantify the ionic, metallic and covalent character of a compound
         by plotting the electronegativity difference (y) vs average (x).
         See:
@@ -365,12 +423,12 @@ def van_arkel_triangle(list_of_materials, annotate=True):
                 Interscience, New York (1956)
         and
             J.A.A Ketelaar, Chemical Constitution (2nd edition), An Introduction
-                to the Theory of the Chemical Bond, Elsevier, New York (1958)
+                to the Theory of the Chemical Bond, Elsevier, New York (1958).
 
     Args:
-         list_of_materials (list): A list of computed entries of binary
+        list_of_materials (list): A list of computed entries of binary
             materials or a list of lists containing two elements (str).
-         annotate (bool): Whether or not to label the points on the
+        annotate (bool): Whether or not to label the points on the
             triangle with reduced formula (if list of entries) or pair
             of elements (if list of list of str).
     """
@@ -392,9 +450,6 @@ def van_arkel_triangle(list_of_materials, annotate=True):
     slope2 = d[1] / d[0]
     b2 = pt3[1] - slope2 * pt3[0]
 
-    # Initialize the plt object
-    import matplotlib.pyplot as plt
-
     # set labels and appropriate limits for plot
     plt.xlim(pt2[0] - 0.45, -b2 / slope2 + 0.45)
     plt.ylim(-0.45, pt1[1] + 0.45)
@@ -487,73 +542,69 @@ def van_arkel_triangle(list_of_materials, annotate=True):
     return plt
 
 
-def get_ax_fig_plt(ax=None, **kwargs):
-    """
-    Helper function used in plot functions supporting an optional Axes argument.
+def get_ax_fig(ax: Axes = None, **kwargs) -> tuple[Axes, Figure]:
+    """Helper function used in plot functions supporting an optional Axes argument.
     If ax is None, we build the `matplotlib` figure and create the Axes else
     we return the current active figure.
 
     Args:
+        ax (Axes, optional): Axes object. Defaults to None.
         kwargs: keyword arguments are passed to plt.figure if ax is not None.
 
     Returns:
-        ax: :class:`Axes` object
-        figure: matplotlib figure
-        plt: matplotlib pyplot module.
+        tuple[Axes, Figure]: matplotlib Axes object and Figure objects
     """
-    import matplotlib.pyplot as plt
-
     if ax is None:
         fig = plt.figure(**kwargs)
         ax = fig.gca()
     else:
         fig = plt.gcf()
 
-    return ax, fig, plt
+    return ax, fig
 
 
-def get_ax3d_fig_plt(ax=None, **kwargs):
-    """
-    Helper function used in plot functions supporting an optional Axes3D
+def get_ax3d_fig(ax: Axes = None, **kwargs) -> tuple[Axes3D, Figure]:
+    """Helper function used in plot functions supporting an optional Axes3D
     argument. If ax is None, we build the `matplotlib` figure and create the
     Axes3D else we return the current active figure.
 
     Args:
+        ax (Axes3D, optional): Axes3D object. Defaults to None.
         kwargs: keyword arguments are passed to plt.figure if ax is not None.
 
     Returns:
-        ax: :class:`Axes` object
-        figure: matplotlib figure
-        plt: matplotlib pyplot module.
+        tuple[Axes3D, Figure]: matplotlib Axes3D and corresponding figure objects
     """
-    import matplotlib.pyplot as plt
-    from mpl_toolkits.mplot3d import axes3d
-
     if ax is None:
         fig = plt.figure(**kwargs)
-        ax = axes3d.Axes3D(fig)
+        ax = fig.add_subplot(projection="3d")
     else:
         fig = plt.gcf()
 
-    return ax, fig, plt
+    return ax, fig
 
 
 def get_axarray_fig_plt(
-    ax_array, nrows=1, ncols=1, sharex=False, sharey=False, squeeze=True, subplot_kw=None, gridspec_kw=None, **fig_kw
+    ax_array,
+    nrows=1,
+    ncols=1,
+    sharex: bool = False,
+    sharey: bool = False,
+    squeeze: bool = True,
+    subplot_kw=None,
+    gridspec_kw=None,
+    **fig_kw,
 ):
-    """
-    Helper function used in plot functions that accept an optional array of Axes
+    """Helper function used in plot functions that accept an optional array of Axes
     as argument. If ax_array is None, we build the `matplotlib` figure and
     create the array of Axes by calling plt.subplots else we return the
     current active figure.
 
     Returns:
-        ax: Array of :class:`Axes` objects
+        ax: Array of Axes objects
         figure: matplotlib figure
         plt: matplotlib pyplot module.
     """
-    import matplotlib.pyplot as plt
-
     if ax_array is None:
         fig, ax_array = plt.subplots(
             nrows=nrows,
@@ -578,15 +629,13 @@ def get_axarray_fig_plt(
 
 
 def add_fig_kwargs(func):
-    """
-    Decorator that adds keyword arguments for functions returning matplotlib
+    """Decorator that adds keyword arguments for functions returning matplotlib
     figures.
 
     The function should return either a matplotlib figure or None to signal
     some sort of error/unexpected event.
     See doc string below for the list of supported options.
     """
-    from functools import wraps
 
     @wraps(func)
     def wrapper(*args, **kwargs):
@@ -617,8 +666,6 @@ def add_fig_kwargs(func):
                 ax.grid(bool(ax_grid))
 
         if ax_annotate:
-            from string import ascii_letters
-
             tags = ascii_letters
             if len(fig.axes) > len(tags):
                 tags = (1 + len(ascii_letters) // len(fig.axes)) * ascii_letters
@@ -636,8 +683,6 @@ def add_fig_kwargs(func):
         if savefig:
             fig.savefig(savefig)
 
-        import matplotlib.pyplot as plt
-
         if show:
             plt.show()
         if fig_close:
