@@ -1,5 +1,4 @@
-"""
-This module defines convenience types for type hinting purposes.
+"""This module defines convenience types for type hinting purposes.
 Type hinting is new to pymatgen, so this module is subject to
 change until best practices are established.
 """
@@ -7,12 +6,9 @@ change until best practices are established.
 from __future__ import annotations
 
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Dict, Sequence, Union
+from typing import TYPE_CHECKING, Any, Union
 
-import numpy as np
-
-from pymatgen.core.composition import Composition
-from pymatgen.core.periodic_table import DummySpecies, Element, Species
+from pymatgen.core import Composition, DummySpecies, Element, Species
 
 if TYPE_CHECKING:  # needed to avoid circular imports
     from pymatgen.analysis.cost import CostEntry  # type: ignore[attr-defined]
@@ -21,7 +17,6 @@ if TYPE_CHECKING:  # needed to avoid circular imports
     from pymatgen.entries.computed_entries import ComputedEntry, ComputedStructureEntry, GibbsComputedStructureEntry
     from pymatgen.entries.exp_entries import ExpEntry
 
-MatrixLike = Union[Sequence[Sequence[float]], Sequence[np.ndarray], np.ndarray]
 
 PathLike = Union[str, Path]
 
@@ -33,7 +28,7 @@ CompositionLike = Union[str, Element, Species, DummySpecies, dict, Composition]
 
 # Entry or any of its subclasses or dicts that can be unpacked into any of them
 EntryLike = Union[
-    Dict[str, Any],
+    dict[str, Any],
     "Entry",
     "PDEntry",
     "ComputedEntry",
